Attribute VB_Name = "Compress"
Option Explicit

Private Declare Sub CopyMemory Lib "kernel32" Alias "RtlMoveMemory" _
    (Destination As Any, Source As Any, ByVal Length As Long)

Private Declare Function fopen Lib "release\cfuncs.dll" _
    Alias "_do_fopen@8" (ByVal Path As String, ByVal Mode As String) As Long
Private Declare Function freadbytes Lib "release\cfuncs.dll" _
    Alias "_do_fread@16" (ByRef Buffer As Byte, ByVal Size As Long, _
    ByVal Count As Long, ByVal Stream As Long) As Long
Private Declare Function fwritebytes Lib "release\cfuncs.dll" _
    Alias "_do_fwrite@16" (ByRef Buffer As Byte, ByVal Size As Long, _
    ByVal Count As Long, ByVal Stream As Long) As Long
Private Declare Function feof Lib "release\cfuncs.dll" _
    Alias "_do_feof@4" (ByVal FPtr As Long) As Long
Private Declare Function fclose Lib "release\cfuncs.dll" _
    Alias "_do_fclose@4" (ByVal FPtr As Long) As Long

Private Declare Function DLL_ZLibCompressByte Lib "release\zlibdll.dll" _
    Alias "_DLL_ZLibCompress@20" (ByRef DestBuffer As Byte, ByRef DestLen As Long, _
    ByRef SourceBuffer As Byte, ByVal SourceLen As Long, ByVal Level As Long) As Long
Private Declare Function DLL_ZLibUnCompressByte Lib "release\zlibdll.dll" _
    Alias "_DLL_ZLibUnCompress@16" (ByRef DestBuffer As Byte, ByRef DestLen As Long, _
    ByRef SourceBuffer As Byte, ByVal SourceLen As Long) As Long

Private Const BLOCKSIZE As Long = (64& * 1024&)
Private Const COMPRESSIONLEVEL As Long = 9

Public Sub CompressFile(FileName As String, AFileName As String)
    Dim ofhdl As Long

    ' Note: FileName is the full path/name of the file to compress.
    ' AFileName is the name (no path) of the compressed file.

    ofhdl = fopen(BAS.InboundArchiveDir & AFileName, "wb")
    If ofhdl = 0 Then
        MsgBox "fopen failed"
        Exit Sub
    End If

    If Not AddFileToCompressedStream(FileName, ofhdl) Then
        fclose ofhdl
        Kill BAS.InboundArchiveDir & FileName
        Exit Sub
    End If

    fclose ofhdl
End Sub

Private Function AddFileToCompressedStream(FileName As String, _
  ofhdl As Long) As Boolean
    Dim ifhdl As Long
    Dim FileNameOnly As String
    Dim BytesRead As Long, BytesWritten As Long, DestBuffSize As Long
    Dim FixedDestBuffSize As Long, TotalBytesWritten As Long
    Dim ByteBuffer() As Byte, CompressBuffer() As Byte, ByteArray(3) As Byte
    Dim StringBytes() As Byte

    ifhdl = fopen(FileName, "rb")
    If ifhdl = 0 Then
        MsgBox "fopen of " & FileName & " failed"
        Exit Function
    End If

    FixedDestBuffSize = BLOCKSIZE + (BLOCKSIZE / 10)
    ReDim ByteBuffer(0 To FixedDestBuffSize)
    ReDim CompressBuffer(0 To FixedDestBuffSize)

    ' Add a series of prime numbers to the stream. (This sequence also
    ' indicates that this is the last (only) file in the stream.)

    ByteArray(0) = 59
    ByteArray(1) = 137
    ByteArray(2) = 193
    ByteArray(3) = 167

    BytesWritten = fwritebytes(ByteArray(0), 1, 4, ofhdl)
    If BytesWritten <> 4 Then
        MsgBox "fwritebytes failed"
        GoTo ErrorCleanup
    End If

    ' Add the file name to the stream.

    FileNameOnly = Leaf(FileName)
    StringBytes = StrConv(FileNameOnly & vbNullChar, vbFromUnicode)
    BytesWritten = fwritebytes(StringBytes(0), 1, Len(FileNameOnly) + 1, ofhdl)
    If BytesWritten <> Len(FileNameOnly) + 1 Then
        MsgBox "fwritebytes failed"
        GoTo ErrorCleanup
    End If

    Do
        ' Read up to BLOCKSIZE bytes.

        BytesRead = freadbytes(ByteBuffer(0), 1, BLOCKSIZE, ifhdl)
        If BytesRead <= 0 Then
            If feof(ifhdl) <> 0 Then
                ' At end of file, check for 0 length file.

                If TotalBytesWritten = 0 Then
                    ' 0 length file.  Write out a 0 for the length then exit.

                    If Not PutLongInToFile(ofhdl, 0) Then
                        MsgBox "fwritebytes failed"
                        GoTo ErrorCleanup
                    End If
                End If
                Exit Do             ' Done on even boundary
            Else
                MsgBox "fread error"
                GoTo ErrorCleanup
            End If
        End If

        ' Compress buffer.

        DestBuffSize = FixedDestBuffSize
        If DLL_ZLibCompressByte(CompressBuffer(0), DestBuffSize, ByteBuffer(0), _
           BytesRead, COMPRESSIONLEVEL) <> 0 Then
            MsgBox "DLL_ZLibCompress failed"
            GoTo ErrorCleanup
        End If

        ' Write out the number of compressed bytes that will be in the stream.

        If Not PutLongInToFile(ofhdl, DestBuffSize) Then
            MsgBox "fwritebytes failed"
            GoTo ErrorCleanup
        End If

        ' Write out the number of uncompress bytes so we can know what
        ' to expect when we decompress.

        If Not PutLongInToFile(ofhdl, BytesRead) Then
            MsgBox "fwritebytes failed"
            GoTo ErrorCleanup
        End If

        ' Write out compressed buffer.

        BytesWritten = fwritebytes(CompressBuffer(0), 1, DestBuffSize, ofhdl)
        If BytesWritten <= 0 Then
            MsgBox "fwritebytes failed"
            GoTo ErrorCleanup
        End If

        TotalBytesWritten = TotalBytesWritten + BytesWritten

        ' Check short block -- last one then.

        If BytesRead < BLOCKSIZE Then Exit Do
    Loop

    AddFileToCompressedStream = True
ErrorCleanup:
    fclose ifhdl
End Function

Public Sub DecompressFile(ArchiveFileName As String)
    Dim ifhdl As Long
    Dim FileName As String

    ' Note: ArchiveFileName is the name (no path) of the compressed file.

    ifhdl = fopen(BAS.InboundArchiveDir & ArchiveFileName, "rb")
    If ifhdl = 0 Then
        MsgBox "fopen failed"
        Exit Sub
    End If

    If Not UnCompressStreamIntoFiles(ifhdl, FileName) Then
        MsgBox "UnCompressStreamIntoFiles failed"
    End If

    fclose ifhdl
End Sub

Private Function UnCompressStreamIntoFiles(ifhdl As Long, _
  ByRef FName As String) As Boolean
    Dim ofhdl As Long
    Dim BytesRead As Long, BytesWritten As Long, DestBuffSize As Long
    Dim ByteBuffer() As Byte, CompressBuffer() As Byte, ByteArray(3) As Byte
    Dim CompressedSize As Long, UnCompressedSize As Long, FixedDestBuffSize As Long
    Dim FileName As String

    FixedDestBuffSize = BLOCKSIZE + (BLOCKSIZE / 10)
    ReDim ByteBuffer(0 To FixedDestBuffSize)
    ReDim CompressBuffer(0 To FixedDestBuffSize)

    ' Look for the prime number sequence first.

    BytesRead = freadbytes(ByteArray(0), 1, 4, ifhdl)
    If BytesRead <> 4 Then
        MsgBox "freadbytes failed, returns " & BytesRead
        GoTo ErrorCleanup
    End If

    If (ByteArray(0) <> 109) Or _
       (ByteArray(1) <> 199) Or _
       (ByteArray(2) <> 173) Or _
       (ByteArray(3) <> 67) Then
        ' Check for last file

        If (ByteArray(0) = 59) And _
           (ByteArray(1) = 137) And _
           (ByteArray(2) = 193) And _
           (ByteArray(3) = 167) Then
        Else
            MsgBox "corrupt archive"
            Exit Function
        End If
    End If

    ' Extract the file name.

    FileName = GetZeroTermStringFromFile(ifhdl)
    If FileName = "" Then
        MsgBox "GetZeroTermStringFromFile failed"
        Exit Function
    End If
    FName = FileName

    ofhdl = fopen(BAS.InboundDir & FileName, "wb")
    If ofhdl = 0 Then
        MsgBox "fopen failed"
        Exit Function
    End If

    Do
        ' Read compressed size. Check for 0 length file.

        CompressedSize = GetLongFromFile(ifhdl)
        If CompressedSize = 0 Then Exit Do

        ' Read uncompressed size.

        UnCompressedSize = GetLongFromFile(ifhdl)

        ' Error check.

        If UnCompressedSize > BLOCKSIZE Then
            MsgBox "Incorrect uncompressed length"
            GoTo ErrorCleanup
        End If

        ' Read up to CompressedSize bytes.

        BytesRead = freadbytes(CompressBuffer(0), 1, CompressedSize, ifhdl)
        If BytesRead <= 0 Then
            MsgBox "freadbytes failed, returns " & BytesRead
            GoTo ErrorCleanup
        End If

        ' Decompress buffer.

        DestBuffSize = FixedDestBuffSize

        If DLL_ZLibUnCompressByte(ByteBuffer(0), DestBuffSize, _
           CompressBuffer(0), CompressedSize) <> 0 Then
            MsgBox "DLL_ZLibUnCompressByte failed"
            GoTo ErrorCleanup
        End If

        ' Write out uncompressed buffer.

        BytesWritten = fwritebytes(ByteBuffer(0), 1, UnCompressedSize, ofhdl)
        If BytesWritten <> UnCompressedSize Then
            MsgBox "fwritebytes failed"
            GoTo ErrorCleanup
        End If

        ' Check short block -- last one then.

        If UnCompressedSize < BLOCKSIZE Then Exit Do
    Loop

    UnCompressStreamIntoFiles = True
ErrorCleanup:
    fclose ofhdl
End Function

Private Function GetLongFromFile(FPtr As Long) As Long
    Dim BytesRead As Long
    Dim ByteArray(3) As Byte

    BytesRead = freadbytes(ByteArray(0), 1, 4, FPtr)
    If BytesRead <= 0 Then Exit Function

    GetLongFromFile = BytesToNumEx(ByteArray(), 0, 3, False)
End Function

Private Function BytesToNumEx(ByteArray() As Byte, StartRec As Long, _
  EndRec As Long, UnSigned As Boolean) As Double
    Dim i As Integer
    Dim lng256 As Double
    Dim lngReturn As Double

    On Error GoTo ErrorHandler
    lng256 = 1
    lngReturn = 0

    lngReturn = lngReturn + (ByteArray(StartRec))
    For i = (StartRec + 1) To EndRec
        lng256 = lng256 * 256
        If i < EndRec Then
            lngReturn = lngReturn + (ByteArray(i) * lng256)
        Else
           ' if -ve

            If ByteArray(i) > 127 And UnSigned = False Then
                lngReturn = (lngReturn + ((ByteArray(i) - 256) * lng256))
            Else
                lngReturn = lngReturn + (ByteArray(i) * lng256)
            End If
        End If
    Next i

    BytesToNumEx = lngReturn
ErrorHandler:
End Function

Private Function GetZeroTermStringFromFile(FPtr As Long) As String
    Dim s As String
    Dim ii As Long
    Dim BytesRead As Long
    Dim ByteArray(0) As Byte

    For ii = 0 To 512
        BytesRead = freadbytes(ByteArray(0), 1, 1, FPtr)
        If BytesRead <= 0 Then Exit Function
        If ByteArray(0) = 0 Then Exit For
        s = s & StrConv(ByteArray, vbUnicode)
    Next ii

    If ii = 512 Then
        MsgBox "filename overrun"
        Exit Function
    End If

    GetZeroTermStringFromFile = s
End Function

Private Function PutLongInToFile(FPtr As Long, DestBuffSize As Long) As Boolean
    Dim BytesWritten As Long
    Dim ByteArray(3) As Byte

    ' Write out the number of compressed bytes that will be in the stream.

    CopyMemory ByteArray(0), ByVal VarPtr(DestBuffSize), Len(DestBuffSize)

    ' Write out compressed length as long.

    BytesWritten = fwritebytes(ByteArray(0), 1, 4, FPtr)
    If BytesWritten <> 4 Then Exit Function

    PutLongInToFile = True
End Function

Private Function Leaf(FileName As String) As String
    Dim Char As String
    Dim ii As Integer

    ' Given a filename, return the last component of it.

    If InStr(FileName, "\") = 0 Then
        Leaf = FileName
        Exit Function
    End If

    ii = Len(FileName)
    Char = Mid(FileName, ii, 1)
    Leaf = ""
    Do While (ii <> 0) And (Char <> "\")
        Leaf = Char & Leaf
        ii = ii - 1
        Char = Mid(FileName, ii, 1)
    Loop
End Function
