Attribute VB_Name = "Config"
Option Explicit
'
'Copyright (c) 2003-2008 IQ-WEST, LLC
'
' $Author: mattcvs $
' $Date: 2006/01/04 18:24:50 $
' $Header: /home/cvs/CVSROOT/Source/vb/MiscSupport/Config.bas,v 1.3 2006/01/04 18:24:50 mattcvs Exp $
' $Id: Config.bas,v 1.3 2006/01/04 18:24:50 mattcvs Exp $
' $Name:  $
' $Locker:  $
' $Log: Config.bas,v $
' Revision 1.3  2006/01/04 18:24:50  mattcvs
' Added new function to convert biq.cnf into biq.ini files.
'
' Revision 1.2  2003/12/01 03:21:01  Matt
' After adding cvs lables.  Also had to change the project setting in the cubedll for some reason -- had mixed dll/multithread compiles for the different libs which go into cubedll.dll.  Straightened it out and seems to link and run properly now.
'
' $RCSfile: Config.bas,v $
' $Revision: 1.3 $
' $Source: /home/cvs/CVSROOT/Source/vb/MiscSupport/Config.bas,v $
' $State: Exp $

Type cfgtype                            ' structure to hold config values
    cfgname As String
    cfgvalue As String
End Type

Public ConfigFile As String             ' path/name of the actual file
Public SuppressError As Boolean         ' set True to be silent on error
Private ConfigInitted As Boolean
Private cfgstrings() As cfgtype         ' configuration strings array
Private cfgsize As Integer              ' total entries in cfgstrings
Private cfgentries As Integer           ' number of entries in use

Public Sub reset_config()
    ' Throw all the config information away (perhaps before reloading it).

    cfgentries = 0                      ' that's all it takes
End Sub

Public Function load_config(config_file As String) As Boolean
    Dim configline As String
    Dim cfgname As String
    Dim cfgvalue As String
    Dim Pos As Integer
    Dim infile As Integer

    ' Read the given configuration file into a data structure.

    ' Restrictions:
    '   In-line comments are not allowed. Full-line comments begin with "#".
    '       (#include "foobar.cfg" works)
    '   Tabs within values will be mutated to spaces.
    '   Trailing spaces and tabs are stripped (unless within quotes).

    load_config = True
    If Not ConfigInitted Then
        ReDim cfgstrings(10)            ' start the array at a reasonable size
        cfgsize = 10
        ConfigInitted = True
    End If

    infile = FreeFile
    On Error GoTo FileError
    Open config_file For Input As infile

    ' Save the name of the first file to be successfully read.

    If Len(ConfigFile) = 0 Then ConfigFile = config_file

    ' Loop through the configuration file

Proceed:
    Do While Not EOF(infile)
        Line Input #infile, configline

        ' Skip the line if it's blank

        If configline <> "" Then
            LTrim configline

            ' Skip the line if it's a comment (full-line comments only allowed)

            If Mid(configline, 1, 1) = "#" Then
                If Mid(configline, 1, 8) = "#include" Then
                    Dim endpos As Integer

                    Pos = InStr(configline, """")
                    If Pos > 0 Then
                        endpos = InStr(Pos + 1, configline, """")
                        cfgname = Mid(configline, Pos + 1, endpos - Pos - 1)
                        load_config cfgname
                    End If
                End If
            Else
                Do                              ' Mutate all tabs to spaces
                    Pos = InStr(configline, Chr(9))
                    If Pos = 0 Then Exit Do
                    Mid(configline, Pos, 1) = " "
                Loop

                ' Delimit the cfg name by the first string of spaces
                ' Separate into name and value

                Pos = InStr(configline, " ")
                If Pos <> 0 Then
                    cfgname = Left(configline, Pos - 1)
                    cfgvalue = Trim(Mid(configline, Pos + 1))
                End If

                ' If the value is surrounded by double quotes, strip them

                If Mid(cfgvalue, 1, 1) = Chr(34) Then _
                    cfgvalue = Mid(cfgvalue, 2, Len(cfgvalue) - 2)

                ' See if the name already exists. If so, ignore this one.

                If lookup_config_val(cfgname) = "" Then
                    ' Expand the array if it's full

                    If cfgentries = cfgsize Then
                        cfgsize = cfgsize + 5
                        ReDim Preserve cfgstrings(cfgsize)
                    End If

                    ' Save the new entry

                    cfgstrings(cfgentries).cfgname = cfgname
                    cfgstrings(cfgentries).cfgvalue = cfgvalue
                    cfgentries = cfgentries + 1
                End If
            End If
        End If
    Loop

    Close infile
    On Error GoTo 0
    Exit Function

FileError:
    cfgname = "\cube\" & config_file
    On Error GoTo FileError1
    Open cfgname For Input As infile
    GoTo Proceed

FileError1:
    If Not SuppressError Then _
        MsgBox "Error opening or reading configuration file '" & config_file & "'"
    load_config = False
End Function

Public Function lookup_config_val(varname As String) As String
    Dim ii As Integer

    ' Find the given configuration variable.
    ' Return its value if found, "" if not.
    ' Note that a string with a value of "" is indistinguishable from one
    ' that does not exist.

    For ii = cfgentries - 1 To 0 Step -1
        If StrComp(cfgstrings(ii).cfgname, varname, 1) = 0 Then
            lookup_config_val = cfgstrings(ii).cfgvalue
            Exit Function
        End If
    Next ii

    lookup_config_val = ""
End Function

#if 0 Then '@@
' Dump all config entries to file pointer
' Format:
'
' [mysqld]
' tmpdir=c:/temp
'
' set-variable    = key_buffer=512M
' set-variable    = max_allowed_packet=1M

Public Sub DumpAllConfigEntriesToIniFormat(FPtr As Long)
    Dim ii As Long

    For ii = cfgentries - 1 To 0 Step -1
        WriteStringToFile cfgstrings(ii).cfgname & " = " & cfgstrings(ii).cfgvalue & vbCrLf, FPtr
    Next ii
End Sub
#endif
