Attribute VB_Name = "DBUpdate"
Option Explicit

Private Const DBVERSION = 12                ' current version of the database

Private TableList() As String               ' list of database tables
Private TableListCount As Integer
Private NormalStateMap As Boolean
Public StateMapIdentifier As String
Private BASVersion As Integer

Public Sub DBUpdate()
    ' Look for missing tables. Add any that aren't already present.

    On Error Resume Next

    ' Get StateMapIdentifier from the config file.

    StateMapIdentifier = lookup_config_val("MarketCodeName")

    ' If the new config variable is not created the user is forced to.
    ' Other choices are disabled.

    If StateMapIdentifier = "" Then
        MsgBox "You need to initialize your Divisional/Market Status Mapping Code." & _
            vbCrLf & "Go to the file menu and choose Tools > Change setup information." & _
            vbCrLf & "Select your assigned Code and restart the BAS", _
            vbDefaultButton3, "Configure Status Mappings"

        FESSetup.laMarketCode.ForeColor = vbRed
        BAS.bnLook.Enabled = False
        BAS.bnProcess.Enabled = False
        BAS.mnResetMultBox.Enabled = False
        BAS.mnAutoIndex.Enabled = False
        BAS.mnClearDatabase.Enabled = False
        BAS.mnEnableWriteIndex.Enabled = False
        BAS.mnExit.Enabled = False
        BAS.mnIncludeOldFiles.Enabled = False
        BAS.mnReplay.Enabled = False
        BAS.mnResetAll.Enabled = False
        BAS.mnResetCounts.Enabled = False
        BAS.mnResetDays.Enabled = False
        BAS.mnResetMultBox.Enabled = False
        BAS.mnClearExceptions.Enabled = False
        BAS.mnUniversal.Enabled = False
        Exit Sub
    End If

    NormalStateMap = False                  ' False == OTHER THEN ORIGINAL SPEC
    FillTableList

    ' Get the version number, if it exists. Otherwise create the table.

    If Not FindTable("FESData") Then
        AddTable "FESData"
        SQLJustDoIt "insert into FESData values(3, '" & DBVERSION & "')"
        BASVersion = DBVERSION
    Else
        BASVersion = SQLGetSingleDatum( _
            "select DataString from FESData where FESDataID = 3")
    End If

    ' If any table doesn't exist, create it.

    If Not FindTable("FESAccountingSystems") Then AddTable "FESAccountingSystems"
    If Not FindTable("FESInternalStates") Then AddTable "FESInternalStates"
    If Not FindTable("FESStateMap") Then AddTable "FESStateMap"
    If Not FindTable("FESOperators") Then AddTable "FESOperators"
    If Not FindTable("FESInputFiles") Then AddTable "FESInputFiles"
    If Not FindTable("FESInputRecords") Then AddTable "FESInputRecords"
    If Not FindTable("FESExceptions") Then AddTable "FESExceptions"
    If Not FindTable("FESCableBoxMap") Then AddTable "FESCableBoxMap"

    ' If new fields need to be added to an existing database, do so now.

    If BASVersion < DBVERSION Then UpgradeDatabase

    ' Check for the existence of some more tables.

    If Not FindTable("FESStateTransitions") Then AddTable "FESStateTransitions"
    If Not FindTable("BASCounts") Then AddTable "BASCounts"
    If Not FindTable("BASManaged") Then AddTable "BASManaged"
    If Not FindTable("BASProduction") Then AddTable "BASProduction"
    If Not FindTable("BASWLMIndex") Then AddTable "BASWLMIndex"
    If Not FindTable("BASWLMIndexOCV") Then AddTable "BASWLMIndexOCV"
End Sub

Private Sub UpgradeDatabase()
    ' Upgrade the database from whatever it is to the current version.
    ' Version 0: record does not exist in FESData (or FESData does not exist)
    ' Version 1: original release (artificial; will always be 0)
    ' Version 2: add version (FESData), ExternalState (FESCableBoxData & Archive)
    ' Version 3: add CompanyRegion field to FESCableBoxData & Archive
    ' Version 4: add PrevLocation field to FESCableBoxData & Archive
    ' Version 5: add EntryType to FESCableBoxMap
    ' Version 6: add ReceiptDate to Database.1
    ' Version 7: add OCV (Cablevision) as an Accounting System
    ' Version 8: drop BASCounts so it will be re-defined
    ' Version 9: ditto
    ' Version 10: drop BASIndex and BASIndexOCV
    ' Version 11: drop BASCounts. Again
    ' Version 12: drop FESStateTransitions

    ' Upgrade from Versions 0 and 1 to Version 2.

    If BASVersion < 2 Then
        If BASVersion = 0 Then
            SQLJustDoIt "insert into FESData values(3, '2')"
        Else
            SQLJustDoIt "update FESData set DataString = '2' where FESDataID = 3"
        End If
    End If

    ' Upgrade from Version 2 to Version 3.
    ' For existing records, initialize to the CompanyRegion saved as a global.

    If BASVersion < 3 Then
        Dim CompanyRegion As String

        CompanyRegion = SQLGetSingleDatum( _
            "select DataString from FESData where FESDataID = 4") & "'"
    End If

    ' Upgrade from Version 3 to Version 4 (nothing to do in the dll version).

    ' Upgrade from Version 4 to Version 5.

    If BASVersion < 5 Then
        SQLJustDoIt _
            "alter table FESCableBoxMap add EntryType tinyint NOT NULL default 2"
    End If

    ' The upgrade to Version 6 requires that the database be rebuilt to add
    ' the new field to the file Database.1. So if the database file exists,
    ' output a warning message and disable everything except Replay.

    If BASVersion < 6 Then
        If FileExists(BAS.DatabaseDir & "CableBoxData1.dat") Then
            BAS.bnLook.Visible = False
            BAS.bnProcess.Enabled = True
            BAS.bnProcess.Caption = "Replay archived data"
            BAS.bnProcess.Width = 1935
            BAS.mnUniversal.Enabled = False
            BAS.ToolsMenu.Enabled = False

            MsgBox "BAS version 3 cannot read the version 2 database." & vbCrLf & vbCrLf & _
                "Please press the ""Replay archived data"" button to upgrade the database."

            Exit Sub                    ' do NOT update the version number
        End If
    End If

    ' Upgrade from Version 6 to Version 7: add OCV as an Accounting System.

    If BASVersion < 7 Then
        If SQLGetSingleDatum("select count(*) from FESAccountingSystems") <> "3" Then
            SQLJustDoIt "insert into FESAccountingSystems values(3, 'OCV');"
        End If
    End If

    ' Upgrade from Version 7 to Version 8: drop BASCounts so it will be rebuilt.
    ' Upgrade from Version 8 to Version 9: ditto.

    If BASVersion < 9 Then
        SQLJustDoIt "drop table BASCounts;"
    End If

    ' Upgrade from Version 9 to Version 10: drop BASIndex and BASIndexOCV.

    If BASVersion < 10 Then
        SQLJustDoIt "drop table BASIndex;"
        SQLJustDoIt "drop table BASIndexOCV;"
    End If

    ' Upgrade from Version 10 to Version 11: drop BASCounts. Again.

    If BASVersion < 11 Then
        SQLJustDoIt "drop table BASCounts;"
    End If

    ' Upgrade from Version 11 to Version 12: drop FESStateTransitions.

    If BASVersion < 12 Then
        SQLJustDoIt "drop table FESStateTransitions;"
    End If

    If BASVersion < DBVERSION Then UpdateDBVersion
End Sub

Public Sub UpdateDBVersion()
    ' Save the fact that the database is now up to date.

    SQLJustDoIt "update FESData set DataString = '" & DBVERSION & _
        "' where FESDataID = 3"
    BASVersion = DBVERSION
End Sub

Public Sub FillTableList()
    Dim TableName As String, TableTag As String

    ' Get a list of the current tables. Keep only those that begin with "FES".

    TableListCount = 0
    If Not SQLStartQueryWithResults("show tables") Then Exit Sub
    Do While Not SQLAtEndOfSet
        TableName = LCase(SQLGetFieldAsString(0))
        TableTag = Left(TableName, 3)
        If (TableTag = "fes") Or (TableTag = "bas") Then
            ReDim Preserve TableList(TableListCount)
            TableList(TableListCount) = TableName
            TableListCount = TableListCount + 1
        End If
        SQLGetNextRow
    Loop
End Sub

Public Function FindTable(Table As String) As Boolean
    Dim ii As Integer

    FindTable = True
    Table = LCase(Table)
    For ii = 0 To TableListCount - 1
        If TableList(ii) = Table Then Exit Function
    Next ii

    FindTable = False
End Function

Private Sub AddTable(Table As String)
    Dim DoInit As Boolean
    Dim s As String

    ' Add the given table.

    Select Case Table
        Case "FESData"
            s = s & "CREATE TABLE FESData ("
            s = s & "FESDataID int NOT NULL,"
            s = s & "DataString varchar(50) NOT NULL,"
            s = s & "PRIMARY KEY (FESDataID)"

        Case "FESAccountingSystems"
            DoInit = True
            s = s & "CREATE TABLE FESAccountingSystems ("
            s = s & "AccountingSystemID int NOT NULL,"
            s = s & "Name varchar(50) NOT NULL,"
            s = s & "PRIMARY KEY (AccountingSystemID)"

        Case "FESInternalStates"
            DoInit = True
            s = s & "CREATE TABLE FESInternalStates ("
            s = s & "StateAbbrev char(1) NOT NULL,"
            s = s & "State varchar(50) NOT NULL,"
            s = s & "PRIMARY KEY (StateAbbrev)"

        Case "FESStateMap"
            SQLJustDoIt "delete from FESData where FESDataID = 5"
            SQLJustDoIt "insert into FESData values(5, '" & StateMapIdentifier & "')"

            DoInit = True
            s = s & "CREATE TABLE FESStateMap ("
            s = s & "StateMapID int NOT NULL,"
            s = s & "AccountingSystemID int NOT NULL,"
            s = s & "ExternalState varchar(50) NOT NULL,"
            s = s & "ExtStateAbbrev char(1) NOT NULL,"
            s = s & "StateAbbrev char(1) NOT NULL,"
            s = s & "PRIMARY KEY (StateMapID)"

        Case "FESStateTransitions"
            DoInit = True
            s = s & "CREATE TABLE FESStateTransitions ("
            s = s & "StateTransitionID int NOT NULL,"
            s = s & "FromStateAbbrev char(1) NOT NULL,"
            s = s & "ToStateAbbrev char(1) NOT NULL,"
            s = s & "LegalMove tinyint NOT NULL,"
            s = s & "AccumFromDays tinyint NOT NULL,"
            s = s & "AccumToCount tinyint NOT NULL,"
            s = s & "PRIMARY KEY (StateTransitionID)"

        Case "FESOperators"
            s = s & "CREATE TABLE FESOperators ("
            s = s & "OperatorID int NOT NULL,"
            s = s & "Name varchar(50) NOT NULL,"
            s = s & "Password varchar(50) NOT NULL,"
            s = s & "AccessLevel tinyint NOT NULL,"
            s = s & "Enabled tinyint NOT NULL,"
            s = s & "PRIMARY KEY (OperatorID)"

        Case "FESInputFiles"
            s = s & "CREATE TABLE FESInputFiles ("
            s = s & "InputFileID int NOT NULL,"
            s = s & "FileName varchar(255) NOT NULL,"
            s = s & "FileNameSys varchar(10) NOT NULL,"
            s = s & "FileNameDate datetime NOT NULL,"
            s = s & "DateEntered datetime NOT NULL,"
            s = s & "Records int NOT NULL,"
            s = s & "OperatorID int NOT NULL,"
            s = s & "Truncated tinyint NOT NULL,"
            s = s & "PRIMARY KEY (InputFileID)"

        Case "FESInputRecords"
            s = s & "CREATE TABLE FESInputRecords ("
            s = s & "InputRecordID int NOT NULL,"
            s = s & "InputFileID int NOT NULL,"
            s = s & "RegionLabel varchar(25) NULL,"
            s = s & "RegionCode varchar(25) NULL,"
            s = s & "DivisionLabel varchar(25) NULL,"
            s = s & "DivisionCode varchar(25) NULL,"
            s = s & "SerialNo varchar(25) NULL,"
            s = s & "EqType varchar(25) NULL,"
            s = s & "ModelCode varchar(25) NULL,"
            s = s & "ModelTypeCode varchar(25) NULL,"
            s = s & "ReceiptDate varchar(25) NULL,"
            s = s & "StatusCode char(1) NOT NULL,"
            s = s & "StatusDate varchar(25) NULL,"
            s = s & "EndDate varchar(25) NULL,"
            s = s & "Location varchar(25) NULL,"
            s = s & "TranReason varchar(25) NULL,"
            s = s & "OperatorID varchar(25) NULL,"
            s = s & "StatusTime varchar(25) NULL,"
            s = s & "ItemType varchar(25) NULL,"
            s = s & "Field12 varchar(25) NULL,"
            s = s & "ReturnReasonDesc varchar(255) NULL,"
            s = s & "SiteID varchar(25) NULL,"
            s = s & "StatusDesc varchar(255) NULL,"
            s = s & "TechType varchar(25) NULL,"
            s = s & "TechTypeDesc varchar(255) NULL,"
            s = s & "ReturnReason varchar(255) NULL,"
            s = s & "ItemNumber varchar(25) NULL,"
            s = s & "Address varchar(100) NULL,"
            s = s & "Address2 varchar(100) NULL,"
            s = s & "OptionalField1 varchar(100) NULL,"
            s = s & "OptionalField2 varchar(100) NULL,"
            s = s & "OptionalField3 varchar(100) NULL,"
            s = s & "OptionalField4 varchar(100) NULL,"
            s = s & "OptionalField5 varchar(100) NULL,"
            s = s & "PRIMARY KEY (InputRecordID)"

        Case "FESExceptions"
            s = s & "CREATE TABLE FESExceptions ("
            s = s & "ExceptionID int NOT NULL,"
            s = s & "ExceptionType int NOT NULL,"
            s = s & "OperatorID int NOT NULL,"
            s = s & "DateEntered datetime NOT NULL,"
            s = s & "Detail varchar(255) NOT NULL,"
            s = s & "Reason varchar(255) NOT NULL,"
            s = s & "PRIMARY KEY (ExceptionID)"

        Case "FESCableBoxMap"
            s = s & "CREATE TABLE FESCableBoxMap ("
            s = s & "CableBoxMapID int NOT NULL,"
            s = s & "EntryType tinyint NOT NULL,"
            s = s & "CableBoxType varchar(100) NOT NULL,"
            s = s & "AorB char(1) NOT NULL,"
            s = s & "PRIMARY KEY (CableBoxMapID)"

        Case "BASCounts"
            s = s & "CREATE TABLE BASCounts ("
            s = s & "GL_WK_Week char(7) NOT NULL,"
            s = s & "GL_WK_SiteID varchar(50) NOT NULL,"
            s = s & "GL_WK_Model varchar(50) NOT NULL,"
            s = s & "GL_GB_EQCount int NOT NULL,"
            s = s & "GL_WK_CountSIH int NOT NULL,"
            s = s & "WL_WK_AddedToWL int NOT NULL,"
            s = s & "WL_GB_InactiveWL int NOT NULL,"
            s = s & "WL_GB_ActiveWLCount int NOT NULL,"
            s = s & "GL_GB_InHouse int NOT NULL,"
            s = s & "WL_GB_InHouse int NOT NULL,"
            s = s & "GL_GB_InRepair int NOT NULL,"
            s = s & "WL_GB_InRepairI int NOT NULL,"
            s = s & "GL_GB_InOther int NOT NULL,"
            s = s & "WL_GB_InOther int NOT NULL,"
            s = s & "GL_GB_TimesInstalled int NOT NULL,"
            s = s & "WL_GB_TimesInstalled int NOT NULL,"
            s = s & "GL_GB_TimesRepaired int NOT NULL,"
            s = s & "WL_GB_TimesRepaired int NOT NULL,"
            s = s & "GL_GB_TimesOther int NOT NULL,"
            s = s & "WL_GB_TimesOther int NOT NULL,"
            s = s & "GL_GB_CountDaysHouse int NOT NULL,"
            s = s & "WL_GB_CountDaysHouse int NOT NULL,"
            s = s & "WL_WK_CountScrap int NOT NULL,"
            s = s & "WL_WK_CountRepair int NOT NULL,"
            s = s & "WL_WK_CountHouse int NOT NULL,"
            s = s & "WL_WK_CountOther int NOT NULL,"
            s = s & "GL_GB_CountDaysTotal int NOT NULL,"
            s = s & "WL_GB_CountDaysTotal int NOT NULL,"
            s = s & "GL_WK_Date date NOT NULL,"
            s = s & "GL_GB_CountOutOfService int NOT NULL,"
            s = s & "WL_GB_InactiveOutOfService int NOT NULL,"
            s = s & "WL_GB_InactiveInHouse int NOT NULL,"
            s = s & "PRIMARY KEY (GL_WK_Week,GL_WK_SiteID,GL_WK_Model)"

        Case "BASManaged"
            s = s & "CREATE TABLE BASManaged ("
            s = s & "BASManagedID int NOT NULL,"
            s = s & "CableBoxSerial varchar(50) NOT NULL,"
            s = s & "InitialWLDate date NOT NULL,"
            s = s & "LatestWLDate date NOT NULL,"
            s = s & "TimesActivated int NOT NULL,"
            s = s & "TimesDiscovered int NOT NULL,"
            s = s & "DaysBetween int NOT NULL,"
            s = s & "DaysSinceInitial int NOT NULL,"
            s = s & "WatchFlag tinyint NOT NULL,"
            s = s & "Action char(1) NOT NULL,"
            s = s & "TimesRolledBack int NOT NULL,"
            s = s & "LatestRollbackDate date NOT NULL,"
            s = s & "DaysSinceRollback int NOT NULL,"
            s = s & "RollbackReason tinyint NOT NULL,"
            s = s & "DaysOnWatch int NOT NULL,"
            s = s & "PRIMARY KEY (BASManagedID,CableBoxSerial)"

        Case "BASProduction"
            s = s & "CREATE TABLE BASProduction ("
            s = s & "BASProductionID int NOT NULL,"
            s = s & "CableBoxSerial varchar(50) NOT NULL,"
            s = s & "Action char(1) NOT NULL,"
            s = s & "SiteID varchar(25) NOT NULL,"
            s = s & "Date date NOT NULL,"
            s = s & "PRIMARY KEY (BASProductionID,CableBoxSerial)"

        Case "BASWLMIndex"
            s = s & "CREATE TABLE BASWLMIndex ("
            s = s & "BASIndexID int NOT NULL,"
            s = s & "Division varchar(50) NOT NULL,"
            s = s & "Make varchar(50) NOT NULL,"
            s = s & "Model varchar(50) NOT NULL,"
            s = s & "CableBoxSerial varchar(50) NOT NULL,"
            s = s & "DaysUnknownR int NOT NULL,"
            s = s & "DaysHouseR int NOT NULL,"
            s = s & "DaysReturnR int NOT NULL,"
            s = s & "DaysRepairR int NOT NULL,"
            s = s & "CapDate date NOT NULL,"
            s = s & "DaysTechR int NOT NULL,"
            s = s & "DaysUnknownP int NOT NULL,"
            s = s & "DaysHouseP int NOT NULL,"
            s = s & "DaysReturn int NOT NULL,"
            s = s & "DaysRepairP int NOT NULL,"
            s = s & "DaysOtherP int NOT NULL,"
            s = s & "DaysTechP int NOT NULL,"
            s = s & "ToHouseR int NOT NULL,"
            s = s & "ToReturnR int NOT NULL,"
            s = s & "ToRepairR int NOT NULL,"
            s = s & "DaysService int NOT NULL,"
            s = s & "ToTechR int NOT NULL,"
            s = s & "ToHouseP int NOT NULL,"
            s = s & "ToReturnP int NOT NULL,"
            s = s & "ToRepairP int NOT NULL,"
            s = s & "ToOtherP int NOT NULL,"
            s = s & "ToTechP int NOT NULL,"
            s = s & "ShortInHouse int NOT NULL,"
            s = s & "PercentInHouse float NOT NULL,"
            s = s & "AvgDaysInHouse float NOT NULL,"
            s = s & "IllegalTransitions int NOT NULL,"
            s = s & "TotalDays int NOT NULL,"
            s = s & "CurrentState varchar(25) NOT NULL,"
            s = s & "DaysInState int NOT NULL,"
            s = s & "BasIdentifier varchar(25) NOT NULL,"
            s = s & "Location varchar(25) NOT NULL,"
            s = s & "Address varchar(100) NOT NULL,"
            s = s & "Address2 varchar(100) NULL,"
            s = s & "DateOfState date NOT NULL,"
            s = s & "TCOO int NOT NULL,"
            s = s & "SiteIDC varchar(50) NOT NULL,"
            s = s & "SiteIDB varchar(50) NOT NULL,"
            s = s & "SiteIDA varchar(50) NOT NULL,"
            s = s & "MTBOF float NOT NULL,"
            s = s & "PRIMARY KEY (BASIndexID,CableBoxSerial)"

        Case "BASWLMIndexOCV"
            s = s & "CREATE TABLE BASWLMIndexOCV ("
            s = s & "BASIndexID int NOT NULL,"
            s = s & "CapPCRem int NOT NULL,"
            s = s & "CurBoxAddMethod varchar(50) NOT NULL,"
            s = s & "PrevBoxAddMethod varchar(50) NOT NULL,"
            s = s & "CurBoxReturnMethod varchar(50) NOT NULL,"
            s = s & "PrevBoxReturnMethod varchar(50) NOT NULL,"
            s = s & "Locator varchar(50) NOT NULL,"
            s = s & "PrevSubinventoryCode varchar(50) NOT NULL,"
            s = s & "PrevOrganizationCode varchar(50) NOT NULL,"
            s = s & "PrevOrgAcronym varchar(50) NOT NULL,"
            s = s & "TCSwapFlagCt int NOT NULL,"
            s = s & "CDFlagCCount int NOT NULL,"
            s = s & "CDFlagICount int NOT NULL,"
            s = s & "TCWFinDate date NOT NULL,"
            s = s & "TCWFindateAvg int NOT NULL,"
            s = s & "TCTech varchar(50) NOT NULL,"
            s = s & "TCInHouseContflag varchar(10) NOT NULL,"
            s = s & "TCFixCodeStr varchar(50) NOT NULL,"
            s = s & "RprWarrantyNwCt int NOT NULL,"
            s = s & "RprWarrantyNwAmt float NOT NULL,"
            s = s & "RprWarrantyWxCt int NOT NULL,"
            s = s & "RprWarrantyWxAmt float NOT NULL,"
            s = s & "RPrWarrantyFwCt int NOT NULL,"
            s = s & "RPrWarrantyFwAmt float NOT NULL,"
            s = s & "RprWarrantyUrCt int NOT NULL,"
            s = s & "RprWarrantyUrAmt float NOT NULL,"
            s = s & "RprWarrantyFsCt int NOT NULL,"
            s = s & "RprWarrantyFsAmt float NOT NULL,"
            s = s & "RprWarrantyOtCt int NOT NULL,"
            s = s & "RprWarrantyOtAmt float NOT NULL,"
            s = s & "RprScrappedFlag varchar(10) NOT NULL,"
            s = s & "RprTotalCharge float NOT NULL,"
            s = s & "RprAverageCharge float NOT NULL,"
            s = s & "RprPartNbrStr varchar(50) NOT NULL,"
            s = s & "RprPartdescr varchar(50) NOT NULL,"
            s = s & "LocMdsLnkCount int NOT NULL,"
            s = s & "LocMdsLnkDays int NOT NULL,"
            s = s & "OrganizationCode varchar(50) NOT NULL,"
            s = s & "OrgAcronym varchar(50) NOT NULL,"
            s = s & "PRIMARY KEY (BASIndexID)"
    End Select

    ' Actually add the table. If it needs to be initialized, do so.

    SQLJustDoIt s & ") TYPE=MyISAM;"
    If DoInit Then InitializeTable Table
End Sub

Private Sub InitializeTable(Table As String)
    Dim s As String

    ' Add the initial (static) data to the given table.

    Select Case Table
        Case "FESAccountingSystems"
            SQLJustDoIt "insert into FESAccountingSystems values(1, 'CSG');"
            SQLJustDoIt "insert into FESAccountingSystems values(2, 'ICOMMS');"
            SQLJustDoIt "insert into FESAccountingSystems values(3, 'OCV');"

        Case "FESInternalStates"
            SQLJustDoIt "insert into FESInternalStates values('U', 'UNKNOWN');"
            SQLJustDoIt "insert into FESInternalStates values('H', 'HOUSE');"
            SQLJustDoIt "insert into FESInternalStates values('R', 'RETURN');"
            SQLJustDoIt "insert into FESInternalStates values('P', 'IN REPAIR');"
            SQLJustDoIt "insert into FESInternalStates values('S', 'OUT OF SERVICE');"
            SQLJustDoIt "insert into FESInternalStates values('T', 'IN TECH STATUS');"
            SQLJustDoIt "insert into FESInternalStates values('O', 'OTHER');"

        Case "FESStateMap"
            Select Case StateMapIdentifier
              Case "Default,Default"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Pending Diagnosis', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Diagnosis', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'In Repair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Factory', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Tech Status', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(100, 1, 'Tech Status', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(102, 1, 'Tech Status', 'L', 'O');"
                SQLJustDoIt "insert into FESStateMap values(103, 1, 'Tech Status', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(104, 1, 'Tech Status', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(105, 1, 'Tech Status', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(106, 1, 'Tech Status', 'Z', 'O');"
                SQLJustDoIt "insert into FESStateMap values(107, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'FACT REPAIR', '2', 'P');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'TECH ISSUE', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'INVENTORY', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'TECH RETURN', 'T', 'R');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'TRANSFER', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'BROKEN', 'B', 'S');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'WAIT TRSFER', 'V', 'O');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'RECALL', 'A', 'S');"
                SQLJustDoIt "insert into FESStateMap values(20, 2, 'WAIT REPAIR', '8', 'P');"
                SQLJustDoIt "insert into FESStateMap values(21, 2, 'FACTORY REPLACE', '3', 'P');"
                SQLJustDoIt "insert into FESStateMap values(22, 2, 'LOST-RMB', 'K', 'S');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'REPL VEND', 'R', 'S');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'AT CORP', '6', 'S');"
                SQLJustDoIt "insert into FESStateMap values(25, 2, 'ACTV-MPV', 'E', 'S');"
                SQLJustDoIt "insert into FESStateMap values(26, 2, 'BAD SER NO', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(27, 2, 'STOLEN RMB', 'I', 'O');"
                SQLJustDoIt "insert into FESStateMap values(28, 2, 'WRITE OFF', 'Y', 'S');"
                SQLJustDoIt "insert into FESStateMap values(29, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(30, 2, 'NON-INVENTORY', 'N', 'S');"

          Case "Bicycle,TWC Raleigh"
                SQLJustDoIt "insert into FESStateMap values(1, 2, 'FACTORY REPR', '2, 'P');"
                SQLJustDoIt "insert into FESStateMap values(2, 2, 'DOCWAREHSE', '4', 'O');"
                SQLJustDoIt "insert into FESStateMap values(3, 2, 'BROKEN', 'B', 'O');"
                SQLJustDoIt "insert into FESStateMap values(4, 2, 'BAD SER NO', 'D', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'NON INV ITEM', 'N', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 2, 'NXT SEQ', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(7, 2, 'REPL VEND', 'R', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8 2, 'TRANSFERED', 'T', 'O');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'WRNTY REPR', 'W', 'P');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'UNKNOWN', 'Z', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'TECHNICIAN', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'INVENTORY', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'WAIT RPR', '8', '0');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'Unknowns', '9', 'O');"

             Case "Black Sand,TWC Hawaii"
                SQLJustDoIt "insert into FESStateMap values(1, 2, 'ACTIVE', 'A', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 2, 'STOCK', 'S', 'O);"
                SQLJustDoIt "insert into FESStateMap values(3, 2, 'TechIssued', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(4, 2, 'INHSE REPAIR', 'Q', 'P');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'OUTSIDE REPAIR', 'O', 'P');"
                SQLJustDoIt "insert into FESStateMap values(6, 2, 'LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(7, 2, 'Other-RETURN', 'D', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 2, 'H', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'P', 'P', 'O);"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'W', 'W', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'Z', 'Z', 'S');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'Y', 'Y', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'R', 'R', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'RETURN', 'V', 'R');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'E', 'E', 'R');"

              Case "White Light,Bright House"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'B-RET', 'B', 'R');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'B-REP', '6', 'P');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'B-WAR', '7', 'P');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'B-NER', '8', 'P');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'Factory', 'F', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Sales Rep', 'R', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Lobby', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(9, 1, 'Customer Owned', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 1, 'Testing', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(11, 1, 'Prepping', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 1, 'Shelf Stock', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(13, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(14, 1, 'Lost', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(15, 1, 'Destoyed', 'K', 'S');"
                SQLJustDoIt "insert into FESStateMap values(16, 1, 'Bright Moves', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(17, 1, 'Deleted', 'Z', 'S');"
                SQLJustDoIt "insert into FESStateMap values(18, 1, 'Tech', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(19, 1, 'Unknown', 'U', 'O');"

              Case "Sports Car TR,TWC Mid Ohio"
                SQLJustDoIt "insert into FESStateMap values(1, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 2, 'REPAIR-Other', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(3, 2, 'TECH TEST', 'Y', 'O');"
                SQLJustDoIt "insert into FESStateMap values(4, 2, 'TECH RETURN', 'T', 'R');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'BAD SERIAL#', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(6, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'LOST PAID', '$', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 2, 'SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(7, 2, 'LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(8, 2, 'SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'LOST RPLVENDOR', 'R', 'S');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'WRITE OFF', 'V', 'S');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'TECHNICIAN', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'PEND INV', 'I', 'T');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'FCTRY REPR', '2', 'P');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'BROKENAUO1', 'B', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'NON INV', 'N', 'O');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'OBSOLETE', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'NEXT SEQ', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'WRNTY REPR', 'W', 'O');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'AT FACT REPR', '2', 'O');"
                SQLJustDoIt "insert into FESStateMap values(20, 2, 'DO NOT USE', '3', 'O');"
                SQLJustDoIt "insert into FESStateMap values(21, 2, 'DO NOT USE', '4', 'O');"
                SQLJustDoIt "insert into FESStateMap values(22, 2, 'RMA AUO1', '8', 'O');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'RMA AUO2', '9', 'O');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'BROKENAUO2', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(25, 2, 'BROKENAUO3', 'H', 'O');"
                SQLJustDoIt "insert into FESStateMap values(26, 2, 'PENDING DEL', 'M', 'O');"
                SQLJustDoIt "insert into FESStateMap values(27, 2, 'UNRECOVERED', 'X', 'O');"
                SQLJustDoIt "insert into FESStateMap values(28, 2, 'DO NOT USE', '6', 'O');"

              Case "Sports Car TT,TWC Mid Ohio TT"
                SQLJustDoIt "insert into FESStateMap values(1, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 2, 'REPAIR-Other', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(3, 2, 'TECH TEST', 'Y', 'O');"
                SQLJustDoIt "insert into FESStateMap values(4, 2, 'TECH RETURN', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'BAD SERIAL#', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(6, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'LOST PAID', '$', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 2, 'SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(7, 2, 'LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(8, 2, 'SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'LOST RPLVENDOR', 'R', 'S');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'WRITE OFF', 'V', 'S');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'TECHNICIAN', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'PEND INV', 'I', 'T');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'FCTRY REPR', '2', 'P');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'BROKENAUO1', 'B', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'NON INV', 'N', 'O');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'OBSOLETE', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'NEXT SEQ', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'WRNTY REPR', 'W', 'O');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'AT FACT REPR', '2', 'O');"
                SQLJustDoIt "insert into FESStateMap values(20, 2, 'DO NOT USE', '3', 'O');"
                SQLJustDoIt "insert into FESStateMap values(21, 2, 'DO NOT USE', '4', 'O');"
                SQLJustDoIt "insert into FESStateMap values(22, 2, 'RMA AUO1', '8', 'O');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'RMA AUO2', '9', 'O');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'BROKENAUO2', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(25, 2, 'BROKENAUO3', 'H', 'O');"
                SQLJustDoIt "insert into FESStateMap values(26, 2, 'PENDING DEL', 'M', 'O');"
                SQLJustDoIt "insert into FESStateMap values(27, 2, 'UNRECOVERED', 'X', 'O');"
                SQLJustDoIt "insert into FESStateMap values(28, 2, 'DO NOT USE', '6', 'O');"

              Case "Red Rock,Charter"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Repair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'TechIssued', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Return to Factory', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Customer Lost', 'G', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'Stock Lost', 'L', 'O');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Stock QControl', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(9, 1, 'Stock Shelved', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(11, 1, 'Quarantine', 'J', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 1, 'Destroyed', 'K', 'O');"
                SQLJustDoIt "insert into FESStateMap values(13, 1, 'Written off', 'W', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'INVENTORY', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'TECHNICIAN', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'RETURN FROM ACCT', 'T', 'R');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'WAIT REPAIR', '8', 'P');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'FACTORY REPAIR', '2', 'P');"
                SQLJustDoIt "insert into FESStateMap values(20, 2, 'BAD SERIALNum', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(21, 2, 'SCRAP', 'J', 'O');"
                SQLJustDoIt "insert into FESStateMap values(22, 2, 'SOLD', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'LOSTSTOLEN', 'Q', 'S');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'QUARANTINE', 'Y', 'S');"

              Case "Agent,TWC NEO"
                SQLJustDoIt "insert into FESStateMap values(1, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 2, 'RETURN FROM ACCT', 'T', 'R');"
                SQLJustDoIt "insert into FESStateMap values(3, 2, 'IN REPAIR', '8', 'P');"
                SQLJustDoIt "insert into FESStateMap values(4, 2, 'INVENTORY', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'DISABLED', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(6, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(7, 2, 'SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(8, 2, 'NON INV', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'REPLE VEND', 'R', 'S');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'BROKEN', 'B', 'S');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'TECHNICIAN', '7', 'T');"

              Case "Cowboy,SE Texas"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'In W.WaitRepair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'TechIssued', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Empty', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Equiped', '2', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'Stolen', '5', 'O');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Stock Checkout', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Stock Front Counter', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(9, 1, 'Return to Factory', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 1, 'Customer Lost', 'G', 'O');"
                SQLJustDoIt "insert into FESStateMap values(11, 1, 'Stock Lost', 'L', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 1, 'Warehouse off Plnt', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(13, 1, 'Warehouse on Plnt', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 1, 'Stock QControl', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 1, 'Sales Rep', 'R', 'O');"
                SQLJustDoIt "insert into FESStateMap values(16, 1, 'Stock Shelved', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(17, 1, 'Untracked', 'U', 'O');"
                SQLJustDoIt "insert into FESStateMap values(18, 1, 'House-Disable', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(19, 1, 'Destroyed', 'K', 'O');"
                SQLJustDoIt "insert into FESStateMap values(20, 1, 'Deleted', 'Z', 'O');"

              Case "Shark,Austar"
                SQLJustDoIt "insert into FESStateMap values(1, 2, 'Customer Purchased', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(2, 2, 'Connect', 'C', 'H');"
                SQLJustDoIt "insert into FESStateMap values(3, 2, 'Aus Post', 'U', 'O');"
                SQLJustDoIt "insert into FESStateMap values(4, 2, 'Faulty', 'Y', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'Refurb', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 2, 'Repair', 'R', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 2, 'Disconnect', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(8, 2, 'Contractor Purchased', 'T', 'O');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'DNB', 'B', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'Held', 'H', 'O');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'Lost/Stolen', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'Written Off', 'W', 'S');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'Intransit', 'I', 'T');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'Available', 'V', 'O');"

              Case "White Star,TWC Central Texas"
                SQLJustDoIt "insert into FESStateMap values(1, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 2, 'FCTRY REPR', '2', 'P');"
                SQLJustDoIt "insert into FESStateMap values(3, 2, 'WRNTY REPR', 'W', 'P');"
                SQLJustDoIt "insert into FESStateMap values(4, 2, 'TECHNICIAN', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'NEXT SEQ', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 2, 'HOWARD2001', 'Y', 'O');"
                SQLJustDoIt "insert into FESStateMap values(7, 2, 'RMA AUO1', '8', 'S');"
                SQLJustDoIt "insert into FESStateMap values(8, 2, 'RMA AUO2', '9', 'S');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'BROKENAUO1', 'B', 'S');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'BROKENAUO2', 'C', 'S');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'BAD SERIAL#', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'BROKENAUO3', 'H', 'S');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'PENDING DEL', 'M', 'S');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'NON INV', 'N', 'S');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'QUARANTINE', 'O', 'S');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(21, 2, 'UNRECOVERED', 'X', 'S');"
                SQLJustDoIt "insert into FESStateMap values(22, 2, 'INVENTORY', '1', 'R');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'DO NOT USE', '3', 'O');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'DO NOT USE', '4', 'O');"
                SQLJustDoIt "insert into FESStateMap values(25, 2, 'DO NOT USE', '6', 'O');"
                SQLJustDoIt "insert into FESStateMap values(26, 2, 'DO NOT USE', 'T', 'O');"

              Case "Tree,Bresnan"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'WAREHSEONPLNT', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, ' STOCK-QTY CNTRL', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'In Repair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Factory', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Tech Status', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(100, 1, 'STOCK SHELVED', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(102, 1, 'LOST', 'L', 'O');"
                SQLJustDoIt "insert into FESStateMap values(103, 1, 'EMPTY', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(104, 1, 'WAREHOUSE OFFPLT', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(105, 1, 'StockFrontCounter', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(106, 1, 'Deleted', 'Z', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 1, 'STOCK CHECKOUT', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(9, 1, ' CUSTOMER LOST ', 'G', 'O');"
                SQLJustDoIt "insert into FESStateMap values(17, 1, ' CUST INACTIVE ', 'I', 'O');"
                SQLJustDoIt "insert into FESStateMap values(11, 1, 'FCC QUARANTINE', 'J', 'O');"
                SQLJustDoIt "insert into FESStateMap values(25, 1, 'DESTROYED', 'K', 'O');"
                SQLJustDoIt "insert into FESStateMap values(24, 1, 'UNTRACKED', 'U', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 1, 'WRITTEN OFF', 'W', 'O');"
                SQLJustDoIt "insert into FESStateMap values(16, 1, 'FORCE TUNED', 'X', 'O');"
                SQLJustDoIt "insert into FESStateMap values(32, 1, 'EQUIPPED', '2', 'O');"
                SQLJustDoIt "insert into FESStateMap values(19, 1, 'ATTACHEDEMPTY', '3', 'O');"
                SQLJustDoIt "insert into FESStateMap values(27, 1, 'ATTACHEDEQUIPD', '4', 'O');"
                SQLJustDoIt "insert into FESStateMap values(23, 1, 'STOLEN', '5', 'O');"
                SQLJustDoIt "insert into FESStateMap values(26, 1, 'DEFECTIVE', '9', 'O');"

              Case "Red Rose,Cox LA"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Pending Diagnosis', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Diagnosis', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'In Repair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Factory', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Tech Status', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(100, 1, 'Tech Status', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(102, 1, 'Tech Status', 'L', 'O');"
                SQLJustDoIt "insert into FESStateMap values(103, 1, 'Tech Status', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(104, 1, 'Tech Status', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(105, 1, 'Tech Status', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(106, 1, 'Tech Status', 'Z', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'FACT REPAIR', '2', 'P');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'TECH ISSUE', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'INVENTORY', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(25, 2, 'TECH RETURN', 'T', 'R');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'TRANSFER', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'BROKEN', 'B', 'S');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(26, 2, 'WAIT TRSFER', 'V', 'O');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(27, 2, 'RECALL', 'A', 'S');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'WAIT REPAIR', '8', 'P');"
                SQLJustDoIt "insert into FESStateMap values(26, 2, 'FACTORY REPLACE', '3', 'P');"
                SQLJustDoIt "insert into FESStateMap values(28, 2, 'LOST-RMB', 'K', 'S');"
                SQLJustDoIt "insert into FESStateMap values(20, 2, 'REPL VEND', 'R', 'S');"
                SQLJustDoIt "insert into FESStateMap values(32, 2, 'AT CORP', '6', 'S');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'ACTV-MPV', 'E', 'S');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'BAD SER NO', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(28, 2, 'STOLEN RMB', 'I', 'O');"
                SQLJustDoIt "insert into FESStateMap values(29, 2, 'WRITE OFF', 'Y', 'S');"
                SQLJustDoIt "insert into FESStateMap values(30, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(31, 2, 'NON-INVENTORY', 'N', 'S');"

              Case "Popcorn,TWC CincDaytonOhio"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Pending Diagnosis', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Diagnosis', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'In Repair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Factory', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Tech Status', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(100, 1, 'Tech Status', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(102, 1, 'Tech Status', 'L', 'O');"
                SQLJustDoIt "insert into FESStateMap values(103, 1, 'Tech Status', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(104, 1, 'Tech Status', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(105, 1, 'Tech Status', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(106, 1, 'Tech Status', 'Z', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'FACT REPAIR', '2', 'P');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'INVENTORY', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(30, 2, 'BANKRUPTCY', 'A', 'O');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'WRITE OFF', 'V', 'O');"
                SQLJustDoIt "insert into FESStateMap values(26, 2, 'LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'TECH ISSUE', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'TECH RETURN', 'T', 'R');"

              Case "Beach,TWC Wisconsin"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Pending Diagnosis', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Diagnosis', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'In Repair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Factory', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Tech Status', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(100, 1, 'Tech Status', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(102, 1, 'Tech Status', 'L', 'O');"
                SQLJustDoIt "insert into FESStateMap values(103, 1, 'Tech Status', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(104, 1, 'Tech Status', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(105, 1, 'Tech Status', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(106, 1, 'Tech Status', 'Z', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'FACT REPAIR', '2', 'P');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'SPC REPAIR', 'Z', 'P');"
                SQLJustDoIt "insert into FESStateMap values(26, 2, 'FACTORY REPLACE', '3', 'P');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'INVENTORY', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'INVENTORY', '8', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'EVIDENCE', 'E', 'S');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(22, 2, 'NON-INVENTORY', 'N', 'S');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'BAD SER NO', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(20, 2, 'REPL VEND', 'R', 'S');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'BROKEN', 'B', 'S');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'TECH ISSUE', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(25, 2, 'TECH RETURN', 'T', 'R');"
                SQLJustDoIt "insert into FESStateMap values(27, 2, 'NEXT SEQ', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(28, 2, 'TECH TEST', 'Y', 'O');"
                SQLJustDoIt "insert into FESStateMap values(29, 2, 'DELETE', '*', 'O');"
                SQLJustDoIt "insert into FESStateMap values(30, 2, 'WAR REPAIR', 'W', 'P');"

              Case "Cloud,TWC Charlotte"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'House-Disable', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'AtVendorRepair', 'P', 'P');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'In Test', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'In W.WaitRepair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'OutofService', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'TechIssued', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(109, 1, 'Lost', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(110, 1, 'DoNotUse', 'K', 'O');"
                SQLJustDoIt "insert into FESStateMap values(111, 1, 'Unknown', 'W', 'O');"
                SQLJustDoIt "insert into FESStateMap values(112, 1, 'Tech Status', '5', 'O');"
                SQLJustDoIt "insert into FESStateMap values(113, 1, 'UnReturned', 'G', 'S');"
                SQLJustDoIt "insert into FESStateMap values(114, 1, 'DoNotUse', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(115, 1, 'Needs to Test', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(116, 1, 'IssueFrntCntr', 'E', 'T');"
                SQLJustDoIt "insert into FESStateMap values(117, 1, 'UnEqPaidbyC', 'U', 'S');"
                SQLJustDoIt "insert into FESStateMap values(118, 1, 'Diagnosis', 'I', 'O');"
                SQLJustDoIt "insert into FESStateMap values(119, 1, 'Treated Transfer', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(120, 1, 'Unknown', 'X', 'O');"
                SQLJustDoIt "insert into FESStateMap values(121, 1, 'Unknown', 'Z', 'S');"
                SQLJustDoIt "insert into FESStateMap values(122, 1, 'Scrap', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(123, 1, 'DoNotUse', '2', 'O');"
                SQLJustDoIt "insert into FESStateMap values(124, 1, 'DoNotUse', '3', 'O');"
                SQLJustDoIt "insert into FESStateMap values(125, 1, 'DoNotUse', '4', 'O');"
                SQLJustDoIt "insert into FESStateMap values(126, 1, 'DoNotUse', '5', 'O');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'TECHNICIAN', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'INVENTORY', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'WRNTY REPR', 'W', 'P');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'RETURN', '8', 'R');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'STORAGE', '6', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'REPL VEND', 'M', 'S');"

              Case "Boat,Comcast Washington"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'House-Disable', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'AtVendorRepair', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'In Test', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'In W.WaitRepair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'OutofService', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'TechIssued', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(9, 1, 'Lost', 'L', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 1, 'DoNotUse', 'K', 'O');"
                SQLJustDoIt "insert into FESStateMap values(11, 1, 'Unknown', 'W', 'O');"
                SQLJustDoIt "insert into FESStateMap values(13, 1, 'UnReturned', 'G', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 1, 'DoNotUse', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 1, 'Needs to Test', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(16, 1, 'IssueFrntCntr', 'E', 'T');"
                SQLJustDoIt "insert into FESStateMap values(17, 1, 'UnRetEqPaidbyC', 'U', 'O');"
                SQLJustDoIt "insert into FESStateMap values(18, 1, 'Diagnosis', 'I', 'O');"
                SQLJustDoIt "insert into FESStateMap values(19, 1, 'Treated as Transfer', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(20, 1, 'Unknown', 'X', 'O');"
                SQLJustDoIt "insert into FESStateMap values(21, 1, 'Unknown', 'Z', 'O');"
                SQLJustDoIt "insert into FESStateMap values(22, 1, 'Scrap', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(23, 1, 'DoNotUse', '2', 'O');"
                SQLJustDoIt "insert into FESStateMap values(24, 1, 'DoNotUse', '3', 'O');"
                SQLJustDoIt "insert into FESStateMap values(25, 1, 'DoNotUse', '4', 'O');"
                SQLJustDoIt "insert into FESStateMap values(26, 1, 'DoNotUse', '5', 'O');"

              Case "Red Wagon,TWC South Carolina"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'House-Disable', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'AtVendorRepair', 'P', 'P');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'In Test', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'In W.WaitRepair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'OutofService', 'F', 'S');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'TechIssued', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(109, 1, 'Lost', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(110, 1, 'DoNotUse', 'K', 'O');"
                SQLJustDoIt "insert into FESStateMap values(111, 1, 'Unknown', 'W', 'O');"
                SQLJustDoIt "insert into FESStateMap values(112, 1, 'Tech Status', '5', 'T');"
                SQLJustDoIt "insert into FESStateMap values(113, 1, 'UnReturned', 'G', 'S');"
                SQLJustDoIt "insert into FESStateMap values(114, 1, 'DoNotUse', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(115, 1, 'Needs to Test', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(116, 1, 'IssueFrntCntr', 'E', 'T');"
                SQLJustDoIt "insert into FESStateMap values(117, 1, 'UnRetEqPaidbyC', 'U', 'O');"
                SQLJustDoIt "insert into FESStateMap values(118, 1, 'Diagnosis', 'I', 'O');"
                SQLJustDoIt "insert into FESStateMap values(119, 1, 'Treated as Transfer', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(120, 1, 'Unknown', 'X', 'O');"
                SQLJustDoIt "insert into FESStateMap values(121, 1, 'Unknown', 'Z', 'S');"
                SQLJustDoIt "insert into FESStateMap values(122, 1, 'Scrap', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(123, 1, 'DoNotUse', '2', 'O');"
                SQLJustDoIt "insert into FESStateMap values(124, 1, 'DoNotUse', '3', 'O');"
                SQLJustDoIt "insert into FESStateMap values(125, 1, 'DoNotUse', '4', 'O');"
                SQLJustDoIt "insert into FESStateMap values(126, 1, 'DoNotUse', '5', 'O');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'TECHNICIAN', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'INVENTORY', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'TECH', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'BAD SER NO', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'BROKEN', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'WRNTY REPR', 'W', 'P');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(20, 2, 'REPL VEND', 'R', 'S');"
                SQLJustDoIt "insert into FESStateMap values(21, 2, 'FCTRY REPR', '2', 'P');"
                SQLJustDoIt "insert into FESStateMap values(22, 2, 'NON-INVENTORY', 'N', 'S');"

              Case "Blue Ball,GRANDE"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'T');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Warehouse', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Diagnosis', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Factory', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Tech Status', 'J', 'P');"
                SQLJustDoIt "insert into FESStateMap values(9, 1, '1Status', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 1, '2Status', '2', 'O');"
                SQLJustDoIt "insert into FESStateMap values(11, 1, '3Status', '3', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 1, '4', '4', 'O');"
                SQLJustDoIt "insert into FESStateMap values(13, 1, 'eStatus', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 1, 'uStatus', 'U', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 1, 'xStatus', 'X', 'O');"
                SQLJustDoIt "insert into FESStateMap values(16, 1, 'Stock Shelved', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(17, 1, 'Stock Checkout', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(18, 1, 'Tech Status', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(19, 1, 'Warehouse', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(20, 1, 'Factory Repair', 'F', 'P');"
                SQLJustDoIt "insert into FESStateMap values(21, 1, 'Stolen', '5', 'S');"
                SQLJustDoIt "insert into FESStateMap values(22, 1, 'Customer Lost', 'G', 'S');"
                SQLJustDoIt "insert into FESStateMap values(23, 1, 'Customer Inactive', 'I', 'S');"
                SQLJustDoIt "insert into FESStateMap values(24, 1, 'Destroyed', 'K', 'S');"
                SQLJustDoIt "insert into FESStateMap values(25, 1, 'Lost', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(26, 1, 'Unrecovered', 'W', 'S');"
                SQLJustDoIt "insert into FESStateMap values(27, 1, 'Deleted', 'Z', 'S');"
                SQLJustDoIt "insert into FESStateMap values(28, 1, 'Tech', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(29, 1, 'Broken', 'B', 'P');"

              Case "Green Balloon,Comcast Atlanta"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Stock-Checkout', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Stock FrontCounter', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Customer Lost', 'G', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'FCC Quarentine', 'I', 'S');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'In Repair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Destroyed', 'K', 'S');"
                SQLJustDoIt "insert into FESStateMap values(9, 1, 'Lost', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(10, 1, 'WareHouse offplnt', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(11, 1, 'Stock QControl', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(13, 1, 'Stock Shelf', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 1, 'IR Tech', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(15, 1, 'Untracked', 'U', 'O');"
                SQLJustDoIt "insert into FESStateMap values(16, 1, 'Written Off', 'W', 'O');"
                SQLJustDoIt "insert into FESStateMap values(17, 1, 'Forced Tuned', 'X', 'O');"
                SQLJustDoIt "insert into FESStateMap values(18, 1, 'Empty', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(19, 1, 'Pending Diagnosis', '2', 'O');"
                SQLJustDoIt "insert into FESStateMap values(20, 1, 'Attached Emp', '3', 'O');"
                SQLJustDoIt "insert into FESStateMap values(21, 1, 'Attached Eqp', '4', 'O');"
                SQLJustDoIt "insert into FESStateMap values(22, 1, 'Stolen', '5', 'S');"
                SQLJustDoIt "insert into FESStateMap values(23, 1, 'Shipped to Cust', '6', 'O');"
                SQLJustDoIt "insert into FESStateMap values(24, 1, 'Defective', '9', 'O');"
                SQLJustDoIt "insert into FESStateMap values(25, 1, 'Deleted', 'Z', 'O');"

              Case "Wagon Wheel,Greensboro"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Pending Diagnosis', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Diagnosis', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'In Repair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Factory', 'F', 'P');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Tech Status', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(109, 1, 'Tech Status', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(110, 1, 'Tech Status', 'K', 'S');"
                SQLJustDoIt "insert into FESStateMap values(111, 1, 'Tech Status', 'W', 'S');"
                SQLJustDoIt "insert into FESStateMap values(112, 1, 'Tech Status', '5', 'S');"
                SQLJustDoIt "insert into FESStateMap values(113, 1, 'Tech Status', 'G', 'S');"
                SQLJustDoIt "insert into FESStateMap values(114, 1, 'Diagnosis', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(115, 1, 'Diagnosis', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(116, 1, 'Diagnosis', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(117, 1, 'Diagnosis', 'U', 'O');"
                SQLJustDoIt "insert into FESStateMap values(118, 1, 'Diagnosis', 'I', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'FACTORY REPAIR', '2', 'P');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'FACTORY WARRANTY', 'W', 'P');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'AT VENDOR FL', '#', 'P');"
                SQLJustDoIt "insert into FESStateMap values(27, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(26, 2, 'REPLACE BY VENDOR', 'R', 'S');"
                SQLJustDoIt "insert into FESStateMap values(25, 2, 'DELETE SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'IN INVENTORY', '1', 'S');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'ISSUED REMOT INV', '4', 'S');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'NON-INV NOT CUSTOMER', '8', 'S');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'DELETEBADSERAIL', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'DELETE LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(22, 2, 'DELETE SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'TECHNICIAN', '7', 'T');"

              Case "Surf Board,LA"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Pending Diagnosis', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Diagnosis', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'In Repair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Factory', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Tech Status', 'T', 'T');"

              Case "CBA,CBA SDLA"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Pending Diagnosis', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Diagnosis', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'In Repair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Factory', 'F', 'P');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Tech Status', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(9, 1, 'Tech Status', 'L', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 1, 'Tech Status', 'K', 'O');"
                SQLJustDoIt "insert into FESStateMap values(11, 1, 'Tech Status', 'W', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 1, 'Tech Status', '5', 'O');"
                SQLJustDoIt "insert into FESStateMap values(13, 1, 'Tech Status', 'G', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 1, 'Diagnosis', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 1, 'Diagnosis', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(16, 1, 'Diagnosis', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(17, 1, 'Diagnosis', 'U', 'O');"
                SQLJustDoIt "insert into FESStateMap values(18, 1, 'Diagnosis', 'I', 'O');"
                SQLJustDoIt "insert into FESStateMap values(19, 1, 'Testing', 'TESTING', 'O');"
                SQLJustDoIt "insert into FESStateMap values(20, 1, 'HOUSE-ACTIVE', 'HOUSE-ACTIVE', 'H');"
                SQLJustDoIt "insert into FESStateMap values(21, 1, 'HOUSE-DISABLED', 'HOUSE-DISABLED', 'H');"
                SQLJustDoIt "insert into FESStateMap values(22, 1, 'STOCK', 'STOCK', 'O');"
                SQLJustDoIt "insert into FESStateMap values(23, 1, 'RETURN FROM FIELD', 'RETURN FROM FIELD', 'O');"
                SQLJustDoIt "insert into FESStateMap values(24, 1, 'TRUCK ISSUE', 'TRUCK ISSUE', 'T');"
                SQLJustDoIt "insert into FESStateMap values(25, 1, 'TRUCK RETURN', 'TRUCK RETURN', 'R');"
                SQLJustDoIt "insert into FESStateMap values(26, 1, 'REPAIR IN HOUSE', 'REPAIR IN HOUSE', 'P');"
                SQLJustDoIt "insert into FESStateMap values(27, 1, 'Diagnosis', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(28, 1, 'Diagnosis', 'I', 'O');"
                SQLJustDoIt "insert into FESStateMap values(29, 1, 'BER/EOL', 'BER/EOL', 'O');"
                SQLJustDoIt "insert into FESStateMap values(30, 1, 'LOST', 'LOST', 'O');"
                SQLJustDoIt "insert into FESStateMap values(31, 1, 'NA', 'N/A', 'O');"
                SQLJustDoIt "insert into FESStateMap values(32, 1, 'REPAIR AT VENDOR', 'REPAIR AT VENDOR', 'P');"

              Case "Blue Wave,Syracuse"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'House', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Disabled', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'Return', 'R', 'R');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Pending Diagnosis', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Diagnosis', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'In Repair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Factory', 'F', 'P');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Tech Status', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(109, 1, 'Tech Status', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(110, 1, 'Tech Status', 'K', 'S');"
                SQLJustDoIt "insert into FESStateMap values(111, 1, 'Tech Status', 'W', 'S');"
                SQLJustDoIt "insert into FESStateMap values(112, 1, 'Tech Status', '5', 'S');"
                SQLJustDoIt "insert into FESStateMap values(113, 1, 'Tech Status', 'G', 'S');"
                SQLJustDoIt "insert into FESStateMap values(114, 1, 'Diagnosis', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(115, 1, 'Diagnosis', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(116, 1, 'Diagnosis', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(117, 1, 'Diagnosis', 'U', 'O');"
                SQLJustDoIt "insert into FESStateMap values(118, 1, 'Diagnosis', 'I', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(30, 2, 'DELETE LOST', 'T', 'R');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'Factory Repair', '2', 'P');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'Factory Replace', '3', 'P');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'FACTORY WARRANTY', 'W', 'P');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'NEXT SEQ', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'IN INVENTORY', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'ISSUED REMOT INV', '4', 'O');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'CONV NEED TEST', 'A', 'S');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'BROKEWAITREPAIR', 'B', 'S');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'DELETEBADSERAIL', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(20, 2, 'LOSTSTOLEN', 'G', 'S');"
                SQLJustDoIt "insert into FESStateMap values(21, 2, 'PEND SCRAP', 'H', 'S');"
                SQLJustDoIt "insert into FESStateMap values(22, 2, 'DELETE SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'DELETE LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'NON-INV NOT CUSTOMER', 'N', 'S');"
                SQLJustDoIt "insert into FESStateMap values(25, 2, 'DELETE SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(26, 2, 'DELETE REP VENDOR', 'R', 'S');"
                SQLJustDoIt "insert into FESStateMap values(27, 2, 'DELETE STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(28, 2, 'RETURN CORP', '6', 'S');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'WAITFORREPAIR', '8', 'S');"
                SQLJustDoIt "insert into FESStateMap values(29, 2, 'TECHNICIAN', '7', 'T');"

              Case "Patriot,Cox NE"
                SQLJustDoIt "insert into FESStateMap values(1, 2, 'IN INVENTORY', '1', 'O');"
                SQLJustDoIt "insert into FESStateMap values(2, 2, 'Wait Repair', '2', 'O');"
                SQLJustDoIt "insert into FESStateMap values(3, 2, 'Factory Replace', '3', 'O');"
                SQLJustDoIt "insert into FESStateMap values(4, 2, 'ISSUED REMOT INV', '4', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(6, 2, 'RETURN CORP', '6', 'S');"
                SQLJustDoIt "insert into FESStateMap values(7, 2, 'TECH ISSUE', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(8, 2, 'REPAIR', '8', 'P');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'RECALLWAITTEST', 'A', 'S');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'BROKEWAITREPAIR', 'B', 'S');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'BADSERIAL', 'D', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'STOLEN RMB', 'I', 'O');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'DELETE SCRAP', 'J', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'LOST-RMB', 'K', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'DELETE LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'TAMPERED', 'M', 'S');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'NON-INVNOTCUST', 'N', 'S');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'TRANSFER OTHER SYS', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'DELETE SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(20, 2, 'NEXT SEQ', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(21, 2, 'REPLACE VENDOR', 'R', 'O');"
                SQLJustDoIt "insert into FESStateMap values(22, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'PENDTECKRETURN', 'T', 'R');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'WAIT SCRAP', 'U', 'O');"
                SQLJustDoIt "insert into FESStateMap values(25, 2, 'WAIT TRANSFER', 'V', 'O');"
                SQLJustDoIt "insert into FESStateMap values(26, 2, 'FACTORYWAR', 'W', 'P');"
                SQLJustDoIt "insert into FESStateMap values(27, 2, 'WAIT SALEORSCRAP', 'X', 'O');"
                SQLJustDoIt "insert into FESStateMap values(28, 2, 'ASSETWRITEOFF', 'Y', 'O');"
                SQLJustDoIt "insert into FESStateMap values(29, 2, 'ITDBCLEANUP', 'Z', 'O');"

              Case "Seagull,Cox SD"
                SQLJustDoIt "insert into FESStateMap values(1, 2, 'CUSTOMER', '5', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 2, 'FACTORYWAR', 'W', 'P');"
                SQLJustDoIt "insert into FESStateMap values(3, 2, 'Factory Repair', '2', 'P');"
                SQLJustDoIt "insert into FESStateMap values(4, 2, 'WAIT REPAIR', '8', 'S');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'PENDTECKRETURN', 'T', 'R');"
                SQLJustDoIt "insert into FESStateMap values(6, 2, 'TECH ISSUE', '7', 'T');"
                SQLJustDoIt "insert into FESStateMap values(7, 2, 'UNTRACKED', 'N', 'S');"
                SQLJustDoIt "insert into FESStateMap values(8, 2, 'BROKEWAITREPAIR', 'B', 'S');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'BADSERAIL', 'D', 'S');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'STOLEN RMB', 'I', 'S');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'DELETE SCRAP', 'J', 'S');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'LOST-RMB', 'K', 'S');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'DELETE LOST', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'TRANSFER OTHER SYS', 'O', 'S');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'DELETE SOLD', 'P', 'S');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'REPLACE VENDOR', 'R', 'S');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'STOLEN', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'WAIT SCRAP', 'U', 'S');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'WAIT TRANSFER', 'V', 'S');"
                SQLJustDoIt "insert into FESStateMap values(20, 2, 'WAIT SALE', 'X', 'S');"
                SQLJustDoIt "insert into FESStateMap values(21, 2, 'ASSETWRITEOFF', 'Y', 'S');"
                SQLJustDoIt "insert into FESStateMap values(22, 2, 'IN INVENTORY', '1', 'S');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'Factory Replace', '3', 'S');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'ISSUED REMOT INV', '4', 'S');"
                SQLJustDoIt "insert into FESStateMap values(25, 2, 'RETURN CORP', '6', 'S');"
                SQLJustDoIt "insert into FESStateMap values(27, 2, 'ITDBCLEANUP', 'Z', 'O');"
                SQLJustDoIt "insert into FESStateMap values(28, 2, 'NEXT SEQ', 'Q', 'O');"

              Case "Elis,Mediacom"
                SQLJustDoIt "insert into FESStateMap values(1, 1, 'Active', 'H', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 1, 'Customer inactive', 'I', 'H');"
                SQLJustDoIt "insert into FESStateMap values(3, 1, 'In repair', 'B', 'P');"
                SQLJustDoIt "insert into FESStateMap values(4, 1, 'Stock - checkout', 'C', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 1, 'Disabled', 'D', 'O');"
                SQLJustDoIt "insert into FESStateMap values(6, 1, 'Stock - front counter', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(7, 1, 'Returned to factory', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 1, 'Customer lost', 'G', 'O');"
                SQLJustDoIt "insert into FESStateMap values(9, 1, 'FCC Quarantine', 'J', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 1, 'Warehouse - off plant', 'O', 'O');"
                SQLJustDoIt "insert into FESStateMap values(11, 1, 'Warehouse - on plant', 'P', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 1, 'Stock - quality control', 'Q', 'O');"
                SQLJustDoIt "insert into FESStateMap values(13, 1, 'Sales representative', 'R', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 1, 'Stock - shelved', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(15, 1, 'Untracked', 'U', 'O');"
                SQLJustDoIt "insert into FESStateMap values(16, 1, 'Force-tuned', 'X', 'O');"
                SQLJustDoIt "insert into FESStateMap values(17, 1, 'Defective', '9', 'O');"
                SQLJustDoIt "insert into FESStateMap values(18, 1, 'Destroyed', 'K', 'S');"
                SQLJustDoIt "insert into FESStateMap values(19, 1, 'Stock - lost', 'L', 'S');"
                SQLJustDoIt "insert into FESStateMap values(20, 1, 'In-house - written off', 'W', 'S');"
                SQLJustDoIt "insert into FESStateMap values(21, 1, 'Deleted', 'Z', 'S');"
                SQLJustDoIt "insert into FESStateMap values(22, 1, 'Technician', 'T', 'T');"

              Case "Apple,Cable Vision"
                SQLJustDoIt "insert into FESStateMap values(1, 2, 'DISCONNECT', 'D', 'R');"
                SQLJustDoIt "insert into FESStateMap values(2, 2, 'CONNECT', 'C', 'H');"
                SQLJustDoIt "insert into FESStateMap values(3, 2, 'REPAIR', 'R', 'P');"
                SQLJustDoIt "insert into FESStateMap values(4, 2, 'TECT', 'T', 'T');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'SCRAP', 'S', 'S');"
                SQLJustDoIt "insert into FESStateMap values(6, 2, 'STAGING', 'A', 'O');"
                SQLJustDoIt "insert into FESStateMap values(7, 2, 'TEST', 'S', 'O');"
                SQLJustDoIt "insert into FESStateMap values(8, 2, 'FAIL', 'F', 'O');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'GOOD', 'G', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'STORE', 'E', 'O');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'OTHER', 'O', 'O');"

              Case "Fire,Cable One"
                SQLJustDoIt "insert into FESStateMap values(1, 2, 'INSTALL_HOUSE', '--', 'H');"
                SQLJustDoIt "insert into FESStateMap values(2, 2, 'INSTALL_TEST_USED', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(3, 2, 'INSTALL_TEST_NEW', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(4, 2, 'INSTALL_NEW_STOCK', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(5, 2, 'INSTALL_TRUCK_OUT', '--', 'T');"
                SQLJustDoIt "insert into FESStateMap values(7, 2, 'INSTALL_TRUCK_RETURNING', '--', 'R');"
                SQLJustDoIt "insert into FESStateMap values(8, 2, 'INSTALL_TEST_USED', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(9, 2, 'INSTALL_OLD_STOCK', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(10, 2, 'STORE', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(11, 2, 'OTHER', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(12, 2, 'INSTALL_SCRAP', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(13, 2, 'INSTALL_VENDOR_BAD', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(14, 2, 'INSTALL_STOLEN', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(15, 2, 'INSTALL_ARRIVE_BAD', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(16, 2, 'INSTALL_AT_VENDOR', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(17, 2, 'INSTALL_DELETE', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(18, 2, 'INSTALL', '--', 'H');"
                SQLJustDoIt "insert into FESStateMap values(19, 2, 'NONE_TEST_NEW', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(20, 2, 'NONE_NEW_STOCK', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(21, 2, 'NONE_TRUCK_OUT', '--', 'T');"
                SQLJustDoIt "insert into FESStateMap values(22, 2, 'NONE_HOUSE', '--', 'H');"
                SQLJustDoIt "insert into FESStateMap values(23, 2, 'NONE_TRUCK_RETURNING', '--', 'R');"
                SQLJustDoIt "insert into FESStateMap values(24, 2, 'NONE_TEST_USED', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(25, 2, 'NONE_OLD_STOCK', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(26, 2, 'NONE_SCRAP', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(27, 2, 'NONE_VENDOR_BAD', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(28, 2, 'NONE_STOLEN', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(29, 2, 'NONE_ARRIVE_BAD', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(30, 2, 'NONE_AT_VENDOR', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(31, 2, 'NONE_DELETE', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(32, 2, 'REMOVE', '--', 'R');"
                SQLJustDoIt "insert into FESStateMap values(33, 2, 'REMOVE_TEST_NEW', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(34, 2, 'REMOVE_NEW_STOCK', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(35, 2, 'REMOVE_TRUCK_OUT', '--', 'T');"
                SQLJustDoIt "insert into FESStateMap values(36, 2, 'REMOVE_HOUSE', '--', 'H');"
                SQLJustDoIt "insert into FESStateMap values(37, 2, 'REMOVE_TRUCK_RETURNING', '--', 'R');"
                SQLJustDoIt "insert into FESStateMap values(38, 2, 'REMOVE_TEST_USED', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(39, 2, 'REMOVE_OLD_STOCK', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(40, 2, 'REMOVE_SCRAP', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(41, 2, 'REMOVE_VENDOR_BAD', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(42, 2, 'REMOVE_STOLEN', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(43, 2, 'REMOVE_ARRIVE_BAD', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(44, 2, 'REMOVE_AT_VENDOR', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(45, 2, 'REMOVE_DELETE', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(47, 2, 'REPAIR_TEST_NEW', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(48, 2, 'REPAIR_NEW_STOCK', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(49, 2, 'REPAIR_TRUCK_OUT', '--', 'T');"
                SQLJustDoIt "insert into FESStateMap values(50, 2, 'REPAIR_HOUSE', '--', 'H');"
                SQLJustDoIt "insert into FESStateMap values(51, 2, 'REPAIR_TRUCK_RETURNING', '--', 'R');"
                SQLJustDoIt "insert into FESStateMap values(52, 2, 'REPAIR_TEST_USED', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(53, 2, 'REPAIR_OLD_STOCK', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(54, 2, 'REPAIR_SCRAP', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(55, 2, 'REPAIR_VENDOR_BAD', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(56, 2, 'REPAIR_STOLEN', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(57, 2, 'REPAIR_ARRIVE_BAD', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(58, 2, 'REPAIR_AT_VENDOR', '--', 'O');"
                SQLJustDoIt "insert into FESStateMap values(59, 2, 'REPAIR_DELETE', '--', 'S');"
                SQLJustDoIt "insert into FESStateMap values(60, 2, 'REPAIR', '--', 'P');"
                SQLJustDoIt "insert into FESStateMap values(61, 2, 'MAINTENANCE_HIT', '--', 'H');"

              Case Else
                MsgBox "Division Map Not found, Run Tools > Change setup information"
                Exit Sub
            End Select

      '  Case "FESStateTransitions"
      '      DoInit = True
      '      s = s & "CREATE TABLE FESStateTransitions ("
      '      s = s & "StateTransitionID int NOT NULL,"
      '      s = s & "FromStateAbbrev char(1) NOT NULL,"
      '      s = s & "ToStateAbbrev char(1) NOT NULL,"
      '      s = s & "LegalMove tinyint NOT NULL,"
      '      s = s & "AccumFromDays tinyint NOT NULL,"
      '      s = s & "AccumToCount tinyint NOT NULL,"
      '      s = s & "PRIMARY KEY (StateTransitionID)"

'@@ why are all the LegalMove flag 0 ?

       Case "FESStateTransitions"
            SQLJustDoIt "insert into FESStateTransitions values(1, 'U', '-', 0, 1, 1);"
#if 0 Then '@@
            If StateMapIdentifier = "Black Sand,TWC Hawaii" Then
                SQLJustDoIt "insert into FESStateTransitions values(2, 'H', 'H', 0, 1, 1);"
            Else
                SQLJustDoIt "insert into FESStateTransitions values(2, 'H', 'H', 0, 1, 0);"
            End If
#End If
            SQLJustDoIt "insert into FESStateTransitions values(2, 'H', 'H', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(3, 'H', 'R', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(4, 'H', 'T', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(5, 'H', 'P', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(6, 'H', 'O', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(7, 'H', 'S', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(8, 'R', 'H', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(9, 'R', 'R', 0, 1, 0);"
            SQLJustDoIt "insert into FESStateTransitions values(10, 'R', 'T', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(11, 'R', 'P', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(12, 'R', 'O', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(13, 'R', 'S', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(14, 'T', 'H', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(15, 'T', 'R', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(16, 'T', 'T', 0, 1, 0);"
            SQLJustDoIt "insert into FESStateTransitions values(17, 'T', 'P', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(18, 'T', 'O', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(19, 'T', 'S', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(20, 'P', 'H', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(21, 'P', 'R', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(22, 'P', 'T', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(23, 'P', 'P', 0, 1, 0);"
            SQLJustDoIt "insert into FESStateTransitions values(24, 'P', 'O', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(25, 'P', 'S', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(26, 'O', 'H', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(27, 'O', 'R', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(28, 'O', 'T', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(29, 'O', 'P', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(30, 'O', 'O', 0, 1, 0);"
            SQLJustDoIt "insert into FESStateTransitions values(31, 'O', 'S', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(32, 'S', 'H', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(33, 'S', 'R', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(34, 'S', 'T', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(35, 'S', 'P', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(36, 'S', 'O', 0, 1, 1);"
            SQLJustDoIt "insert into FESStateTransitions values(37, 'S', 'S', 0, 1, 0);"
    End Select
End Sub
