Attribute VB_Name = "HookMsgs"
Option Explicit

Private Declare Function FindWindow Lib "user32" Alias "FindWindowA" _
    (ByVal lpClassName As Long, ByVal lpWindowName As Long) As Long
Private Declare Function GetWindow Lib "user32" (ByVal hwnd As Long, _
    ByVal wCmd As Long) As Long
Private Declare Function GetWindowThreadProcessId Lib "user32" _
    (ByVal hwnd As Long, lpdwProcessId As Long) As Long
Private Declare Function GetParent Lib "user32" (ByVal hwnd As Long) As Long
Private Declare Function GetCurrentProcessId Lib "kernel32" () As Long
Private Declare Function GetWindowLong Lib "user32" Alias "GetWindowLongA" _
    (ByVal hwnd As Long, ByVal nIndex As Long) As Long
Private Declare Function CallWindowProc Lib "user32" Alias "CallWindowProcA" _
    (ByVal lpPrevWndFunc As Long, ByVal hwnd As Long, ByVal Msg As Long, _
    ByVal wParam As Long, ByVal lParam As Long) As Long
Public Declare Function SetWindowLong Lib "user32" Alias "SetWindowLongA" _
    (ByVal hwnd As Long, ByVal nIndex As Long, ByVal dwNewLong As Long) As Long

Private Const MAXWINDOWHOOKS = 50
Private Const WM_QUERYENDSESSION = 17
Private Const WM_ENDSESSION = 22
Private Const GWL_WNDPROC = (-4)
Private Const GW_HWNDNEXT = 2
Private Const WS_VISIBLE = &H10000000
Private Const GWL_STYLE = (-16)

Private WndProcList(MAXWINDOWHOOKS) As Long
Private HWList(MAXWINDOWHOOKS) As Long
Private OldProc(MAXWINDOWHOOKS) As Long

Public HookWindowEndMessagesFlag As Boolean

Private Function WindowProc(ByVal hw As Long, ByVal uMsg As Long, _
  ByVal wParam As Long, ByVal lParam As Long) As Long
    Dim ii As Long

    ' Find our hwnd

    WindowProc = True
    For ii = 0 To UBound(HWList)
        If HWList(ii) = hw Then
            If uMsg = WM_QUERYENDSESSION Then Exit Function
            If uMsg = WM_ENDSESSION Then Exit Function
            WindowProc = _
                CallWindowProc(WndProcList(ii), hw, uMsg, wParam, lParam)
        End If
    Next ii
End Function

Public Sub HookAllTopLevelWindows()
    Dim ii As Long
    Dim s As String
    Dim ss As String
    Dim lParent As Long

    ' Remove all old hooks first

    RemoveAllHooks

    ' Hook all top level windows

    lParent = ProcessToParentWnd(GetCurrentProcessId)
    Do While lParent
        'ss = Space(255)
        'GetWindowText lParent, ss, 255
        's = s & Time & " " & handle_zero_term(ss) & vbCrLf

        OldProc(ii) = GetWindowLong(lParent, GWL_WNDPROC)
        WndProcList(ii) = SetWindowLong(lParent, GWL_WNDPROC, AddressOf WindowProc)
        HWList(ii) = lParent
        ii = ii + 1

        lParent = ProcessToParentWnd(GetCurrentProcessId)
    Loop

    ' Reset internal statics in function

    ProcessToParentWnd 0

    'ii = fopen("c:\hooklog.txt", "w")
    'WriteStringToFile s, ii
    'fclose ii
End Sub

Public Sub RemoveMyHook(hw As Long)
    Dim ii As Long

    For ii = 0 To UBound(HWList)
        If HWList(ii) = hw Then
            SetWindowLong hw, GWL_WNDPROC, OldProc(ii)
            HWList(ii) = 0
            Exit For
        End If
    Next ii
End Sub

Public Sub RemoveAllHooks()
    Dim ii As Long

    For ii = 0 To UBound(HWList)
        If HWList(ii) <> 0 Then
            SetWindowLong HWList(ii), GWL_WNDPROC, OldProc(ii)
            HWList(ii) = 0
        End If
    Next ii
End Sub

Private Function ProcessToParentWnd(ByVal lProcID As Long, Optional bReturnVisible As Boolean = True) As Long
    Dim lTestHwnd As Long, lTestPID As Long, lStyle As Long
    Static ssPreviousParents As String, slLastProcID As Long

    ' Purpose  Returns a top level (parent) window handle for a specified process ID
    ' Inputs   lProcID             The process ID to return a parent window handle of.
    '                              Note, can be called recursively to retrieve all the
    '                              parent windows owned by a process.
    '          [bReturnVisible]    If True only returns top level windows which have the WS_VISIBLE style bit set.
    ' Outputs  Returns the handle of parent window owned by the specified process

    If lProcID = 0 Then
        ' Reset statics

        ssPreviousParents = ""
        slLastProcID = 0
        Exit Function
    End If

    ' Find the first window

    lTestHwnd = FindWindow(ByVal 0&, ByVal 0&)
    Do While lTestHwnd <> 0
        ' Check if the window isn't a child

        If GetParent(lTestHwnd) = 0 Then
            ' Get the window's ProcessID

            Call GetWindowThreadProcessId(lTestHwnd, lTestPID)

            If lTestPID = lProcID Then
                If bReturnVisible Then
                    ' Do not return hidden windows

                    lStyle = GetWindowLong(lTestHwnd, GWL_STYLE)
                    If (lStyle And WS_VISIBLE) = False Then
                        ' Not a visible window

                        lTestPID = -1
                    End If
                End If
            End If

            If lTestPID = lProcID Then
                If slLastProcID = lProcID Then
                    ' Called with the same proc ID twice

                    If InStr(1, ssPreviousParents, CStr(lTestHwnd) & "|") = 0 Then
                        ' Return the next parent handle for this process

                        ProcessToParentWnd = lTestHwnd
                        ssPreviousParents = ssPreviousParents & ProcessToParentWnd & "|"
                        slLastProcID = lProcID
                        Exit Do
                    End If
                Else
                    ' New Proc ID

                    ProcessToParentWnd = lTestHwnd
                    ssPreviousParents = ProcessToParentWnd & "|"
                    slLastProcID = lProcID
                    Exit Do
                End If
            End If
        End If

        ' Retrieve the next window

        lTestHwnd = GetWindow(lTestHwnd, GW_HWNDNEXT)
    Loop
End Function
