// Read watch file - set WF to 2 (ProcessWatchFile)
// Remove from WL - if 2, only if state is Repair or Scrap
//      (but not if time in H is >30)
// Managed List - New column "MANUAL ADD"; Yes or No
// Production List - if 2, output DESIRED ACTION as "M"

/*
 * BASENGINE.C - The program that does the real BAS work.
 * This runs as a minimized console program. It accepts commands from BAS
 * over Winsock, and reports status back.
 */
#define DBNTWIN32
#define _CRT_SECURE_NO_WARNINGS

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <malloc.h>
#include <windows.h>
#include <winsock.h>

#define DEBUGMSGS       1               // debug messages
#define DEBUGMSGS0      0               // disabled debug messages
#define DEBUGMSGSW      1               // watch list debug messages
#define DEBUGWKCHK      0               // check the yyyy-ww string
#define DEBUGWATCH      1               // check watch list counts
#define DEBUGWCOUNT     1               // check watch list counts

#define REPAIR_VERSION  1

#define SERVICELIFE     1800            // Expected life span of a box (days)
#define SECSINADAY      (60 * 60 * 24)  // Seconds in a day (86400)
#define JAN_2_2012      1325480400      // time_t for 1/2/2012
//@@ #define JAN_2_2012      1306904400 // time_t for 6/1/2011
#define JAN_1_1980       315550800      // time_t for 1/1/1980 (default SOW)

#define CSG_REGION      0               // fields in a CSG input record
#define CSG_DIVISION    1
#define CSG_SERIAL      2
#define CSG_TYPE        3
#define CSG_BOXMODEL    4
#define CSG_BOXMAKE     5
#define CSG_RECEIPT     6
#define CSG_STATE       7
#define CSG_STATEDATE   8
#define CSG_ENDDATE     9
#define CSG_LOCATION   10
#define CSG_STATETIME  11
#define CSG_TRAN       12
#define CSG_OPERATOR   13
#define CSG_FIELDSMAX  14

#define ICM_REGION      0               // fields in an ICOMMS record
#define ICM_DIVISION    1
#define ICM_SITEID      2
#define ICM_SERIAL      3
#define ICM_ITEMNO      4
#define ICM_ITEMTYPE    5
#define ICM_STATE       6
#define ICM_STATEDESC   7
#define ICM_STATEDATE   8
#define ICM_STATETIME   9
#define ICM_LOCATION   10
#define ICM_RETREASON  11
#define ICM_RETFLAG    12
#define ICM_RETDESC    13
#define ICM_TECHTYPE   14
#define ICM_TECHDESC   15
#define ICM_ADDRESS    16
#define ICM_ADDRESS2   17
#define ICM_LOCATOR    18
#define ICM_ZIPCODE    19
#define ICM_ITEMDESC   20
#define ICM_FIELDSMIN  21
#define ICM_FIELDSMAX  22

// Fields in a CableVision record.

#define OCV_TM_MATERIAL_TRANS_ID      0 // no
#define OCV_MTL_ITEM_ID               1 // no
#define OCV_SERIAL_NUMBER_ID          2 // 14 ICM_TECHTYPE
#define OCV_SERIAL_NUMBER             3 //  3 ICM_SERIAL
#define OCV_PURCHASED_DATE            4 // 11 ICM_RETREASON
#define OCV_INVENTORY_ITEM_ID         5 //  4 ICM_ITEMNO
#define OCV_ITEM                      6 //  5 ICM_ITEMTYPE
#define OCV_BOX_TYPE                  7 // 20 ICM_ITEMDESC
#define OCV_BEGIN_DATE                8 //  8 ICM_STATEDATE
#define OCV_END_DATE                  9 // (no)
#define OCV_DAYS_IN_STATUS           10 // (no)
#define OCV_BOX_ADD_METHOD           11 //  x
#define OCV_BOX_RETURN_METHOD        12 //  x
#define OCV_NFM_MATERIAL_TRANS_ID    13 // (no)
#define OCV_SUB_INVENTORY_CODE       14 //  7 ICM_STATEDESC
#define OCV_LOCATOR                  15 //  x
#define OCV_ORGANIZATION_CODE        16 // (used to find State)
#define OCV_ORG_ACRONYM              17 // 18 ICM_LOCATOR
#define OCV_PREV_SUB_INVENTORY_CODE  18 //  x
#define OCV_PREV_LOCATOR             19 // 19 ICM_ZIPCODE
#define OCV_PREV_ORGANIZATION_CODE   20 //  x
#define OCV_PREV_ORG_ACRONYM         21 //  x
#define OCV_CORP                     22 // (used as Location)
#define OCV_HOUSE                    23 // (used as Location)
#define OCV_CUST                     24 // (used as Location)
#define OCV_TC_SWAP_FLAG             25 // 12 ICM_RETFLAG
#define OCV_TC_BOX_SWAP_FIX_CD_FLAG  26 //  x
#define OCV_TC_WFINDATE              27 //  x
#define OCV_TC_TECH                  28 //  x
#define OCV_TC_INHOUSE_CONT_FLAG     29 //  x
#define OCV_TC_FIX_CODE_STR          30 //  x
#define OCV_RPR_WARRANTY_REPAIR_CODE 31 // (no)
#define OCV_RPR_WARRANTY_DESCR       32 //  x
#define OCV_RPR_SCRAPPED_FLAG        33 // 15 ICM_TECHDESC
#define OCV_REPAIR_AMT               34 // 17 ICM_ADDRESS2
#define OCV_RPR_PART_NBR_STR         35 //  x
#define OCV_RPR_PART_DESCR_STR       36 //  x
#define OCV_FIELDSMAX                37

// Data structure field definitions:

#define DB_EXTERNALSTATE  0             // fields in Strings
#define DB_CABLEBOXMAKE   1
#define DB_CABLEBOXMODEL  2
#define DB_LOCATION       3
#define DB_ADDRESS        4
#define DB_ADDRESS2       5
#define DB_COMPANYREGION  6
#define DB_HOUSELOCATION  7             // to here: comes in input record
#define DS_PREVLOCATION   8             // here and beyond: appended by BAS
#define DS_BILLINGSYSTEM  9
#ifdef CBA_VERSION
#define DB_LOCATIONB     10
#define DB_LOCATIONC     11
#define DB_STATEB        12
#define DB_STATEC        13
#define DS_FIELDSMAX     14
#else
#define DS_FIELDSMAX     10
#endif

#define WL_SERIAL        0              // fields in a Watch List record
#define WL_ACTION        1

#define ML_SERIAL        0              // fields in a Managed List record
#define ML_INITIALDATE   1
#define ML_LATESTDATE    2
#define ML_TIMESONLIST   3
#define ML_TIMESDISC     4
#define ML_DAYSSINCEPREV 5
#define ML_WATCHFLAG     7
#define ML_ACTION        8
#define ML_TIMESRBACK    9
#define ML_LATESTRBACK  10
#define ML_RBACKREASON  12
#define ML_FIELDSMAX    13

#define WO_SERIAL        0              // fields in a Work Order record
#define WO_ACCOUNTNO     1
#define WO_COMPDATE      2
#define WO_DATEENTERED   3
#define WO_PROBLEMCODE   4
#define WO_PROBLEMDESC   5
#define WO_FINDINGCODE   6
#define WO_FINDINGDESC   7
#define WO_SOLUTIONCODE  8
#define WO_SOLUTIONDESC  9
#define WO_INSTALLER    10
#define WO_WONUMBER     11
#define WO_TYPE         12
#define WO_CLASS        13
#define WO_STATUS       14
#define WO_QCODE        20
#define WO_BILLTYPE     21
#define WO_CHECKINDATE  26
#define WO_DISCONCODE   27
#define WO_DISCONDESC   28
#define WO_ITEMNUMBER   29
#define WO_FIELDSMAX    30

#define DE_SITE          0              // fields in a Defective Equipment rec
#define DE_CREATED       1
#define DE_SUBMITTER     2
#define DE_SALESNO       3
#define DE_SERIAL        4
#define DE_MODEL         5
#define DE_PROBLEM       6
#define DE_PDETAILS      7
#define DE_DIAGNOSIS     8
#define DE_SOLUTION      9
#define DE_SDETAILS     10
#define DE_RESOLVER     11
#define DE_RESDATE      12
#define DE_FIELDSMAX    13

#define RV_SERIAL        0              // fields in a Repair List record
#define RV_ACTION        1
#define RV_DATE          2
#define RV_FIELDSMAX     3

// Socket parameters

#define PORT (unsigned short) 8181
#define MAXBUFLEN 1024

// Various types of freespace:
// DB space: holds the database binary tree
// WL space: holds the watch list database binary tree
// String space: holds each database record's string list
// Permanent space: holds static database data and other constant info
// Temporary space: holds data pertaining to a particular record (not used)

#define DBSSPACESIZE   (1024 * 500)
#define WLSSPACESIZE   (1024 * 100)
#define STGSPACESIZE   (1024 * 100)
#define PERMSPACESIZE  (1024 * 10)
#define TEMPSPACESIZE  (1024 * 100)

char *mydbspaceptr, *mydbspacelist, *mydbspacefree, **mydbspacecur;
long mydbspacesize = 0;                 // size of remainder of current block

char *mywlspaceptr, *mywlspacelist, *mywlspacefree, **mywlspacecur;
long mywlspacesize = 0;

char *mystgspaceptr, *mystgspacelist, *mystgspacecur;
long mystgspacesize = 0;

char *mypermspaceptr;
long mypermspacesize = 0;

typedef struct string_s {
    struct string_s *next;
    unsigned long len;
} STRING;

STRING *stringlist50, *stringlist60, *stringlist;
STRING *stringptr, *stringprev;
long listlen50, listlen60, listlen;

// CableBoxData and CableBoxArchive data structure.

typedef struct boxnode_s {
    short balance;                      // tree balance: -1, 0, 1 (right)
    struct boxnode_s *llink;            // pointer to left-hand child
    struct boxnode_s *rlink;            // pointer to right-hand child
    char CableBoxSerial[30];
    char CurrentState;
    short Universal;
    time_t DateOfState;
    short RDaysUnknown;
    short RDaysHouse;
    short RDaysReturn;
    short RDaysRepair;
    short RDaysOther;
    short RDaysTech;
    short PDaysUnknown;
    short PDaysHouse;
    short PDaysReturn;
    short PDaysRepair;
    short PDaysOther;
    short PDaysTech;
    short RToHouse;
    short RToReturn;
    short RToRepair;
    short RToOther;
    short RToTech;
    short PToHouse;
    short PToReturn;
    short PToRepair;
    short PToOther;
    short PToTech;
    short ShortInHouse;
    short IllegalTransitions;
    short ShortInHouseBU;
    time_t HouseDate;                   // not used
    short HouseDays;                    // holds previous SIH flag
    time_t ReceiptDate;
#ifdef CBA_VERSION
    time_t DateOfStateB;
    time_t DateOfStateC;
    time_t DateCBAFlag;
    short TimesCBAFlag;
#endif
    char *Strings;                      // ext state, make, model, location,
} NODE;                                 // (locationB, locationC), addr1, addr2,
                                        // corp/region, house location,
                                        // prev location, billing system

NODE *bxtreeroot;                       // the root of the cable box tree

// Watch list data structure.

#define RBR_UNKNOWN 0                   // reason for the latest rollback:
#define RBR_MANUAL  1                   // box rolled back by user
#define RBR_REPAIR  2                   // box moved to Repair state
#define RBR_SERVICE 3                   // box moved to Out of Service
#define RBR_HOUSE   4                   // box in House >= 90 days
#define RBR_FILER   5                   // repair found in file
#define RBR_FILES   6                   // scrap found in file
#define RBR_MAX     6                   // maximum expected value

                                        // values of WatchFlag:
#define WF_DELETED -1                   // entry is "deleted"
#define WF_INACTIVE 0                   // entry is currently inactive
#define WF_ACTIVE   1                   // entry is currently active
#define WF_MANUAL   2                   // entry was manually added

typedef struct wlnode_s {
    short balance;                      // tree balance: -1, 0, 1 (right)
    struct wlnode_s *llink;             // pointer to left-hand child
    struct wlnode_s *rlink;             // pointer to right-hand child
    char CableBoxSerial[30];
    time_t InitialDate;                 // initial watch list date
    time_t LatestDate;                  // latest watch list date
    short TimesOnList;                  // times on list
    short TimesDiscovered;              // times discovered on list
    short DaysSincePrevious;            // days since previous listing
    short WatchFlag;                    // watch flag (see values above)
    short Action;                       // desired action
    short TimesRolledBack;              // times rolled back
    time_t LatestRollback;              // latest rollback date
    short RollbackReason;               // rollback reason code
#ifdef REPAIR_VERSION
    time_t VScrapDate;
    short VCountNoProblem;
    short PVCountRepair;
    short RVCountRepair;
    time_t LatestVRepairDate;
    short AvgDaysBtwnRepair;
#endif
} WLNODE;

WLNODE *wltreeroot, *wlcurnode;         // the root of the rollback tree

// Model Counts data structure.

typedef struct ctnode_s {
    short balance;                      // tree balance: -1, 0, 1 (right)
    struct ctnode_s *llink;             // pointer to left-hand child
    struct ctnode_s *rlink;             // pointer to right-hand child
    char *SiteID_Model;                 // "siteID","model"
    long GL_Count;                      // count of boxes
    long WL_Count;
    long WL_RemCount;
    long GL_InHouse;
    long WL_InHouse;
    long GL_InRepair;
    long WL_InRepairI;
    long GL_InOther;
    long WL_InOther;
    long GL_Installed;
    long WL_Installed;
    long GL_Repair;
    long WL_Repair;
    long GL_Other;
    long WL_Other;
    long GL_DaysHouse;
    long WL_DaysHouse;
    long GL_DaysTotal;
    long WL_DaysTotal;
    long GL_OutOfService;
    long WL_OutOfServiceI;
    long WL_InHouseI;
} CTNODE;

CTNODE *cttreeroot, *ctcurnode;         // the root of the model counts tree

// Model Counts weekly data structure.

typedef struct mwnode_s {
    short balance;                      // tree balance: -1, 0, 1 (right)
    struct mwnode_s *llink;             // pointer to left-hand child
    struct mwnode_s *rlink;             // pointer to right-hand child
    char *Week_SiteID_Model;            // week,"siteID","model"
    long GL_Count;                      // count of boxes
    long GL_SIHCount;                   // boxes that are Short in House
    long WL_AddCount;                   // boxes added to watch list
    long WL_RemCount;                   // boxes once on watch list but not now
    long WL_Count;
    long GL_InHouse;
    long WL_InHouse;
    long GL_InRepair;
    long WL_InRepairI;
    long GL_InOther;
    long WL_InOther;
    long GL_Installed;
    long WL_Installed;
    long GL_Repair;
    long WL_Repair;
    long GL_Other;
    long WL_Other;
    long WL_OtherCount;
    long WL_ScrapCount;
    long WL_HouseCount;
    long WL_RepairCount;
    long GL_DaysHouse;
    long WL_DaysHouse;
    long GL_DaysTotal;
    long WL_DaysTotal;
    long GL_OutOfService;
    long WL_OutOfServiceI;
    long WL_InHouseI;
} MWNODE;

MWNODE *mwtreeroot, *mwcurnode;         // the root of the model week tree

#ifdef CAPEQ_VERSION
// Capital equipment data structures.

typedef struct WOnode_s {
    short balance;                      // tree balance: -1, 0, 1 (right)
    struct WOnode_s *llink;             // pointer to left-hand child
    struct WOnode_s *rlink;             // pointer to right-hand child
    char CableBoxSerial[22];
    char *AccountNo;
    short TimesDiscovered;
    char *SiteID_C;
    char *SiteID_B;
    char *SiteID_A;
    time_t WOCompletionDatePrev;
    time_t WOCompletionDateCur;
    time_t DateEntered;
    time_t PrevDateEntered;
    time_t FirstDateEntered;
    char ProblemCodePrev[3];
    char ProblemCodeCur[3];
    char FindingCodePrev[3];
    char FindingCodeCur[3];
    char SolutionCodePrev[3];
    char SolutionCodeCur[3];
    char *AssignedInstallerPrev;
    char *AssignedInstallerCur;
    char *WorkOrderNoPrev;
    char *WorkOrderNoCur;
    char WOtype[3];
    char WOclass[3];
    char WOstatus[3];
    char QCode[3];
    char *BillTypeCode;
    time_t CheckinDatePrev;
    time_t CheckinDateCur;
    char DisconnectCode[3];
    char *ItemNumber;
} WONODE;

WONODE *wotreeroot, *wocurnode;         // the root of the work order tree

// Work order codes and descriptions.

typedef struct probcode_s {
    struct probcode_s *next;
    char ProblemCode[3];
    char ProblemDesc[1];
} PROBCODE;

PROBCODE *ProbCodeRoot, *ProbCodeCur;   // the root of all problems

typedef struct findcode_s {
    struct findcode_s *next;
    char FindingCode[3];
    char FindingDesc[1];
} FINDCODE;

FINDCODE *FindCodeRoot, *FindCodeCur;   // the root of findings

typedef struct solcode_s {
    struct solcode_s *next;
    char SolutionCode[3];
    char SolutionDesc[1];
} SOLCODE;

SOLCODE *SolCodeRoot, *SolCodeCur;      // the root of solutions

typedef struct disccode_s {
    struct disccode_s *next;
    char DisconnectCode[3];
    char DisconnectDesc[1];
} DISCCODE;

DISCCODE *DiscCodeRoot, *DiscCodeCur;   // the root of disconnects

// Defective Equipment data structure.

typedef struct defnode_s {
    short balance;                      // tree balance: -1, 0, 1 (right)
    struct defnode_s *llink;            // pointer to left-hand child
    struct defnode_s *rlink;            // pointer to right-hand child
    char CableBoxSerial[17];
    char *SiteID;
    char *Submitter;
    time_t CreatedDate;
    time_t PrevCreateDate;
    time_t FirstCreateDate;
    char *SalesNo;
    char *Model;
    char *ProblemPrev;
    char *ProblemCur;
    char *Details;
    char *DiagnosisPrev;
    char *DiagnosisCur;
    char *Solution;
    char *Resolver;
    time_t ResolvedDate;
    short TimesDiscovered;
} DENODE;

DENODE *detreeroot, *decurnode;         // root of the defective equipment tree
#endif

// Cablevision (OCV) data structure.

typedef struct ocvnode_s {
    short balance;
    struct ocvnode_s *llink;
    struct ocvnode_s *rlink;
    char CableBoxSerial[17];
    short StringSize;
    time_t TCWFindate;
    short CDFlagCCount;
    short CDFlagICount;
    short TCWFindateDays;
    short RprWarrantyNWCt;              // no warranty - special project
    long RprWarrantyNWAmt;
    short RprWarrantyWXCt;              // manufacturer warranty expired
    long RprWarrantyWXAmt;
    short RprWarrantyFWCt;              // repaired under full mfg wty
    long RprWarrantyFWAmt;
    short RprWarrantyURCt;              // unrepairable
    long RprWarrantyURAmt;
    short RprWarrantyFSCt;              // failed screen and clean
    long RprWarrantyFSAmt;
    short RprWarrantyOTCt;              // other repair
    long RprWarrantyOTAmt;
    short RprChargeCount;
    long RprTotalCharge;
    short TCSwapFlagCount;
    short LocMDSLNKCount;
    time_t LocMDSLNKDate;
    char *SiteID_C;
    char *SiteID_B;
    char *SiteID_A;
    char *CurBoxAddMethod;
    char *PrevBoxAddMethod;
    char *CurBoxReturnMethod;
    char *PrevBoxReturnMethod;
    char *Locator;
    char *PrevSubInventoryCode;
    char *PrevOrganizationCode;
    char *PrevOrgAcronym;
    char *TCTech;
    char *TCInhouseContFlag;
    char *TCFixCodeStr;
    char *RprScrappedFlag;
    char *RprPartNbrStr;
    char *RprPartDescr;
    char *OrganizationCode;
    char *OrgAcronym;
} CVNODE;

CVNODE *cvtreeroot, *cvcurnode;         // root of the Cablevision tree

// Drop model list data structure.

typedef struct dmnode_s {
    short balance;                      // tree balance: -1, 0, 1 (right)
    struct dmnode_s *llink;             // pointer to left-hand child
    struct dmnode_s *rlink;             // pointer to right-hand child
    char Model[1];                      // model to be dropped
} DMNODE;

DMNODE *dmtreeroot, *dmcurnode;         // the root of the drop model tree

// Globals for the currently active tree.

NODE *treeroot, *curnode;               // the root of the current tree

// Data used by the binary tree routines.

short nodelevel = -1;                   // values for firstnode, nextnode
short nodestate;
NODE *thisnode;
NODE *nodelevels[50];

// List of boxes that were reset because they went into the Repair state
// and were on the watch list.

typedef struct boxreset_s {
    struct boxreset_s *next;
    char CurrentState;
    char CableBoxSerial[1];
} BOXRESET;

BOXRESET *BoxResetRoot, *BoxResetCur;   // the root of all box resets

// List of boxes moving to the external J state.

typedef struct JStateBoxes_s {
    struct JStateBoxes_s *next;
    NODE *CableBox;
} JSTATEBOXES;

JSTATEBOXES *JStateList, *JStatePtr;

// Fields of the current database record broken out of Strings[].

#ifdef CBA_VERSION
char dbStrings[300];
#else
char dbStrings[200];
#endif
char *dStrings[DS_FIELDSMAX];

char HouseLocation[100];
#ifdef CBA_VERSION
char *OldLocation;
#endif

// Fields in the input file record.

char *fCableBoxSerial;                  // fields of the current file record
char fStatusCode;

char *fExternalState;
char *fCableBoxMake;
char fCableBoxModel[150];
char *fLocation;
char *fAddress;
char *fAddress2;
char fCompanyRegion[100];
char *fPrevLocation;
char fStrings[500];
time_t fDateOfState;
time_t fReceiptDate;
time_t MostRecentDOS;

// Fields that will go in the output file.

char StatusOutOfSequence[50];
short DaysBetweenStates;

// Global database values that are sent from VB.

char BASIdentifier[25];
short DoingCSG;                 // 0=ICOMMS, 1=CSG, 2=OCV
short DoingUniversal;           // 1 iff processing a Universal file
short WriteOutputFiles;         // 1 iff output files should be written
short MapBUsingLocation;        // 1 to use location to determine B state
short IgnoreLocation;           // 1 to ignore location for ShortInHouse
short MutateQState;             // 1 optionally mutate the external Q state
short AutoRollback;             // 1 reset watched boxes that are Repair-ed
time_t DiscardRecent;           // !=0 discard entries later than file date
short HouseLocationFlag;        // 0=Location, 1=Loc+Addr, 2=always unique
short ShortInHouseReset;        // reset value for ShortInHouse
short ShortInHouseFlag = 1;     // 1 to append SIH flag to TRANS file
short ShortInHouseField;        // value (0, 1) to append for above flag
short CoxFlag;                  // set the Location field for Cox
short MediaFlag;                // set special processing for Mediacom
time_t StartOfWorld;
short AddFiveFields;
short valShortInHouse;
char *InboundDir;               // where to find input files
char *OutputDir;                // where to write output files
char *AlternateDir;             // where to write alternate output files
char *LogFileDir;               // path of the log file
char *LogFileFile;              // where to write the log file
char *ModelFile;
char *DatabaseDir;              // residence of the database
char *JFileDir;                 // path of the J-file
char *InDatabaseName;           // read: CableBoxData or -Archive
char *OutDatabaseName;          // write: CableBoxData or -Archive
char DatabaseMode;
char WLDatabaseMode;
char CTDatabaseMode;
char MWDatabaseMode;
char CVDatabaseMode;
short WriteWatchFile;
short WatchSIH;
long WatchAverageDays;
long WatchPercentDays;
#ifdef CAPEQ_VERSION
char WODatabaseMode;
char DEDatabaseMode;
#endif

// Miscellaneous global variables.

short DebugFlag;                // enable debug code
char *Flds[50];                 // fields in the input record
char FilenameSiteID[50];        // site ID from the input filename
char FilenameDate[9];           // date ditto
FILE *ifhdl;                    // inbound file handle
FILE *ofhdl;                    // output file handle (Trans or Index)
FILE *wfhdl;                    // watch file handle
FILE *topofhdl;
time_t DateOfNow;               // the current date
time_t CurFileDate;             // the date used for the file name
long RecordCount;               // count of records read
short WritingIndexFile;         // 1 == writing index, 0 == trans
SOCKET recvSocket;              // the Winsock used to talk with VB
short IncludeTime;              // 1 == include time when converting date
long RecordsDropped;            // count of records dropped

short WatchDataDirty;           // 1 == watch data needs to be written out
short ModelCountsDirty;         // 1 == model counts need to be written out
#ifdef CAPEQ_VERSION
short WorkOrderDataDirty;       // 1 == ditto work order data
short DefectiveEquipmentDataDirty; // 1 == ditto defective equipment data
#endif
char CurrentWeek[10];           // current week "yyyy-ww" (with quotes)
#ifdef _DEBUG
char *DebugAction;              // debug action string
#endif
#if DEBUGWCOUNT
long WatchListCount;            // count of records in the WL database
#endif

char *ActionChar = "xRDSIU";    // watch list action codes

// Various static table sent from VB (held in MySQL).
// The internal states table.

typedef struct InternalStates_s {
    struct InternalStates_s *next;
    char StateAbbrev;
    char StateName[15];
} INTERNALSTATES;

INTERNALSTATES *InternalStates, *InternalStatesPtr;

// The state mapping table.

typedef struct StateMap_s {
    struct StateMap_s *next;
    char *ExternalState;
    char ExtStateAbbrev;
    char StateAbbrev;
} STATEMAP;

// The state mapping table time table.
// Sorted descendingly by StartTime.

typedef struct StateMapDate_s {
    struct StateMapDate_s *next;
    time_t StartDate;
    STATEMAP *CSGStateMap;
    STATEMAP *ICOMMSStateMap;
} STATEMAPDATE;

// The state mapping table location table.

typedef struct StateMapLoc_s {
    struct StateMapLoc_s *next;
    char *Location;
    STATEMAPDATE *StateMapDate;
} STATEMAPLOC;

STATEMAPLOC *StateMapLocRoot, *StateMapLocPtr;
STATEMAPDATE *StateMapDatePtr;
STATEMAP *CSGStateMap, *ICOMMSStateMap;

// The state transition table.

typedef struct StateTransitions_s {
    struct StateTransitions_s *next;
    short FromToState;
    short LegalMove;
    short AccumFromDays;
    short AccumToCount;
} STATETRANSITIONS;

STATETRANSITIONS *StateTransitions, *StateTransitionsPtr;
STATETRANSITIONS *UStateTransitions;

typedef struct OutputFiles_s {
    struct OutputFiles_s *next;
    char *Division;
    char AorB;
    FILE *ofhdl;
} OUTPUTFILES;

OUTPUTFILES *OutputFiles, *OutputFilesPtr;

typedef struct CableBoxMap_s {
    struct CableBoxMap_s *next;
    char *BoxType;
    char AorB;
} CABLEBOXMAP;

CABLEBOXMAP *CableBoxMap, *CableBoxUnMap, *CableBoxMapPtr;
CABLEBOXMAP *OrganizationMap, *OrganizationUnMap, *OrganizationMapPtr;

#ifdef CBA_VERSION
// Interesting C-B-A state changes.

typedef struct StateChanges_s {
    struct StateChanges_s *next;
    char *StateChange;
} STATECHANGES;

STATECHANGES *StateChangeList, *StateChange;
#endif

// Prototypes.
// Routines dispatched to from VB.

void DoBASCommand( char *buffer);
void SendReply( char *Reply);

void Ping( void);
void GetCurrentWeek( void);
void ProcessCSGFile( void);
void ProcessICOMMSFile( void);
void ProcessOCVFile( void);
void DoneProcessing( void);

void LoadDataString( void);
void LoadDataValue( void);
void LoadStateMap( void);
void LoadStateTransition( void);
void LoadInternalState( void);
void LoadCableBoxMap( void);

void ReadDBFromDisk( void);
void FindEarliestDate( void);
void WriteIndexFile( void);
void WriteJBoxList( void);

void ProcessWatchFile( short flag);
void ProcessManagedFile( void);
void WriteManagedFile( void);
void WriteProductionFile( void);
void WriteModelCountFile( void);

void ProcessWorkOrderFile( void);
void ProcessDefEqFile( void);

void DoesCableBoxExist( void);
void ResetDays( void);
void ResetCounts( void);
void SelectiveReset( void);
void ProcessRVFile( void);
void WriteDBToDisk( void);
void DiscardDBChanges( void);
void ClearDatabase( void);

void ExitEngine( void);

// Local subroutines.

long ReadDatabaseFromDisk( char DataValue);
void WriteDatabaseToDisk( void);
long OpenInputFile( void);
FILE *OpenOutputFile( char *TailStg);
FILE *OpenIndexFile( char *TailStg, char *IDStg, short FileCount);
void AddBoxToJList( void);
void OpenWatchFile( void);
long DoCSGWork( char *Line);
long DoICOMMSWork( char *Line);
long DoOCVWork( char *Line);
void DeleteDatabaseFile( char *Template);

char *OCVGetState( void);
char *OCVGetStateTime( void);
char *OCVGetLocation( char *TmpStg);
long OCVGetAmount( void);

void WriteWLDataToDisk( void);
long ReadWLDataFromDisk( char DataValue);
FILE *OpenWatchOutputFile( char *OutputFileName, short type);
time_t GetDateOfState( void);

void WriteMWDataToDisk( void);
long ReadMWDataFromDisk( char DataValue);
void AppendModelCountData( char *Week);
void BuildInitialModelCountData( void);
char *BuildSiteAndModel( char *Key, short IncludeModel);

void WriteCVDataToDisk( void);
long ReadCVDataFromDisk( char DataValue);

#ifdef CAPEQ_VERSION
void WriteWODataToDisk( void);
long ReadWODataFromDisk( char DataValue);
void WriteDEDataToDisk( void);
long ReadDEDataFromDisk( char DataValue);
char *FindDescription( char *Stg, PROBCODE *Root);
#endif
char *NextString( char **spptr);

void SetWatchData( short flag);
void ReadDropModelFile( void);
long MatchDropModel( char *ModelNo);

char *BuildFileDate( char *DateStr, char *MDYDateStr);
void ReadCableBoxRecord( void);
long CalculateOnState( void);
void UpdateCableBoxRecord( void);
long FindCableBoxMap( void);
void CloseAllFiles( void);
time_t GetMDYAsTimet( void);
time_t ConvertMDYToTimet( char *DateString);
char *ConvertTimetToMDY( time_t Datet, char *DateString);
char *ConvertTimetToWeek( time_t Datet, char *DateString);
char *ConvertWeekToDate( char *WeekString, char *DateString);
char *ConvertTimetToMDYHMS( time_t Datet, char *DateString);
char *ConvertTimetToYYYYMMDD( time_t Datet, char *DateString);
void GetStateTransition( char CurrentState, char NewState);
long LoadStateMapFile( void);
char ConvertState( void);
char *GetFullStateName( char StateAbbrev);
void CheckDate( void);
void SetRVRepair( time_t Dateval);
void WriteResetReport();
void WatchListRollback( char *CableBoxSerial);
long RollBackCableBox( void);
void ProcessModelData( void);
void AppendModelData( char Key, time_t DateOfState);
void SetModelFileName( void);
void GetModelWeek( void);
void SaveModelWeek( void);
long ReadAndProcessCSVLine( char *InLine, FILE *FPtr);
long SplitOnTabs( char *line);
void SplitOnTabsIntoArray( char *line, char **flds);
char *Trunc( char *lptr, long size);

//   char *Trim( char *lptr);               //@@ not called
//   long CountFileLines( char *FileName);

long btinit( void);
long wlbtinit( void);
long pmbtinit( void);
long btreestore( NODE *nptr);
long btreestorep( CTNODE *nptr);
NODE *btreefind( char *key);
CTNODE *btreefindp( char *key);
MWNODE *btreefindpn( char *key);
NODE *btfirstnode( void);
NODE *btnextnode( void);
char *mydbmalloc( long size);
void mydbfree( void);
char *mywlmalloc( long size);
void mywlfree( void);
char *mystgmalloc( long size);
char *mypermmalloc( long size);
void AppendErrorMessage( char *mptr, char *data1, long val1);
void ErrorWatchData( short flag, long PercentInHouse, long AvgDaysInHouse, short DaysInState);
#if DEBUGWKCHK
void CheckWeek( char *Week);
#endif
#if DEBUGWCOUNT
void CountWLRecords( void);
#endif


void main( long argc, char *argv[])
{
    WSADATA Data;
    SOCKADDR_IN recvSockAddr;
    long status, numrecv;
    char buffer[MAXBUFLEN], *sptr, *nptr;

    // Minimize ourselves.

    ShowWindow( GetForegroundWindow(), SW_SHOWMINIMIZED);

    // Tell the user what special features are in this version.

#ifdef VER64
#ifdef CAPEQ_VERSION
    printf( "CP64 - 64-bit, CAPITAL EQUIPMENT, VERSION\n");
#else
    printf( "CET64 - 64-bit VERSION\n");
#endif
#else
#ifdef CAPEQ_VERSION
    printf( "CP32 - 32-bit, CAPITAL EQUIPMENT, VERSION\n");
#else
    printf( "CET32 - 32-bit VERSION\n");
#endif
#endif

#ifdef REPAIR_VERSION
    printf( "REPAIR/ROLLBACK FILE VERSION\n");
#endif
    printf( "OCV VERSION\n");

    // Open the socket.

    status = WSAStartup( MAKEWORD( 1, 1), &Data);
    if (status) exit( -1);

    memset( &recvSockAddr, 0, sizeof( recvSockAddr));

    recvSockAddr.sin_port = htons( PORT);
    recvSockAddr.sin_family = AF_INET;
    recvSockAddr.sin_addr.s_addr = htonl( INADDR_ANY);

    recvSocket = socket( AF_INET, SOCK_STREAM, 0); // SOCK_DGRAM, 0);
    if (recvSocket == INVALID_SOCKET) exit( -2);

    status = bind( recvSocket, (LPSOCKADDR) &recvSockAddr, sizeof( recvSockAddr));
    if (status == SOCKET_ERROR) exit( -3);

    status = listen( recvSocket, 1);
    recvSocket = accept( recvSocket, (LPSOCKADDR) &recvSockAddr, NULL);

    // Loop forever receiving messages from the socket and acting on them.

    while (1) {
        numrecv = recv( recvSocket, buffer, MAXBUFLEN, 0);
        if (numrecv == SOCKET_ERROR) break;

        *(buffer + numrecv) = '\0';
        *(buffer + numrecv + 1) = '\0';

        // More than one message may arrive, so separate them with a null
        // and execute each one.

        for (sptr = buffer; *sptr; ++sptr) if (*sptr == '$') *sptr = '\0';

        sptr = nptr = buffer + 1;
        while (*(sptr)) {
            while (*nptr++);
            DoBASCommand( sptr);
            sptr = nptr;
        }
    }

    // Control should never get here, but in case it does...

    status = closesocket( recvSocket);
    status = WSACleanup();
    exit( 0);
}


/*
 * DOBASCOMMAND - Perform the command received over the socket from VB.
 */
void DoBASCommand( char *buffer)
{
    if (!buffer) return;
    printf( "%s\n", buffer);
#if DEBUGMSGS
    if (strncmp( buffer, "Load", 4)) AppendErrorMessage( "%s\n", buffer, 0);
#endif
    SplitOnTabsIntoArray( buffer, (char **) &Flds);

    if      (!strcmp( Flds[0], "LoadDataString"))      LoadDataString();
    else if (!strcmp( Flds[0], "LoadDataValue"))       LoadDataValue();
    else if (!strcmp( Flds[0], "LoadStateMap"))        LoadStateMap();
    else if (!strcmp( Flds[0], "LoadStateTransition")) LoadStateTransition();
    else if (!strcmp( Flds[0], "LoadInternalState"))   LoadInternalState();
    else if (!strcmp( Flds[0], "LoadCableBoxMap"))     LoadCableBoxMap();

    else if (!strcmp( Flds[0], "ProcessCSGFile"))      ProcessCSGFile();
    else if (!strcmp( Flds[0], "ProcessICOMMSFile"))   ProcessICOMMSFile();
    else if (!strcmp( Flds[0], "ProcessOCVFile"))      ProcessOCVFile();
    else if (!strcmp( Flds[0], "DoneProcessing"))      DoneProcessing();

    else if (!strcmp( Flds[0], "ProcessWatchFile"))    ProcessWatchFile( 1);
    else if (!strcmp( Flds[0], "ProcessManagedFile"))  ProcessManagedFile();
    else if (!strcmp( Flds[0], "WriteManagedList"))    WriteManagedFile();
    else if (!strcmp( Flds[0], "WriteProductionList")) WriteProductionFile();
    else if (!strcmp( Flds[0], "WriteModelCounts"))    WriteModelCountFile();

    else if (!strcmp( Flds[0], "ProcessWorkOrderFile")) ProcessWorkOrderFile();
    else if (!strcmp( Flds[0], "ProcessDefEqFile"))    ProcessDefEqFile();

    else if (!strcmp( Flds[0], "DoesCableBoxExist"))   DoesCableBoxExist();
    else if (!strcmp( Flds[0], "ResetDays"))           ResetDays();
    else if (!strcmp( Flds[0], "ResetCounts"))         ResetCounts();
    else if (!strcmp( Flds[0], "SelectiveReset"))      SelectiveReset();
    else if (!strcmp( Flds[0], "ProcessRVFile"))       ProcessRVFile();
    else if (!strcmp( Flds[0], "WriteDBToDisk"))       WriteDBToDisk();
    else if (!strcmp( Flds[0], "DiscardDBChanges"))    DiscardDBChanges();
    else if (!strcmp( Flds[0], "ClearDatabase"))       ClearDatabase();

    else if (!strcmp( Flds[0], "ReadDBFromDisk"))      ReadDBFromDisk();
    else if (!strcmp( Flds[0], "FindEarliestDate"))    FindEarliestDate();
    else if (!strcmp( Flds[0], "WriteIndexFile"))      WriteIndexFile();
    else if (!strcmp( Flds[0], "WriteJBoxList"))       WriteJBoxList();

    else if (!strcmp( Flds[0], "Ping"))                Ping();
    else if (!strcmp( Flds[0], "GetCurrentWeek"))      GetCurrentWeek();
    else if (!strcmp( Flds[0], "ExitEngine"))          ExitEngine();
}


/*
 * SENDREPLY - Send the given reply back to VB (usually indicating "done").
 * Write it to MSDOS, save it in the "error" file, and send it to VB.
 */
void SendReply( char *Reply)
{
    printf( "    %s\n", Reply);
#if DEBUGMSGS
    AppendErrorMessage( "    %s\n", Reply, 0);
#endif
    send( recvSocket, Reply, strlen( Reply), 0);
}


/*
 * PING - Just send a reply back to tell the caller all is well.
 */
void Ping( void)
{
    SendReply( "$Ping\t1\t");
}


/*
 * GETCURRENTWEEK - Send back the current week string, or "-" if it
 * has not been set.
 */
void GetCurrentWeek( void)
{
    char Reply[50];

    if (!*CurrentWeek) SendReply( "$GetCurrentWeek\t-\t");
    else {
        sprintf( Reply, "$GetCurrentWeek\t%s\t", CurrentWeek);
        SendReply( Reply);
    }
}


/*
 * EXITENGINE - Close the socket and exit the program.
 */
void ExitEngine( void)
{
    long status;

    status = closesocket( recvSocket);
    status = WSACleanup();
    exit( 0);
}


/*
 * PROCESSCSGFILE - Open, read, and process the given CSG file.
 * This assumes that the cable box database has already been read in.
 * Returns 0 on success, != 0 for error.
 */
void ProcessCSGFile( void)
{
    long ret;
    char FileText[300], Reply[100], DOS[11];

    // -1 == open failure; >0 == (wrong) number of columns read
    // Read the list of models to be dropped, if there is one.

    ReadDropModelFile();
    RecordsDropped = 0;
    DoingCSG = 1;
    time( &DateOfNow);

    // Read the watch data, if desired.

    if (WriteWatchFile) {
        bxtreeroot = treeroot;
        treeroot = (NODE *) wltreeroot;
        ReadWLDataFromDisk( DatabaseMode);
        treeroot = bxtreeroot;
    }

    ofhdl = NULL;
    if ((ret = OpenInputFile()) != 0) goto Done;

    // Read and process each line of the file.

    RecordCount = 0;
    while (ReadAndProcessCSVLine( FileText, ifhdl)) {
        if ((ret = DoCSGWork( FileText)) < 0) {
            if (ret != -2) goto Done0;
            fclose( ifhdl);
            sprintf( Reply, "$ProcessCSGFile\t-2\t%d\t%s\t%s\t%s\t",
                RecordCount, Flds[CSG_SERIAL], Flds[CSG_STATEDATE],
                ConvertTimetToMDY( curnode->DateOfState, DOS));
            goto Done1;
        }

        // Every so often send status to VB.

        if (!(++RecordCount % 25000)) {
            sprintf( Reply, "$Status\t%d\t", RecordCount);
            SendReply( Reply);
        }
    }
    ret = 0;

Done0:
    fclose( ifhdl);
    if (ofhdl) fclose( ofhdl);
Done:
    sprintf( Reply, "$ProcessCSGFile\t%d\t", ret);
Done1:
    if (RecordsDropped > 0) printf( "Records dropped: %d\n", RecordsDropped);
    DiscardRecent = (time_t) 0;
    if (BoxResetRoot) WriteResetReport();

    AppendErrorMessage( "Checking watch at end\n", "", 0);
    if (WriteWatchFile) SetWatchData( 1);
    SendReply( Reply);
}


/*
 * PROCESSICOMMSFILE - Open, read, and process the given ICOMMS file.
 * This assumes that the cable box database has already been read in.
 * Returns 0 on success, != 0 for error.
 */
void ProcessICOMMSFile( void)
{
    long ret;
    char FileText[300], Reply[100], DOS[11];

    // Read the list of models to be dropped, if there is one.

    ReadDropModelFile();
    DoingCSG = (short) RecordsDropped = 0;
    time( &DateOfNow);

    // Read the watch data.

    if (WriteWatchFile) {
        bxtreeroot = treeroot;
        treeroot = (NODE *) wltreeroot;
        ReadWLDataFromDisk( DatabaseMode);
        treeroot = bxtreeroot;
    }

    ofhdl = NULL;
    if ((ret = OpenInputFile()) != 0) goto Done;

    // Read and process each line of the file.

    RecordCount = 0;
    while (ReadAndProcessCSVLine( FileText, ifhdl)) {
        if ((ret = DoICOMMSWork( FileText)) < 0) {
//@@        if (ret != -2) goto Done0;
            fclose( ifhdl);
            if (ofhdl) fclose( ofhdl);
            sprintf( Reply, "$ProcessICOMMSFile\t%d\t%d\t%s\t%s\t%s\t",
                ret, RecordCount, Flds[ICM_SERIAL], Flds[ICM_STATEDATE],
                ConvertTimetToMDY( curnode->DateOfState, DOS));
            goto Done1;
        }

        // Every so often send status to VB.

        if (!(++RecordCount % 25000)) {
            sprintf( Reply, "$Status\t%d\t", RecordCount);
            SendReply( Reply);
        }
    }
    ret = 0;
    AppendErrorMessage( "All records processed\n", "", 0);

Done0:
    fclose( ifhdl);
    if (ofhdl) fclose( ofhdl);
Done:
    sprintf( Reply, "$ProcessICOMMSFile\t%d\t", ret);
Done1:
    if (RecordsDropped > 0) printf( "Records dropped: %d\n", RecordsDropped);
    DiscardRecent = (time_t) 0;
    if (BoxResetRoot) WriteResetReport();

    AppendErrorMessage( "Checking watch at end\n", "", 0);
    if (WriteWatchFile) SetWatchData( 1);
    SendReply( Reply);
}


/*
 * PROCESSOCVFILE - Open, read, and process the given OCV file.
 * This assumes that the cable box database has already been read in.
 * Returns 0 on success, != 0 for error.
 */
void ProcessOCVFile( void)
{
    long ret;
    char FileText[801], Reply[100], DOS[11];

    // Read the Cablevision-specific data.

    bxtreeroot = treeroot;
    treeroot = (NODE *) cvtreeroot;
    if (ReadCVDataFromDisk( DatabaseMode) == -1) goto Done;
    cvtreeroot = (CVNODE *) treeroot;

    // Read the watch data.

    if (WriteWatchFile) {
        treeroot = (NODE *) wltreeroot;
        ReadWLDataFromDisk( DatabaseMode);
        treeroot = bxtreeroot;
    }

    // Read the list of models to be dropped, if there is one.

    ReadDropModelFile();
    RecordsDropped = 0;
    DoingCSG = 2;
    time( &DateOfNow);

    ofhdl = NULL;
    if ((ret = OpenInputFile()) != 0) goto Done;

    // Read and process each line of the file.

    RecordCount = 0;
    GetModelWeek();
    while (ReadAndProcessCSVLine( FileText, ifhdl)) {
        if ((ret = DoOCVWork( FileText)) < 0) {
            if (ret != -2) goto Done0;
            fclose( ifhdl);
            sprintf( Reply, "$ProcessOCVFile\t-2\t%d\t%s\t%s\t%s\t",
                RecordCount, Flds[OCV_SERIAL_NUMBER], Flds[OCV_BEGIN_DATE],
                ConvertTimetToMDY( curnode->DateOfState, DOS));
            goto Done1;
        }

        // Every so often send status to VB.

        if (!(++RecordCount % 25000)) {
            sprintf( Reply, "$Status\t%d\t", RecordCount);
            SendReply( Reply);
        }
    }
    ret = 0;

Done0:
    fclose( ifhdl);
    if (ofhdl) fclose( ofhdl);
    SaveModelWeek();
Done:
    sprintf( Reply, "$ProcessOCVFile\t%d\t", ret);
Done1:
    if (RecordsDropped > 0) printf( "Records dropped: %d\n", RecordsDropped);
    DiscardRecent = (time_t) 0;
    if (BoxResetRoot) WriteResetReport();

    AppendErrorMessage( "Checking watch at end\n", "", 0);
    if (WriteWatchFile) SetWatchData( 1);
    SendReply( Reply);
}


/*
 * OPENINPUTFILE - Open the input file. Skip the header if there is one.
 * Returns 0 on success, -1 on file open failure,
 * <# columns seen> if the number of columns is wrong.
 */
long OpenInputFile( void)
{
    char FileName[300], FileText[701], *sptr, *dptr, chr;
    long FieldCount;

    // Extract the site ID, if there is one, and the date, from the filename.

    sptr = Flds[1] + 2;
    dptr = FilenameSiteID;
    while ((chr = *sptr++) && (chr != '-'));
    if (chr) {
        while ((chr = *sptr++) && ((*dptr++ = chr) != '-'));
    }

    if (!chr) sptr = dptr = FilenameSiteID;
    strncpy( FilenameDate, sptr, 8);
    *(FilenameDate + 8) = *dptr = '\0';

    // Prepend the path. The Universal file already has it.

    if (DoingUniversal) strcpy( FileName, Flds[1]);
    else                sprintf( FileName, "%s%s", InboundDir, Flds[1]);

    // Open the file and read the first line.
    // Make sure the file has the correct number of columns.

    if (!(ifhdl = fopen( FileName, "r"))) return -1;
    ReadAndProcessCSVLine( FileText, ifhdl);
    FieldCount = SplitOnTabs( FileText);
    if (((DoingCSG == 1) && (FieldCount != CSG_FIELDSMAX)) ||
        ((DoingCSG == 0) && (FieldCount != ICM_FIELDSMIN)) ||
        ((DoingCSG == 2) && (FieldCount != OCV_FIELDSMAX))) {
            fclose( ifhdl);
            return FieldCount;
    }

    // If the first line is the header, skip it.
    // It's a header if the either the state date or the end date (CSG, OCV)
    // state time (ICOMMS) contain alphabetic characters.

    sprintf( FileText, "%s%s", Flds[CSG_STATEDATE], Flds[CSG_ENDDATE]);
    sptr = FileText;
    while (chr = *sptr++)
        if (((chr >= 'A') && (chr <= 'Z')) ||
            ((chr >= 'a') && (chr <= 'z'))) break;

    if (!chr) {
        fclose( ifhdl);
        ifhdl = fopen( FileName, "r");
    }
    return 0;
}


/*
 * OPENOUTPUTFILE - Open the output file and write the header line.
 * The open file handle is the global ofhdl. Someone else must close it.
 */
FILE *OpenOutputFile( char *TailStg)
{
    char OutputFileName[200], *sptr;

    // Create the path if it does not already exist.

    if (*TailStg) {
        sprintf( OutputFileName, "%s%s", OutputDir, TailStg);
        sptr = OutputFileName + strlen( OutputFileName) - 3;
        *sptr = '\0';
        CreateDirectory( OutputFileName, NULL);
        *sptr = '\\';
        CreateDirectory( OutputFileName, NULL);
    }

    // Open the transaction file and write the header.

    sprintf( OutputFileName, "%s%sTRANS_INPUT-[%s%s].csv",
        OutputDir, TailStg, FilenameSiteID, FilenameDate);

    if (!(ofhdl = fopen( OutputFileName, "w"))) return (FILE *) NULL;

    // Output the header.

#if 0 //@@ #ifdef _DEBUG
    fprintf( ofhdl,
        "LINE NUM,TAG (col N),DATE OF STATE,DAYS IN STATE,SIH,ext Prev-Cur,"
        "int Prev-Cur,PREV MODEL,CUR MODEL,NOTE\n");
#else
    if (DoingCSG != 2) {
        fprintf( ofhdl,
            "REGION LABEL,REGION CODE,DIVISION LABEL,DIVISION CODE,"
            "SERIAL NUMBER,EQUIPMENT TYPE,MODEL CODE,MODEL TYPE CODE,"
            "PREVIOUS STATUS CODE,RECEIPT DATE,NEW STATUS CODE,"
            "NEW STATUS DATE,END DATE,LOCATION,TRAN REASON,OPERATOR ID,"
            "STATUS TIME,ITEM TYPE,UNDEF FIELD 12,RETURN REASON DESC,SITE ID,"
            "STATUS DESC,TECH TYPE,TECH TYPE DESC,RETURN REASON,ITEM NUMBER,"
            "ADDRESS,ADDRESS 2,DAYS BETWEEN STATUS,STATUS OUT OF SEQUENCE,"
            "ERROR DOCUMENTATION,LOCATOR CODE,ZIP CODE,ITEM DESCRIPTION,"
            "OLD EXTERNAL STATUS,NEW EXTERNAL STATUS");

        if (ShortInHouseFlag) fprintf( ofhdl, ",SHORT IN HOUSE FLAG");

        if (AddFiveFields) fprintf( ofhdl,
            ",CURRENT LOCATION,EXTRA1,EXTRA2,EXTRA3,EXTRA4,EXTRA5");
    }
    else {
#if 1 //@@
        fprintf( ofhdl, "TM_MATERIAL_TRANS_ID,MTL_ITEM_ID,SERIAL_NUMBER_ID,"
            "SERIAL_NUMBER,PURCHASED_DATE,INVENTORY_ITEM_ID,ITEM,BOX_TYPE,"
            "BEGIN_DATE,END_DATE,DAYS_IN_STATUS,BOX_ADD_METHOD,"
            "BOX_RETURN_METHOD,NFM_MATERIAL_TRANS_ID,SUB_INVENTORY_CODE,"
            "LOCATOR,ORGANIZATION_CODE,ORG_ACRONYM,PREV_SUB_INVENTORY_CODE,"
            "PREV_LOCATOR,PREV_ORGANIZATION_CODE,PREV_ORG_ACRONYM,CORP,HOUSE,"
            "CUST,TC_SWAP_FLAG,TC_BOX_SWAP_FIX_CD_FLAG,TC_WFINDATE,TC_TECH,"
            "TC_INHOUSE_CONT_FLAG,TC_FIX_CODE_STR,RPR_WARRANTY_REPAIR_CODE,"
            "RPR_WARRANTY_DESCR,RPR_SCRAPPED_FLAG,REPAIR_AMT,RPR_PART_NBR_STR,"
            "RPR_PART_DESCR_STR,DAYS BETWEEN STATUS,SHORT IN HOUSE FLAG,"
            "TIME_OF_STATE,CUR_EXT_STATE,PREV_EXT_STATE,CUR_INT_STATE,"
            "PREV_INT_STATE");
#else
        fprintf( ofhdl, ",BOX_ADD_METHOD,BOX_RETURN_METHOD,LOCATOR,"
            "PREV_SUB_INVENTORY_CODE,PREV_ORGANIZATION_CODE,"
            "PREV_ORG_ACRONYM,TC_BOX_SWAP_FIX_CD_FLAG,TC_WFINDATE,TC_TECH,"
            "TC_INHOUSE_CONT_FLAG,TC_FIX_CODE_STR,RPR_WARRANTY_DESCR,"
            "RPR_PART_NBR_STR,RPR_PART_DESCR_STR,ORGANIZATION_CODE");
#endif
    }
    fprintf( ofhdl, "\n");
#endif
    return ofhdl;
}


/*
 * OPENINDEXFILE - Open the index file and write the header line.
 * The open file handle is the global ofhdl. Someone else must close it.
 */
FILE *OpenIndexFile( char *TailStg, char *IDStg, short FileCount)
{
    char OutputFileName[200], *sptr, *ODptr;
    FILE *ofhdl;

    // Create the path if it does not already exist.

    ODptr = OutputDir;
    if (*TailStg) {
        if (!strcmp( TailStg, "WLM_")) {
            if (AlternateDir && *AlternateDir) ODptr = AlternateDir;
        }
        else {
            sprintf( OutputFileName, "%s%s", OutputDir, TailStg);
            sptr = OutputFileName + strlen( OutputFileName) - 3;
            *sptr = '\0';
            CreateDirectory( OutputFileName, NULL);
            *sptr = '\\';
            CreateDirectory( OutputFileName, NULL);
        }
    }

    // Open the index file and write the header.

    if (FileCount <= 1)
        sprintf( OutputFileName, "%s%sINDEX_INPUT-[%s].csv",
            ODptr, TailStg, IDStg);
    else
        sprintf( OutputFileName, "%s%sINDEX_INPUT-[%s-%d].csv",
            ODptr, TailStg, IDStg, FileCount);

    if (!(ofhdl = fopen( OutputFileName, "w"))) return (FILE *) NULL;

    // Output the header.

    fprintf( ofhdl,
        "DIVISION,MAKE,MODEL,SERIAL NUMBER,DAYS UNKNOWN RESET,"
        "DAYS HOUSE RESET,DAYS RETURN RESET,DAYS REPAIR RESET,"
        "CAP DATE,DAYS TECH RESET,DAYS UNKNOWN PERM,"
        "DAYS HOUSE PERM,DAYS RETURN,DAYS REPAIR PERM,DAYS OTHER PERM,"
        "DAYS TECH PERM,TO HOUSE RESET,TO RETURN RESET,TO REPAIR RESET,"
        "DAYS SERVICE,TO TECH RESET,TO HOUSE PERM,TO RETURN PERM,"
        "TO REPAIR PERM,TO OTHER PERM,TO TECH PERM,SHORT IN HOUSE,"
        "PERCENT IN HOUSE,AVG DAYS IN HOUSE,ILLEGAL TRANSITIONS,"
        "TOTAL DAYS,CURRENT STATE,DAYS IN STATE,BAS IDENTIFIER,"
#ifdef CBA_VERSION
        "LOCATION,ADDRESS,ADDRESS2,DATE OF STATE,STATE B,"
        "DATE OF STATE B,LOCATION B,STATE C,DATE OF STATE C,LOCATION C,"
        "DAYS C TO NOW,DAYS B TO NOW,C TO B TO A,B TO A,"
        "DATECBAFLAG,TIMESCBAFLAG");

#else
        "LOCATION,ADDRESS,ADDRESS2,DATE OF STATE");
#endif

    if (AddFiveFields)
        fprintf( ofhdl, ",EXTRA1,EXTRA2,EXTRA3,EXTRA4,EXTRA5");

#ifdef CAPEQ_VERSION
    if (!cvtreeroot || !cvtreeroot->rlink) {
        fprintf( ofhdl,
            ",COMPLETIONDATEPREV,COMPLETIONDATECUR,DATEENTERED,PROBLEMDESCPREV,"
            "PROBLEMDESCCUR,FINDINGDESCPREV,FINDINGDESCCUR,SOLUTIONDESCPREV,"
            "SOLUTIONDESCCUR,INSTALLERPREV,INSTALLERCUR,WORKORDERNOPREV,"
            "WORKORDERNOCUR,WOTYPE,WOCLASS,WOSTATUS,QCODE,BILLTYPECODE,"
            "CHECKINDATEPREV,CHECKINDATECUR,DISCONNECTDESC,ITEMNUMBER,SITEID,"
            "SUBMITTER,SALESNO,MODEL,PROBLEMPREV,PROBLEMCUR,DETAILS,"
            "DIAGNOSISPREV,DIAGNOSISCUR,SOLUTION,RESOLVER,RESOLVEDDATE,"
            "CREATEDDATE,TCOO,SITEIDC,SITEIDB,SITEIDA,MTBOF,CAPPCREM,TIMESTC,"
            "DAYSBETWEENTC,AVGDAYSBETWEENTC,DAYSBTWNDETRECS,TIMESINDETSYSTEM,"
            "AVGDAYSBTWNDETDISC");
    }
#endif

//@@        ",TCOO,SITEIDC,SITEIDB,SITEIDA,MTBOF,CAPPCREM,CURBOXADDMETHOD,"

    if (cvtreeroot && cvtreeroot->rlink) {
        fprintf( ofhdl,
            ",TCOO,SITEIDC,SITEIDB,SITEIDA,MTBOF,CAPPCREM,CURBOXADDMETHOD,"
            "PREVBOXADDMETHOD,CURBOXRETURNMETHOD,PREVBOXRETURNMETHOD,"
            "LOCATOR,PREVSUBINVENTORYCODE,PREVORGANIZATIONCODE,PREVORGACRONYM,"
            "TCSWAPFLAGCT,CDFLAGCCOUNT,CDFLAGICOUNT,TCWFINDATE,TCWFINDATEAVG,"
            "TCTECH,TCINHOUSECONTFLAG,TCFIXCODESTR,RPRWARRANTYNWCT,"
            "RPRWARRANTYNWAMT,RPRWARRANTYWXCT,RPRWARRANTYWXAMT,RPRWARRANTYFWCT,"
            "RPRWARRANTYFWAMT,RPRWARRANTYURCT,RPRWARRANTYURAMT,RPRWARRANTYFSCT,"
            "RPRWARRANTYFSAMT,RPRWARRANTYOTCT,RPRWARRANTYOTAMT,RPRSCRAPPEDFLAG,"
            "RPRTOTALCHARGE,RPRAVERAGECHARGE,RPRPARTNBRSTR,RPRPARTDESCR,"
            "LOCMDSLNKCOUNT,LOCMDSLNKDAYS,ORGANIZATIONCODE,ORGACRONYM");
    }

    fprintf( ofhdl, "\n");
    return ofhdl;
}


/*
 * ADDBOXTOJLIST - Add the current box to the J state list.
 */
void AddBoxToJList( void)
{
    JStatePtr = (JSTATEBOXES *) mypermmalloc( sizeof( JSTATEBOXES));
    JStatePtr->CableBox = curnode;
    JStatePtr->next = JStateList;
    JStateList = JStatePtr;
}


/*
 * WRITEJBOXLIST - If any boxes have moved to the external J state, report them.
 */
void WriteJBoxList( void)
{
    char FileDate[16];

    // If no report is wanted or there are no such boxes, just finish.

    if (!JFileDir || !JStateList) goto Done;
    BuildFileDate( FileDate, NULL);
//@@FileDate[8] = '\0';

    // Open the report file and write the header.

    sprintf( fStrings, "%sICOMS_INBOUND-%s.csv", JFileDir, FileDate);
    if (!(ofhdl = fopen( fStrings, "w"))) return;
//@@fprintf( ofhdl, "SERIAL NUMBER,CODE,DATE\n");

    // Output the information for each box.

    for (JStatePtr = JStateList; JStatePtr; JStatePtr = JStatePtr->next) {
        curnode = JStatePtr->CableBox;
        fprintf( ofhdl, "\"%s\",\"S\",\"%s\"\n", curnode->CableBoxSerial,
            ConvertTimetToYYYYMMDD( curnode->DateOfState, FileDate));
    }

    fclose( ofhdl);
    JStateList = (JSTATEBOXES *) NULL;
Done:
    SendReply( "$WriteJBoxList\t1\t");
}


/*
 * OPENWATCHFILE - Open the watch file and write the header line.
 * The open file handle is the global ofhdl. Someone else must close it.
 */
void OpenWatchFile( void)
{
    char FileDate[16];

    // Open the watch file and write the header.

    BuildFileDate( FileDate, NULL);
    FileDate[8] = '\0';

    sprintf( fStrings, "%sWATCH-%s.csv", InboundDir, FileDate);
    if (!(wfhdl = fopen( fStrings, "w"))) return;
    Flds[1] = fStrings;

    // Output the header.

#if 1 //@@ #ifdef _DEBUG
    fprintf( wfhdl, "SERIAL NUMBER,ShortInHouse,PercentInHouse,AvgDaysInHouse\n");
#else
    fprintf( wfhdl, "SERIAL NUMBER\n");
#endif
}


/*
 * PROCESSWATCHFILE - Open, read, and process the given watch list file.
 * The path/name of the file is in Flds[1].
 * Call with flag == 1 to send a reply to VB, else remain silent.
 * Returns 0 on success, != 0 for error.
 */
void ProcessWatchFile( short flag)
{
    short ret;
    char FileText[300];
    short Action;
    time_t DateOfState;

    // Open the file.

    ret = -1;
    RecordCount = 0;
    if (!(ifhdl = fopen( Flds[1], "r"))) goto Done;

    // Make sure the cable box database has been read.
    // Set aside the cable box tree and point to the watch list tree.

    ReadDatabaseFromDisk( DatabaseMode);
    bxtreeroot = treeroot;
    treeroot = (NODE *) wltreeroot;
    if (ReadWLDataFromDisk( DatabaseMode) == -1) goto Done0;

    // Read the first line. If a header, skip it, else jump to process it.

    ReadAndProcessCSVLine( FileText, ifhdl);
    if (!strstr( FileText, "erial") && !strstr( FileText, "ERIAL")) goto NoHead;

    // Read and process each line of the file.

    while (ReadAndProcessCSVLine( FileText, ifhdl)) {
NoHead:
        if (SplitOnTabs( FileText) != 2) Flds[WL_ACTION] = "U";

        switch (toupper( *Flds[WL_ACTION])) {
            case 'R': Action = 1; break;    // Return
            case 'D': Action = 2; break;    // Disable
            case 'S': Action = 3; break;    // Scrap (?)
            case 'I': Action = 4; break;    // Ignore
            default:  Action = 5;           // Unknown
        }

        // If the entry already exists, set various fields.

        if (wlcurnode = (WLNODE *) btreefind( Flds[WL_SERIAL])) {
            // If the entry is active, just bump times discovered.
            // If the action in Unknown, set it.
            // Otherwise make the entry active and set several fields.

            ++wlcurnode->TimesDiscovered;
            wlcurnode->Action = Action;

            if (wlcurnode->WatchFlag == WF_INACTIVE) {
                DateOfState = GetDateOfState();
                ++wlcurnode->TimesOnList;
                wlcurnode->DaysSincePrevious = (short)
                    ((DateOfState - wlcurnode->LatestDate) / SECSINADAY);
                wlcurnode->LatestDate = DateOfState;
                wlcurnode->WatchFlag = WF_ACTIVE; //@@ WF_MANUAL;
            }
        }

        // If the entry does not exist, create and populate it.

        else {
            if (!(wlcurnode = (WLNODE *) mywlmalloc( sizeof( WLNODE))))
                goto Done0;

            strcpy( wlcurnode->CableBoxSerial, Flds[WL_SERIAL]);
            btreestore( (NODE *) wlcurnode);

            wlcurnode->InitialDate =
            wlcurnode->LatestDate = GetDateOfState();
            wlcurnode->TimesOnList =
            wlcurnode->TimesDiscovered =
            wlcurnode->WatchFlag = WF_ACTIVE; //@@ WF_MANUAL;
            wlcurnode->DaysSincePrevious =
            wlcurnode->TimesRolledBack =
#ifdef REPAIR_VERSION
            wlcurnode->VCountNoProblem =
            wlcurnode->PVCountRepair =
            wlcurnode->RVCountRepair =
            wlcurnode->AvgDaysBtwnRepair =
#endif
            wlcurnode->RollbackReason = 0;
            wlcurnode->Action = Action;
#ifdef REPAIR_VERSION
            wlcurnode->VScrapDate =
            wlcurnode->LatestVRepairDate =
#endif
            wlcurnode->LatestRollback = (time_t) 0;
        }
        if (curnode) AppendModelData( 'W', wlcurnode->LatestDate);

        // Every so often send status to VB.

        ++RecordCount;
        if (flag && !(RecordCount % 10000)) {
            sprintf( FileText, "$Status\t%d\t", RecordCount);
            SendReply( FileText);
        }
    }
    WatchDataDirty = 1;
    ret = 0;

Done0:
    fclose( ifhdl);
Done:
    if (flag) {
        sprintf( FileText, "$ProcessWatchFile\t%d\t%d\t", ret, RecordCount);
        SendReply( FileText);
    }

    // Restore the cable box tree; done.

    wltreeroot = (WLNODE *) treeroot;
    treeroot = bxtreeroot;
}


/*
 * PROCESSMANAGEDFILE - Open, read, and process the given managed list file.
 * Discard the current watch data and replace it with the contents.
 * The path/name of the file is in Flds[1].
 * Returns 0 on success, != 0 for error.
 */
void ProcessManagedFile( void)
{
    short ret;
    char FileText[300];
    short Action;

    // Open the file.

    ReadDatabaseFromDisk( DatabaseMode);
    bxtreeroot = treeroot;
    treeroot = (NODE *) wltreeroot;
    ret = -1;
    RecordCount = 0;
    if (!(ifhdl = fopen( Flds[1], "r"))) goto Done;

    // Start a shiny new watch list tree.

    wlbtinit();

    // Read the first line. If a header, skip it, else jump to process it.

    ReadAndProcessCSVLine( FileText, ifhdl);
    if (!strstr( FileText, "erial") && !strstr( FileText, "ERIAL")) goto NoHead;

    // Read and process each line of the file.

    while (ReadAndProcessCSVLine( FileText, ifhdl)) {
NoHead:
        // Make sure there are 12 or 14 columns; else return error.

        ret = (short) SplitOnTabs( FileText);
        if ((ret != 12) || (ret != 14)) {
            ret = -2;
            WatchDataDirty = WLDatabaseMode = 0;
            goto Done0;
        }

        switch (toupper( *Flds[ML_ACTION])) {
            case 'R': Action = 1; break;    // Return
            case 'D': Action = 2; break;    // Disable
            case 'S': Action = 3; break;    // Scrap (?)
            case 'I': Action = 4; break;    // Ignore
            default:  Action = 5;           // Unknown
        }

        // The entry does not exist. Create and populate it.

        if (!(wlcurnode = (WLNODE *) mywlmalloc( sizeof( WLNODE))))
            goto Done0;

        strcpy( wlcurnode->CableBoxSerial, Flds[ML_SERIAL]);
        wlcurnode->InitialDate = ConvertMDYToTimet( Flds[ML_INITIALDATE]);
        wlcurnode->LatestDate = ConvertMDYToTimet( Flds[ML_LATESTDATE]);
        wlcurnode->TimesOnList = atoi( Flds[ML_TIMESONLIST]);
        wlcurnode->TimesDiscovered = atoi( Flds[ML_TIMESDISC]);
        wlcurnode->DaysSincePrevious = atoi( Flds[ML_DAYSSINCEPREV]);
        wlcurnode->WatchFlag = 1 - strcmp( Flds[ML_WATCHFLAG], "Yes");
        wlcurnode->Action = Action;
        wlcurnode->TimesRolledBack = atoi( Flds[ML_TIMESRBACK]);
        wlcurnode->LatestRollback = (*Flds[ML_LATESTRBACK] == '\0') ? 0 :
            ConvertMDYToTimet( Flds[ML_LATESTRBACK]);
        wlcurnode->RollbackReason = 0;
        if (ret == 13) wlcurnode->RollbackReason = atoi( Flds[ML_RBACKREASON]);

#ifdef REPAIR_VERSION
        wlcurnode->VCountNoProblem =
        wlcurnode->PVCountRepair =
        wlcurnode->RVCountRepair =
        wlcurnode->AvgDaysBtwnRepair = 0;
        wlcurnode->VScrapDate =
        wlcurnode->LatestVRepairDate = (time_t) 0;
#endif

        btreestore( (NODE *) wlcurnode);

        // Find the corresponding cable box record.
        // Append a model watch record to the file.

        wltreeroot = (WLNODE *) treeroot;
        treeroot = bxtreeroot;
        if (curnode = btreefind( wlcurnode->CableBoxSerial))
            AppendModelData( 'W', wlcurnode->LatestDate);
        bxtreeroot = treeroot;
        treeroot = (NODE *) wltreeroot;

        // Every so often send status to VB.

        if (!(++RecordCount % 10000)) {
            sprintf( FileText, "$Status\t%d\t", RecordCount);
            SendReply( FileText);
        }
    }
    WatchDataDirty = 1;
    WLDatabaseMode = '1';
    ret = 0;

Done0:
    fclose( ifhdl);
Done:
    sprintf( FileText, "$ProcessManagedFile\t%d\t%d\t", ret, RecordCount);
    SendReply( FileText);

    // Restore the cable box tree; done.

    wltreeroot = (WLNODE *) treeroot;
    treeroot = bxtreeroot;
}


/*
 * GETDATEOFSTATE - Set aside the watch data, get the transaction data,
 * and return the Date of State (or 0 if no transaction record).
 * Point back to the watch data before returning.
 */
time_t GetDateOfState( void)
{
    time_t DateOfState;

    // Set aside the watch list tree and point to the cable box tree.

    wltreeroot = (WLNODE *) treeroot;
    treeroot = bxtreeroot;

    // Look up the cable box. If not found, return 0.

    if (!(curnode = btreefind( wlcurnode->CableBoxSerial)))
         DateOfState = (time_t) 0;
    else DateOfState = curnode->DateOfState;

    // Restore the watch list tree.

    bxtreeroot = treeroot;
    treeroot = (NODE *) wltreeroot;
    return DateOfState;
}


/*
 * WRITEMANAGEDFILE - Write the managed watch list file to disk.
 */
void WriteManagedFile( void)
{
    char FileName1[100], FileName2[100], OutputLine[200], SiteIDModel[100];
    char IDateStg[16], LDateStg[16], RDateStg[16];
    char FileDate[16], MDYFileDate[11];
    short DaysSinceInitial, DaysSinceRollback, DaysOnWatch;
    time_t curtime;
    FILE *dofhdl;
    short retval;

    // Set aside the cable box tree and point to the watch list tree.
    // Read the watch data, if it has not already been done.

    ReadDatabaseFromDisk( DatabaseMode);

    retval = 1;
    dofhdl = (FILE *) NULL;
    bxtreeroot = treeroot;
    treeroot = (NODE *) wltreeroot;
    if (ReadWLDataFromDisk( DatabaseMode) != 1) goto Done;

    // Get the first watch list entry. If none, don't write the file.

    if (!(wlcurnode = (WLNODE *) btfirstnode())) goto Done;

    // There is data: open the output files and write the headers.

    retval = 0;
    BuildFileDate( FileDate, MDYFileDate);
    sprintf( FileName2, "%sR_MANAGED_INPUT-[%s].csv", OutputDir, BASIdentifier);

    if (!OpenWatchOutputFile( FileName2, 2)) goto Done;
    dofhdl = ofhdl;

    // Always write an old file to OutputDir.

    sprintf( FileName1, "%sMANAGED_INPUT-[%s].csv", OutputDir, BASIdentifier);
    if (!OpenWatchOutputFile( FileName1, 1)) goto Done;

    // Walk through the Watch List tree and output each record.

    retval = 1;
    curtime = GetMDYAsTimet();
    while (wlcurnode) {
        if (wlcurnode->WatchFlag == WF_DELETED) goto Next;
        DaysSinceInitial = (short)
            ((curtime - wlcurnode->InitialDate) / SECSINADAY);
        DaysSinceRollback = (!wlcurnode->LatestRollback) ? 0 :
            (short) ((curtime - wlcurnode->LatestRollback) / SECSINADAY);
        DaysOnWatch = (wlcurnode->WatchFlag == WF_INACTIVE) ? 0 :
            (short) ((curtime - wlcurnode->LatestDate) / SECSINADAY);

        if ((wlcurnode->RollbackReason < 0) ||
            (wlcurnode->RollbackReason > RBR_MAX))
                wlcurnode->RollbackReason = 0;

        // Find the model number for this box.

        wltreeroot = (WLNODE *) treeroot;
        treeroot = (NODE *) bxtreeroot;
        curnode = btreefind( wlcurnode->CableBoxSerial);
        treeroot = (NODE *) wltreeroot;
        if (!curnode) strcpy( SiteIDModel, "\"\",\"\"");
        else          BuildSiteAndModel( SiteIDModel, 1);

#if 1 //@@
        sprintf( OutputLine,
            "\"%s\",\"%s\",\"%s\",%d,%d,%d,%d,\"%s\",\"%c\",%d,\"%s\",%d,%d,%d",
            wlcurnode->CableBoxSerial,
            ConvertTimetToMDY( wlcurnode->InitialDate, IDateStg),
            ConvertTimetToMDY( wlcurnode->LatestDate, LDateStg),
            wlcurnode->TimesOnList,
            wlcurnode->TimesDiscovered,
            wlcurnode->DaysSincePrevious,
            DaysSinceInitial,
            (wlcurnode->WatchFlag ? "Yes" : "No"),
            ActionChar[wlcurnode->Action],
            wlcurnode->TimesRolledBack,
            (!wlcurnode->LatestRollback ? "" :
                ConvertTimetToMDY( wlcurnode->LatestRollback, RDateStg)),
            DaysSinceRollback,
            wlcurnode->RollbackReason,
            DaysOnWatch);
#else
        sprintf( OutputLine,
            "\"%s\",\"%s\",\"%s\",%d,%d,%d,%d,\"%s\",\"%c\",%d,\"%s\",%d,%d,%d,\"%s\"",
            wlcurnode->CableBoxSerial,
            ConvertTimetToMDY( wlcurnode->InitialDate, IDateStg),
            ConvertTimetToMDY( wlcurnode->LatestDate, LDateStg),
            wlcurnode->TimesOnList,
            wlcurnode->TimesDiscovered,
            wlcurnode->DaysSincePrevious,
            DaysSinceInitial,
            (wlcurnode->WatchFlag ? "Yes" : "No"),
            ActionChar[wlcurnode->Action],
            wlcurnode->TimesRolledBack,
            (!wlcurnode->LatestRollback ? "" :
                ConvertTimetToMDY( wlcurnode->LatestRollback, RDateStg)),
            DaysSinceRollback,
            wlcurnode->RollbackReason,
            DaysOnWatch,
            ((wlcurnode->WatchFlag == WF_MANUAL) ? "Yes" : "No"));
#endif

        fprintf( ofhdl, "%s\n", OutputLine);
        fprintf( dofhdl, "%s,%s,\"%s\"\n", OutputLine, SiteIDModel, MDYFileDate);
Next:   wlcurnode = (WLNODE *) btnextnode();
    }
    fclose( ofhdl);
    if (dofhdl) fclose( dofhdl);
    ofhdl = (FILE *) NULL;

    // If an alternate directory is defined, copy the files to it.

    if (strcmp( OutputDir, Flds[1])) {
        sprintf( OutputLine, "%sMANAGED_INPUT-[%s].csv",
            Flds[1], BASIdentifier);
        CopyFile( FileName1, OutputLine, FALSE);

        sprintf( OutputLine, "%sR_MANAGED_INPUT-[%s].csv", Flds[1], BASIdentifier);
        CopyFile( FileName2, OutputLine, FALSE);
    }

    // Restore the cable box tree.
    // Return 0 if the output file failed to open, else 1.

Done:
    treeroot = bxtreeroot;
    sprintf( OutputLine, "$WriteManagedList\t%d\t", retval);
    SendReply( OutputLine);
}


/*
 * WRITEPRODUCTIONFILE - Write the production watch list file to disk.
 */
void WriteProductionFile( void)
{
    char FileName[100], OutputLine[100], SiteID[100], Action;
    char FileDate[16], MDYFileDate[11];
    short retval;

    // Set aside the cable box tree and point to the watch list tree.
    // Read the watch data, if it has not already been done.

    ReadDatabaseFromDisk( DatabaseMode);

    retval = 1;
    bxtreeroot = treeroot;
    treeroot = (NODE *) wltreeroot;
    strcpy( FileName, "z");
    if (ReadWLDataFromDisk( DatabaseMode) != 1) goto Done;

    // Get the first watch list entry. If none, don't write the file.

    if (!(wlcurnode = (WLNODE *) btfirstnode())) goto Done;

    // There is data: open the output file and write the header.

#if 1 //@@
    BuildFileDate( FileDate, MDYFileDate);
    sprintf( FileName, "%sPRODUCTION_LIST-[%s].csv",
        OutputDir, BASIdentifier);
#else
    sprintf( FileName, "%sPRODUCTION_LIST-[%s-%s].csv",
        OutputDir, BuildFileDate( FileDate, MDYFileDate), BASIdentifier);
#endif

    if (!OpenWatchOutputFile( FileName, 0)) {
        retval = 0;
        goto Done;
    }

    // Walk through the Watch List tree and output the appropriate records.

    wlcurnode = (WLNODE *) btfirstnode();
    while (wlcurnode) {
        if (wlcurnode->WatchFlag >= WF_ACTIVE) {
            // Find the Site ID in the current cable box record.

            wltreeroot = (WLNODE *) treeroot;
            treeroot = bxtreeroot;
            if (!(curnode = btreefind( wlcurnode->CableBoxSerial)))
                 *SiteID = '\0';
            else BuildSiteAndModel( SiteID, 0);
            treeroot = (NODE *) wltreeroot;

            // Output the production record.

            Action = (wlcurnode->WatchFlag == WF_MANUAL) ?
                'M' : ActionChar[wlcurnode->Action];

            fprintf( ofhdl, "\"%s\",\"%c\",%s,\"%s\"\n",
                wlcurnode->CableBoxSerial,
                Action,
                SiteID,
                MDYFileDate);
        }
        wlcurnode = (WLNODE *) btnextnode();
    }
    fclose( ofhdl);
    ofhdl = (FILE *) NULL;

    // If an alternate directory is defined, copy the file to it.

    if (strcmp( OutputDir, Flds[1])) {
#if 1 //@@
        sprintf( OutputLine, "%sPRODUCTION_LIST-[%s].csv",
            Flds[1], BASIdentifier);
#else
        sprintf( OutputLine, "%sPRODUCTION_LIST-[%s-%s].csv",
            Flds[1], FileDate, BASIdentifier);
#endif

        CopyFile( FileName, OutputLine, FALSE);
    }

    // Restore the cable box tree.
    // Return 0 if the output file failed to open, else 1.

Done:
    treeroot = bxtreeroot;
    sprintf( OutputLine, "$WriteProductionList\t%d\t%s\t", retval, FileName);
    SendReply( OutputLine);
}


/*
 * WRITEMODELCOUNTFILE - Write out the model counts data.
 */
void WriteModelCountFile( void)
{
    char FileName[70], OutputLine[300], FileDate[8];
    short retval, ii;

    // Set aside the cable box tree and point to the model counts tree.
    // Read the weekly model counts data.

    retval = 2;
    treeroot = (NODE *) mwtreeroot;
    ReadMWDataFromDisk( DatabaseMode);

    // Get the first model counts entry. If none, don't write the file.
    // If so, save the week of the first entry for use in the file name.

    if (!(mwcurnode = (MWNODE *) btfirstnode())) goto Done;
    strncpy( FileDate, mwcurnode->Week_SiteID_Model + 1, 7);
    *(FileDate + 7) = '\0';

    // Meld the counts on disk into the model data structure.

    retval = 1;
    ProcessModelData();

    // Open the output file and write the header.

    sprintf( FileName, "%sI_MODEL-[%s-%s].csv", OutputDir,
        FileDate, BASIdentifier);

#if 1 //@@
    AppendErrorMessage( "    Opening %s for writing\n", FileName, 0);
    if (!(ofhdl = fopen( FileName, "w"))) {
        retval = 0;
        AppendErrorMessage( "    Open of %s failed\n", FileName, 0);
        goto Done;
    }
    AppendErrorMessage( "    %s is open; writing\n", FileName, 0);
#endif

    fprintf( ofhdl,
        "GL_WK_WEEK,"
        "GL_WK_SITE ID,"
        "GL_WK_MODEL,"
        "GL_GB_EQCOUNT,"
        "GL_WK_COUNT SIH,"
        "WL_WK_ADDED TO WL,"
        "WL_GB_INACTIVE WL,"
        "WL_GB_ACTIVE WL COUNT,"
        "GL_WK_IN HOUSE,"
        "WL_WK_IN HOUSE,"
        "GL_WK_IN REPAIR,"
        "WL_WK_IN REPAIRI,"
        "GL_WK_IN OTHER,"
        "WL_WK_IN OTHER,"
        "GL_GB_TIMES INSTALLED,"
        "WL_GB_TIMES INSTALLED,"
        "GL_GB_TIMES REPAIRED,"
        "WL_GB_TIMES REPAIRED,"
        "GL_GB_TIMES OTHER,"
        "WL_GB_TIMES OTHER,"
        "GL_GB_COUNT DAYS HOUSE,"
        "WL_GB_COUNT DAYS HOUSE,"
        "WL_WK_COUNT SCRAP,"
        "WL_WK_COUNT REPAIR,"
        "WL_WK_COUNT HOUSE,"
        "WL_WK_COUNT OTHER,"
        "GL_GB_COUNT DAYS TOTAL,"
        "WL_GB_COUNT DAYS TOTAL,"
        "GL_WK_DATE,"
        "GL_GB_OUTOFSERVICE,"
        "WL_GB_OUTOFSERVICEI,"
        "WL_GB_INHOUSEI\n");

    // Walk through the Model Count Week tree and output each record.

    mwcurnode = (MWNODE *) btfirstnode();
    while (mwcurnode) {
        fprintf( ofhdl,
            "%s,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,"
            "%d,%d,%d,%d,%d,%d,%d,%s,%d,%d,%d\n",
            mwcurnode->Week_SiteID_Model,
            mwcurnode->GL_Count,
            mwcurnode->GL_SIHCount,
            mwcurnode->WL_AddCount,
            mwcurnode->WL_RemCount,
            mwcurnode->WL_Count,
            mwcurnode->GL_InHouse,
            mwcurnode->WL_InHouse,
            mwcurnode->GL_InRepair,
            mwcurnode->WL_InRepairI,
            mwcurnode->GL_InOther,
            mwcurnode->WL_InOther,
            mwcurnode->GL_Installed,
            mwcurnode->WL_Installed,
            mwcurnode->GL_Repair,
            mwcurnode->WL_Repair,
            mwcurnode->GL_Other,
            mwcurnode->WL_Other,
            mwcurnode->GL_DaysHouse,
            mwcurnode->WL_DaysHouse,
            mwcurnode->WL_ScrapCount,
            mwcurnode->WL_RepairCount,
            mwcurnode->WL_HouseCount,
            mwcurnode->WL_OtherCount,
            mwcurnode->GL_DaysTotal,
            mwcurnode->WL_DaysTotal,
            ConvertWeekToDate( mwcurnode->Week_SiteID_Model, OutputLine),
            mwcurnode->GL_OutOfService,
            mwcurnode->WL_OutOfServiceI,
            mwcurnode->WL_InHouseI);

        mwcurnode = (MWNODE *) btnextnode();
    }
#if 1 //@@
    AppendErrorMessage( "    Closing %s\n", FileName, 0);
    ii = fclose( ofhdl);
    AppendErrorMessage( "    %s is closed: %d\n", FileName, ii);
#endif
    ofhdl = (FILE *) NULL;

    // If an alternate directory is defined, copy the file to it.

    if (strcmp( OutputDir, Flds[1])) {
        sprintf( OutputLine, "%sI_MODEL-[%s-%s].csv", Flds[1],
            FileDate, BASIdentifier);
        CopyFile( FileName, OutputLine, FALSE);
    }
    sprintf( OutputLine, "%s%s9.dat", DatabaseDir, OutDatabaseName);
    DeleteFile( OutputLine);

    mwtreeroot = (MWNODE *) NULL;
    MWDatabaseMode = 0;

    // Restore the cable box tree.
    // Return 0 if the output file failed to open, else 1.

Done:
    treeroot = bxtreeroot;
    sprintf( OutputLine, "$WriteModelCounts\t%d\t%s\t", retval, FileName);
    SendReply( OutputLine);
}


/*
 * PROCESSWORKORDERFILE - Read the work order input file and build its
 * database records.
 */
void ProcessWorkOrderFile( void)
{
#ifdef CAPEQ_VERSION
    short ret;
    char FileText[1000], OutputLine[500], SiteID[100], *sptr;

    // Open the file.

    ret = -1;
    RecordCount = 0;
    if (!(ifhdl = fopen( Flds[1], "r"))) goto Done;

    // Copy the input file as a WO_TRANS output file.

    sprintf( FileText, "%sWO_TRANS_INPUT-[%s-%s].csv",
        OutputDir, BASIdentifier, BuildFileDate( SiteID, NULL));
    CopyFile( Flds[1], FileText, FALSE);

    // Set aside the cable box tree and point to the work order tree.
    // Read the existing WO database, if it has not been done already.

    ReadDatabaseFromDisk( DatabaseMode);

    bxtreeroot = treeroot;
    treeroot = (NODE *) wotreeroot;
    if (ReadWODataFromDisk( DatabaseMode) == -1) goto Done;

    // Read the first line. If a header, skip it, else jump to process it.

    ReadAndProcessCSVLine( FileText, ifhdl);
    if (!strstr( FileText, "erial") && !strstr( FileText, "ERIAL")) goto NoHead;

    // Read and process each line of the file.

    while (ReadAndProcessCSVLine( FileText, ifhdl)) {
NoHead:
        if (SplitOnTabs( FileText) < WO_FIELDSMAX) {
            AppendErrorMessage( "%s Record %d skipped: too few fields\n",
                Flds[1], RecordCount + 1);
            goto SkipRecord;
        }

        // If there are new code/descriptions, add them.

        if (*Flds[WO_PROBLEMCODE]) {
            if (FindDescription( Flds[WO_PROBLEMCODE], ProbCodeRoot) == "") {
                if (!(ProbCodeCur = (PROBCODE *) mypermmalloc(
                    sizeof( PROBCODE) + strlen( Flds[WO_PROBLEMDESC]))))
                    goto Done;
                strcpy( ProbCodeCur->ProblemCode, Flds[WO_PROBLEMCODE]);
                strcpy( ProbCodeCur->ProblemDesc, Flds[WO_PROBLEMDESC]);
                ProbCodeCur->next = ProbCodeRoot;
                ProbCodeRoot = ProbCodeCur;
            }
        }

        if (*Flds[WO_FINDINGCODE]) {
            if (FindDescription( Flds[WO_FINDINGCODE], (PROBCODE *) FindCodeRoot) == "") {
                if (!(FindCodeCur = (FINDCODE *) mypermmalloc(
                    sizeof( FINDCODE) + strlen( Flds[WO_FINDINGDESC]))))
                    goto Done;
                strcpy( FindCodeCur->FindingCode, Flds[WO_FINDINGCODE]);
                strcpy( FindCodeCur->FindingDesc, Flds[WO_FINDINGDESC]);
                FindCodeCur->next = FindCodeRoot;
                FindCodeRoot = FindCodeCur;
            }
        }

        if (*Flds[WO_SOLUTIONCODE]) {
            if (FindDescription( Flds[WO_SOLUTIONCODE], (PROBCODE *) SolCodeRoot) == "") {
                if (!(SolCodeCur = (SOLCODE *) mypermmalloc(
                    sizeof( SOLCODE) + strlen( Flds[WO_SOLUTIONDESC]))))
                    goto Done;
                strcpy( SolCodeCur->SolutionCode, Flds[WO_SOLUTIONCODE]);
                strcpy( SolCodeCur->SolutionDesc, Flds[WO_SOLUTIONDESC]);
                SolCodeCur->next = SolCodeRoot;
                SolCodeRoot = SolCodeCur;
            }
        }

        if (*Flds[WO_DISCONCODE]) {
            if (FindDescription( Flds[WO_DISCONCODE], (PROBCODE *) DiscCodeRoot) == "") {
                if (!(DiscCodeCur = (DISCCODE *) mypermmalloc(
                    sizeof( DISCCODE) + strlen( Flds[WO_DISCONDESC]))))
                    goto Done;
                strcpy( DiscCodeCur->DisconnectCode, Flds[WO_DISCONCODE]);
                strcpy( DiscCodeCur->DisconnectDesc, Flds[WO_DISCONDESC]);
                DiscCodeCur->next = DiscCodeRoot;
                DiscCodeRoot = DiscCodeCur;
            }
        }

        // If the entry already exists, copy various cur's to prev's.
        // Otherwise create a new record.

        if (wocurnode = (WONODE *) btreefind( Flds[WO_SERIAL])) {
            strcpy( wocurnode->ProblemCodePrev, wocurnode->ProblemCodeCur);
            strcpy( wocurnode->FindingCodePrev, wocurnode->FindingCodeCur);
            strcpy( wocurnode->SolutionCodePrev, wocurnode->SolutionCodeCur);

            wocurnode->AssignedInstallerPrev = wocurnode->AssignedInstallerCur;
            wocurnode->WorkOrderNoPrev = wocurnode->WorkOrderNoCur;
            wocurnode->WOCompletionDatePrev = wocurnode->WOCompletionDateCur;
            wocurnode->CheckinDatePrev = wocurnode->CheckinDateCur;
            wocurnode->SiteID_C = wocurnode->SiteID_B;
            wocurnode->SiteID_B = wocurnode->SiteID_A;

            wocurnode->PrevDateEntered = wocurnode->DateEntered;
            wocurnode->DateEntered = ConvertMDYToTimet( Flds[WO_DATEENTERED]);

            ++wocurnode->TimesDiscovered;
        }
        else {
            if (!(wocurnode = (WONODE *) mypermmalloc( sizeof( WONODE))))
                goto Done;

            strcpy( wocurnode->CableBoxSerial, Trunc( Flds[WO_SERIAL], 21));
            *wocurnode->ProblemCodePrev =
            *wocurnode->FindingCodePrev =
            *wocurnode->SolutionCodePrev = '\0';

            wocurnode->AssignedInstallerPrev =
            wocurnode->WorkOrderNoPrev =
            wocurnode->SiteID_C =
            wocurnode->SiteID_B = "";

            wocurnode->PrevDateEntered =
            wocurnode->WOCompletionDatePrev =
            wocurnode->CheckinDatePrev = (time_t) 0;

            wocurnode->FirstDateEntered =
            wocurnode->DateEntered = ConvertMDYToTimet( Flds[WO_DATEENTERED]);

            wocurnode->TimesDiscovered = 1;
            btreestore( (NODE *) wocurnode);
        }

        // Find the Site ID in the current cable box record.

        wotreeroot = (WONODE *) treeroot;
        treeroot = bxtreeroot;
        if (!(curnode = btreefind( Flds[WO_SERIAL]))) *SiteID = '\0';
        else BuildSiteAndModel( SiteID, 0);
        treeroot = (NODE *) wotreeroot;

        // Update the database fields from the input record.

        strcpy( wocurnode->ProblemCodeCur,  Trunc( Flds[WO_PROBLEMCODE], 2));
        strcpy( wocurnode->FindingCodeCur,  Trunc( Flds[WO_FINDINGCODE], 2));
        strcpy( wocurnode->SolutionCodeCur, Trunc( Flds[WO_SOLUTIONCODE], 2));
        strcpy( wocurnode->WOtype,          Trunc( Flds[WO_TYPE], 2));
        strcpy( wocurnode->WOclass,         Trunc( Flds[WO_CLASS], 2));
        strcpy( wocurnode->WOstatus,        Trunc( Flds[WO_STATUS], 2));
        strcpy( wocurnode->QCode,           Trunc( Flds[WO_QCODE], 2));
        strcpy( wocurnode->DisconnectCode,  Trunc( Flds[WO_DISCONCODE], 2));

        // Save

        sprintf( OutputLine, "%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t",
            wocurnode->SiteID_C,
            wocurnode->SiteID_B,
            SiteID,
            Trunc( Flds[WO_ACCOUNTNO], 16),
            wocurnode->AssignedInstallerPrev,
            Trunc( Flds[WO_INSTALLER], 12),
            wocurnode->WorkOrderNoPrev,
            Trunc( Flds[WO_WONUMBER], 8),
            Trunc( Flds[WO_BILLTYPE], 16),
            Trunc( Flds[WO_ITEMNUMBER], 7));

        sptr = mypermmalloc( 1 + strlen( OutputLine));
        strcpy( sptr, OutputLine);

        wocurnode->SiteID_C =              NextString( &sptr);
        wocurnode->SiteID_B =              NextString( &sptr);
        wocurnode->SiteID_A =              NextString( &sptr);
        wocurnode->AccountNo =             NextString( &sptr);
        wocurnode->AssignedInstallerPrev = NextString( &sptr);
        wocurnode->AssignedInstallerCur =  NextString( &sptr);
        wocurnode->WorkOrderNoPrev =       NextString( &sptr);
        wocurnode->WorkOrderNoCur =        NextString( &sptr);
        wocurnode->BillTypeCode =          NextString( &sptr);
        wocurnode->ItemNumber =            NextString( &sptr);

        wocurnode->WOCompletionDateCur = ConvertMDYToTimet( Flds[WO_COMPDATE]);
        wocurnode->CheckinDateCur = ConvertMDYToTimet( Flds[WO_CHECKINDATE]);

        // Every so often send status to VB.

SkipRecord:
        if (!(++RecordCount % 5000)) {
            sprintf( FileText, "$Status\t%d\t", RecordCount);
            SendReply( FileText);
        }
    }
    fclose( ifhdl);
    WorkOrderDataDirty = 1;
    ret = 0;

Done:
    sprintf( FileText, "$ProcessWorkOrderFile\t%d\t%d\t", ret, RecordCount);
    SendReply( FileText);

    // Restore the cable box tree; done.

    wotreeroot = (WONODE *) treeroot;
    treeroot = bxtreeroot;
#else
    SendReply( "$ProcessWorkOrderFile\t-10\t0\t");
#endif
}


/*
 * PROCESSDEFEQFILE - Read the defective equipment input file and build its
 * database records.
 */
void ProcessDefEqFile( void)
{
#ifdef CAPEQ_VERSION
    short ret;
    char FileText[801], FileName[100], *sptr;

    // Open the file.

    ret = -1;
    RecordCount = 0;
    if (!(ifhdl = fopen( Flds[1], "r"))) goto Done;
    strcpy( FileName, Flds[1]);

    // Copy the input file as a DE_TRANS file.

    sprintf( FileText, "%sDE_TRANS_INPUT-[%s-%s].csv",
        OutputDir, BASIdentifier, BuildFileDate( FileName, NULL));
    CopyFile( Flds[1], FileText, FALSE);

    // Set aside the cable box tree and point to the defective equipment tree.
    // Read the existing database, if it has not been done already.

    ReadDatabaseFromDisk( DatabaseMode);

    bxtreeroot = treeroot;
    treeroot = (NODE *) detreeroot;
    if (ReadDEDataFromDisk( DatabaseMode) == -1) goto Done;

    // Read the first line. If a header, skip it, else jump to process it.

    ReadAndProcessCSVLine( FileText, ifhdl);
    if (!strstr( FileText, "erial") && !strstr( FileText, "ERIAL")) goto NoHead;

    // Read and process each line of the file.

    IncludeTime = 1;
    while (ReadAndProcessCSVLine( FileText, ifhdl)) {
NoHead:
        if (SplitOnTabs( FileText) < DE_FIELDSMAX) {
            AppendErrorMessage( "%s Record %d skipped: too few fields\n",
                FileName, RecordCount + 1);
            goto SkipRecord;
        }

        // If there is no site ID or serial number, the record is spurious.

        if (!*Flds[DE_SITE] || !*Flds[DE_SERIAL]) {
            AppendErrorMessage( "%s Record %d skipped: no Site ID or Serial No\n",
                FileName, RecordCount + 1);
            goto SkipRecord;
        }

        // If the entry already exists, copy various cur's to prev's.
        // Otherwise create a new record.

        if (decurnode = (DENODE *) btreefind( Flds[DE_SERIAL])) {
            decurnode->ProblemPrev =    decurnode->ProblemCur;
            decurnode->DiagnosisPrev =  decurnode->DiagnosisCur;
            decurnode->PrevCreateDate = decurnode->CreatedDate;
            decurnode->CreatedDate =    ConvertMDYToTimet( Flds[DE_CREATED]);
            ++decurnode->TimesDiscovered;
        }
        else {
            if (!(decurnode = (DENODE *) mypermmalloc( sizeof( DENODE))))
                goto Done;

            strcpy( decurnode->CableBoxSerial, Trunc( Flds[DE_SERIAL], 16));
            decurnode->ProblemPrev =
            decurnode->DiagnosisPrev = "";
            decurnode->FirstCreateDate =
            decurnode->CreatedDate = ConvertMDYToTimet( Flds[DE_CREATED]);
            decurnode->PrevCreateDate = (time_t) 0;
            decurnode->TimesDiscovered = 1;

            btreestore( (NODE *) decurnode);
        }

        // Update the database fields from the input record.

        decurnode->ResolvedDate = ConvertMDYToTimet( Flds[DE_RESDATE]);

        sprintf( FileText, "%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t",
            Trunc( Flds[DE_SITE],      16),
            Trunc( Flds[DE_SUBMITTER], 24),
            Trunc( Flds[DE_SALESNO],   10),
            Trunc( Flds[DE_MODEL],     16),
            Trunc( Flds[DE_PROBLEM],   36),
            Trunc( Flds[DE_PDETAILS],  75),
            Trunc( Flds[DE_DIAGNOSIS], 50),
            Trunc( Flds[DE_SOLUTION],  24),
            Trunc( Flds[DE_RESOLVER],  24));

        sptr = mypermmalloc( 1 + strlen( FileText));
        strcpy( sptr, FileText);

        decurnode->SiteID =       NextString( &sptr);
        decurnode->Submitter =    NextString( &sptr);
        decurnode->SalesNo =      NextString( &sptr);
        decurnode->Model =        NextString( &sptr);
        decurnode->ProblemCur =   NextString( &sptr);
        decurnode->Details =      NextString( &sptr);
        decurnode->DiagnosisCur = NextString( &sptr);
        decurnode->Solution =     NextString( &sptr);
        decurnode->Resolver =     NextString( &sptr);

        if (!strcmp( decurnode->Resolver, ",")) *decurnode->Resolver = '\0';

        if (!*decurnode->ProblemPrev)
            decurnode->ProblemPrev = decurnode->DiagnosisPrev = sptr - 1;

        // Every so often send status to VB.

SkipRecord:
        if (!(++RecordCount % 5000)) {
            sprintf( FileText, "$Status\t%d\t", RecordCount);
            SendReply( FileText);
        }
    }
    fclose( ifhdl);
    DefectiveEquipmentDataDirty  = 1;
    ret = 0;

Done:
    IncludeTime = 0;
    sprintf( FileText, "$ProcessDefEqFile\t%d\t%d\t", ret, RecordCount);
    SendReply( FileText);

    // Restore the cable box tree; done.

    detreeroot = (DENODE *) treeroot;
    treeroot = bxtreeroot;
#else
    SendReply( "$ProcessDefEqFile\t-10\t0\t");
#endif
}


/*
 * OPENWATCHOUTPUTFILE - Open the watch list output file of the given name
 * and write out its header. The file handle is in the global ofhdl.
 * Call with type == 2 or 1 for the managed file; 0 == production file.
 */
FILE *OpenWatchOutputFile( char *OutputFileName, short type)
{
    if (!(ofhdl = fopen( OutputFileName, "w"))) return (FILE *) NULL;

    // Output the appropriate header.

    fprintf( ofhdl, (!type) ?
        "SERIAL NUMBER,DESIRED ACTION,SITE ID,DATE\n" :
        "SERIAL NUMBER,INITIAL WATCH LIST DATE,LATEST WL ACTIVATION DATE,"
        "TIMES ACTIVATED ON WL,TIMES DISCOVERED ON LIST,"
        "DAYS BTW PREVIOUS-CURR WL ACTIVATION,DAYS SINCE INITIAL LISTING,"
        "WATCH FLAG,DESIRED ACTION,TIMES ROLLED BACK,LATEST ROLLBACK DATE,"
        "DAYS SINCE LATEST ROLLBACK,ROLLBACK REASON,DAYS ON WATCH,"
        "MANUAL ADD");
    if (type > 0) {
        if (type == 2) fprintf( ofhdl, ",SITE ID,MODEL NUMBER,DATE");
        fprintf( ofhdl, "\n");
    }

    return ofhdl;
}


/*
 * BUILDFILEDATE - Copy Now into DateStr in "yyyymmdd-hhnnss" format.
 * Also optionally build "mm/dd/yyy" in MDYDateStr, if non-NULL.
 * Returns DateStr.
 */
char *BuildFileDate( char *DateStr, char *MDYDateStr)
{
    time_t curtime;
    struct tm *tmstr;

    time( &curtime);

    // Make sure this date/time is at least one second later than any
    // previously-used date/time.

    if (curtime <= CurFileDate) curtime = CurFileDate + 1;
    CurFileDate = curtime;

    tmstr = localtime( &curtime);
    strftime( DateStr, 16, "%Y%m%d-%H%M%S", tmstr);

    // If the caller wants a MDY string too, build it.

    if (MDYDateStr) ConvertTimetToMDY( curtime, MDYDateStr);

    return DateStr;
}


/*
 * DOCSGWORK - Do the work required for the given CSG record.
 * Returns 1 if o.k., 1 to skip the record, -2 if there's an early date
 * problem, -3 if the cable box can't be found. -2 and -3 abort processing.
 */
long DoCSGWork( char *Line)
{
    short ret;
    long FieldCount;
    char *OldExternalState, PreviousState, sfStatusCode;
    char DateStg[10];
#ifndef CBA_VERSION
    char *OldLocation;
#endif
    char *sptr, chr;

    // Split the record into fields; trim each field.
    // Return skip-this-record if the data is invalid.

    FieldCount = (short) SplitOnTabs( Line);
    if (*Flds[CSG_SERIAL] == '\0') return 1;
    if ((dmtreeroot > (DMNODE *) 1) && MatchDropModel( Flds[CSG_BOXMODEL])) {
        ++RecordsDropped;
        return 1;
    }

    fLocation = Flds[CSG_LOCATION];
    fExternalState = Flds[CSG_STATE];
    fDateOfState = ConvertMDYToTimet( Flds[CSG_STATEDATE]);
    if (fDateOfState > MostRecentDOS) MostRecentDOS = fDateOfState;
    sprintf( fCompanyRegion, "%s-%s", Flds[CSG_REGION], Flds[CSG_DIVISION]);
    fStatusCode = ConvertState();

    // If the week has changed from that of the previous transaction,
    // build the model counts data and append it to its database file.

    if (!DoingUniversal) {
        ConvertTimetToWeek( fDateOfState, DateStg);
        if (!*CurrentWeek) strcpy( CurrentWeek, DateStg);
        else if (strcmp( CurrentWeek, DateStg)) {
            sfStatusCode = fStatusCode;
            SendReply( "$Status\tM\t");
            SetWatchData( 0);
            BuildInitialModelCountData();
            AppendModelCountData( CurrentWeek);
            strcpy( CurrentWeek, DateStg);
            fStatusCode = sfStatusCode;
        }
    }

    // Set up global values from the record data.

    fCableBoxSerial = Flds[CSG_SERIAL];
    fCableBoxMake = Flds[CSG_BOXMAKE];
    sprintf( fCableBoxModel, "%s|%s", Flds[CSG_BOXMODEL], Flds[CSG_TYPE]);
    fAddress = "";
    fAddress2 = "";

    // For some reason, ReadAndProcessCSVLine (called from VB) puts a
    // dot at the end of the Region and Division numbers. Remove the dots.
    // Also, change all dashes in the REGION to spaces.

    sptr = Flds[CSG_REGION];
    while (chr = *sptr++) if (chr == '-') *(sptr - 1) = ' ';
    if (*(sptr - 2) == '.') *(sptr - 2) = '\0';
    sptr = Flds[CSG_DIVISION] + strlen( Flds[CSG_DIVISION]) - 1;
    if (*sptr == '.') *sptr = '\0';

    if (DiscardRecent &&
        ((fDateOfState == -1) || (fDateOfState >= DiscardRecent))) return 1;
    if (fDateOfState == -1) fDateOfState = StartOfWorld;

    sprintf( fStrings, "%s\t%s\t%s\t%s\t%s\t%s\t%s\t",
        fExternalState, fCableBoxMake, fCableBoxModel, fLocation,
        fAddress, fAddress2, fCompanyRegion);   // (no previous location, etc.)

    // If this is the universal file, then if the date is in the future,
    // use the start of world date.

    if (DoingUniversal) CheckDate();

    // Find or create the box's data record; get its data.

    ReadCableBoxRecord();

#if 0 //@@ not applicable to CSG ?
    // For Hawaii, if the serial number, state, and location are the same as in
    // the database, ignore this record.

    if (MutateQState &&
        !strcmp( dStrings[DB_EXTERNALSTATE], fExternalState) &&
        !strcmp( dStrings[DB_LOCATION], fLocation)) return 1;
#endif

    // Patch up a universal entry, or make calculations on a real entry.

    fReceiptDate = ConvertMDYToTimet( Flds[CSG_RECEIPT]);
    if (fReceiptDate == -1) fReceiptDate = 0;
    curnode->ReceiptDate = fReceiptDate;

    if (DoingUniversal) {
        if (!curnode->Universal) return 1;
        curnode->DateOfState = fDateOfState;
        PreviousState = 'U';
        *StatusOutOfSequence = '\0';
        DaysBetweenStates = 0;
        if ((ret = (short) CalculateOnState()) < 0) return (ret == -1) ? -2 : 1;
    }
    else {
        if ((ret = (short) CalculateOnState()) < 0) return (ret == -1) ? -2 : 1;
        PreviousState = curnode->CurrentState;
    }

    // Write the output record to the file, if desired.

#ifdef CBA_VERSION
    OldLocation = (PreviousState == 'U') ? "" : dStrings[DB_LOCATION];
#endif

    if (WriteOutputFiles) {
        if (!FindCableBoxMap()) return -3;
        if (ofhdl) {
#ifdef CBA_VERSION
            OldExternalState =
                (PreviousState == 'U') ? "U" : dStrings[DB_EXTERNALSTATE];
#else
            if (PreviousState == 'U') {
                OldExternalState = "U";
                OldLocation = "";
            }
            else {
                OldExternalState = dStrings[DB_EXTERNALSTATE];
                OldLocation = dStrings[DB_LOCATION];
            }
#endif

//@@$$      fprintf( ofhdl,
//              ",\"%s\",,\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",%s,\"%s\",%s,%s,%s,"
//              "\"%s\",\"%s\",\"%s\",%s,0,0,0,0,0,0,0,0,0,0,0,%d,\"%s\",\"\","
//              "0,0,0,\"%s\",\"%s\"",

            fprintf( ofhdl,
                ",\"%s\",,\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",%s,\"%s\",%s,%s,%s,"
                "\"%s\",\"%s\",\"%s\",%s,,,,,,,,,,,,%d,\"%s\",\"\",,,,\"%s\",\"%s\"",
                Flds[CSG_REGION],
                Flds[CSG_DIVISION],
                Flds[CSG_SERIAL],
                Flds[CSG_TYPE],
                Flds[CSG_BOXMODEL],
                Flds[CSG_BOXMAKE],
                GetFullStateName( PreviousState),
                Flds[CSG_RECEIPT],
                GetFullStateName( fStatusCode),
                Flds[CSG_STATEDATE],
                Flds[CSG_ENDDATE],
                OldLocation,
                Flds[CSG_TRAN],
                Flds[CSG_OPERATOR],
                Flds[CSG_STATETIME],
                DaysBetweenStates,
                StatusOutOfSequence,
                OldExternalState,
                fExternalState);

//@@$$      if (AddFiveFields) fprintf( ofhdl, ",\"%s\",0,0,0,0,", fLocation);

            if (AddFiveFields) fprintf( ofhdl, ",\"%s\",,,,,", fLocation);
            if (ShortInHouseFlag) fprintf( ofhdl, ",%d", ShortInHouseField);
            fprintf( ofhdl, "\n");
        }
    }

    UpdateCableBoxRecord();         // save the updated info
    return 1;
}


/*
 * DOICOMMSWORK - Do the work required for the given ICOMMS record.
 * Returns 1 if o.k., -1 to skip the record, -2 if there's an early date
 * problem, -3 if the cable box can't be found. -2 and -3 abort processing.
 */
long DoICOMMSWork( char *Line)
{
    short ret;
    long FieldCount;
    char *OldExternalState, PreviousState, sfStatusCode;
    char DateStg[10];
#ifndef CBA_VERSION
    char *OldLocation;
#endif
    char *sptr, chr;

    // Split the record into fields; trim each field.
    // Return skip-this-record if the data is invalid.

    FieldCount = (short) SplitOnTabs( Line);
    if (*Flds[ICM_SERIAL] == '\0') return 1;
    if ((dmtreeroot > (DMNODE *) 1) && MatchDropModel( Flds[ICM_ITEMDESC])) {
        ++RecordsDropped;
        return 1;
    }

    fExternalState = Flds[ICM_STATE];
    if (CoxFlag) {
        if ((*fExternalState == '7') || (*fExternalState == 'T'))
            fLocation = Flds[ICM_RETFLAG];
        else if (*fExternalState == '5') fLocation = Flds[ICM_LOCATION];
        else                             fLocation = "IN INVENTORY";
    }
    else fLocation = Flds[ICM_LOCATION];

    fDateOfState = ConvertMDYToTimet( Flds[ICM_STATEDATE]);
    if (fDateOfState > MostRecentDOS) {
        MostRecentDOS = fDateOfState;
#if DEBUGWKCHK
        AppendErrorMessage( "    %sUpdating most recent to %d\n",
            "", MostRecentDOS);
#endif
    }

    sprintf( fCompanyRegion, "%s-%s-%s",
        Flds[ICM_REGION], Flds[ICM_DIVISION], Flds[ICM_SITEID]);
    fStatusCode = ConvertState();

    // If the week has changed from that of the previous transaction,
    // build the model counts data and append it to its database file.

    if (!DoingUniversal) {
        ConvertTimetToWeek( fDateOfState, DateStg);
        if (!*CurrentWeek) strcpy( CurrentWeek, DateStg);
        else if (strcmp( CurrentWeek, DateStg)) {
            sfStatusCode = fStatusCode;
            SendReply( "$Status\tM\t");
            SetWatchData( 0);
            BuildInitialModelCountData();
            AppendModelCountData( CurrentWeek);
            strcpy( CurrentWeek, DateStg);
            fStatusCode = sfStatusCode;
        }
    }

    // Use a different Location value for Q-mapping and certain states.

    if (MutateQState && ((*fExternalState == 'H') ||
        (*fExternalState == 'A') || (*fExternalState == 'D')))
            fLocation = Flds[ICM_RETFLAG];

    // Set up global values from the record data.

    fCableBoxSerial = Flds[ICM_SERIAL];
    fCableBoxMake = "";
    sprintf( fCableBoxModel, "%s|%s|%s",
        Flds[ICM_ITEMDESC], Flds[ICM_ITEMTYPE], Flds[ICM_ITEMNO]);
    fAddress = Flds[ICM_ADDRESS];
    fAddress2 = Flds[ICM_ADDRESS2];

    // Change all dashes in the REGION to spaces.

    sptr = Flds[ICM_REGION];
    while (chr = *sptr++) if (chr == '-') *(sptr - 1) = ' ';

    if (fDateOfState == -1) fDateOfState = StartOfWorld;
    if (DiscardRecent && (fDateOfState >= DiscardRecent)) return 1;

    sprintf( fStrings, "%s\t%s\t%s\t%s\t%s\t%s\t%s\t",
        fExternalState, fCableBoxMake, fCableBoxModel, fLocation,
        fAddress, fAddress2, fCompanyRegion);   // (no previous location, etc.)

    // If this is the universal file, then if the date is in the future,
    // use the start of world date.

    if (DoingUniversal) CheckDate();

    // Find or create the box's data record; get its data.

    ReadCableBoxRecord();

    // Use the Return Reason input field as the Receipt Date.

    if ((fReceiptDate = ConvertMDYToTimet( Flds[ICM_RETREASON])) == -1)
        fReceiptDate = 0;

    // For Hawaii, ignore this record if the serial number, state,
    // are the same as in the database. However, if the transition is
    // H -> H, ignore it only if the location is the same.

    if (MutateQState) {
#ifdef _DEBUG
        {   //@@ make these strings easy to read
            char *oldModel, *newModel;

            oldModel = dStrings[DB_CABLEBOXMODEL];
            newModel = Flds[ICM_ITEMDESC];
            ret = 1;
        }
#endif

#ifdef _DEBUG
        DebugAction = "";
        if (!DoingUniversal &&
            !strcmp( dStrings[DB_EXTERNALSTATE], fExternalState) &&
            (*fExternalState != 'E') &&
            ((fStatusCode != 'H') ||
              !strncmp( dStrings[DB_CABLEBOXMODEL],
                Flds[ICM_ITEMDESC], strlen( Flds[ICM_ITEMDESC]))))
        {
            fprintf( ofhdl, "%d,%s,%s,%d,%d,%s->%s,%c->%c,\"%s\",\"%s\",\"%s\"\n",
                RecordCount + 31,           // line number
                Flds[ICM_RETDESC],          // tag
                Flds[ICM_STATEDATE],        // date of state
                0,                          // days in state
                0,                          // Short In House flag
                dStrings[DB_EXTERNALSTATE], // previous external state
                fExternalState,             // current external state
                curnode->CurrentState,      // previous internal state
                fStatusCode,                // current internal state
                dStrings[DB_CABLEBOXMODEL], // old model (truncate at "|")
                Flds[ICM_ITEMDESC],         // new model
                "DROP");                    // action

            return 1;
        }
#else
        if (!DoingUniversal &&
            !strcmp( dStrings[DB_EXTERNALSTATE], fExternalState) &&
            (*fExternalState != 'E') &&
            ((fStatusCode != 'H') ||
              !strncmp( dStrings[DB_CABLEBOXMODEL],
                Flds[ICM_ITEMDESC], strlen( Flds[ICM_ITEMDESC]))))
                    return 1;
#endif
    }

    // Patch up a universal entry, or make calculations on a real entry.

    curnode->ReceiptDate = fReceiptDate;
    if (DoingUniversal) {
        if (!curnode->Universal) return 1;
        curnode->DateOfState = fDateOfState;
        PreviousState = 'U';
        *StatusOutOfSequence = '\0';
        DaysBetweenStates = 0;
        if ((ret = (short) CalculateOnState()) < 0) return (ret == -1) ? -2 : 1;
    }
    else {
        if ((ret = (short) CalculateOnState()) < 0) return (ret == -1) ? -2 : 1;
        PreviousState = curnode->CurrentState;
    }

    // Write the output record to the file, if desired.

#ifdef CBA_VERSION
    OldLocation = (PreviousState == 'U') ? "" : dStrings[DB_LOCATION];
#endif

    if (WriteOutputFiles) {
        if (!FindCableBoxMap()) return -3;
        if (ofhdl) {
#ifdef CBA_VERSION
            OldExternalState =
                (PreviousState == 'U') ? "U" : dStrings[DB_EXTERNALSTATE];
#else
            if (PreviousState == 'U') {
                OldExternalState = "U";
                OldLocation = "";
            }
            else {
                OldExternalState = dStrings[DB_EXTERNALSTATE];
                OldLocation = dStrings[DB_LOCATION];
            }
#endif

#ifdef _DEBUG
            fprintf( ofhdl, "%d,%s,%s,%d,%d,%s->%s,%c->%c,\"%s\",\"%s\",\"%s\"\n",
                RecordCount + 31,               // line number
                Flds[ICM_RETDESC],              // tag
                Flds[ICM_STATEDATE],            // date of state
                DaysBetweenStates,              // days in state
                ShortInHouseField,              // Short In House flag
                dStrings[DB_EXTERNALSTATE],     // previous external state
                fExternalState,                 // current external state
                curnode->CurrentState,          // previous internal state
                fStatusCode,                    // current internal state
                dStrings[DB_CABLEBOXMODEL],     // old model (truncate at "|")
                Flds[ICM_ITEMDESC],             // new model
                DebugAction);                   // action
#else
//@@$$      fprintf( ofhdl,
//              "\"%s\",,\"%s\",0,\"%s\",0,0,0,\"%s\",\"%s\",\"%s\",\"%s\",\"\","
//              "\"%s\",0,0,\"%s\","
//              "\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\","
//              "\"%s\",\"%s\",%d,\"%s\",\"\",\"%s\",%s,\"%s\",\"%s\",\"%s\"",

            fprintf( ofhdl,
                "\"%s\",,\"%s\",,\"%s\",,,,\"%s\",\"%s\",\"%s\",%s,\"\",\"%s\",,,%s,"
                "\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",%s,"
                "\"%s\",\"%s\",%d,\"%s\",\"\",\"%s\",%s,\"%s\",\"%s\",\"%s\"",
                Flds[ICM_REGION],
                Flds[ICM_DIVISION],
                Flds[ICM_SERIAL],
                GetFullStateName( PreviousState),
                ((fReceiptDate == 0) ? "" : Flds[ICM_RETREASON]),
                GetFullStateName( fStatusCode),
                Flds[ICM_STATEDATE],
                OldLocation,
                Flds[ICM_STATETIME],
                Flds[ICM_ITEMTYPE],
                Flds[ICM_RETFLAG],
                Flds[ICM_RETDESC],
                Flds[ICM_SITEID],
                Flds[ICM_STATEDESC],
                Flds[ICM_TECHTYPE],
                Flds[ICM_TECHDESC],
                Flds[ICM_RETREASON],
                Flds[ICM_ITEMNO],
                fAddress,
                fAddress2,
                DaysBetweenStates,
                StatusOutOfSequence,
                Flds[ICM_LOCATOR],
                Flds[ICM_ZIPCODE],
                Flds[ICM_ITEMDESC],
                OldExternalState,
                fExternalState);

//@@$$      if (AddFiveFields) fprintf( ofhdl, ",\"%s\",0,0,0,0,", fLocation);
            if (AddFiveFields) fprintf( ofhdl, ",\"%s\",,,,,", fLocation);
            if (ShortInHouseFlag) fprintf( ofhdl, ",%d", ShortInHouseField);
            fprintf( ofhdl, "\n");
#endif
        }
    }

    UpdateCableBoxRecord();         // save the updated info
    if (JFileDir && (*fExternalState == 'J')) AddBoxToJList();
    return 1;
}


/*
 * DOOCVWORK - Do the work required for the given OCV record.
 * Returns 1 if o.k., -1 to skip the record, -2 if there's an early date
 * problem, -3 if the cable box can't be found. -2 and -3 abort processing.
 */
long DoOCVWork( char *Line)
{
    short ret;
    long FieldCount, amt;
    char *OldExternalState, PreviousState, sfStatusCode, TmpStr[501], *sptr;
    char DateStg[10];
    time_t TempDate;
#ifndef CBA_VERSION
    char *OldLocation;
#endif

    // Split the record into fields; trim each field.
    // Return skip-this-record if the data is invalid.

    FieldCount = (short) SplitOnTabs( Line);
    if (*Flds[OCV_SERIAL_NUMBER] == '\0') return 1;
    if ((dmtreeroot > (DMNODE *) 1) && MatchDropModel( Flds[OCV_BOX_TYPE])) {
        ++RecordsDropped;
        return 1;
    }

    fExternalState = OCVGetState();
    fLocation = OCVGetLocation( TmpStr);
    fDateOfState = ConvertMDYToTimet( Flds[OCV_BEGIN_DATE]);
    if (fDateOfState > MostRecentDOS) MostRecentDOS = fDateOfState;
    fStatusCode = ConvertState();
    strcpy( fCompanyRegion, Flds[OCV_ORGANIZATION_CODE]);

    // If the week has changed from that of the previous transaction,
    // build the model counts data and append it to its database file.

    if (!DoingUniversal) {
        ConvertTimetToWeek( fDateOfState, DateStg);
        if (!*CurrentWeek) strcpy( CurrentWeek, DateStg);
        else if (strcmp( CurrentWeek, DateStg)) {
            sfStatusCode = fStatusCode;
            SendReply( "$Status\tM\t");
            SetWatchData( 0);
            BuildInitialModelCountData();
            AppendModelCountData( CurrentWeek);
            strcpy( CurrentWeek, DateStg);
            fStatusCode = sfStatusCode;
        }
    }

    // Use a different Location value for Q-mapping and certain states.

    if (MutateQState && ((*fExternalState == 'H') ||
        (*fExternalState == 'A') || (*fExternalState == 'D')))
            fLocation = Flds[OCV_TC_SWAP_FLAG];

    // Set up global values from the record data.

    fCableBoxSerial = Flds[OCV_SERIAL_NUMBER];
    fCableBoxMake = "";
    sprintf( fCableBoxModel, "%s|%s", Flds[OCV_BOX_TYPE], Flds[OCV_ITEM]);
    fAddress = "";
    fAddress2 = Flds[OCV_REPAIR_AMT];

    if (fDateOfState == -1) fDateOfState = StartOfWorld;
    if (DiscardRecent && (fDateOfState >= DiscardRecent)) return 1;

    sprintf( fStrings, "%s\t%s\t%s\t%s\t%s\t%s\t%s\t",
        fExternalState, fCableBoxMake, fCableBoxModel, fLocation,
        fAddress, fAddress2, fCompanyRegion);   // (no previous location, etc.)

    // If this is the universal file, then if the date is in the future,
    // use the start of world date.

    if (DoingUniversal) CheckDate();

    // Find or create the box's data record; get its data.

    ReadCableBoxRecord();

    // Use the Return Reason input field as the Receipt Date.

    if ((fReceiptDate = ConvertMDYToTimet( Flds[OCV_PURCHASED_DATE])) == -1)
        fReceiptDate = 0;

    // For Hawaii, ignore this record if the serial number, state,
    // are the same as in the database. However, if the transition is
    // H -> H, ignore it only if the location is the same.

    if (MutateQState) {
#if 0 //@@ #ifdef _DEBUG
        {   //@@ make these strings easy to read
            char *oldModel, *newModel;

            oldModel = dStrings[DB_CABLEBOXMODEL];
            newModel = Flds[OCV_BOX_TYPE];
            ret = 1;
        }
#endif

#if 0 //@@ #ifdef _DEBUG
        DebugAction = "";
        if (!DoingUniversal &&
            !strcmp( dStrings[DB_EXTERNALSTATE], fExternalState) &&
            (*fExternalState != 'E') &&
            ((fStatusCode != 'H') ||
              !strncmp( dStrings[DB_CABLEBOXMODEL],
                Flds[OCV_BOX_TYPE], strlen( Flds[OCV_BOX_TYPE]))))
        {
            fprintf( ofhdl, "%d,%s,%s,%d,%d,%s->%s,%c->%c,\"%s\",\"%s\",\"%s\"\n",
                RecordCount + 31,           // line number
                "\"\"",                     // tag
                Flds[OCV_BEGIN_DATE],       // date of state
                0,                          // days in state
                0,                          // Short In House flag
                dStrings[DB_EXTERNALSTATE], // previous external state
                fExternalState,             // current external state
                curnode->CurrentState,      // previous internal state
                fStatusCode,                // current internal state
                dStrings[DB_CABLEBOXMODEL], // old model (truncate at "|")
                Flds[OCV_BOX_TYPE],         // new model
                "DROP");                    // action

            return 1;
        }
#else
        if (!DoingUniversal &&
            !strcmp( dStrings[DB_EXTERNALSTATE], fExternalState) &&
            (*fExternalState != 'E') &&
            ((fStatusCode != 'H') ||
              !strncmp( dStrings[DB_CABLEBOXMODEL],
                Flds[OCV_BOX_TYPE], strlen( Flds[OCV_BOX_TYPE]))))
                    return 1;
#endif
    }

    // Patch up a universal entry, or make calculations on a real entry.

    curnode->ReceiptDate = fReceiptDate;
    if (DoingUniversal) {
        if (!curnode->Universal) return 1;
        curnode->DateOfState = fDateOfState;
        PreviousState = 'U';
        *StatusOutOfSequence = '\0';
        DaysBetweenStates = 0;
        if ((ret = (short) CalculateOnState()) < 0) return (ret == -1) ? -2 : 1;
    }
    else {
        if ((ret = (short) CalculateOnState()) < 0) return (ret == -1) ? -2 : 1;
        PreviousState = curnode->CurrentState;
    }

    // Update the Cablevision database record.
    // Read the record. If it doesn't exist, create it.

    bxtreeroot = treeroot;
    treeroot = (NODE *) cvtreeroot;
    if (!(cvcurnode = (CVNODE *) btreefind( Flds[OCV_SERIAL_NUMBER]))) {
        cvcurnode = (CVNODE *) mypermmalloc( sizeof( CVNODE));

        strcpy( cvcurnode->CableBoxSerial, Flds[OCV_SERIAL_NUMBER]);
        cvcurnode->SiteID_C =
        cvcurnode->SiteID_B =
        cvcurnode->SiteID_A =
        cvcurnode->CurBoxAddMethod =
        cvcurnode->CurBoxReturnMethod = "";

        cvcurnode->StringSize =
        cvcurnode->CDFlagCCount =
        cvcurnode->CDFlagICount =
        cvcurnode->TCWFindateDays =
        cvcurnode->LocMDSLNKCount =
        cvcurnode->RprWarrantyNWCt =
        cvcurnode->RprWarrantyWXCt =
        cvcurnode->RprWarrantyFWCt =
        cvcurnode->RprWarrantyURCt =
        cvcurnode->RprWarrantyFSCt =
        cvcurnode->RprWarrantyOTCt =
        cvcurnode->TCSwapFlagCount =
        cvcurnode->RprChargeCount = (short)
       (cvcurnode->TCWFindate =
        cvcurnode->LocMDSLNKDate = (time_t)
       (cvcurnode->RprWarrantyNWAmt =
        cvcurnode->RprWarrantyWXAmt =
        cvcurnode->RprWarrantyFWAmt =
        cvcurnode->RprWarrantyURAmt =
        cvcurnode->RprWarrantyFSAmt =
        cvcurnode->RprWarrantyOTAmt =
        cvcurnode->RprTotalCharge = 0));

        btreestore( (NODE *) cvcurnode);
    }
    cvtreeroot = (CVNODE *) treeroot;
    treeroot = bxtreeroot;

    // Copy all the strings into the record (and currents to previouses).

    sprintf( TmpStr, "%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t"
        "%s\t%s\t%s\t%s\t%s\t%s\t",
        cvcurnode->SiteID_B,
        cvcurnode->SiteID_A,
        Flds[OCV_ORGANIZATION_CODE],
        cvcurnode->CurBoxAddMethod,
        Flds[OCV_BOX_ADD_METHOD],
        cvcurnode->CurBoxReturnMethod,
        Flds[OCV_BOX_RETURN_METHOD],
        Flds[OCV_LOCATOR],
        Flds[OCV_PREV_SUB_INVENTORY_CODE],
        Flds[OCV_PREV_ORGANIZATION_CODE],
        Flds[OCV_PREV_ORG_ACRONYM],
        Flds[OCV_TC_TECH],
        Flds[OCV_TC_INHOUSE_CONT_FLAG],
        Flds[OCV_TC_FIX_CODE_STR],
        Flds[OCV_RPR_SCRAPPED_FLAG],
        Flds[OCV_RPR_PART_NBR_STR],
        Flds[OCV_RPR_PART_DESCR_STR],
        Flds[OCV_ORGANIZATION_CODE],
        Flds[OCV_ORG_ACRONYM]);

    // If the current string space is large enough, re-use it.
    // Otherwise discard it and allocate a larger block.

    ret = 1 + strlen( TmpStr);
    if (ret > cvcurnode->StringSize) {
        sptr = mypermmalloc( 1 + strlen( TmpStr));
        cvcurnode->StringSize = ret;
    }
    else sptr = cvcurnode->SiteID_C;
    strcpy( sptr, TmpStr);

    cvcurnode->SiteID_C =             NextString( &sptr);
    cvcurnode->SiteID_B =             NextString( &sptr);
    cvcurnode->SiteID_A =             NextString( &sptr);
    cvcurnode->PrevBoxAddMethod =     NextString( &sptr);
    cvcurnode->CurBoxAddMethod =      NextString( &sptr);
    cvcurnode->PrevBoxReturnMethod =  NextString( &sptr);
    cvcurnode->CurBoxReturnMethod =   NextString( &sptr);
    cvcurnode->Locator =              NextString( &sptr);
    cvcurnode->PrevSubInventoryCode = NextString( &sptr);
    cvcurnode->PrevOrganizationCode = NextString( &sptr);
    cvcurnode->PrevOrgAcronym =       NextString( &sptr);
    cvcurnode->TCTech =               NextString( &sptr);
    cvcurnode->TCInhouseContFlag =    NextString( &sptr);
    cvcurnode->TCFixCodeStr =         NextString( &sptr);
    cvcurnode->RprScrappedFlag =      NextString( &sptr);
    cvcurnode->RprPartNbrStr =        NextString( &sptr);
    cvcurnode->RprPartDescr =         NextString( &sptr);
    cvcurnode->OrganizationCode =     NextString( &sptr);
    cvcurnode->OrgAcronym =           NextString( &sptr);

    // Set various numeric fields.

    if (TempDate = ConvertMDYToTimet( Flds[OCV_TC_WFINDATE]) < 0) TempDate = 0;
    if (TempDate && cvcurnode->TCWFindate)
        cvcurnode->TCWFindateDays = (short)
            ((TempDate - cvcurnode->TCWFindate) / SECSINADAY);
    cvcurnode->TCWFindate = TempDate;

    if (*Flds[OCV_TC_BOX_SWAP_FIX_CD_FLAG] == 'C') ++cvcurnode->CDFlagCCount;
    else if (*Flds[OCV_TC_BOX_SWAP_FIX_CD_FLAG] == 'I') ++cvcurnode->CDFlagICount;

    if (!strcmp( Flds[OCV_SUB_INVENTORY_CODE], "MDSLNK")) {
        strcpy( fCompanyRegion, "TRANS");
        ++cvcurnode->LocMDSLNKCount;
        if (!cvcurnode->LocMDSLNKDate)
            cvcurnode->LocMDSLNKDate = GetMDYAsTimet();
    }
    else cvcurnode->LocMDSLNKDate = (time_t) 0;

    // If there's a warranty description, set some counts and amounts.

    amt = OCVGetAmount();
    if (*(sptr = Flds[OCV_RPR_WARRANTY_DESCR])) {
        if (!strcmp( sptr, "NO WARRANTY - SPECIAL PROJECT")) {
            ++cvcurnode->RprWarrantyNWCt;
            cvcurnode->RprWarrantyNWAmt += amt;
        }
        else if (!strcmp( sptr, "MANUFACTURER WARRANTY EXPIRED")) {
            ++cvcurnode->RprWarrantyWXCt;
            cvcurnode->RprWarrantyWXAmt += amt;
        }
        else if (!strcmp( sptr, "REPAIRED UNDER FULL MFG WTY")) {
            ++cvcurnode->RprWarrantyFWCt;
            cvcurnode->RprWarrantyFWAmt += amt;
        }
        else if (!strcmp( sptr, "UNREPAIRABLE")) {
            ++cvcurnode->RprWarrantyURCt;
            cvcurnode->RprWarrantyURAmt += amt;
        }
        else if (!strcmp( sptr, "FAILED SCREEN AND CLEAN")) {
            ++cvcurnode->RprWarrantyFSCt;
            cvcurnode->RprWarrantyFSAmt += amt;
        }
        else {
            ++cvcurnode->RprWarrantyOTCt;
            cvcurnode->RprWarrantyOTAmt += amt;
        }
    }

    // If there's any charge at all, count it.

    if (amt > 0) {
        ++cvcurnode->RprChargeCount;
        cvcurnode->RprTotalCharge += amt;
    }

    // If the swap flag is set, bump the count.

    if (*Flds[OCV_TC_SWAP_FLAG]) ++cvcurnode->TCSwapFlagCount;

    // Write the output record to the file, if desired.

#ifdef CBA_VERSION
    OldLocation = (PreviousState == 'U') ? "" : dStrings[DB_LOCATION];
#endif

    if (WriteOutputFiles) {
        if (!FindCableBoxMap()) return -3;
        if (ofhdl) {
#ifdef CBA_VERSION
            OldExternalState =
                (PreviousState == 'U') ? "U" : dStrings[DB_EXTERNALSTATE];
#else
            if (PreviousState == 'U') {
                OldExternalState = "U";
                OldLocation = "";
            }
            else {
                OldExternalState = dStrings[DB_EXTERNALSTATE];
                OldLocation = dStrings[DB_LOCATION];
            }
#endif

#if 0 //@@ #ifdef _DEBUG
            fprintf( ofhdl, "%d,%s,%s,%d,%d,%s->%s,%c->%c,\"%s\",\"%s\",\"%s\"\n",
                RecordCount + 31,               // line number
                "\"\"",                         // tag
                Flds[OCV_BEGIN_DATE],           // date of state
                DaysBetweenStates,              // days in state
                ShortInHouseField,              // Short In House flag
                dStrings[DB_EXTERNALSTATE],     // previous external state
                fExternalState,                 // current external state
                curnode->CurrentState,          // previous internal state
                fStatusCode,                    // current internal state
                dStrings[DB_CABLEBOXMODEL],     // old model (truncate at "|")
                Flds[OCV_BOX_TYPE],             // new model
                DebugAction);                   // action
#endif
#if 1 //@@
            fprintf( ofhdl,
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "\"%s\","
                "%d,"
                "%d,"
                "%s,"
                "%s,"
                "%s,"
                "%s,"
                "%s\n",
                Flds[OCV_TM_MATERIAL_TRANS_ID],
                Flds[OCV_MTL_ITEM_ID],
                Flds[OCV_SERIAL_NUMBER_ID],
                Flds[OCV_SERIAL_NUMBER],
                Flds[OCV_PURCHASED_DATE],
                Flds[OCV_INVENTORY_ITEM_ID],
                Flds[OCV_ITEM],
                Flds[OCV_BOX_TYPE],
                Flds[OCV_BEGIN_DATE],
                Flds[OCV_END_DATE],
                Flds[OCV_DAYS_IN_STATUS],
                Flds[OCV_BOX_ADD_METHOD],
                Flds[OCV_BOX_RETURN_METHOD],
                Flds[OCV_NFM_MATERIAL_TRANS_ID],
                Flds[OCV_SUB_INVENTORY_CODE],
                Flds[OCV_LOCATOR],
                Flds[OCV_ORGANIZATION_CODE],
                Flds[OCV_ORG_ACRONYM],
                Flds[OCV_PREV_SUB_INVENTORY_CODE],
                Flds[OCV_PREV_LOCATOR],
                Flds[OCV_PREV_ORGANIZATION_CODE],
                Flds[OCV_PREV_ORG_ACRONYM],
                Flds[OCV_CORP],
                Flds[OCV_HOUSE],
                Flds[OCV_CUST],
                Flds[OCV_TC_SWAP_FLAG],
                Flds[OCV_TC_BOX_SWAP_FIX_CD_FLAG],
                Flds[OCV_TC_WFINDATE],
                Flds[OCV_TC_TECH],
                Flds[OCV_TC_INHOUSE_CONT_FLAG],
                Flds[OCV_TC_FIX_CODE_STR],
                Flds[OCV_RPR_WARRANTY_REPAIR_CODE],
                Flds[OCV_RPR_WARRANTY_DESCR],
                Flds[OCV_RPR_SCRAPPED_FLAG],
                Flds[OCV_REPAIR_AMT],
                Flds[OCV_RPR_PART_NBR_STR],
                Flds[OCV_RPR_PART_DESCR_STR],
                DaysBetweenStates,
                ShortInHouseField,
                OCVGetStateTime(),
                GetFullStateName( fStatusCode),
                GetFullStateName( PreviousState),
                fExternalState,
                OldExternalState);
#endif
        }
    }

    UpdateCableBoxRecord();         // save the updated info
    return 1;
}


/*
 * OCVGETSTATE - Figure out and return the OCV state.
 */
char *OCVGetState( void)
{
    if (strstr( Flds[OCV_SUB_INVENTORY_CODE], "DISCONNECT")) return "DISCONNECT";
    if (strstr( Flds[OCV_SUB_INVENTORY_CODE], "CONNECT"))    return "CONNECT";
    if (strstr( Flds[OCV_ORGANIZATION_CODE], "3PL"))         return "REPAIR";
    if (strstr( Flds[OCV_ORGANIZATION_CODE], "TEC"))         return "TECT";
    if (strstr( Flds[OCV_LOCATOR], "SCRAP"))                 return "SCRAP";
    if (strstr( Flds[OCV_LOCATOR], "STAGING"))               return "STAGING";
    if (strstr( Flds[OCV_SUB_INVENTORY_CODE], "TEST"))       return "TEST";
    if (strstr( Flds[OCV_SUB_INVENTORY_CODE], "FAIL"))       return "FAIL";
    if (strstr( Flds[OCV_SUB_INVENTORY_CODE], "GOOD"))       return "GOOD";
    if (strstr( Flds[OCV_ORGANIZATION_CODE], "WIC"))         return "STORE";
//  if (strstr( Flds[OCV_LOCATOR], "CAGE"))                  return "OTHER";
    return "OTHER";
}


/*
 * OCVGETSTATETIME - Extract the time from the OCV begin date field.
 * End the date in that field with a NULL.
 */
char *OCVGetStateTime( void)
{
    char *sptr;

    sptr = Flds[OCV_BEGIN_DATE];
    while (*sptr != ' ') ++sptr;
    *sptr++ = '\0';
    return sptr;
}


/*
 * OCVGETLOCATION - Copy the OCV Location into the given string.
 */
char *OCVGetLocation( char *TmpStg)
{
    if (strcmp( Flds[OCV_LOCATOR], ".") && strcmp( Flds[OCV_LOCATOR], "...."))
        return Flds[OCV_SUB_INVENTORY_CODE];

    sprintf( TmpStg, "%s-%s-%s",
        Flds[OCV_CORP], Flds[OCV_HOUSE], Flds[OCV_CUST]);
    return TmpStg;
}


/*
 * OCVGETAMOUNT - Return the given amount, in cents (ie, times 100).
 */
long OCVGetAmount( void)
{
    char *sptr, chr;
    long amt;
    short dotflag;

    dotflag = (short) (amt = 0);
    sptr = Flds[OCV_REPAIR_AMT];
    while (chr = *sptr++) {
        if (chr == '.') dotflag = 1;
        else if ((chr >= '0') && (chr <= '9')) amt = (amt * 10) + (chr - '0');
    }
    if (!dotflag) amt *= 100;

    return amt;
}


/*
 * READCABLEBOXRECORD - Find the record of the given serial number in the
 * binary tree. If not found, add it. Either way, return curnode pointing
 * to the record.
 */
void ReadCableBoxRecord( void)
{
    short RecordExists;

    if (!(curnode = btreefind( fCableBoxSerial))) {
        RecordExists = 0;
        if (!(curnode = (NODE *) mydbmalloc( sizeof( NODE)))) return;

        strcpy( curnode->CableBoxSerial, fCableBoxSerial);

        if (DoingUniversal) {
            curnode->CurrentState = 'U';
            curnode->Universal = 1;
        }
        else {
            curnode->CurrentState = 'U';
            curnode->Universal = 0;
        }
#ifdef CBA_VERSION
        curnode->DateCBAFlag = (time_t) 0;
        curnode->TimesCBAFlag = 0;

        curnode->DateOfStateB =
        curnode->DateOfStateC =
#endif
        curnode->DateOfState = StartOfWorld;
        curnode->RDaysUnknown =
        curnode->RDaysHouse =
        curnode->RDaysReturn =
        curnode->RDaysRepair =
        curnode->RDaysOther =
        curnode->RDaysTech =
        curnode->PDaysUnknown =
        curnode->PDaysHouse =
        curnode->PDaysReturn =
        curnode->PDaysRepair =
        curnode->PDaysOther =
        curnode->PDaysTech =
        curnode->RToHouse =
        curnode->RToReturn =
        curnode->RToRepair =
        curnode->RToOther =
        curnode->RToTech =
        curnode->PToHouse =
        curnode->PToReturn =
        curnode->PToRepair =
        curnode->PToOther =
        curnode->PToTech =
        curnode->ShortInHouse =
        curnode->IllegalTransitions =
        curnode->ShortInHouseBU =
        curnode->HouseDays = 0;
        curnode->HouseDate = (time_t) 0;
        curnode->Strings = fStrings;

        btreestore( curnode);

#ifdef CBA_VERSION
        dStrings[DB_STATEB] =
        dStrings[DB_LOCATIONB] =
        dStrings[DB_STATEC] =
        dStrings[DB_LOCATIONC] = "";
#endif

        // Bump the appropriate Model Counts record.
        // If one does not exist, create it.

        if (ModelCountsDirty != -1) {
            char Key[100];

            sprintf( Key, "\"%s\",\"%s\"", fCompanyRegion,
                (DoingCSG == 2) ? Flds[OCV_BOX_TYPE] :
                ((DoingCSG) ? Flds[CSG_BOXMODEL] : Flds[ICM_ITEMDESC]));
            bxtreeroot = treeroot;
            treeroot = (NODE *) cttreeroot;

            if (ctcurnode = (CTNODE *) btreefindp( Key)) ++ctcurnode->GL_Count;
            else {
                ctcurnode = (CTNODE *) mypermmalloc( sizeof( CTNODE));
                ctcurnode->SiteID_Model = mypermmalloc( 1 + strlen( Key));
                strcpy( ctcurnode->SiteID_Model, Key);
                ctcurnode->GL_Count = 1;

                btreestorep( ctcurnode);
            }
            treeroot = bxtreeroot;
            ModelCountsDirty = 1;
        }
    }
    else {
        // There's an existing record.

        RecordExists = 1;
        if (DoingUniversal && (curnode->Universal == 1))
            curnode->CurrentState = fStatusCode;
    }

    strcpy( dbStrings, curnode->Strings);
    dStrings[DS_BILLINGSYSTEM] = "";
    SplitOnTabsIntoArray( dbStrings, (char **) &dStrings);
    strcpy( HouseLocation, dStrings[DB_HOUSELOCATION]);

    // If there is no billing system defined, set it now.
    // If it's a new record, set up what type of file is being processed.
    // Otherwise make a guess at what the existing record came from.
    // The CompanyRegion field should have one dash for CSG, two for ICOMMS.

    if (!*dStrings[DS_BILLINGSYSTEM]) {
        if (RecordExists) {
            char *sptr, chr;
            short cnt;

            cnt = 0;
            sptr = dStrings[DB_COMPANYREGION];
            while (chr = *sptr++) if (chr == '-') ++cnt;
            dStrings[DS_BILLINGSYSTEM] =
                (cnt == 2) ? "I" : ((cnt) ? "C" : "O");
        }
        else dStrings[DS_BILLINGSYSTEM] =
            (DoingCSG == 2) ? "O" : ((DoingCSG) ? "C" : "I");
    }
    if (!RecordExists) dStrings[DB_EXTERNALSTATE] = "";
}


/*
 * CALCULATEONSTATE - Make calculations on the database record in curnode
 * using the data from the input file record.
 * Returns 1 on success, -1 on failure, -2 to ignore the record.
 */
long CalculateOnState( void)
{
    char LocTemp[100];

    ShortInHouseField = 0;

    // Make calculations depending on the state transition.
    // If desired, mutate an external Q state from Return to Repair.
    // (Note that the "CSG_" constants below have the same values for ICM.

#ifdef _DEBUG
    if (MutateQState) {
        if (fDateOfState < JAN_2_2012) {
            if (!strcmp( fExternalState, "Q")) {
                if (!strcmp( Flds[ICM_SITEID], "1")) {
                    if (strcmp( dStrings[DB_EXTERNALSTATE], "P") &&
                        strcmp( dStrings[DB_EXTERNALSTATE], "O") &&
                        strcmp( dStrings[DB_EXTERNALSTATE], "Z")) {
                            DebugAction = "iP changed to iR";
                            fStatusCode = 'R';
                    }
                }
                else {
                    DebugAction = "iP changed to iR";
                    fStatusCode = 'R';
                }
            }
        }
    }
#else
    if (MutateQState &&
        (fDateOfState < JAN_2_2012) &&
        !strcmp( fExternalState, "Q"))
    {
        if (!strcmp( Flds[ICM_SITEID], "1")) {
            if (strcmp( dStrings[DB_EXTERNALSTATE], "P") &&
                strcmp( dStrings[DB_EXTERNALSTATE], "O") &&
                strcmp( dStrings[DB_EXTERNALSTATE], "Z"))
                    fStatusCode = 'R';
        }
        else fStatusCode = 'R';
    }
#endif

    // Get the state transition information.

    GetStateTransition( curnode->CurrentState, fStatusCode);

    // Possibly bump the day count of the old state.
    // Note: curnode->DateOfState is the date of the previous state,
    //       fDateOfState         is the date of the new state.

    DaysBetweenStates = 0;
    if (StateTransitionsPtr->AccumFromDays) {
        // If the date of the current state is earlier than that of the
        // previous state, return failure.

        DaysBetweenStates = (short)
            ((fDateOfState - curnode->DateOfState) / SECSINADAY);
        if (DaysBetweenStates < 0) {
            char RD[11], DD[11];

            sprintf( LocTemp, "@@@Negative days in state: "
                "%d  %s  Rec: %s  DB: %s\n",
                DaysBetweenStates,
                Flds[ICM_SERIAL],
                ConvertTimetToMDY( fDateOfState, DD),
                ConvertTimetToMDY( curnode->DateOfState, DD));
            AppendErrorMessage( LocTemp, "", 0);

            if (((DoingCSG == 1) && (*dStrings[DS_BILLINGSYSTEM] == 'I')) ||
                ((DoingCSG == 0) && (*dStrings[DS_BILLINGSYSTEM] == 'C')) ||
                ((DoingCSG == 2) && (*dStrings[DS_BILLINGSYSTEM] == 'O'))) {
                    AppendErrorMessage( "Returning -2 (skip record)\n", "", 0);
                    return -2;
            }

            // Return -2 to ignore the record, -1 to abort processing.

            if (curnode->DateOfState != StartOfWorld) {
                if (!curnode->Universal) {
                    AppendErrorMessage( "Returning -1 (abort processing)\n", "", 0);
                    return -1;
                }
            }
            else if (fDateOfState != (time_t) -1) StartOfWorld = fDateOfState;
            DaysBetweenStates = 0;
        }

        // Note that the box is moving from CurrentState to fStatusCode.

        switch (curnode->CurrentState) {
          case 'U':
            curnode->RDaysUnknown += DaysBetweenStates;
            curnode->PDaysUnknown += DaysBetweenStates;
            break;
          case 'H':
            curnode->RDaysHouse += DaysBetweenStates;
            curnode->PDaysHouse += DaysBetweenStates;
            break;
          case 'R':
            curnode->RDaysReturn += DaysBetweenStates;
            curnode->PDaysReturn += DaysBetweenStates;
            break;
          case 'P':
            curnode->RDaysRepair += DaysBetweenStates;
            curnode->PDaysRepair += DaysBetweenStates;
            break;
          case 'T':
            curnode->RDaysTech += DaysBetweenStates;
            curnode->PDaysTech += DaysBetweenStates;
            break;
          case 'O':
            curnode->RDaysOther += DaysBetweenStates;
            curnode->PDaysOther += DaysBetweenStates;
        }
    }

    // If moving from house, see if the time in house was too short.

    if (curnode->CurrentState == 'H') {
        if (fStatusCode == 'H') {
            strcpy( LocTemp, fLocation);
            if (HouseLocationFlag == 1) strcat( LocTemp, fAddress);

            if (!IgnoreLocation && (HouseLocationFlag != 2) &&
                !strcmp( dStrings[DB_HOUSELOCATION], LocTemp))
                    goto ToSameHouse;
        }

        if (DaysBetweenStates < valShortInHouse) {
                ++curnode->ShortInHouse;
                ++curnode->ShortInHouseBU;
                ShortInHouseField = 1;
                AppendModelData( 'S', fDateOfState);
        }
    }
ToSameHouse:

    // If moving into House and the Location is the same as the last
    // time in House, possibly negate a previous Short in House.

    if (fStatusCode == 'H') {
#if 0 //@@
        if (DebugFlag & 2) {
            AppendErrorMessage( "    %s to House,,,,,%d\n",
                curnode->CableBoxSerial, fDateOfState);
        }
#endif

        strcpy( LocTemp, fLocation);
        if (HouseLocationFlag == 1) strcat( LocTemp, fAddress);

        if (!IgnoreLocation && (HouseLocationFlag != 2) &&
            !strcmp( dStrings[DB_HOUSELOCATION], LocTemp))
        {
            if (curnode->HouseDays == 1) {
                --curnode->ShortInHouse;
                --curnode->ShortInHouseBU;
                --ShortInHouseField;
                AppendModelData( 'C', fDateOfState);
            }

            // If moving from House to House, keep the earlier date of state.

            if (curnode->CurrentState == 'H')
                fDateOfState = curnode->DateOfState;
        }
        strcpy( HouseLocation, LocTemp);
    }

    // For Hawaii, if moving from external state D to A and Short In House
    // was previously set, negate SIH by outputting -1. Also, decrement counts.

    if (MutateQState &&
        (curnode->HouseDays == 1) &&
        !strcmp( dStrings[DB_EXTERNALSTATE], "D") &&
        !strcmp( fExternalState, "A"))
    {
        --curnode->ShortInHouse;
        --curnode->ShortInHouseBU;
        --ShortInHouseField;
        AppendModelData( 'C', fDateOfState);
    }

    // If moving to repair or out of service, or in house for more than
    // 90 days, see if the box is on the watch list.
    // If so, reset all its counters and add the box to the Box Reset list.

#if 0   //@@@
    if ((AutoRollback & 5) && (fStatusCode == 'S') &&
        !strcmp( curnode->CableBoxSerial, "71YBMU5CX216967")) {
        --ShortInHouseField;
    }
#endif

    if (AutoRollback &&
        (((AutoRollback & 3) && (fStatusCode == 'P')) ||
         ((AutoRollback & 5) && (fStatusCode == 'S')) ||
         ((AutoRollback & 9) &&
          (curnode->CurrentState == 'H') && (DaysBetweenStates > 90))))
            RollBackCableBox();

    // Possibly bump the transition count of the new state.

    if (StateTransitionsPtr->AccumToCount) {
        switch (fStatusCode) {
          case 'H':
            if (ShortInHouseField != -1) curnode->HouseDate = fDateOfState;
            if (IgnoreLocation || (HouseLocationFlag == 2) ||
                strcmp( dStrings[DB_HOUSELOCATION], LocTemp))
            {
                ++curnode->RToHouse;
                ++curnode->PToHouse;
            }
            break;
          case 'R':
            ++curnode->RToReturn;
            ++curnode->PToReturn;
            break;
          case 'P':
            ++curnode->RToRepair;
            ++curnode->PToRepair;
            break;
          case 'T':
            ++curnode->RToTech;
            ++curnode->PToTech;
            break;
          case 'O':
            ++curnode->RToOther;
            ++curnode->PToOther;
        }
    }

    // If it's not a legal transition, save the from and to states.

    StatusOutOfSequence[0] = '\0';
    if (!StateTransitionsPtr->LegalMove) {
        sprintf( StatusOutOfSequence, "%s-%s",
            GetFullStateName( curnode->CurrentState),
            GetFullStateName( fStatusCode));
        ++curnode->IllegalTransitions;
    }

    return 1;
}


/*
 * UPDATECABLEBOXRECORD - Update the database record in curnode using the
 * data from the input file.
 */
void UpdateCableBoxRecord( void)
{
    unsigned long fStringLen;
    char line[100];
#ifdef CBA_VERSION
    char CtoBtoA[100];
#endif

    // Saves the information in the globals in the database record
    // for this cable box. The record is assumed to exist.

    // If the new Strings fits in the old space, just copy it in.
    // Otherwise allocate new string space to hold it.

    if (DoingUniversal) {
#ifdef CBA_VERSION
        mystgspacecur = mystgmalloc( strlen( fStrings) + 5);
        sprintf( mystgspacecur, "%s\t\t\t\t", fStrings);
#else
        mystgspacecur = mystgmalloc( strlen( fStrings) + 2);
        sprintf( mystgspacecur, "%s\t", fStrings);
#endif
        curnode->Strings = mystgspacecur;
        curnode->CurrentState = fStatusCode;
        curnode->DateOfState = fDateOfState;
        return;
    }

    // Save the current Short In House flag. Always for MutateQState,
    // only when moving from House for all others.

    if ((curnode->CurrentState == 'H') || MutateQState)
        curnode->HouseDays = ShortInHouseField;

    // Append the previous location to the strings.

    sprintf( line, "%s\t", HouseLocation);
    if (curnode->CurrentState != 'U') strcat( line, dStrings[DB_LOCATION]);
    strcat( fStrings, line);

    // Append the billing system (and two previous states and locations)
    // to the strings.

#ifdef CBA_VERSION
    curnode->DateOfStateC = curnode->DateOfStateB;
    curnode->DateOfStateB = curnode->DateOfState;

    if (StateChangeList) {
        sprintf( CtoBtoA, "%s to %s to %s",
                 (!*dStrings[DB_STATEB]) ? "U" : dStrings[DB_STATEB],
                 (!*dStrings[DB_EXTERNALSTATE]) ? "U" : dStrings[DB_EXTERNALSTATE],
                 fExternalState);

        for (StateChange = StateChangeList; StateChange;
             StateChange = StateChange->next)
        {
            if (!strcmp( CtoBtoA, StateChange->StateChange)) {
                curnode->DateCBAFlag = fDateOfState;
                ++curnode->TimesCBAFlag;
                break;
            }
        }
    }

    sprintf( line, "\t%s\t%s\t%s\t%s\t%s",
        dStrings[DS_BILLINGSYSTEM], OldLocation, dStrings[DB_LOCATIONB],
        dStrings[DB_EXTERNALSTATE], dStrings[DB_STATEB]);
#else
    sprintf( line, "\t%s", dStrings[DS_BILLINGSYSTEM]);
#endif
    strcat( fStrings, line);

    fStringLen = strlen( fStrings);
    if ((curnode->CurrentState == 'U') ||
        (strlen( curnode->Strings) < fStringLen))
    {
        long slen;

        slen = strlen( curnode->Strings);

        if (slen >= 65) goto LookForBig;
        if (slen >= 50) goto LookFor60;

        stringprev = (STRING *) NULL;
        for (stringptr = stringlist50; stringptr; stringptr = stringptr->next)
        {
            if (stringptr->len >= fStringLen) {
                mystgspacecur = (char *) stringptr;
                if (stringprev)
                     stringprev->next = stringptr->next;
                else stringlist50 = stringptr->next;
                --listlen50;
#if 0 //@@D
        {
        FILE *dfh;

        if ((dfh = fopen( "C:\\Debug.txt", "a")) != NULL) {
            fprintf( dfh, "re-using 50 string %4d for %4d. list len %d %d %d\n",
                stringptr->len, fStringLen, listlen50, listlen60, listlen);
            fclose( dfh);
        }
        }
#endif
                goto UseBlock;
            }
            stringprev = stringptr;
        }

LookFor60:
        stringprev = (STRING *) NULL;
        for (stringptr = stringlist60; stringptr; stringptr = stringptr->next)
        {
            if (stringptr->len >= fStringLen) {
                mystgspacecur = (char *) stringptr;
                if (stringprev)
                     stringprev->next = stringptr->next;
                else stringlist60 = stringptr->next;
                --listlen60;
#if 0 //@@D
        {
        FILE *dfh;

        if ((dfh = fopen( "C:\\Debug.txt", "a")) != NULL) {
            fprintf( dfh, "re-using 60 string %4d for %4d. list len %d %d %d\n",
                stringptr->len, fStringLen, listlen50, listlen60, listlen);
            fclose( dfh);
        }
        }
#endif
                goto UseBlock;
            }
            stringprev = stringptr;
        }

LookForBig:
        stringprev = (STRING *) NULL;
        for (stringptr = stringlist; stringptr; stringptr = stringptr->next)
        {
            if (stringptr->len >= fStringLen) {
                mystgspacecur = (char *) stringptr;
                if (stringprev)
                     stringprev->next = stringptr->next;
                else stringlist = stringptr->next;
                --listlen;
#if 0 //@@D
        {
        FILE *dfh;

        if ((dfh = fopen( "C:\\Debug.txt", "a")) != NULL) {
            fprintf( dfh, "re-using big string %4d for %4d. list len %d %d %d\n",
                stringptr->len, fStringLen, listlen50, listlen60, listlen);
            fclose( dfh);
        }
        }
#endif
                goto UseBlock;
            }
            stringprev = stringptr;
        }

        // Put the old string on the list.

        if (curnode->CurrentState != 'U') {
            stringptr = (STRING *) curnode->Strings;
            stringptr->len = slen;
            if (slen < 50) {
                stringptr->next = stringlist50;
                stringlist50 = stringptr;
                ++listlen50;
            }
            else if (slen < 65) {
                stringptr->next = stringlist60;
                stringlist60 = stringptr;
                ++listlen60;
            }
            else {
                stringptr->next = stringlist;
                stringlist = stringptr;
                ++listlen;
            }
        }

#if 0 //@@D
        {
        FILE *dfh;

        if (curnode->CurrentState != 'U') {
        if ((dfh = fopen( "C:\\Debug.txt", "a")) != NULL) {
            fprintf( dfh, "replace string %4d with %4d. list len %d %d %d\n",
                slen, fStringLen, listlen50, listlen60, listlen);
            fclose( dfh);
        }
        }
        }
#endif

        mystgspacecur = mystgmalloc( fStringLen + 1);
UseBlock:
        strcpy( mystgspacecur, fStrings);
        curnode->Strings = mystgspacecur;
    }
    else strcpy( curnode->Strings, fStrings);

    curnode->CurrentState = fStatusCode;
    curnode->DateOfState = fDateOfState;
    curnode->Universal = 0;
}


/*
 * DONEPROCESSING - Call when processing a CSG or ICOMMS file is done,
 * to clean up. Returns the current StartOfWorld and the record count,
 * as a string, in Line.
 */
void DoneProcessing( void)
{
    char SSOW[11], Line[50];

    if (WriteOutputFiles) CloseAllFiles();
    DoingUniversal = 0;

    if (StartOfWorld < 0) strcpy( SSOW, "0");
    else                  ConvertTimetToMDY( StartOfWorld, SSOW);

    sprintf( Line, "$DoneProcessing\t%s\t%d\t", SSOW, RecordCount);
    SendReply( Line);
}


#if 0 //@@ not used
/*
 * COUNTFILELINES - Return the number of lines in the file.
 */
long CountFileLines( char *FileName)
{
    long LineCount;
    FILE *fhdl;
    char line[501];

    LineCount = 0;
    if (!(fhdl = fopen( FileName, "r"))) return 0;
    while (fgets( line, 500, fhdl)) ++LineCount;
    fclose( fhdl);
    return LineCount;
}
#endif


/*
 * FINDEARLIESTDATE - Find the earliest date of state in the first 20000
 * lines of the inbound file. Set this up as StartOfWorld and return it
 * to the caller.
 */
void FindEarliestDate( void)
{
    char FileText[801], SOW[11];
    long Counter;
    time_t TimeOfNow, NewStartOfWorld, RecordDate;

    sprintf( FileText, "%s%s", InboundDir, Flds[1]);
    if (!(ifhdl = fopen( FileText, "r"))) {
        SendReply( "$FindEarliestDate\t0\t");
        return;
    }

    time( &TimeOfNow);
    NewStartOfWorld = TimeOfNow;

    ReadAndProcessCSVLine( FileText, ifhdl);        // skip the header
    for (Counter = 1; Counter < 20000; ++Counter) {
        if (!ReadAndProcessCSVLine( FileText, ifhdl)) break;
        if (SplitOnTabs( FileText) < 9) continue;
        RecordDate = ConvertMDYToTimet( Flds[ICM_STATEDATE]);
        if ((RecordDate >= 0) && (RecordDate < NewStartOfWorld))
            NewStartOfWorld = RecordDate;
    }
    fclose( ifhdl);

    if (NewStartOfWorld == TimeOfNow) NewStartOfWorld = JAN_1_1980;

    StartOfWorld = NewStartOfWorld;
    sprintf( FileText, "$FindEarliestDate\t%s\t",
        ConvertTimetToMDY( StartOfWorld, SOW));
    SendReply( FileText);
}


/*
 * WRITEINDEXFILE - Output an index file using the current data.
 * Call with "1" for CSG, "2" for ICOMMS.
 * Returns 1 if successful, 0 on failure.
 */
void WriteIndexFile( void)
{
    short DaysInState, TotalDays, DaysSinceReceipt;
    short RDaysUnknown, RDaysHouse, RDaysReturn, RDaysRepair, RDaysOther;
    short RDaysTech, RToHouse, PDaysUnknown, PDaysHouse, PDaysReturn;
    short PDaysRepair, PDaysOther, PDaysTech, FileCount, MDSLNKDays;
    long PercentInHouse, AvgDaysInHouse;
    long iRecordCount, MTBOF, TCOO, Temp;
    char RDateStg[17], SDateStg[17], OutputLine[800], Reply[100];
#ifdef CAPEQ_VERSION
    char TDateStg[17];
    short DaysBetween, AvgDaysBetween;
#endif
#ifdef CBA_VERSION
    short DaysCtoNow, DaysBtoNow;
    char SDateStgB[16], SDateStgC[16], SDateStgF[16], CtoBtoA[100], BtoA[100];
#endif
    FILE *WLMfhdl;
    short OutputToWLM;

    // Read the database if it hasn't already been done.

    DoingCSG = (*Flds[1] == '1') ? 1 : ((*Flds[1] == '2') ? 0 : 2);
    AlternateDir = Flds[2];
    *fStrings = '\0';
    time( &DateOfNow);
    ReadDatabaseFromDisk( DatabaseMode);
    WLMfhdl = (FILE *) NULL;
    bxtreeroot = treeroot;

    treeroot = (NODE *) wltreeroot;
    ReadWLDataFromDisk( DatabaseMode);
    wltreeroot = (WLNODE *) treeroot;

    treeroot = (NODE *) cvtreeroot;
    ReadCVDataFromDisk( DatabaseMode);
    cvtreeroot = (CVNODE *) treeroot;

#ifdef CAPEQ_VERSION
    treeroot = (NODE *) wotreeroot;
    ReadWODataFromDisk( DatabaseMode);

    treeroot = (NODE *) detreeroot;
    ReadDEDataFromDisk( DatabaseMode);
#endif
    treeroot = bxtreeroot;

    iRecordCount = FileCount = WritingIndexFile = 1;
    topofhdl = OpenIndexFile( "", BASIdentifier, 1);
    curnode = btfirstnode();
    OutputToWLM = (WatchDataDirty == -1) ? -1 : 0;

    while (curnode) {
        if (OutputToWLM == 1) OutputToWLM = 0;
        strcpy( dbStrings, curnode->Strings);
        SplitOnTabsIntoArray( dbStrings, (char **) &dStrings);

        if (!FindCableBoxMap()) {
            WritingIndexFile = 0;
            SendReply( "$WriteIndexFile\t0\t\t");
            return;
        }

        DaysInState = (short) ((DateOfNow - curnode->DateOfState) / SECSINADAY);

        RDaysUnknown = 0;
        RDaysHouse = curnode->RDaysHouse;
        RDaysReturn = curnode->RDaysReturn;
        RDaysRepair = curnode->RDaysRepair;
        RDaysOther = curnode->RDaysOther;
        RDaysTech = curnode->RDaysTech;

        PDaysUnknown = 0;
        PDaysHouse = curnode->PDaysHouse;
        PDaysReturn = curnode->PDaysReturn;
        PDaysRepair = curnode->PDaysRepair;
        PDaysOther = curnode->PDaysOther;
        PDaysTech = curnode->PDaysTech;

        switch (curnode->CurrentState) {
          case 'H':
            RDaysHouse += DaysInState;
            PDaysHouse += DaysInState;
            break;
          case 'R':
            RDaysReturn += DaysInState;
            PDaysReturn += DaysInState;
            break;
          case 'P':
            RDaysRepair += DaysInState;
            PDaysRepair += DaysInState;
            break;
          case 'T':
            RDaysTech += DaysInState;
            PDaysTech += DaysInState;
            break;
          case 'O':
            RDaysOther += DaysInState;
            PDaysOther += DaysInState;
        }

        PercentInHouse = ((TotalDays = RDaysHouse + RDaysReturn +
            RDaysRepair + RDaysOther + RDaysTech) <= 0) ?
            0 : ((RDaysHouse * 100000) / TotalDays) + 5;

        AvgDaysInHouse = ((RToHouse = curnode->RToHouse) <= 0) ?
            0 : ((RDaysHouse * 1000) / RToHouse) + 5;

        TotalDays += RDaysUnknown;

        DaysSinceReceipt = 0;
        if (fReceiptDate = curnode->ReceiptDate)
            DaysSinceReceipt = (short) ((DateOfNow - fReceiptDate) / SECSINADAY);

#ifdef CBA_VERSION
        if (!*dStrings[DB_STATEB]) {
            DaysBtoNow = 0;
            sprintf( BtoA, "U to %s", dStrings[DB_EXTERNALSTATE]);
        }
        else {
            DaysBtoNow = (DateOfNow - curnode->DateOfStateB) / SECSINADAY;
            sprintf( BtoA, "%s to %s",
                dStrings[DB_STATEB], dStrings[DB_EXTERNALSTATE]);
        }

        if (!*dStrings[DB_STATEC]) {
            DaysCtoNow = 0;
            sprintf( CtoBtoA, "U to %s", BtoA);
        }
        else {
            DaysCtoNow = (DateOfNow - curnode->DateOfStateC) / SECSINADAY;
            sprintf( CtoBtoA, "%s to %s", dStrings[DB_STATEC], BtoA);
        }
#endif

#if 0 //@@ disabled
        // If this box is flaky, write it to the watch file.

        if (WriteWatchFile &&
            (curnode->ShortInHouse >= WatchSIH) &&
            (AvgDaysInHouse <= WatchAverageDays) &&
            (PercentInHouse <= WatchPercentDays) &&
            ((curnode->CurrentState != 'H') || (DaysInState < 90)))
        {
            if (!wfhdl) OpenWatchFile();
#if 1 //@@ #ifdef _DEBUG
            fprintf( wfhdl, "%s,%d,%d.%02d,%d.%02d\n",
                curnode->CableBoxSerial,
                curnode->ShortInHouse,
                (PercentInHouse / 1000), ((PercentInHouse / 10) % 100),
                (AvgDaysInHouse / 1000), ((AvgDaysInHouse / 10) % 100));
#else
            fprintf( wfhdl, "%s\n", curnode->CableBoxSerial);
#endif
        }
#endif

        sprintf( OutputLine,
#ifdef CBA_VERSION
            ((AddFiveFields) ?
            "\"%s\",\"%s\",\"%s\",\"%s\",%d,%d,%d,%d,\"%s\",%d,%d,%d,%d,%d,"
            "%d.%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d.%02d,%d.%02d,%d,%d,"
            "\"%s|%s\",%d,\"%s\",\"%s|%s\",\"%s\",\"%s\",\"%s\","
            "%s,%s,\"%s\",\"%s\",\"%s\",\"%s\",%d,%d,\"%s\",\"%s\",\"%s\",%d,0,0,0," :
            "\"%s\",\"%s\",\"%s\",\"%s\",%d,%d,%d,%d,\"%s\",%d,%d,%d,%d,%d,"
            "%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d.%02d,%d.%02d,%d,%d,"
            "\"%s|%s\",%d,\"%s\",\"%s|%s\",\"%s\",\"%s\",\"%s\","
            "\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",%d,%d,\"%s\",\"%s\",\"%s\",%d"),
#else
            ((AddFiveFields) ?
            "\"%s\",\"%s\",\"%s\",\"%s\",%d,%d,%d,%d,\"%s\",%d,%d,%d,%d,%d,"
            "%d.%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d.%02d,%d.%02d,%d,%d,"
            "\"%s|%s\",%d,\"%s\",\"%s|%s\",\"%s\",\"%s\",\"%s\",0,0,0,0," :
            "\"%s\",\"%s\",\"%s\",\"%s\",%d,%d,%d,%d,\"%s\",%d,%d,%d,%d,%d,"
            "%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d.%02d,%d.%02d,%d,%d,"
            "\"%s|%s\",%d,\"%s\",\"%s|%s\",\"%s\",\"%s\",\"%s\""),
#endif
            dStrings[DB_COMPANYREGION],
            dStrings[DB_CABLEBOXMAKE],
            dStrings[DB_CABLEBOXMODEL],
            curnode->CableBoxSerial,
            RDaysUnknown,
            RDaysHouse,
            RDaysReturn,
            RDaysRepair,
            (fReceiptDate ? ConvertTimetToMDY( fReceiptDate, RDateStg) : ""),
            RDaysTech,
            PDaysUnknown,
            PDaysHouse,
            PDaysReturn,
            PDaysRepair,
            PDaysOther,
            PDaysTech,
            RToHouse,
            curnode->RToReturn,
            curnode->RToRepair,
            DaysSinceReceipt,
            curnode->RToTech,
            curnode->PToHouse,
            curnode->PToReturn,
            curnode->PToRepair,
            curnode->PToOther,
            curnode->PToTech,
            curnode->ShortInHouse,
            (PercentInHouse / 1000), ((PercentInHouse / 10) % 100),
            (AvgDaysInHouse / 1000), ((AvgDaysInHouse / 10) % 100),
            curnode->IllegalTransitions,
            TotalDays,
            GetFullStateName(curnode->CurrentState), dStrings[DB_EXTERNALSTATE],
            DaysInState,
            BASIdentifier,
            dStrings[DS_PREVLOCATION], dStrings[DB_LOCATION],
            dStrings[DB_ADDRESS],
            dStrings[DB_ADDRESS2],
#ifdef CBA_VERSION
            ConvertTimetToMDY( curnode->DateOfState, SDateStg),
            dStrings[DB_STATEB],
            ConvertTimetToMDY( curnode->DateOfStateB, SDateStgB),
            dStrings[DB_LOCATIONB],
            dStrings[DB_STATEC],
            ConvertTimetToMDY( curnode->DateOfStateC, SDateStgC),
            dStrings[DB_LOCATIONC],
            DaysCtoNow,
            DaysBtoNow,
            CtoBtoA,
            BtoA,
            (!curnode->DateCBAFlag ? "" :
                ConvertTimetToMDY( curnode->DateCBAFlag, SDateStgF)),
            curnode->TimesCBAFlag);
#else
            ConvertTimetToMDY( curnode->DateOfState, SDateStg));
#endif

#if 0 //@@DEBUG - write out only records that have either a WO or a DET
        wocurnode = (WONODE *) NULL;
        if (WorkOrderDataDirty != -1) {
            treeroot = (NODE *) wotreeroot;
            wocurnode = (WONODE *) btreefind( curnode->CableBoxSerial);
        }

        decurnode = (DENODE *) NULL;
        if (DefectiveEquipmentDataDirty != -1) {
            treeroot = (NODE *) detreeroot;
            decurnode = (DENODE *) btreefind( curnode->CableBoxSerial);
        }
        treeroot = bxtreeroot;
        if (!wocurnode && !decurnode) {
            curnode = btnextnode();
            continue;
        }
#endif

        if (ofhdl) fprintf( ofhdl, "%s", OutputLine);
        fprintf( topofhdl, "%s", OutputLine);

        if (OutputToWLM != -1) {
            treeroot = (NODE *) wltreeroot;
            if (wlcurnode = (WLNODE *) btreefind( curnode->CableBoxSerial)) {
                if (!WLMfhdl) WLMfhdl = OpenIndexFile( "WLM_", BASIdentifier, 1);
                if (WLMfhdl) {
                    fprintf( WLMfhdl, "%s", OutputLine);
                    OutputToWLM = 1;
                }
                else OutputToWLM = -1;
            }
            treeroot = bxtreeroot;
        }

#ifdef CAPEQ_VERSION
        // If there is work order data, output it.

        if (cvtreeroot && cvtreeroot->rlink) goto StartCV;

        wocurnode = (WONODE *) NULL;
        if (WorkOrderDataDirty != -1) {
            treeroot = (NODE *) wotreeroot;
            wocurnode = (WONODE *) btreefind( curnode->CableBoxSerial);
            treeroot = bxtreeroot;
        }
        if (wocurnode) {
            sprintf( OutputLine, ",\"%s\",\"%s\",\"%s\",",
                (wocurnode->WOCompletionDatePrev ? ConvertTimetToMDY(
                    wocurnode->WOCompletionDatePrev, RDateStg) : ""),
                (wocurnode->WOCompletionDateCur ? ConvertTimetToMDY(
                    wocurnode->WOCompletionDateCur, SDateStg) : ""),
                (wocurnode->DateEntered ? ConvertTimetToMDY(
                    wocurnode->DateEntered, TDateStg) : ""));

            if (ofhdl) fprintf( ofhdl, "%s", OutputLine);
            fprintf( topofhdl, "%s", OutputLine);
            if (OutputToWLM == 1) fprintf( WLMfhdl, "%s", OutputLine);

            sprintf( OutputLine, "\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\","
                "\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\","
                "\"%s\",\"%s\",\"%s\",\"%s\",\"%s\"",
                FindDescription( wocurnode->ProblemCodePrev, ProbCodeRoot),
                FindDescription( wocurnode->ProblemCodeCur, ProbCodeRoot),
                FindDescription( wocurnode->FindingCodePrev, (PROBCODE *) FindCodeRoot),
                FindDescription( wocurnode->FindingCodeCur, (PROBCODE *) FindCodeRoot),
                FindDescription( wocurnode->SolutionCodePrev, (PROBCODE *) SolCodeRoot),
                FindDescription( wocurnode->SolutionCodeCur, (PROBCODE *) SolCodeRoot),
                wocurnode->AssignedInstallerPrev,
                wocurnode->AssignedInstallerCur,
                wocurnode->WorkOrderNoPrev,
                wocurnode->WorkOrderNoCur,
                wocurnode->WOtype,
                wocurnode->WOclass,
                wocurnode->WOstatus,
                wocurnode->QCode,
                wocurnode->BillTypeCode,
                (wocurnode->CheckinDatePrev ? ConvertTimetToMDY(
                    wocurnode->CheckinDatePrev, RDateStg) : ""),
                (wocurnode->CheckinDateCur ? ConvertTimetToMDY(
                    wocurnode->CheckinDateCur, SDateStg) : ""),
                FindDescription( wocurnode->DisconnectCode, (PROBCODE *) DiscCodeRoot),
                wocurnode->ItemNumber);
        }
        else strcpy( OutputLine, ",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\","
            "\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\","
            "\"\",");

        if (ofhdl) fprintf( ofhdl, "%s", OutputLine);
        fprintf( topofhdl, "%s", OutputLine);
        if (OutputToWLM == 1) fprintf( WLMfhdl, "%s", OutputLine);

        // If there is work order data, output it.

        decurnode = (DENODE *) NULL;
        if (DefectiveEquipmentDataDirty != -1) {
            treeroot = (NODE *) detreeroot;
            decurnode = (DENODE *) btreefind( curnode->CableBoxSerial);
            treeroot = bxtreeroot;
        }
        if (decurnode) {
            sprintf( OutputLine,
                ",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\","
                "\"%s\",\"%s\",\"%s\",\"%s\",\"%s\"",
                decurnode->SiteID,
                decurnode->Submitter,
                decurnode->SalesNo,
                decurnode->Model,
                decurnode->ProblemPrev,
                decurnode->ProblemCur,
                decurnode->Details,
                decurnode->DiagnosisPrev,
                decurnode->DiagnosisCur,
                decurnode->Solution,
                decurnode->Resolver,
                (decurnode->ResolvedDate ? ConvertTimetToMDYHMS(
                    decurnode->ResolvedDate, RDateStg) : ""),
                (decurnode->CreatedDate ? ConvertTimetToMDYHMS(
                    decurnode->CreatedDate, SDateStg) : ""));
        }
        else strcpy( OutputLine, ",\"\",\"\",\"\",\"\",\"\",\"\","
            "\"\",\"\",\"\",\"\",\"\",\"\",\"\"");

        if (ofhdl) fprintf( ofhdl, "%s", OutputLine);
        fprintf( topofhdl, "%s", OutputLine);
        if (OutputToWLM == 1) fprintf( WLMfhdl, "%s", OutputLine);

        // Output various calculations:
        // TCOO - Total cost of ownership.

        sprintf( OutputLine, ",%d,",
            (20 * curnode->PToRepair) + (71 * curnode->PToHouse) +
                (2 * curnode->PToTech));

        if (ofhdl) fprintf( ofhdl, "%s", OutputLine);
        fprintf( topofhdl, "%s", OutputLine);
        if (OutputToWLM == 1) fprintf( WLMfhdl, "%s", OutputLine);

        // If there's work order data:
        // Site IDs of the current and previous two work orders.
        // MTBOF - Mean Time Between Operational Failure.
        // CAP % Rem. - Percent of service life in existence.
        // Count of work orders.
        // Days between current and previous work orders.
        // Average days between work orders.

        MTBOF = RDaysHouse * 1000;
        if (curnode->ShortInHouse > 0)
            MTBOF = (MTBOF / (curnode->ShortInHouse + 1)) + 5;

        if (wocurnode) {
            if (wocurnode->TimesDiscovered == 1)
                DaysBetween = AvgDaysBetween = 0;
            else {
                DaysBetween = (short) ((wocurnode->DateEntered -
                    wocurnode->PrevDateEntered) / SECSINADAY);

                AvgDaysBetween = (short)
                    ((wocurnode->DateEntered - wocurnode->FirstDateEntered) /
                    (SECSINADAY * (wocurnode->TimesDiscovered - 1)));
            }

            // Get the percent of service life.

            DaysSinceReceipt = (DaysSinceReceipt * 100) / SERVICELIFE;

            sprintf( OutputLine, "\"%s\",\"%s\",\"%s\",%d.%02d,%d,%d,%d,%d,",
                wocurnode->SiteID_C,
                wocurnode->SiteID_B,
                wocurnode->SiteID_A,
                (MTBOF / 1000), ((MTBOF / 10) % 100),
                DaysSinceReceipt,
                wocurnode->TimesDiscovered,
                DaysBetween,
                AvgDaysBetween);
        }
        else sprintf( OutputLine, "\"\",\"\",\"\",%d.%02d,0,0,0,0,",
                (MTBOF / 1000), ((MTBOF / 10) % 100));

        if (ofhdl) fprintf( ofhdl, "%s", OutputLine);
        fprintf( topofhdl, "%s", OutputLine);
        if (OutputToWLM == 1) fprintf( WLMfhdl, "%s", OutputLine);

        // If there's defective equipment data:
        // Days between current and previous defective equipment records.
        // Count of defective equipment records.
        // Average days between defective equipment records.

        if (decurnode) {
            if (decurnode->TimesDiscovered == 1)
                DaysBetween = AvgDaysBetween = 0;
            else {
                DaysBetween = (short) (((decurnode->CreatedDate -
                    decurnode->PrevCreateDate) / SECSINADAY));

                AvgDaysBetween = (short)
                    ((decurnode->CreatedDate - decurnode->FirstCreateDate) /
                    (SECSINADAY * (decurnode->TimesDiscovered - 1)));
            }

            sprintf( OutputLine, "%d,%d,%d",
                DaysBetween,
                decurnode->TimesDiscovered,
                AvgDaysBetween);
        }
        else strcpy( OutputLine, "0,0,0");

        if (ofhdl) fprintf( ofhdl, "%s", OutputLine);
        fprintf( topofhdl, "%s", OutputLine);
        if (OutputToWLM == 1) fprintf( WLMfhdl, "%s", OutputLine);
        goto SkipCV;
StartCV:
#endif
        // If there is Cablevision data, find and output the corresponding node.

        // TCOO - Total cost of ownership.
        // MTBOF - Mean Time Between Operational Failure
        // Percent of service life.

        TCOO = (20 * curnode->PToRepair) + (71 * curnode->PToHouse) +
               (2 * curnode->PToTech);

        MTBOF = RDaysHouse * 1000;
        if (curnode->ShortInHouse > 0)
            MTBOF = (MTBOF / (curnode->ShortInHouse + 1)) + 5;

        DaysSinceReceipt = (DaysSinceReceipt * 100) / SERVICELIFE;

        if (cvtreeroot && cvtreeroot->rlink) {
            bxtreeroot = treeroot;
            treeroot = (NODE *) cvtreeroot;
            if ((cvcurnode = (CVNODE *) btreefind( curnode->CableBoxSerial))) {

                Temp = (cvcurnode->RprChargeCount) ?
                    cvcurnode->RprTotalCharge / cvcurnode->RprChargeCount : 0;

                MDSLNKDays = (short) ((cvcurnode->LocMDSLNKDate == (time_t) 0) ? 0 :
                    ((DateOfNow - cvcurnode->LocMDSLNKDate) / SECSINADAY));

                // If any of these values are negative, use 0 instead

                if (cvcurnode->RprWarrantyNWAmt < 0)
                    cvcurnode->RprWarrantyNWAmt = 0;
                if (cvcurnode->RprWarrantyWXAmt < 0)
                    cvcurnode->RprWarrantyWXAmt = 0;
                if (cvcurnode->RprWarrantyFWAmt < 0)
                    cvcurnode->RprWarrantyFWAmt = 0;
                if (cvcurnode->RprWarrantyURAmt < 0)
                    cvcurnode->RprWarrantyURAmt = 0;
                if (cvcurnode->RprWarrantyFSAmt < 0)
                    cvcurnode->RprWarrantyFSAmt = 0;
                if (cvcurnode->RprWarrantyOTAmt < 0)
                    cvcurnode->RprWarrantyOTAmt = 0;
                if (cvcurnode->RprTotalCharge < 0)
                    cvcurnode->RprTotalCharge = 0;

                sprintf( OutputLine,
                    ",%d,\"%s\",\"%s\",\"%s\",%d.%02d,%d,\"%s\",\"%s\",\"%s\","
                    "\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",%d,%d,%d,\"%s\",%d,\"%s\","
                    "\"%s\",\"%s\",%d,%d.%02d,%d,%d.%02d,%d,%d.%02d,%d,"
                    "%d.%02d,%d,%d.%02d,%d,%d.%02d,\"%s\",%d.%02d,%d.%02d,"
                    "\"%s\",\"%s\",%d,%d,\"%s\",\"%s\"",
                    TCOO,
                    cvcurnode->SiteID_C,
                    cvcurnode->SiteID_B,
                    cvcurnode->SiteID_A,
                    (MTBOF / 1000), ((MTBOF / 10) % 100),
                    DaysSinceReceipt,
                    cvcurnode->CurBoxAddMethod,
                    cvcurnode->PrevBoxAddMethod,
                    cvcurnode->CurBoxReturnMethod,
                    cvcurnode->PrevBoxReturnMethod,
                    cvcurnode->Locator,
                    cvcurnode->PrevSubInventoryCode,
                    cvcurnode->PrevOrganizationCode,
                    cvcurnode->PrevOrgAcronym,
                    cvcurnode->TCSwapFlagCount,
                    cvcurnode->CDFlagCCount,
                    cvcurnode->CDFlagICount,
                    (cvcurnode->TCWFindate ? ConvertTimetToMDYHMS(
                        cvcurnode->TCWFindate, SDateStg) : ""),
                    cvcurnode->TCWFindateDays,
                    cvcurnode->TCTech,
                    cvcurnode->TCInhouseContFlag,
                    cvcurnode->TCFixCodeStr,
                    cvcurnode->RprWarrantyNWCt,
                    (cvcurnode->RprWarrantyNWAmt / 100),
                    (cvcurnode->RprWarrantyNWAmt % 100),
                    cvcurnode->RprWarrantyWXCt,
                    (cvcurnode->RprWarrantyWXAmt / 100),
                    (cvcurnode->RprWarrantyWXAmt % 100),
                    cvcurnode->RprWarrantyFWCt,
                    (cvcurnode->RprWarrantyFWAmt / 100),
                    (cvcurnode->RprWarrantyFWAmt % 100),
                    cvcurnode->RprWarrantyURCt,
                    (cvcurnode->RprWarrantyURAmt / 100),
                    (cvcurnode->RprWarrantyURAmt % 100),
                    cvcurnode->RprWarrantyFSCt,
                    (cvcurnode->RprWarrantyFSAmt / 100),
                    (cvcurnode->RprWarrantyFSAmt % 100),
                    cvcurnode->RprWarrantyOTCt,
                    (cvcurnode->RprWarrantyOTAmt / 100),
                    (cvcurnode->RprWarrantyOTAmt % 100),
                    cvcurnode->RprScrappedFlag,
                    (cvcurnode->RprTotalCharge / 100),
                    (cvcurnode->RprTotalCharge % 100),
                    (Temp / 100),
                    (Temp % 100),
                    cvcurnode->RprPartNbrStr,
                    cvcurnode->RprPartDescr,
                    cvcurnode->LocMDSLNKCount,
                    MDSLNKDays,
                    cvcurnode->OrganizationCode,
                    cvcurnode->OrgAcronym);

                if (ofhdl) fprintf( ofhdl, "%s", OutputLine);
                fprintf( topofhdl, "%s", OutputLine);
                if (OutputToWLM == 1) fprintf( WLMfhdl, "%s", OutputLine);
            }
#ifdef CAPEQ_VERSION
SkipCV:
#endif
            treeroot = bxtreeroot;
        }

        if (ofhdl) fprintf( ofhdl, "\n");
        fprintf( topofhdl, "\n");
        if (OutputToWLM == 1) fprintf( WLMfhdl, "\n");

        // Every so often send status to VB.

        if (!(++iRecordCount % 25000)) {
            sprintf( Reply, "$Status\t%d\t", iRecordCount);
            SendReply( Reply);

            // If the file has enough records, close it and open a new file.

            if (!(iRecordCount % 5000000)) {
                printf( "Starting index file %d\n", ++FileCount);
                fclose( topofhdl);
                topofhdl = OpenIndexFile( "", BASIdentifier, FileCount);
            }
        }

        curnode = btnextnode();
    }

    printf( "Done writing index file. Records: %d Files: %d\n", iRecordCount, FileCount);
    WritingIndexFile = 0;
    AlternateDir = NULL;

    CloseAllFiles();
    fclose( topofhdl);
    if (WLMfhdl) fclose( WLMfhdl);
    SendReply( "$WriteIndexFile\t1\t\t");
}


/*
 * SETWATCHDATA - See if any cable box needs to be watched.
 * If so, add it to the watch data.
 * Call with flag == 0 if at the end of a week, 1 at the end of a file.
 */
void SetWatchData( short flag)
{
    char CurrentState;
    short DaysInState, TotalDays;
    short RDaysHouse, RDaysReturn, RDaysRepair, RDaysOther;
    short RDaysTech, RToHouse;
    long PercentInHouse, AvgDaysInHouse;

    // Read the main and watch databases if they haven't already been read.

//@@time( &DateOfNow);
    ReadDatabaseFromDisk( DatabaseMode);
    bxtreeroot = treeroot;
    treeroot = (NODE *) wltreeroot;
    ReadWLDataFromDisk( DatabaseMode);
    treeroot = bxtreeroot;

    curnode = btfirstnode();
    while (curnode) {
        // See if this box should be removed from the watch list and reset.

        fStatusCode = CurrentState = curnode->CurrentState;
//@@    DaysInState = (short) ((DateOfNow - curnode->DateOfState) / SECSINADAY);
//@@    DaysInState = (short) ((fDateOfState - curnode->DateOfState) / SECSINADAY);
        DaysInState = (short) ((MostRecentDOS - curnode->DateOfState) / SECSINADAY);

        if (DaysInState < 0) DaysInState = 0;
#if 0 //@@
        if (DebugFlag & 1) {
            if (CurrentState == 'H') {
#if DEBUGMSGSW
                if (RollBackCableBox()) {
                    ErrorWatchData( 0, PercentInHouse, AvgDaysInHouse, DaysInState);
                }
#else
                RollBackCableBox();
#endif
                goto Proceed;
            }
        }
        else
#endif
        {
            if ((CurrentState == 'H') && (DaysInState > 90)) {
#if DEBUGMSGSW
                if (RollBackCableBox()) {
                    ErrorWatchData( 0, PercentInHouse, AvgDaysInHouse, DaysInState);
                }
#else
                RollBackCableBox();
#endif
                goto Proceed;
            }
        }

        // See if this box should be added to the watch list.

        RDaysHouse  = curnode->RDaysHouse;
        RDaysReturn = curnode->RDaysReturn;
        RDaysRepair = curnode->RDaysRepair;
        RDaysTech   = curnode->RDaysTech;
        RDaysOther  = curnode->RDaysOther;

        switch (CurrentState) {
          case 'H': RDaysHouse  += DaysInState; break;
          case 'R': RDaysReturn += DaysInState; break;
          case 'P': RDaysRepair += DaysInState; break;
          case 'T': RDaysTech   += DaysInState; break;
          case 'O': RDaysOther  += DaysInState;
        }

        PercentInHouse = ((TotalDays = RDaysHouse + RDaysReturn +
            RDaysRepair + RDaysOther + RDaysTech) <= 0) ?
            0 : ((RDaysHouse * 100000) / TotalDays) + 5;

        AvgDaysInHouse = ((RToHouse = curnode->RToHouse) <= 0) ?
            0 : ((RDaysHouse * 1000) / RToHouse) + 5;

        // If this box is flaky, add it to the watch data.

        if ((CurrentState != 'S') && (CurrentState != 'P') &&
            (curnode->ShortInHouse >= WatchSIH) &&
            (AvgDaysInHouse <= WatchAverageDays) &&
            (PercentInHouse <= WatchPercentDays) &&
            ((curnode->CurrentState != 'H') || (DaysInState < 90)))
        {
#if 0   //@@@
            if (!strcmp( curnode->CableBoxSerial, "71YBMU5CX216967")) {
                bxtreeroot = treeroot;
            }
#endif

            bxtreeroot = treeroot;
            treeroot = (NODE *) wltreeroot;
            WatchDataDirty = 1;

            // If the watch entry already exists, set various fields.

            if (wlcurnode = (WLNODE *) btreefind( curnode->CableBoxSerial)) {
                // If the entry is active, just bump times discovered.
                // If the action in Unknown, set it.
                // Otherwise make the entry active and set several fields.

                ++wlcurnode->TimesDiscovered;
                wlcurnode->Action = 5;

                if (wlcurnode->WatchFlag == WF_INACTIVE) {
                    ++wlcurnode->TimesOnList;
                    wlcurnode->DaysSincePrevious = (short)
                        ((fDateOfState - wlcurnode->LatestDate) /
                        SECSINADAY);
                    wlcurnode->LatestDate = fDateOfState;
                    wlcurnode->WatchFlag = WF_ACTIVE;
#if DEBUGMSGSW
                    ErrorWatchData( 1, PercentInHouse, AvgDaysInHouse, DaysInState);
#endif
                    AppendModelData( 'W', fDateOfState);
                }
#if DEBUGMSGS0 // DEBUGMSGSW
                else if (flag == 1)
                    ErrorWatchData( 3, PercentInHouse, AvgDaysInHouse, DaysInState);
#endif
            }

            // If the entry does not exist, create and populate it.

            else {
                if (!(wlcurnode = (WLNODE *) mywlmalloc( sizeof( WLNODE))))
                    goto Done;

                strcpy( wlcurnode->CableBoxSerial, curnode->CableBoxSerial);
                wlcurnode->InitialDate =
                wlcurnode->LatestDate = fDateOfState;
                wlcurnode->TimesOnList =
                wlcurnode->TimesDiscovered =
                wlcurnode->WatchFlag = WF_ACTIVE;
                wlcurnode->DaysSincePrevious =
                wlcurnode->TimesRolledBack =
#ifdef REPAIR_VERSION
                wlcurnode->VCountNoProblem =
                wlcurnode->PVCountRepair =
                wlcurnode->RVCountRepair =
                wlcurnode->AvgDaysBtwnRepair =
#endif
                wlcurnode->RollbackReason = 0;
                wlcurnode->Action = 5;
#ifdef REPAIR_VERSION
                wlcurnode->VScrapDate =
                wlcurnode->LatestVRepairDate =
#endif
                wlcurnode->LatestRollback = (time_t) 0;

                btreestore( (NODE *) wlcurnode);
#if DEBUGMSGSW
                ErrorWatchData( 1, PercentInHouse, AvgDaysInHouse, DaysInState);
#endif
                AppendModelData( 'W', fDateOfState);
            }
Done:       wltreeroot = (WLNODE *) treeroot;
            treeroot = bxtreeroot;
        }

        // If the box should not be on the watch list, but is, then
        // if it's the first time on the list, flag it as deleted (WatchFlag=-1)
        // otherwise decrement the count and set WatchFlag to 0 (No).

        else if (flag == 1) {
            bxtreeroot = treeroot;
            treeroot = (NODE *) wltreeroot;
            WatchDataDirty = 1;

            if ((wlcurnode = (WLNODE *) btreefind( curnode->CableBoxSerial)) &&
                (wlcurnode->WatchFlag >= WF_ACTIVE))
            {
                if (wlcurnode->TimesOnList == 1) {
                    wlcurnode->WatchFlag = WF_DELETED;
#if DEBUGMSGSW
                    ErrorWatchData( 4, PercentInHouse, AvgDaysInHouse, DaysInState);
#endif
                }
                else {
                    --wlcurnode->TimesOnList;
                    wlcurnode->WatchFlag = WF_INACTIVE;
#if DEBUGMSGSW
                    ErrorWatchData( 5, PercentInHouse, AvgDaysInHouse, DaysInState);
#endif
                }
            }
#if DEBUGMSGS0 // DEBUGMSGSW
            else ErrorWatchData( 2, PercentInHouse, AvgDaysInHouse, DaysInState);
#endif
            treeroot = bxtreeroot;
        }

        // If this is Mediacom and the box has been in the external "D" state
        // for >= 120 days, change its internal state to "S" (out of service).

Proceed:
        if ((flag == 1) && (MediaFlag == 1) && (*curnode->Strings == 'D') &&
            (DaysInState > 120))
        {
            curnode->CurrentState = fStatusCode = 'S';
            RollBackCableBox();
        }

        curnode = btnextnode();
    }
}


#ifdef CAPEQ_VERSION
/*
 * FINDDESCRIPTION - Using the given root pointer, return the description
 * that matches the given code.
 * Call with ProbCodeRoot, FindCodeRoot, SolCodeRoot, or DiscCodeRoot.
 */
char *FindDescription( char *Stg, PROBCODE *Root)
{
    if (*Stg)
        for (ProbCodeCur = Root; ProbCodeCur; ProbCodeCur = ProbCodeCur->next)
            if (!strcmp( ProbCodeCur->ProblemCode, Stg))
                return ProbCodeCur->ProblemDesc;

     return "";              // if not found, return blankness
}
#endif


/*
 * FINDCABLEBOXMAP - Using dStrings[], look up the model number in the model map.
 * Returns 1 on success, 0 if there is no map entry.
 * If successful, CableBoxMapPtr and OutputFilesPtr point to the mappings
 * and the global ofhdl is the handle to write output to.
 */
long FindCableBoxMap( void)
{
    OUTPUTFILES *OutputFilesPrev;
    CABLEBOXMAP *CableBoxMapPrev;
    char *TypePtr, *TEndPtr, *DivPtr, *DivDirPtr, *DEndPtr, AorB;
    char OutputPathTail[25], OutputID[50];

    // If no mappings, open the one output file (the old method).
    // Otherwise find the mapping for this model.

    if (!CableBoxMap) {
        if (!WritingIndexFile && !ofhdl) ofhdl = OpenOutputFile( "");
        return 1;
    }

    // CSG:    Point to the model type (after the '|').
    //         Point to the Region (before the '-').
    // ICOMMS: Point to the model (before the '|').
    //         Point to the Division (between the two '-'s).
    // OCV:    Point to the model (before the '|').
    //         Point to the Division (between the two '-'s).

    DivPtr = DEndPtr = dStrings[DB_COMPANYREGION];
    while (*DEndPtr && (*DEndPtr != '-')) ++DEndPtr;
    if (DoingCSG) {
        TypePtr = dStrings[DB_CABLEBOXMODEL];
        while (*TypePtr && (*TypePtr++ != '|'));
    }
    else {
        TypePtr = TEndPtr = dStrings[DB_CABLEBOXMODEL];
        while (*TEndPtr && (*TEndPtr != '|')) ++TEndPtr;
        *TEndPtr = '\0';

        DivPtr = ++DEndPtr;
        while (*DEndPtr && (*DEndPtr != '-')) ++DEndPtr;
    }
    *DEndPtr = '\0';
    DivDirPtr = DivPtr;

    // See if this organization gets split into A and B or not.
    // If the organization is not found, write into ...\BAS UNDEFINED\A.

    for (OrganizationMapPtr = OrganizationMap; OrganizationMapPtr;
         OrganizationMapPtr = OrganizationMapPtr->next)
            if (!strcmp( OrganizationMapPtr->BoxType, DivPtr)) break;

    if (!OrganizationMapPtr) {
        for (OrganizationMapPtr = OrganizationUnMap; OrganizationMapPtr;
             OrganizationMapPtr = OrganizationMapPtr->next)
                if (!strcmp( OrganizationMapPtr->BoxType, DivPtr)) break;

        if (!OrganizationMapPtr) {
            OrganizationMapPtr = (CABLEBOXMAP *)
                mypermmalloc( sizeof( CABLEBOXMAP));
            OrganizationMapPtr->next = OrganizationUnMap;
            OrganizationUnMap = OrganizationMapPtr;
            OrganizationMapPtr->BoxType = mypermmalloc( strlen( DivPtr) + 1);
            strcpy( OrganizationMapPtr->BoxType, DivPtr);
            AppendErrorMessage(
                "There is no organization mapping for %s\n", DivPtr, 0);
        }

        DivDirPtr = "BAS UNDEFINED";
        AorB = 'A';
        goto Proceed;
    }

    if (OrganizationMapPtr->AorB == 'A') {
        AorB = 'A';
        goto Proceed;
    }

    CableBoxMapPrev = (CABLEBOXMAP *) NULL;
    for (CableBoxMapPtr = CableBoxMap; CableBoxMapPtr; CableBoxMapPtr = CableBoxMapPtr->next) {
        if (!strcmp( CableBoxMapPtr->BoxType, TypePtr)) break;
        CableBoxMapPrev = CableBoxMapPtr;
    }

    // If no mapping, write the information into A.
    // The UnMap list is kept so that the error message will be
    // output only once.

    if (!CableBoxMapPtr) {
        for (CableBoxMapPtr = CableBoxUnMap; CableBoxMapPtr; CableBoxMapPtr = CableBoxMapPtr->next)
            if (!strcmp( CableBoxMapPtr->BoxType, TypePtr)) break;

        if (!CableBoxMapPtr) {
            CableBoxMapPtr = (CABLEBOXMAP *) mypermmalloc( sizeof( CABLEBOXMAP));
            CableBoxMapPtr->next = CableBoxUnMap;
            CableBoxUnMap = CableBoxMapPtr;
            CableBoxMapPtr->BoxType = mypermmalloc( strlen( TypePtr) + 1);
            strcpy( CableBoxMapPtr->BoxType, TypePtr);
            AppendErrorMessage( "There is no mapping for model %s\n", TypePtr, 0);
        }
        AorB = 'A';
        goto Proceed;
    }

    // Move the mapping to the front of the list.

    if (CableBoxMapPrev) {
        CableBoxMapPrev->next = CableBoxMapPtr->next;
        CableBoxMapPtr->next = CableBoxMap;
        CableBoxMap = CableBoxMapPtr;
    }

    // Find the corporate and A/B entry.

    AorB = CableBoxMapPtr->AorB;
Proceed:
    OutputFilesPrev = (OUTPUTFILES *) NULL;
    for (OutputFilesPtr = OutputFiles; OutputFilesPtr;
         OutputFilesPtr = OutputFilesPtr->next)
    {
        if (!strcmp( OutputFilesPtr->Division, DivPtr) &&
            (AorB == OutputFilesPtr->AorB)) break;
        OutputFilesPrev = OutputFilesPtr;
    }

    // If found, move the entry to the front of the list.
    // Otherwise create a new entry.

    if (OutputFilesPtr) {
        if (OutputFilesPrev) {
            OutputFilesPrev->next = OutputFilesPtr->next;
            OutputFilesPtr->next = OutputFiles;
            OutputFiles = OutputFilesPtr;
        }
    }
    else {
        OutputFilesPtr = (OUTPUTFILES *) mypermmalloc( sizeof( OUTPUTFILES));
        OutputFilesPtr->next = OutputFiles;
        OutputFiles = OutputFilesPtr;
        OutputFilesPtr->Division = mypermmalloc( strlen( DivPtr) + 1);
        strcpy( OutputFilesPtr->Division, DivPtr);
        OutputFilesPtr->AorB = AorB;
        OutputFilesPtr->ofhdl = (FILE *) NULL;
    }

    // If the output or index file has not been opened yet, do so now.

    if (!OutputFilesPtr->ofhdl) {
        sprintf( OutputPathTail, "%s\\%c\\", DivDirPtr, AorB);
        if (WritingIndexFile) {
            sprintf( OutputID, "%s-%c", DivPtr, AorB);
            OutputFilesPtr->ofhdl = OpenIndexFile( OutputPathTail, OutputID, 1);
        }
        else OutputFilesPtr->ofhdl = OpenOutputFile( OutputPathTail);
    }

    if (!DoingCSG) *TEndPtr = '|';
    *DEndPtr = '-';
    ofhdl = OutputFilesPtr->ofhdl;
    return 1;
}


/*
 * CLOSEALLFILES - Walk through the model map and close all files.
 * If there are no mappings, just close the one output file.
 */
void CloseAllFiles( void)
{
    if (!OutputFiles) {
        if (!WritingIndexFile && ofhdl) fclose( ofhdl);
        ofhdl = (FILE *) NULL;
        return;
    }

    for (OutputFilesPtr = OutputFiles; OutputFilesPtr;
         OutputFilesPtr = OutputFilesPtr->next)
    {
        if (OutputFilesPtr->ofhdl) {
            fclose( OutputFilesPtr->ofhdl);
            OutputFilesPtr->ofhdl = (FILE *) NULL;
        }
    }
}


/*
 * GETMDYASTIMET - Returns a time_t with the current date, at midnight.
 */
time_t GetMDYAsTimet( void)
{
    time_t curtime;
    struct tm *tmptr;

    time( &curtime);
    tmptr = localtime( &curtime);

    // convert the set of values into a time_t.

    tmptr->tm_hour =
    tmptr->tm_min =
    tmptr->tm_sec =
    tmptr->tm_isdst = 0;

    return mktime( tmptr);
}


/*
 * CONVERTMDYTOTIMET - Convert a string in the form "mm/dd/yyyy" into
 * a time_t. mm and dd may be 1 or 2 digits. yyyy must be 4 digits.
 * The delimiter can be any non-number (most likely a slash).
 * The date might be followed by a hh:mm time, which is ignored.
 */
time_t ConvertMDYToTimet( char *DateString)
{
    char *sptr, chr;
    short values[3], vix;
    struct tm tmptr;

    // Put the three values (separated by some non-digit delimiter)
    // into the values array.

    vix = values[0] = values[1] = values[2] = 0;
    sptr = DateString;
    while (chr = *sptr++) {
        if ((chr >= '0') && (chr <= '9'))
            values[vix] = (values[vix] * 10) + chr - '0';
        else if (++vix > 2) break;
    }

    // If the year comes first, assume it's yyyy/mm/dd, and reorder.

    if (values[0] > 1900) {
        vix = values[0];
        values[0] = values[1];
        values[1] = values[2];
        values[2] = vix;
    }

    // Convert the set of values into a time_t.

    tmptr.tm_year = values[2] - 1900;
    tmptr.tm_mon = values[0] - 1;
    tmptr.tm_mday = values[1];
    tmptr.tm_hour =
    tmptr.tm_min =
    tmptr.tm_sec =
    tmptr.tm_isdst = 0;

    // If the time should be included, expect it to be in the format
    // <non-digits>hh:mm where hh is 24-hour time.

    if (IncludeTime && (chr != '\0')) {
        while ((chr = *sptr) && ((chr < '0') || (chr > '9'))) ++sptr;
        if (!chr) goto Finish;

        tmptr.tm_hour = chr - '0';
        if (((chr = *++sptr) >= '0') && (chr <= '9')) {
            tmptr.tm_hour = (tmptr.tm_hour * 10) + chr - '0';
            if (((chr = *++sptr) < '0') || (chr > '9')) ++sptr;
        }

        if (((chr = *sptr++) < '0') || (chr > '9')) goto Finish;
        tmptr.tm_min = chr - '0';
        if (((chr = *sptr++) >= '0') && (chr <= '9'))
            tmptr.tm_min = (tmptr.tm_min * 10) + chr - '0';
    }

Finish:
    return mktime( &tmptr);
}


/*
 * CONVERTTIMETTOMDY - Convert the given time_t to a string in the form
 * "mm/dd/yyyy".
 */
char *ConvertTimetToMDY( time_t Datet, char *DateString)
{
    struct tm *tmptr;

    if (Datet == (time_t) -1) Datet = StartOfWorld;
    tmptr = localtime( &Datet);
    sprintf( DateString, "%02d/%02d/%04d",
        tmptr->tm_mon + 1, tmptr->tm_mday, tmptr->tm_year + 1900);

    return DateString;
}


/*
 * CONVERTTIMETTOWEEK - Convert the given time_t to a week, in the form
 * "yyyy-ww", where "ww" goes from 01 to 53.
 */
char *ConvertTimetToWeek( time_t Datet, char *DateString)
{
    struct tm *tmptr;

    if (Datet == (time_t) -1) Datet = StartOfWorld;
    tmptr = localtime( &Datet);
    sprintf( DateString, "\"%04d-%02d\"",
        tmptr->tm_year + 1900, ((tmptr->tm_yday + 7) / 7));

#if DEBUGWKCHK
    CheckWeek( DateString);
#endif
    return DateString;
}


/*
 * CONVERTWEEKTODATE - Convert the given week (yyyy-ww) to the date of
 * the last day of the week (mm/dd/yyyy).
 */
char *ConvertWeekToDate( char *WeekString, char *DateString)
{
    struct tm tmstr, *tmptr;
    time_t weekt;

#if DEBUGWKCHK
    CheckWeek( WeekString);
#endif
    strncpy( DateString, WeekString + 1, 7);
    *(DateString + 4) = *(DateString + 7) = '\0';

    tmstr.tm_year = atoi( DateString) - 1900;
    tmstr.tm_mon = 0;
    tmstr.tm_mday = 7 * atoi( DateString + 5);
    tmstr.tm_hour =
    tmstr.tm_min =
    tmstr.tm_sec =
    tmstr.tm_isdst = 0;

    weekt = mktime( &tmstr);
    tmptr = localtime( &weekt);

    sprintf( DateString, "\"%02d/%02d/%04d\"",
        tmptr->tm_mon + 1, tmptr->tm_mday, tmptr->tm_year + 1900);

    return DateString;
}


/*
 * CONVERTTIMETTOMDYHMS - Convert the given time_t to a string in the form
 * "mm/dd/yyyy hh:mm".
 */
char *ConvertTimetToMDYHMS( time_t Datet, char *DateString)
{
    struct tm *tmptr;

    if (Datet == (time_t) -1) Datet = StartOfWorld;
    tmptr = localtime( &Datet);
    sprintf( DateString, "%02d/%02d/%04d %02d:%02d",
        tmptr->tm_mon + 1, tmptr->tm_mday, tmptr->tm_year + 1900,
        tmptr->tm_hour, tmptr->tm_min);

    return DateString;
}


/*
 * CONVERTTIMETTOYYYYMMDD - Convert the given time_t to a string in the form
 * "yyyymmdd".
 */
char *ConvertTimetToYYYYMMDD( time_t Datet, char *DateString)
{
    struct tm *tmptr;

    if (Datet == (time_t) -1) Datet = StartOfWorld;
    tmptr = localtime( &Datet);
    sprintf( DateString, "%04d%02d%02d",
        tmptr->tm_year + 1900, tmptr->tm_mon + 1, tmptr->tm_mday);

    return DateString;
}


/*
 * LOADDATASTRING - Save a data string in its global variable.
 */
void LoadDataString( void)
{
    short DataID;
    char *DataString;

    DataID = atoi( Flds[1]);
    DataString = Flds[2];

    switch (DataID) {
      case 1:                   // Start of World date
        StartOfWorld = ConvertMDYToTimet( DataString);
        break;

      case 2:                   // BAS Identifier
        strcpy( BASIdentifier, DataString);
        MostRecentDOS = 0;
        break;

      case 100:                 // log file directory
        LogFileDir = mypermmalloc( strlen( DataString) + 1);
        strcpy( LogFileDir, DataString);
        LogFileFile = mypermmalloc( strlen( DataString) + 15);
        sprintf( LogFileFile, "%sBASLogFile.txt", DataString);
        break;

      case 101:                 // output directory
        OutputDir = mypermmalloc( strlen( DataString) + 1);
        strcpy( OutputDir, DataString);
        break;

      //   102, 103             // values; see below

      case 104:                 // path of the database
        DatabaseDir = mypermmalloc( strlen( DataString) + 1);
        strcpy( DatabaseDir, DataString);
        break;

      //   105, 106             // values; see below

      case 107:                 // inbound directory
        InboundDir = mypermmalloc( strlen( DataString) + 1);
        strcpy( InboundDir, DataString);
        break;

      //   108 - 114            // values; see below

#ifdef CBA_VERSION
      case 114:                 // C-B-A state change
        StateChange = (STATECHANGES *) mypermmalloc( sizeof( STATECHANGES));
        StateChange->StateChange = mypermmalloc( strlen( DataString) + 1);
        strcpy( StateChange->StateChange, DataString);
        StateChange->next = StateChangeList;
        StateChangeList = StateChange;
        break;
#endif

      case 115:                 // Discard entries later than the file date
        DiscardRecent = ConvertMDYToTimet( DataString);
        break;

      case 117:                 // Current week string
        strcpy( CurrentWeek, DataString);
        break;

      case 120:                 // Path for writing J-File
        JFileDir = mypermmalloc( strlen( DataString) + 1);
        strcpy( JFileDir, DataString);
    }
}


/*
 * LOADDATAVALUE - Save a data value in its global variable.
 */
void LoadDataValue( void)
{
    short DataID;
    short DataValue;

    DataID = atoi( Flds[1]);
    DataValue = atoi( Flds[2]);

    switch (DataID) {
      case 102:                 // AddFiveFields flag
        AddFiveFields = DataValue;
        break;

      case 103:                 // ShortInHouse value
        valShortInHouse = DataValue;
        break;

      case 105:                 // DoingUniversal
        DoingUniversal = DataValue;
        break;

      case 106:                 // WriteOutputFiles
        WriteOutputFiles = DataValue;
        break;

      case 108:                 // IgnoreLocation (for Austar)
        IgnoreLocation = DataValue;
        break;

      case 109:                 // HouseLocationFlag
        HouseLocationFlag = DataValue;
        break;

      case 110:                 // map B state using contents of Location
        MapBUsingLocation = DataValue;  // (for Bright House)
        break;

      case 111:                 // Reset value for ShortInHouse
        ShortInHouseReset = DataValue;
        break;

      case 112:                 // Set the Location for Cox
        CoxFlag = DataValue;
        break;

      case 113:                 // Mutate ext'l Q state from Return to Repair
        MutateQState = DataValue;
        break;

      case 114:                 // Reset watched boxes that are Repair-ed
        AutoRollback = DataValue;
        break;

      case 116:                 // Write a watch file when writing the index
        if (WriteWatchFile = DataValue) {
            WatchSIH = atoi( Flds[3]);
            WatchAverageDays = 1000 * atoi( Flds[4]);
            WatchPercentDays = 1000 * atoi( Flds[5]);
        }
        break;

      case 118:                 // Set special processing for Mediacom
        MediaFlag = DataValue;
        break;

      case 119:                 // Enable debug code
        DebugFlag = DataValue;
    }
}


/*
 * LOADSTATETRANSITION - Save a state transition.
 */
void LoadStateTransition( void)
{
    char FromStateAbbrev, ToStateAbbrev;
    long LegalMove, AccumFromDays, AccumToCount;

    // If FromStateAbbrev is "", discard the existing values.

    FromStateAbbrev = *Flds[1];
    if (FromStateAbbrev == '\0') {
        StateTransitions = UStateTransitions = (STATETRANSITIONS *) NULL;
        return;
    }

    ToStateAbbrev = *Flds[2];
    LegalMove = atol( Flds[3]);
    AccumFromDays = atol( Flds[4]);
    AccumToCount = atol( Flds[5]);

    StateTransitionsPtr =
        (STATETRANSITIONS *) mypermmalloc( sizeof( STATETRANSITIONS));

    StateTransitionsPtr->FromToState =
        (short) (FromStateAbbrev << 8) | ToStateAbbrev;
    StateTransitionsPtr->LegalMove = (short) LegalMove;
    StateTransitionsPtr->AccumFromDays = (short) AccumFromDays;
    StateTransitionsPtr->AccumToCount = (short) AccumToCount;

    if (FromStateAbbrev == 'U')
        UStateTransitions = StateTransitionsPtr;
    else {
        StateTransitionsPtr->next = StateTransitions;
        StateTransitions = StateTransitionsPtr;
    }
}


/*
 * GETSTATETRANSITION - Given the current and new states, return
 * StateTransitionsPtr pointing to the state transition information.
 */
void GetStateTransition( char CurrentState, char NewState)
{
    long CurNew;

    // Look up the information for the transition from the previous state
    // to the new one. Treat "Unknown" specially.

    if (CurrentState == 'U') {
        StateTransitionsPtr = UStateTransitions;
        return;
    }

    CurNew = (CurrentState << 8) | NewState;

    for (StateTransitionsPtr = StateTransitions;
         StateTransitionsPtr;
         StateTransitionsPtr = StateTransitionsPtr->next)
            if (StateTransitionsPtr->FromToState == CurNew) return;
}


/*
 * LOADSTATEMAP - Add one more entry to either accounting system's state map.
 */
void LoadStateMap( void)
{
    char AcctSys, *ExtState;
    STATEMAP *smptr;

    // If AcctSys is 1, read the file "BASStateMap.csv".

    if (*Flds[1] == '9') {
        StateMapLocRoot = (STATEMAPLOC *) NULL;
        LoadStateMapFile();
        return;
    }

    // If AcctSys is 0, discard the existing tables and start a new set.

    if ((AcctSys = *Flds[1]) == '0') {
        StateMapLocRoot = (STATEMAPLOC *) NULL;
        CSGStateMap =
        ICOMMSStateMap = (STATEMAP *) NULL;
        return;
    }

    // Otherwise prepend this mapping to the appropriate list.

    ExtState = Flds[2];
    smptr = (STATEMAP *) mypermmalloc( sizeof( STATEMAP));
    if (AcctSys == '1') {
        smptr->next = CSGStateMap;
        CSGStateMap = smptr;
    }
    else {
        smptr->next = ICOMMSStateMap;
        ICOMMSStateMap = smptr;
    }

    smptr->ExternalState = mypermmalloc( strlen( ExtState) + 1);
    strcpy( smptr->ExternalState, ExtState);
    smptr->ExtStateAbbrev = *(Flds[3] + 1) ? '\0' : *Flds[3];
    smptr->StateAbbrev = *Flds[4];
}


/*
 * LOADSTATEMAPFILE - Read the state mappings from the file "BASStateMap.csv".
 * Note that the date entries must be in ascending order within location.
 * Returns 1 if successful, < 0 on failure.
 */
long LoadStateMapFile( void)
{
    long ret;
    char FileText[300], Reply[100];
    short AcctSys;
    time_t TableDate, NewTableDate;
    STATEMAP *smptr;

    // Open the file.

    ret = -1;
    if (!(ifhdl = fopen( Flds[2], "r"))) goto Done1;

    // Read the first line. If a header, skip it, else jump to process it.

    ret = -2;
    TableDate = (time_t) 0;
    StateMapDatePtr = (STATEMAPDATE *) NULL;
    ReadAndProcessCSVLine( FileText, ifhdl);
    if (!strstr( FileText, "ate") && !strstr( FileText, "ATE")) goto NoHead;

    // Read and process each line of the file.
    // NOTE: Just use the last three digits of the SiteID from the transaction.

    while (ReadAndProcessCSVLine( FileText, ifhdl)) {
NoHead:
        if (SplitOnTabs( FileText) < 6) goto Done;

        // If the location has changed, allocate a new location structure.

        if (*Flds[0] && (!StateMapLocPtr ||
            strcmp( StateMapLocPtr->Location, Flds[0])))
        {
            StateMapLocPtr = (STATEMAPLOC *)
                mypermmalloc( sizeof( STATEMAPLOC));
            StateMapLocPtr->next = StateMapLocRoot;
            StateMapLocRoot = StateMapLocPtr;
            StateMapLocPtr->StateMapDate = StateMapDatePtr = (STATEMAPDATE *) NULL;
            StateMapLocPtr->Location = mypermmalloc( 1 + strlen( Flds[0]));
            strcpy( StateMapLocPtr->Location, Flds[0]);
            TableDate = (time_t) 0;
        }

        // If the date has changed, it must be ascending.

        if (*Flds[1]) {
            if ((NewTableDate = ConvertMDYToTimet( Flds[1])) <= TableDate) {
                ret = -3;
                goto Done;
            }
            TableDate = NewTableDate;
        }
        if (*Flds[2]) AcctSys = (*Flds[2] == 'C');

        // If the date has changed, allocate a new date structure.

        if (!StateMapDatePtr || (StateMapDatePtr->StartDate != TableDate)) {
            StateMapDatePtr = (STATEMAPDATE *)
                mypermmalloc( sizeof( STATEMAPDATE));
            StateMapDatePtr->next = StateMapLocPtr->StateMapDate;
            StateMapLocPtr->StateMapDate = StateMapDatePtr;
            StateMapDatePtr->CSGStateMap =
            StateMapDatePtr->ICOMMSStateMap = (STATEMAP *) NULL;
            StateMapDatePtr->StartDate = TableDate;
        }

        // Prepend this mapping to the appropriate list.

        smptr = (STATEMAP *) mypermmalloc( sizeof( STATEMAP));
        if (AcctSys) {
            smptr->next = StateMapDatePtr->CSGStateMap;
            StateMapDatePtr->CSGStateMap = smptr;
        }
        else {
            smptr->next = StateMapDatePtr->ICOMMSStateMap;
            StateMapDatePtr->ICOMMSStateMap = smptr;
        }

        smptr->ExternalState = mypermmalloc( strlen( Flds[3]) + 1);
        strcpy( smptr->ExternalState, Flds[3]);
        smptr->ExtStateAbbrev = *(Flds[4] + 1) ? '\0' : *Flds[4];
        smptr->StateAbbrev = *Flds[5];
    }
    ret = 1;

Done:
    fclose( ifhdl);
Done1:
    sprintf( Reply, "$LoadStateMap\t%d\t", ret);
    SendReply( Reply);
    return ret;
}


/*
 * CONVERTSTATE - Convert the given accounting system's external state
 * (in the global fExternalState) to its internal equivalent.
 */
char ConvertState( void)
{
    char *SiteID, ExtStateAbbrev;
    STATEMAP *smptr;

    // Convert the given external state for the given accounting system
    // to its internal equivalent. Returns the internal state abbreviation.

    // Find the right table given the date of state.

    if (StateMapLocPtr = StateMapLocRoot) {
        // Find the right location, then the right date, then the right
        // billing system, then map the state.

        SiteID = fCompanyRegion + strlen( fCompanyRegion) - 3;
        if (*(SiteID + 1) == '-') SiteID += 2;
        while (StateMapLocPtr) {
            if (!strcmp( StateMapLocPtr->Location, SiteID)) break;
            StateMapLocPtr = StateMapLocPtr->next;
        }
        if (!StateMapLocPtr) return 'O';

        StateMapDatePtr = StateMapLocPtr->StateMapDate;
        while (StateMapDatePtr) {
            if (fDateOfState >= StateMapDatePtr->StartDate) break;
            StateMapDatePtr = StateMapDatePtr->next;
        }
        if (!StateMapDatePtr) return 'O';

        smptr = (DoingCSG == 1) ?
            StateMapDatePtr->CSGStateMap : StateMapDatePtr->ICOMMSStateMap;
    }
    else smptr = (DoingCSG == 1) ? CSGStateMap : ICOMMSStateMap;

    // If the external state is a single letter, compare it with the
    // abbreviation. Otherwise compare it with the full state name.

    if (!*(fExternalState + 1)) {
        ExtStateAbbrev = *fExternalState;

        if (MapBUsingLocation && (ExtStateAbbrev == 'B')) {
            if      (strstr( fLocation, "RET")) fExternalState = "B-RET";
            else if (strstr( fLocation, "REP")) fExternalState = "B-REP";
            else if (strstr( fLocation, "WAR")) fExternalState = "B-WAR";
            else if (strstr( fLocation, "NER")) fExternalState = "B-NER";
            else                                fExternalState = "B-UND";
            goto MapFullName;
        }

        while (smptr) {
            if (smptr->ExtStateAbbrev == ExtStateAbbrev)
                return smptr->StateAbbrev;
            smptr = smptr->next;
        }
    }
    else {
MapFullName:
        while (smptr) {
            if (!strcmp(smptr->ExternalState, fExternalState))
                return smptr->StateAbbrev;
            smptr = smptr->next;
        }
    }

    return 'O';                         // if it's not found, it's Other
}


/*
 * LOADINTERNALSTATE - Save an internal state abbreviation->full string map.
 */
void LoadInternalState( void)
{
    char StateAbbrev, *StateName;

    // If StateAbbrev is "", discard the existing values.

    StateAbbrev = *Flds[1];
    if (StateAbbrev == '\0') {
        InternalStates = (INTERNALSTATES *) NULL;
        return;
    }

    StateName = Flds[2];
    InternalStatesPtr =
        (INTERNALSTATES *) mypermmalloc( sizeof( INTERNALSTATES));
    InternalStatesPtr->next = InternalStates;
    InternalStates = InternalStatesPtr;

    InternalStatesPtr->StateAbbrev = StateAbbrev;
    strcpy( InternalStatesPtr->StateName, StateName);
}


/*
 * GETFULLSTATENAME
 * Given an internal state abbreviation, return its full name.
 */
char *GetFullStateName( char StateAbbrev)
{
    for (InternalStatesPtr = InternalStates;
         InternalStatesPtr;
         InternalStatesPtr = InternalStatesPtr->next)
            if (InternalStatesPtr->StateAbbrev == StateAbbrev)
                return InternalStatesPtr->StateName;

    return "OTHER";
}


/*
 * LOADCABLEBOXMAP - Save a mapping between cable box model and A or B.
 */
void LoadCableBoxMap( void)
{
    char EntryType, *CableBoxType, AorB;

    // If the Type is the empty string. clear the table.

    EntryType = *Flds[1];
    if (!EntryType) {
        CableBoxMap = (CABLEBOXMAP *) OutputFiles = NULL;
        OrganizationMap = (CABLEBOXMAP *) NULL;
        return;
    }

    CableBoxType = Flds[2];
    AorB = *Flds[3];

    CableBoxMapPtr = (CABLEBOXMAP *) mypermmalloc( sizeof( CABLEBOXMAP));
    CableBoxMapPtr->BoxType = mypermmalloc( strlen( CableBoxType) + 1);
    strcpy( CableBoxMapPtr->BoxType, CableBoxType);
    CableBoxMapPtr->AorB = AorB;

    if (EntryType == '2') {
        CableBoxMapPtr->next = CableBoxMap;
        CableBoxMap = CableBoxMapPtr;
    }
    else {
        CableBoxMapPtr->next = OrganizationMap;
        OrganizationMap = CableBoxMapPtr;
    }
}


/*
 * CHECKDATE - If the date of state from the record is in the future,
 * use StartOfWorld. This is called during Universal file processing.
 */
void CheckDate( void)
{
    if (fDateOfState > DateOfNow) {
        fDateOfState = StartOfWorld;
        ConvertTimetToMDY( fDateOfState, Flds[CSG_STATEDATE]);
    }
}


/*
 * DOESCABLEBOXEXIST - Returns 1 if the given cable box exists, 0 if not.
 */
void DoesCableBoxExist( void)
{
    char *CableBoxSerial, Line[50];

    CableBoxSerial = Flds[1];
    ReadDatabaseFromDisk( DatabaseMode);

    sprintf( Line, "$DoesCableBoxExist\t%d\t",
        (btreefind( CableBoxSerial)) ? 1 : 0);

    SendReply( Line);
}


/*
 * RESETDAYS - Reset the day counts for the given cable box.
 */
void ResetDays( void)
{
    char *CableBoxSerial;

    CableBoxSerial = Flds[1];
    ReadDatabaseFromDisk( DatabaseMode);
    if (!(curnode = btreefind( CableBoxSerial))) {
        SendReply( "$ResetDays\t0\t");
        return;
    }

    curnode->RDaysUnknown =
    curnode->RDaysHouse =
    curnode->RDaysReturn =
    curnode->RDaysRepair =
    curnode->RDaysOther =
    curnode->RDaysTech = 0;

    WatchListRollback( CableBoxSerial);

    SendReply( "$ResetDays\t1\t");
}


/*
 * RESETCOUNTS - Reset the transition counts for the given cable box.
 */
void ResetCounts( void)
{
    char *CableBoxSerial;

    CableBoxSerial = Flds[1];
    ReadDatabaseFromDisk( DatabaseMode);
    if (!(curnode = btreefind( CableBoxSerial))) {
        SendReply( "$ResetCounts\t0\t");
        return;
    }

    curnode->RToHouse =
    curnode->RToReturn =
    curnode->RToRepair =
    curnode->RToOther =
    curnode->RToTech = 0;

    if (*Flds[2] == '1') WatchListRollback( CableBoxSerial);

    SendReply( "$ResetCounts\t1\t");
}


/*
 * SELECTIVERESET - Reset specific counts for the given cable box,
 * each to the given value. -1 means don't change the current value.
 */
void SelectiveReset( void)
{
    char *CableBoxSerial;
    short DaysUnknown, DaysHouse, DaysReturn, DaysRepair;
    short DaysOther, DaysTech, ToHouse, ToReturn;
    short ToRepair, ToOther, ToTech, ShortInHouse;

    CableBoxSerial = Flds[1];
    DaysUnknown = atoi( Flds[2]);
    DaysHouse = atoi( Flds[3]);
    DaysReturn = atoi( Flds[4]);
    DaysRepair = atoi( Flds[5]);
    DaysOther = atoi( Flds[6]);
    DaysTech = atoi( Flds[7]);
    ToHouse = atoi( Flds[8]);
    ToReturn = atoi( Flds[9]);
    ToRepair = atoi( Flds[10]);
    ToOther = atoi( Flds[11]);
    ToTech = atoi( Flds[12]);
    ShortInHouse = atoi( Flds[13]);

    ReadDatabaseFromDisk( DatabaseMode);
    if (!(curnode = btreefind( CableBoxSerial))) {
        SendReply( "$SelectiveReset\t0\t");
        return;
    }

    if (DaysUnknown != -1)  curnode->RDaysUnknown = DaysUnknown;
    if (DaysHouse != -1)    curnode->RDaysHouse = DaysHouse;
    if (DaysReturn != -1)   curnode->RDaysReturn = DaysReturn;
    if (DaysRepair != -1)   curnode->RDaysRepair = DaysRepair;
    if (DaysOther != -1)    curnode->RDaysOther = DaysOther;
    if (DaysTech != -1)     curnode->RDaysTech = DaysTech;

    if (ToHouse != -1)      curnode->RToHouse = ToHouse;
    if (ToReturn != -1)     curnode->RToReturn = ToReturn;
    if (ToRepair != -1)     curnode->RToRepair = ToRepair;
    if (ToOther != -1)      curnode->RToOther = ToOther;
    if (ToTech != -1)       curnode->RToTech = ToTech;
    if (ShortInHouse != -1) curnode->ShortInHouse = ShortInHouse;

    WatchListRollback( CableBoxSerial);

    SendReply( "$SelectiveReset\t1\t");
}


/*
 * PROCESSRVFILE - Read and process the repair-rollback file.
 */
void ProcessRVFile( void)
{
#ifdef REPAIR_VERSION
    char Datestr[11], FileText[100], Action;
    time_t Dateval;

    RecordCount = 0;
    if (!(ifhdl = fopen( Flds[1], "r"))) goto Failed;

    // Make sure the cable box database has been read.
    // Set aside the cable box tree and point to the watch list tree.

    ReadDatabaseFromDisk( DatabaseMode);
    bxtreeroot = treeroot;
    treeroot = (NODE *) wltreeroot;
    if (ReadWLDataFromDisk( DatabaseMode) == -1) goto Failed0;

    // Read the first line. If a header, skip it, else jump to process it.

    ReadAndProcessCSVLine( FileText, ifhdl);
    if (!strstr( FileText, "erial") && !strstr( FileText, "ERIAL")) goto NoHead;

    // Read and process each line of the file.

    while (ReadAndProcessCSVLine( FileText, ifhdl)) {
NoHead:
        if (SplitOnTabs( FileText) < RV_FIELDSMAX) {
            AppendErrorMessage( "%s Record %d skipped: too few fields\n",
                Flds[1], RecordCount + 1);
            goto SkipRecord;
        }

        // Ignore all records except those with Repair or No Problem action.
//@@    // Ignore all records except those with Repair action.

//@@    if (*Flds[RV_ACTION] != 'R') goto SkipRecord;
        if (((Action = *Flds[RV_ACTION]) != 'R') && (Action != 'N'))
            goto SkipRecord;

        // Find the box's watch record.

        wlcurnode = (WLNODE *) btreefind( Flds[RV_SERIAL]);

        // Look up the cable box record.

        wltreeroot = (WLNODE *) treeroot;
        treeroot = bxtreeroot;
        curnode = btreefind( Flds[RV_SERIAL]);
        bxtreeroot = treeroot;
        treeroot = (NODE *) wltreeroot;

        // Convert the YYYYMMDD date to a time_t. Ugly, but efficient.

        Datestr[0] = Flds[RV_DATE][4];
        Datestr[1] = Flds[RV_DATE][5];
        Datestr[2] = '/';
        Datestr[3] = Flds[RV_DATE][6];
        Datestr[4] = Flds[RV_DATE][7];
        Datestr[5] = '/';
        Datestr[6] = Flds[RV_DATE][0];
        Datestr[7] = Flds[RV_DATE][1];
        Datestr[8] = Flds[RV_DATE][2];
        Datestr[9] = Flds[RV_DATE][3];
        Datestr[10] = '\0';
        if ((Dateval = ConvertMDYToTimet( Datestr)) < 0) {
            AppendErrorMessage( "%s Record %d skipped: bad date format\n",
                Flds[1], RecordCount + 1);
            goto SkipRecord;
        }

        // Skip this record if the watch entry was not found or it's not active.

        if (!wlcurnode || (wlcurnode->WatchFlag <= WF_INACTIVE)) goto Finish;

        // Set values for whether the box was repaired, scrapped, or no problem.
        // Note that only Repaired causes a rollback.

        WatchDataDirty = 1;

        switch (Action) {
          case 'R':                         // repaired
            wlcurnode->WatchFlag = WF_INACTIVE;
            if (wlcurnode->PVCountRepair > 0)
                wlcurnode->AvgDaysBtwnRepair = (short)
                    (((wlcurnode->AvgDaysBtwnRepair *
                      (wlcurnode->PVCountRepair - 1)) +
                    ((Dateval - wlcurnode->LatestVRepairDate) / SECSINADAY)) /
                        wlcurnode->PVCountRepair);

            ++wlcurnode->RVCountRepair;
            ++wlcurnode->PVCountRepair;
            wlcurnode->LatestVRepairDate = Dateval;
            wlcurnode->RollbackReason = RBR_FILER;
            ++wlcurnode->TimesRolledBack;
            break;
          case 'N':
            ++wlcurnode->VCountNoProblem;   // no problem - just bump the count
            goto Finish;                    // and don't roll back counters
          case 'S':
            wlcurnode->VScrapDate = Dateval; // scrapped - give it last rites
//          wlcurnode->RollbackReason = RBR_FILES;
          default:                          // (ignore any other action)
            goto Finish;                    // and don't roll back counters
        }

        // Roll back the counters for Repair only (not Scrapped or No Problem).

        if (curnode) {
            wlcurnode->LatestRollback = curnode->DateOfState;
            curnode->RDaysUnknown =
            curnode->RDaysHouse =
            curnode->RDaysReturn =
            curnode->RDaysRepair =
            curnode->RDaysOther =
            curnode->RDaysTech =
            curnode->RToHouse =
            curnode->RToReturn =
            curnode->RToRepair =
            curnode->RToOther =
            curnode->RToTech = 0;
            curnode->ShortInHouse = ShortInHouseReset;

            AppendModelData( 'R', curnode->DateOfState);
        }

Finish:
        if (CoxFlag && curnode) SetRVRepair( Dateval);

SkipRecord:
        if (!(++RecordCount % 5000)) {
            sprintf( FileText, "$Status\t%d\t", RecordCount);
            SendReply( FileText);
        }
    }

    // Restore the cable box tree; done.

    fclose( ifhdl);
    wltreeroot = (WLNODE *) treeroot;
    treeroot = bxtreeroot;
    sprintf( FileText, "$ProcessRVFile\t0\t%d\t", RecordCount);
    SendReply( FileText);
    return;

Failed0:
    fclose( ifhdl);
Failed:
    SendReply( "$ProcessRVFile\t1\t1\t");
#else
    SendReply( "$ProcessRVFile\t0\t1\t");
#endif
}


/*
 * SETRVREPAIR - Set a Repair state for the box in the RV file.
 * Call with the date/time from the RV record,
 * and curnode pointing to the cable box record.
 */
void SetRVRepair( time_t Dateval)
{
    char ExtState, IntState;
    short DaysInState;

    // If the box is currently in the Repair state, there's nothing to do.

    if ((IntState = curnode->CurrentState) == 'P') return;

    // Count a transition to the Repair state no matter what.
    // Guard against the RV date being earlier than the record date.

    ++curnode->RToRepair;
    ++curnode->PToRepair;
    if (((ExtState = *curnode->Strings) != '1') &&
        (Dateval <= curnode->DateOfState)) return;

    // If the current external state is '1', set it to '2' / 'P' and adjust
    // the counts.

    curnode->CurrentState = 'P';
    *curnode->Strings = '2';

    if (ExtState == '1') {
        --curnode->RToOther;
        --curnode->PToOther;
        return;
    }

    // If the external state is not '1', then to box needs to move into Repair.
    // Find the date of state of that Repair: one day before the RV date.
    // However, if that date is earlier than the current date of state,
    // set it to half the time between the date of state and the RV date.

    Dateval -= SECSINADAY;
    if (curnode->DateOfState >= Dateval) {
        Dateval += SECSINADAY;
        Dateval = Dateval - ((Dateval - curnode->DateOfState) / 2);
    }

    DaysInState = (short) ((Dateval - curnode->DateOfState) / SECSINADAY);

    switch (IntState) {
      case 'H': curnode->RDaysHouse  += DaysInState;
                curnode->PDaysHouse  += DaysInState; break;
      case 'R': curnode->RDaysReturn += DaysInState;
                curnode->PDaysReturn += DaysInState; break;
      case 'P': curnode->RDaysRepair += DaysInState;
                curnode->PDaysRepair += DaysInState; break;
      case 'T': curnode->RDaysTech   += DaysInState;
                curnode->PDaysTech   += DaysInState; break;
      case 'O': curnode->RDaysOther  += DaysInState;
                curnode->PDaysOther  += DaysInState;
    }

    curnode->DateOfState = Dateval;
}


/*
 * WRITERESETREPORT - If boxes have been automatically reset, report them.
 */
void WriteResetReport()
{
    char OutputName[200];
    char FileDate[16];
    FILE *ofhdl;

    // Set up the name of the report file, and open it for writing.

    sprintf( OutputName, "%sBOX-RESET-%s.csv",
        LogFileDir, BuildFileDate( FileDate, NULL));

    if (!(ofhdl = fopen( OutputName, "w"))) return;

    // Output the header.

    fprintf( ofhdl, "SERIAL NUMBER,EXISTS,DAYS UNKNOWN,DAYS IN HOUSE,"
        "DAYS IN RETURN,DAYS IN REPAIR,DAYS IN OTHER,DAYS IN TECH,"
        "COUNT IN HOUSE,COUNT IN RETURN,COUNT IN REPAIR,COUNT IN OTHER,"
        "COUNT IN TECH,COUNT INSTALL-RETURN,STATE\n");

    // Walk through the Box Reset list and write the reset report.

    for (BoxResetCur = BoxResetRoot; BoxResetCur; BoxResetCur = BoxResetCur->next) {
        fprintf( ofhdl, "%s,\"Yes\",0,0,0,0,0,0,0,0,0,0,0,0,%c\n",
            BoxResetCur->CableBoxSerial, BoxResetCur->CurrentState);
    }

    fclose( ofhdl);
    BoxResetRoot = (BOXRESET *) NULL;
}


/*
 * WATCHLISTROLLBACK - Roll back the watch list data for the given cable box,
 * if there is such a record.
 * Note: Assumes that curnode points to the cable box record.
 */
void WatchListRollback( char *CableBoxSerial)
{
    // Set aside the cable box tree and point to the watch list tree.

    bxtreeroot = treeroot;
    treeroot = (NODE *) wltreeroot;
    if (ReadWLDataFromDisk( DatabaseMode) != 1) goto Done;

    // Find the watch list record, if there is one, for this cable box,
    // and note that it was rolled back.

    if (wlcurnode = (WLNODE *) btreefind( CableBoxSerial)) {
        wlcurnode->WatchFlag = WF_INACTIVE;
        ++wlcurnode->TimesRolledBack;
        wlcurnode->LatestRollback = curnode->DateOfState;
        wlcurnode->RollbackReason = RBR_MANUAL;
        WatchDataDirty = 1;
        AppendModelData( 'O', curnode->DateOfState);
    }

    // Restore the cable box tree.

Done:
    wltreeroot = (WLNODE *) treeroot;
    treeroot = bxtreeroot;
}


/*
 * ROLLBACKCABLEBOX - Remove a box from the watch list, reset its counters,
 * and add it to the Box Reset list.
 * Assumes curnode points to the box.
 */
long RollBackCableBox( void)
{
    char RReason;
    long ret;
#if 0 //@@
    short DaysInState;
    char Msg[100];
#endif

    // Set aside the cable box tree and point to the watch list tree.

    ret = 0;
    bxtreeroot = treeroot;
    treeroot = (NODE *) wltreeroot;
    if (ReadWLDataFromDisk( DatabaseMode) != 1) goto Done;

    // Find the watch list record, if there is one, for this cable box,
    // and note that it was rolled back.

    if ((wlcurnode = (WLNODE *) btreefind( curnode->CableBoxSerial)) &&
        (wlcurnode->WatchFlag >= WF_ACTIVE))
    {
#if 0 //@@
        if (DebugFlag & 1) {
            if (curnode->CurrentState == 'H') {
                DaysInState = (short) ((MostRecentDOS - curnode->DateOfState) / SECSINADAY);

                // Log the fact that the box is in House and on the watch list.

                sprintf( Msg, "    %%s on Watch, in House %%d days,,,%d,%d\n",
                    MostRecentDOS, curnode->DateOfState);

                AppendErrorMessage( Msg, curnode->CableBoxSerial, DaysInState);

                if (DaysInState <= 90) goto Done;
                AppendErrorMessage( "    %s ROLLED BACK\n", curnode->CableBoxSerial, 0);
            }
        }
#endif

        WatchDataDirty = 1;
        wlcurnode->WatchFlag = WF_INACTIVE;
        ++wlcurnode->TimesRolledBack;
        wlcurnode->LatestRollback = curnode->DateOfState;

        if (fStatusCode == 'P') {
            wlcurnode->RollbackReason = RBR_REPAIR;
            RReason = 'R';
        }
        else if (fStatusCode == 'S') {
            wlcurnode->RollbackReason = RBR_SERVICE;
            RReason = 'V';
        }
        else if (curnode->CurrentState == 'H') {
            if (wlcurnode->WatchFlag == WF_MANUAL) goto Done;
            wlcurnode->RollbackReason = RBR_HOUSE;
            RReason = 'H';
        }
        else {
            wlcurnode->RollbackReason = RBR_UNKNOWN;
            RReason = 'O';
        }

        curnode->RDaysUnknown =
        curnode->RDaysHouse =
        curnode->RDaysReturn =
        curnode->RDaysRepair =
        curnode->RDaysOther =
        curnode->RDaysTech =
        curnode->RToHouse =
        curnode->RToReturn =
        curnode->RToRepair =
        curnode->RToOther =
        curnode->RToTech = 0;
        curnode->ShortInHouse = ShortInHouseReset;

        BoxResetCur = (BOXRESET *)
            mypermmalloc( sizeof( BOXRESET) + strlen( curnode->CableBoxSerial));
        strcpy( BoxResetCur->CableBoxSerial, curnode->CableBoxSerial);
        BoxResetCur->CurrentState = ((fStatusCode == 'P') ||
            (fStatusCode == 'S')) ? fStatusCode : 'H';

        BoxResetCur->next = BoxResetRoot;
        BoxResetRoot = BoxResetCur;

        AppendModelData( RReason, fDateOfState);
        ret = 1;
    }

    // Restore the cable box tree.

Done:
    wltreeroot = (WLNODE *) treeroot;
    treeroot = bxtreeroot;
    return ret;
}


/*
 * READDROPMODELFILE - Read the drop model file, if there is one.
 */
void ReadDropModelFile( void)
{
    char FileText[100];

    // If the file has already been read, just return.

    if (dmtreeroot) return;
    sprintf( FileText, "%sModel_Drop.csv", InboundDir);
    if (!(ifhdl = fopen( FileText, "r"))) {
        dmtreeroot = (DMNODE *) 1;
        return;
    }

    // Set aside the cable box tree and point to the drop model tree.

    printf( "Reading %s\n", FileText);
    bxtreeroot = treeroot;
    treeroot = (NODE *) dmtreeroot;

    // Initialize the drop model tree.
    // Then read and process each line of the file.

    pmbtinit();
    while (ReadAndProcessCSVLine( FileText, ifhdl)) {
        SplitOnTabs( FileText);
        if (!(dmcurnode = (DMNODE *)
            mypermmalloc( sizeof( DMNODE) + strlen( Flds[0])))) goto Done;

        strcpy( dmcurnode->Model, Flds[0]);
        btreestore( (NODE *) dmcurnode);
    }

Done:
    fclose( ifhdl);

    // Restore the cable box tree; done.

    dmtreeroot = (DMNODE *) treeroot;
    treeroot = bxtreeroot;
}


/*
 * MATCHDROPMODEL - See if the given model is to be dropped.
 * Return 1 to drop the record, 0 to proceed.
 */
long MatchDropModel( char *ModelNo)
{
    long retval;

    // Set aside the cable box tree and point to the drop model tree.

    bxtreeroot = treeroot;
    treeroot = (NODE *) dmtreeroot;

    retval = (btreefind( ModelNo)) ? 1 : 0;

    // Restore the cable box tree; done.

    treeroot = bxtreeroot;
    return retval;
}


/*
 * PROCESSMODELDATA - Read the weekly model data and insert it into the
 * model data structure. treeroot points to the mwtreeroot.
 */
void ProcessModelData( void)
{
    FILE *mfhdl, *nfhdl;
    char line[201], WeekSiteModel[100], *dptr, *SiteModel, *Week, flag;
    char NewModelFile[100];

    SetModelFileName();
    if (!(mfhdl = fopen( ModelFile, "r"))) return;
    sprintf( NewModelFile, "%sModelData1.dat", DatabaseDir);
    if (!(nfhdl = fopen( NewModelFile, "w"))) return;

    while (fgets( line, 200, mfhdl)) {
        dptr = line;
        SiteModel = NextString( &dptr);
        flag = *dptr;
        NextString( &dptr);
        Week = NextString( &dptr);
#if DEBUGWKCHK
        CheckWeek( Week);
#endif

        // Look for any entry from the desired week.
        // If none, save the entry for next time, in the new model file.

        if (!(mwcurnode = btreefindpn( Week))) {
            fprintf( nfhdl, "%s\t%c\t%s\t\n", SiteModel, flag, Week);
            continue;
        }

        // Now find and increment the appropriate week,site,model record.

        sprintf( WeekSiteModel, "%s,%s", Week, SiteModel);
        if (mwcurnode = (MWNODE *) btreefindp( WeekSiteModel)) {
            switch (flag) {
              case 'S':
                ++mwcurnode->GL_SIHCount;   // boxes that are Short in House
                break;
              case 'C':                     // correct Short in House
                if (mwcurnode->GL_SIHCount > 0) --mwcurnode->GL_SIHCount;
                break;
              case 'W':
                ++mwcurnode->WL_AddCount;   // boxes added to watch list
                break;
              case 'O':
                ++mwcurnode->WL_OtherCount; // for some reason other than below
                break;
              case 'V':
                ++mwcurnode->WL_ScrapCount;
                break;
              case 'H':
                ++mwcurnode->WL_HouseCount;
                break;
              case 'R':
                ++mwcurnode->WL_RepairCount;
            }
        }
    }
    fclose( mfhdl);
    fclose( nfhdl);
    DeleteFile( ModelFile);
    rename( NewModelFile, ModelFile);
}


/*
 * APPENDMODELDATA - Append the given message to the model log.
 * Assumes that curnode points to the appropriate cable box record.
 * Key =
 *     'S'=short in house
 *     'C'=SIH correction
 *     'W'=add watch
 * also, remove from watch list because:
 *     'O'=Other (UNKNOWN, MANUAL)
 *     'V'=Out of Service (SERVICE, FILES)
 *     'H'=House (HOUSE)
 *     'R'=Repair (REPAIR, FILER)
 */
void AppendModelData( char Key, time_t DateOfState)
{
    FILE *mfhdl;
    char SiteModel[100], DateStg[10];

    if (!curnode) return;
    SetModelFileName();
    if (!(mfhdl = fopen( ModelFile, "a"))) return;
    BuildSiteAndModel( SiteModel, 1);
    fprintf( mfhdl, "%s\t%c\t%s\t\n",
        SiteModel, Key, ConvertTimetToWeek( DateOfState, DateStg));
    fclose( mfhdl);
}


/*
 * SETMODELFILENAME - Set the name of the model file, if it hasn't been done.
 */
void SetModelFileName( void)
{
    if (!ModelFile) {
        ModelFile = mypermmalloc( strlen( DatabaseDir) + 14);
        sprintf( ModelFile, "%sModelData.dat", DatabaseDir);
    }
}


/*
 * GETMODELWEEK - Read the model week file to get the current week.
 */
void GetModelWeek( void)
{
    char ModelWeekFile[100];
    FILE *mfhdl;

    if (*CurrentWeek) return;
    sprintf( ModelWeekFile, "%sModelWeek.dat", DatabaseDir);
    if (!(mfhdl = fopen( ModelWeekFile, "r"))) return;
    fgets( ModelWeekFile, 100, mfhdl);
    fclose( mfhdl);
    if (strlen( ModelWeekFile) >= 7) strncpy( CurrentWeek, ModelWeekFile, 7);
}


/*
 * SAVEMODELWEEK - Save the current week in the model week file.
 */
void SaveModelWeek( void)
{
    char ModelWeekFile[100];
    FILE *mfhdl;

    if (!*CurrentWeek) return;
    sprintf( ModelWeekFile, "%sModelWeek.dat", DatabaseDir);
    if (!(mfhdl = fopen( ModelWeekFile, "w"))) return;
    fprintf( mfhdl, "%s", CurrentWeek);
    fclose( mfhdl);
}


#if 0 //@@ not called
/*
 * TRIM - Remove leading and trailing spaces from the given string.
 */
char *Trim( char *lptr)
{
    char *sptr, *dptr;

    dptr = (sptr = lptr) + strlen( lptr);
    while (*--dptr == ' ');
    *(dptr + 1) = '\0';

    if (*sptr == ' ') {
        while (*sptr++ == ' ');
        strcpy( lptr, sptr - 1);
    }
    return lptr;
}
#endif


/*
 * SPLITONTABS - Split the given line into the global array Flds[],
 * where each field is delimited by a tab. Trims leading and trailing
 * spaces from each field.
 *
 * Returns the number of fields.
 */
long SplitOnTabs( char *line)
{
    long fix;
    char chr, *lptr, *sptr, *eptr;

    fix = 0;
    lptr = sptr = line;
    do {
        while ((chr = *lptr) && (chr != '\t')) ++lptr;
        eptr = lptr++;

        // Now sptr and eptr point to the start and end of the string.
        // lptr points to the start of the next string.
        // Move sptr forward and eptr back to remove leading/trailing spaces.
        // Save a null at eptr, and save sptr in Flds[].

        while (*sptr == ' ') ++sptr;
        if (sptr != eptr) while (*(eptr - 1) == ' ') --eptr;
        *eptr = '\0';
        Flds[fix++] = sptr;
        sptr = lptr;
    } while (chr);

    return fix;
}


/*
 * SPLITONTABSINTOARRAY - Split the given line into the given array,
 * where each field is delimited by a tab. Does not trim spaces.
 */
void SplitOnTabsIntoArray( char *line, char **flds)
{
    char chr, *lptr, *sptr;

    lptr = sptr = line;
    do {
        while ((chr = *lptr) && (chr != '\t')) ++lptr;
        *flds++ = sptr;
        *lptr = '\0';
        sptr = ++lptr;
    } while (chr);
}


/*
 * TRUNC - If the given string is longer then the given size, truncate it
 * to that size.
 */
char *Trunc( char *lptr, long size)
{
    if (((long) strlen( lptr)) > size) *(lptr + size) = '\0';
    return lptr;
}


#define LOOKINGFORSTARTQUOTE 0
#define LOOKINGFORENDQUOTE   1
#define LOOKINGFORCOMMA      2

#define _getc_lk(_stream) (--(_stream)->_cnt >= 0 ? 0xff & *(_stream)->_ptr++ : _filbuf(_stream))

/*
 * READANDPROCESSCSVLINE - Process the csv line, removing the (expected)
 * double quotes, and replacing the commas with tabs.
 * Returns >0 = number of characters in line and 0 for badness.
 */
long ReadAndProcessCSVLine( char *InLine, FILE *FPtr)
{
    long State, c, LeftTrimming;
    char *OutPtr;

    State = LOOKINGFORSTARTQUOTE;
    LeftTrimming = 1;
    OutPtr = InLine;

StartOver:
    *OutPtr = '\0';

    while (1) {
        c = _getc_lk( FPtr);
        if (FPtr && (c == 0)) c = ' ';          // Change embedded nulls to space
        if ((c == 0) || (c == EOF)) break;

TryAgain:
        if (c == ',') {
            if ((State == LOOKINGFORCOMMA) || (State == LOOKINGFORSTARTQUOTE)) {
                // Back up over all spaces< then move forward and punch the tab in.
                // This will be an effective rtrim().

                while (OutPtr != InLine) {
                    OutPtr--;
                    if (*OutPtr != ' ') {
                        OutPtr++;               // Non space. Move foward one.
                        break;                  // Here's where we'll put in the tab.
                    }
                }

                *OutPtr++ = '\t';               // Found comma, replace with tab
                State = LOOKINGFORSTARTQUOTE;
                LeftTrimming = 0;               // No longer left-trimming
            }
            else                                // State = LOOKINGFORENDQUOTE
                *OutPtr++ = (char) ',';         // Found sepchar in middle of field -- pass through.
        }
        else {
            switch (c) {      // breaking out of this switch means "process the next character"
              case '\t':
                if (!LeftTrimming) {
                    c = ' ';
                    goto TryAgain;   // goto TryAgain means "try again with the new value of c"
                }
                else break;

              case '\"':
                switch (State) {
                  case LOOKINGFORSTARTQUOTE:
                    State = LOOKINGFORENDQUOTE; // Found it.  Switch state to looking for end quote.
                    LeftTrimming = 1;
                    break;   //  breaking out of this means "process the next character"

                  case LOOKINGFORENDQUOTE:
                    // Could be an embedded double quote. If so, then the next char will also be a double quote

                    c = _getc_lk( FPtr);
                    if (FPtr && (c == 0) && !LeftTrimming)
                        c = ' ';                // Change embedded nulls in files to space

                    if ((c == 0) || (c == EOF)) goto Done;

                    if (c == '\"') {
                        *OutPtr++ = '\'';       // Replace with two single quotes
                        *OutPtr++ = '\'';       // and "eat" second double.
                    }
                    else {
                        if ((c == ',') || (c == '\n') || (c == '\r') || ( c == ' ')) {
                            LeftTrimming = 0;
                            State = LOOKINGFORCOMMA; // Found it.  Switch state to looking for comma.
                            if (FPtr) ungetc( c, FPtr);
                        }
                        else {
                            // Found a illegal quote.  Change it to two singles

                            *OutPtr++ = '\'';   // Replace with two single quotes
                            *OutPtr++ = '\'';
                            if (FPtr) ungetc( c, FPtr);
                        }
                    }

                    break;

                  default:
                    // Found an illegal quote.  Change it to two singles

                    *OutPtr++ = '\'';           // Replace with two single quote
                    *OutPtr++ = '\'';
                }

                break;

              case '\n':
              case '\r':
                // Regardless of state, check for blank lines, and simply eat them

                if (OutPtr == InLine) {
                    // No characters added yet, so we are at the start of a line

                    goto StartOver;
                }

                if (State == LOOKINGFORENDQUOTE) {
                    if (!LeftTrimming) *OutPtr++ = ' '; // In quote, repace binary character with space
                }
                else {
                    // check for lf

                    if (c == '\n') goto Done;
                    else {
                        c = _getc_lk( FPtr);
                        if (FPtr && (c == 0)) c = ' ';  // Change embedded nulls in files to space

                        if ((c != '\n') && FPtr) ungetc( c, FPtr);
                        goto Done;
                    }
                }
                break;

              case '\\':
                *OutPtr++ = '-';                // switch to dash
                break;

              case ' ':
                if (LeftTrimming) break;

                // else fall through

              default:
                // Check for unquoted numeric fields

                if (State == LOOKINGFORSTARTQUOTE) State = LOOKINGFORCOMMA;
                LeftTrimming = 0;
                *OutPtr++ = (char) c;
                break;
            }
        }
    }

Done:
    // Before truncating the line, move to the left and remove any trailing
    // spaces that might come after the end of the last field.

    while (OutPtr > InLine) {
        if (*(OutPtr - 1) != ' ') break;
        --OutPtr;
    }

    *OutPtr = '\0';
    return (long) (OutPtr - InLine);
}


/*
 * BTINIT - Initialize a new binary tree for cable box data.
 * Returns 0 on success, -1 on error.
 */
long btinit( void)
{
    if (!(treeroot = (NODE *) mydbmalloc( sizeof( NODE)))) return -1;
    treeroot->llink = treeroot->rlink = (NODE *) NULL;
    treeroot->balance = 0;
    treeroot->Strings = (char *) NULL;
    return 0;
}


/*
 * WLBTINIT - Initialize a new binary tree for watch list data.
 * Returns 0 on success, -1 on error.
 */
long wlbtinit( void)
{
    if (!(treeroot = (NODE *) mywlmalloc( sizeof( WLNODE)))) return -1;
    treeroot->llink = treeroot->rlink = (NODE *) NULL;
    treeroot->balance = 0;
    treeroot->Strings = (char *) NULL;
    return 0;
}


/*
 * PMBTINIT - Initialize a new binary tree for all other kinds of data.
 * Returns 0 on success, -1 on error.
 */
long pmbtinit( void)
{
    if (!(treeroot = (NODE *) mypermmalloc( sizeof( DMNODE)))) return -1;
    treeroot->llink = treeroot->rlink = (NODE *) NULL;
    treeroot->balance = 0;
    return 0;
}


/*
 * BTREESTORE - Store the given data structure in the tree.
 * Returns: 0 if the key was already in the tree.
 *          1 if the record was stored successfully.
 *
 * This is right out of Knuth vol 3, pages 451-456.
 */
long btreestore( NODE *nptr)
{
    char *key;
    NODE *p, *q, *r, *s, *t;
    short comp, alpha;

    if (!treeroot) return -1;
    nptr->llink = nptr->rlink = (NODE *) NULL;
    nptr->balance = 0;

    // A1 (initialize)
    // If the tree is empty, insert the first entry.

    if (!(s = p = treeroot->rlink)) {
        treeroot->rlink = q = nptr;
        return 1;
    }

    // A2 (compare)

    key = nptr->CableBoxSerial;
    t = treeroot;
    while (1) {
        comp = strcmp( key, p->CableBoxSerial);
        if (!comp) return 0;            // don't allow a duplicate entry

        // A3 (move left)

        if (comp < 0) {
            if (!(q = p->llink)) {
                p->llink = q = nptr;
                break;
            }
        }

        // A4 (move right)

        else {
            if (!(q = p->rlink)) {
                p->rlink = q = nptr;
                break;
            }
        }

        if (q->balance) {
            t = p;
            s = q;
        }
        p = q;
    }

    // A5 (insert)

    // A6 (adjust balance factors)

    if (strcmp( key, s->CableBoxSerial) < 0) p = s->llink;
    else                                     p = s->rlink;

    r = p;
    while (p != q) {
        if (strcmp( key, p->CableBoxSerial) < 0) {
            p->balance = -1;
            p = p->llink;
        }
        else {
            p->balance = 1;
            p = p->rlink;
        }
    }

    // A7 (balancing act)

    alpha = (strcmp( key, s->CableBoxSerial) < 0) ? -1 : 1;
    if (!s->balance) {
        s->balance = alpha;
        return 1;
    }

    if (s->balance == -alpha) {
        s->balance = 0;
        return 1;
    }

    // A8 (single rotation)

    if (r->balance == alpha) {
        p = r;

        if (alpha == 1) {
            s->rlink = r->llink;
            r->llink = s;
        }
        else {
            s->llink = r->rlink;
            r->rlink = s;
        }
        s->balance = r->balance = 0;
    }

    // A9 (double rotation)

    else {
        if (alpha == 1) {
            if (!(p = r->llink)) return 1;
            r->llink = p->rlink;
            p->rlink = r;
            s->rlink = p->llink;
            p->llink = s;
        }
        else {
            if (!(p = r->rlink)) return 1;
            r->rlink = p->llink;
            p->llink = r;
            s->llink = p->rlink;
            p->rlink = s;
        }
        if (!p->balance) s->balance = r->balance = 0;
        else if (p->balance == alpha) {
            s->balance = -alpha;
            r->balance = 0;
        }
        else {
            s->balance = 0;
            r->balance = alpha;
        }
        p->balance = 0;
    }

    // A10 (finishing touch)

    if (s == t->rlink) t->rlink = p;
    else               t->llink = p;
    return 1;
}


/*
 * BTREEFIND - Find the given key in the tree, where key field is a string.
 * Returns the node if found, else NULL.
 */
NODE *btreefind( char *key)
{
    NODE *p;
    short comp;

    // If the tree is empty, always return failure.

    if (!treeroot || !(p = treeroot->rlink)) return (NODE *) NULL;

    // Traverse the tree looking for the key.

    while (1) {
        comp = strcmp( key, p->CableBoxSerial);
        if (!comp) return p;
        if (!(p = (comp < 0) ? p->llink : p->rlink)) return (NODE *) NULL;
    }
}


/*
 * BTREESTOREP - Store the given data structure in the tree.
 * Returns: 0 if the key was already in the tree.
 *          1 if the record was stored successfully.
 * This uses a pointer to the key string rather than the string array.
 */
long btreestorep( CTNODE *nptr)
{
    char *key;
    CTNODE *p, *q, *r, *s, *t;
    short comp, alpha;

    if (!treeroot) return -1;
    nptr->llink = nptr->rlink = (CTNODE *) NULL;
    nptr->balance = 0;

    // A1 (initialize)
    // If the tree is empty, insert the first entry.

    if (!(s = p = (CTNODE *) treeroot->rlink)) {
        treeroot->rlink = (NODE *) (q = nptr);
        return 1;
    }

    // A2 (compare)

    key = nptr->SiteID_Model;
    t = (CTNODE *) treeroot;
    while (1) {
        comp = strcmp( key, p->SiteID_Model);
        if (!comp) return 0;            // don't allow a duplicate entry

        // A3 (move left)

        if (comp < 0) {
            if (!(q = (CTNODE *) p->llink)) {
                p->llink = q = nptr;
                break;
            }
        }

        // A4 (move right)

        else {
            if (!(q = (CTNODE *) p->rlink)) {
                p->rlink = q = nptr;
                break;
            }
        }

        if (q->balance) {
            t = p;
            s = q;
        }
        p = q;
    }

    // A5 (insert)

    // A6 (adjust balance factors)

    if (strcmp( key, s->SiteID_Model) < 0) p = (CTNODE *) s->llink;
    else                                   p = (CTNODE *) s->rlink;

    r = p;
    while (p != q) {
        if (strcmp( key, p->SiteID_Model) < 0) {
            p->balance = -1;
            p = (CTNODE *) p->llink;
        }
        else {
            p->balance = 1;
            p = (CTNODE *) p->rlink;
        }
    }

    // A7 (balancing act)

    alpha = (strcmp( key, s->SiteID_Model) < 0) ? -1 : 1;
    if (!s->balance) {
        s->balance = alpha;
        return 1;
    }

    if (s->balance == -alpha) {
        s->balance = 0;
        return 1;
    }

    // A8 (single rotation)

    if (r->balance == alpha) {
        p = r;

        if (alpha == 1) {
            s->rlink = r->llink;
            r->llink = s;
        }
        else {
            s->llink = r->rlink;
            r->rlink = s;
        }
        s->balance = r->balance = 0;
    }

    // A9 (double rotation)

    else {
        if (alpha == 1) {
            if (!(p = (CTNODE *) r->llink)) return 1;
            r->llink = p->rlink;
            p->rlink = r;
            s->rlink = p->llink;
            p->llink = s;
        }
        else {
            if (!(p = (CTNODE *) r->rlink)) return 1;
            r->rlink = p->llink;
            p->llink = r;
            s->llink = p->rlink;
            p->rlink = s;
        }
        if (!p->balance) s->balance = r->balance = 0;
        else if (p->balance == alpha) {
            s->balance = -alpha;
            r->balance = 0;
        }
        else {
            s->balance = 0;
            r->balance = alpha;
        }
        p->balance = 0;
    }

    // A10 (finishing touch)

    if (s == t->rlink) t->rlink = p;
    else               t->llink = p;
    return 1;
}


/*
 * BTREEFINDP - Find the given key in the tree, where key field is a
 * pointer to a string.
 * Returns the node if found, else NULL.
 */
CTNODE *btreefindp( char *key)
{
    CTNODE *p;
    short comp;

    // If the tree is empty, always return failure.

    if (!treeroot || !(p = (CTNODE *) treeroot->rlink))
        return (CTNODE *) NULL;

    // Traverse the tree looking for the key.

    while (1) {
        comp = strcmp( key, p->SiteID_Model);
        if (!comp) return p;
        if (!(p = (comp < 0) ? p->llink : p->rlink)) return (CTNODE *) NULL;
    }
}


/*
 * BTREEFINDPN - Find the given key in the tree, where key field is a
 * pointer to a string. Compares only as far as the length of the key.
 * Returns the node if found, else NULL.
 */
MWNODE *btreefindpn( char *key)
{
    MWNODE *p;
    short comp, len;

    // If the tree is empty, always return failure.

    if (!treeroot || !(p = (MWNODE *) treeroot->rlink))
        return (MWNODE *) NULL;

    // Traverse the tree looking for the key.

    len = strlen( key);
    while (1) {
        if (!(comp = strncmp( key, p->Week_SiteID_Model, len))) return p;
        if (!(p = (comp < 0) ? p->llink : p->rlink)) return (MWNODE *) NULL;
    }
}


/*
 * BTFIRSTNODE - Set up to start doing nextnodes.
 * Finds the first node whose key is the given key, if key is non-NULL.
 * Otherwise finds the node with the lowest key value.
 * Returns the node's value if found, else -1.
 */
NODE *btfirstnode( void)
{
    if (!treeroot) return (NODE *) NULL;
    nodelevel = 0;
    thisnode = treeroot->rlink;
    if (!thisnode) return (NODE *) NULL;

    // Find the first (lowest) entry.

    nodestate = 0;
    return btnextnode();
}


/*
 * BTNEXTNODE - Returns the next node of the tree that's currently being
 * traversed. The caller MUST have done a firstnode some time in the past.
 * Returns the node's value if found, -1 when tree is exhausted.
 */
NODE *btnextnode( void)
{
    if (nodestate) {
        while (!(thisnode = thisnode->rlink)) {
            if (!nodelevel--) return (NODE *) NULL;
            thisnode = nodelevels[nodelevel];
            return thisnode;
        }
    }

    while (nodelevel >= 0) {
        if (thisnode->llink) {
            nodelevels[nodelevel++] = thisnode;
            thisnode = thisnode->llink;
            continue;
        }
        nodestate = 1;
        return thisnode;
    }
    nodestate = 0;
    return (NODE *) NULL;
}


/*
 * WRITEDBTODISK - Write the entire database to disk and free its storage.
 * (This is called from DoBASCommand).
 */
void WriteDBToDisk( void)
{
    WriteDatabaseToDisk();
    if (WatchDataDirty == 1) WriteWLDataToDisk();

#ifdef CAPEQ_VERSION
    if (WorkOrderDataDirty == 1) {
        bxtreeroot = treeroot;
        treeroot = (NODE *) wotreeroot;
        WriteWODataToDisk();
        treeroot = bxtreeroot;
    }

    if (DefectiveEquipmentDataDirty == 1) {
        bxtreeroot = treeroot;
        treeroot = (NODE *) detreeroot;
        WriteDEDataToDisk();
        treeroot = bxtreeroot;
    }
#endif

    if (cvtreeroot && cvtreeroot->rlink) {
        bxtreeroot = treeroot;
        treeroot = (NODE *) cvtreeroot;
        WriteCVDataToDisk();
        treeroot = bxtreeroot;
    }

    SendReply( "$WriteDBToDisk\t1\t");
}


/*
 * DISCARDDBCHANGES - Don't save the in-memory image of the database.
 * This has the effect of discarding all changes made since the database
 * was read in.
 */
void DiscardDBChanges( void)
{
    mydbfree();
}


/*
 * WRITEDATABASETODISK - Write the entire database to disk and free its storage.
 */
void WriteDatabaseToDisk( void)
{
    FILE *ofh1, *ofh2;
    char line[201];
    char **dbpptr, *dbptr;
    NODE *nptr;
#if DEBUGMSGS0
    long count;

    count = 0;
#endif

    // Write out each block of the database.
    // First store an end-flag in the next free spot of the last block.

    if (!(dbptr = mydbspacelist)) return;
    dbpptr = (char **) mydbspaceptr;
    *dbpptr = (char *) 101;

    sprintf( line, "%s%s1.dat", DatabaseDir, OutDatabaseName);
    if (!(ofh1 = fopen( line, "wb"))) return;
    sprintf( line, "%s%s2.dat", DatabaseDir, OutDatabaseName);
    if (!(ofh2 = fopen( line, "w"))) goto Close1;

    do {
        fwrite( dbptr, DBSSPACESIZE, 1, ofh1);
        dbpptr = (char **) dbptr;

        dbptr += sizeof( char *);
        while (1) {
            nptr = (NODE *) dbptr;
#if DEBUGMSGS0
            ++count;
            if (((nptr->balance < -1) || (nptr->balance > 1)) &&
                (nptr->balance < 100)) {
                AppendErrorMessage(
                    "Balance %s %d\n", "is", nptr->balance);
                AppendErrorMessage(
                    "line    %s %d\n", "  ", count);
            }

            if (nptr->balance >= 100) {
                AppendErrorMessage(
                    "Breaking because balance %s %d\n", "is", nptr->balance);
                AppendErrorMessage(
                    "Breaking %s line            %d\n", "on", count);
            }
#endif
            if (nptr->balance >= 100) break;

            if (nptr->Strings) fprintf( ofh2, "%s\n", nptr->Strings);
            dbptr += sizeof( NODE);
        }
    } while (dbptr = *dbpptr);

    // Close and return.

    fclose( ofh1);
    fclose( ofh2);
    mydbfree();
    return;

    // Close and return on error.

    fclose( ofh2);
Close1:
    fclose( ofh1);
}


/*
 * READDBFROMDISK - Read the entire database from disk and save the data
 * in the binary tree. If reading the archive, also read the watch list,
 * work order, and defective equipment data, if there is any. Also, delete
 * the model counts (database 4) so they will be recalculated.
 * (This is called from VB via DoBASCommand).
 */
void ReadDBFromDisk( void)
{
    long ret;
    char Line[50], flag;

    ret = ReadDatabaseFromDisk( flag = *Flds[1]);
    if ((ret == 1) && (flag != '1')) {
        bxtreeroot = treeroot;
        treeroot = (NODE *) wltreeroot;
        ReadWLDataFromDisk( flag);
        wltreeroot = (WLNODE *) treeroot;

#ifdef CAPEQ_VERSION
        treeroot = (NODE *) wotreeroot;
        ReadWODataFromDisk( flag);
        wotreeroot = (WONODE *) treeroot;

        treeroot = (NODE *) detreeroot;
        ReadDEDataFromDisk( flag);
        detreeroot = (DENODE *) treeroot;
#endif

        treeroot = bxtreeroot;
        DeleteDatabaseFile( "%sCableBoxData4.dat");
    }

    sprintf( Line, "$ReadDBFromDisk\t%d\t", ret);
    SendReply( Line);
}


/*
 * READDATABASEFROMDISK - Read the entire database from disk and save
 * the data in the binary tree. (This is called from local routines).
 * Returns 1 on success, -1 on failure.
 */
long ReadDatabaseFromDisk( char DataValue)
{
    FILE *ifh1, *ifh2;
    char *mptr;
    char line[201];
    NODE *nptr;
    long LineLen;
#if DEBUGMSGS0
    long count;

    count = 0;
#endif

    // database mode:
    // '0' database has not yet been read
    // '1' read and write CableBoxData
    // '2' read and write CableBoxArchive
    // '3' read CableBoxArchive, write CableBoxData

    // If the data has already been read in, there's nothing to do.

    if (!DataValue) DataValue = '1';
    if (DatabaseMode == DataValue) return 1;

    // If there currently is database data, then write it out if it's
    // now coming from a different place. Otherwise don't need to read
    // it again.

    if (DatabaseMode) WriteDatabaseToDisk();

    if (DataValue == '1')
        InDatabaseName = OutDatabaseName = "CableBoxData";
    else if (DataValue == '2')
        InDatabaseName = OutDatabaseName = "CableBoxArchive";
    else {
        InDatabaseName = "CableBoxArchive";
        OutDatabaseName = "CableBoxData";
    }

    if (((DatabaseMode == '2') && (DataValue == '3')) ||
        ((DatabaseMode == '3') && (DataValue == '2'))) {
            DatabaseMode = DataValue;
            return 1;
    }
    DatabaseMode = DataValue;

    // Open the database file, read it in block by block, saving all
    // the nodes in each block in the binary tree.

    btinit();
    sprintf( line, "%s%s1.dat", DatabaseDir, InDatabaseName);
    if (!(ifh1 = fopen( line, "rb"))) return 1;
    sprintf( line, "%s%s2.dat", DatabaseDir, InDatabaseName);
    if (!(ifh2 = fopen( line, "r"))) goto Close1;

    // Read the first block into treeroot.

    fread( mydbspacelist, DBSSPACESIZE, 1, ifh1);
    treeroot->llink = treeroot->rlink = (NODE *) NULL;

    mptr = ((char *) treeroot) + sizeof( NODE);
    goto Proceed;

    while (1) {
        mydbspaceptr = (char *) nptr;
        mptr = mydbmalloc( DBSSPACESIZE);

        // read a block into mptr

        if ((!fread( mptr, sizeof( char *), 1, ifh1)) ||
            (!fread( mptr, DBSSPACESIZE - sizeof( char *), 1, ifh1)))
                goto Close2;
Proceed:
        while (1) {
            nptr = (NODE *) mptr;
#if DEBUGMSGS0
            ++count;
            if (((nptr->balance < -1) || (nptr->balance > 1)) &&
                (nptr->balance < 100)) {
                AppendErrorMessage(
                    "Balance %s %d\n", "is", nptr->balance);
                AppendErrorMessage(
                    "line    %s %d\n", "  ", count);
            }

            if (nptr->balance >= 100) {
                AppendErrorMessage(
                    "Breaking because balance %s %d\n", "is", nptr->balance);
                AppendErrorMessage(
                    "Breaking %s line            %d\n", "on", count);
            }
#endif
            if (nptr->balance >= 100) break;

            if (!fgets( line, 200, ifh2)) goto Close2;

#if DEBUGMSGS0
            if (strlen( line) > 200) {
                AppendErrorMessage(
                    "Got %slong line at %d\n", "a ", count);
            }
#endif

            line[(LineLen = strlen( line)) - 1] = '\0';
            if (nptr->Strings) {
                if (!(mystgspacecur = mystgmalloc( LineLen))) break;
                strcpy( mystgspacecur, line);
                nptr->Strings = mystgspacecur;
            }

            btreestore( nptr);
            mptr += sizeof( NODE);
        }
#if DEBUGMSGS0
        if (nptr->balance == 101)
            AppendErrorMessage( "Done reading database\n", "", 0);
#endif
        if (nptr->balance == 101) break;
    }

    // Set the last block's next pointer to NULL.

#if DEBUGMSGS0
    AppendErrorMessage( "Out of while loop\n", "", 0);
#endif
    *mydbspacecur = (char *) NULL;
    mydbspaceptr = (char *) nptr;
    mydbspacesize = DBSSPACESIZE - sizeof( char *) - sizeof( char *) -
        (((char *) nptr) - ((char *) mydbspacecur));

    // Close the database file.

#if DEBUGMSGS0
    AppendErrorMessage( "Closing and returning\n", "", 0);
#endif
    fclose( ifh1);
#if DEBUGMSGS0
    AppendErrorMessage( "After close 1\n", "", 0);
#endif
    fclose( ifh2);
#if DEBUGMSGS0
    AppendErrorMessage( "After close 2\n", "", 0);
#endif
    return 1;

Close2:
    fclose( ifh1);
Close1:
    fclose( ifh2);
    return -1;
}


/*
 * CLEARDATABASE - Delete the in-memory and disk images of the database.
 */
void ClearDatabase( void)
{
    DeleteDatabaseFile( "%sCableBoxData1.dat");     // cable boxes
    DeleteDatabaseFile( "%sCableBoxData2.dat");     // cable box strings
    DeleteDatabaseFile( "%sCableBoxData3.dat");     // watch data
    DeleteDatabaseFile( "%sCableBoxData4.dat");     // model count data
    DeleteDatabaseFile( "%sCableBoxData5.dat");     // defective equipment data
    DeleteDatabaseFile( "%sCableBoxData6.dat");     // work order data
    DeleteDatabaseFile( "%sCableBoxData7.dat");     // work order code/desc's
    DeleteDatabaseFile( "%sCableBoxData8.dat");     // Cablevision extra data
    DeleteDatabaseFile( "%sCableBoxData9.dat");     // weekly model count data
    DeleteDatabaseFile( "%sCableBoxArchive1.dat");
    DeleteDatabaseFile( "%sCableBoxArchive2.dat");
    DeleteDatabaseFile( "%sCableBoxArchive3.dat");
    DeleteDatabaseFile( "%sCableBoxArchive4.dat");
    DeleteDatabaseFile( "%sCableBoxArchive5.dat");
    DeleteDatabaseFile( "%sCableBoxArchive6.dat");
    DeleteDatabaseFile( "%sCableBoxArchive7.dat");
    DeleteDatabaseFile( "%sCableBoxArchive8.dat");
    DeleteDatabaseFile( "%sCableBoxArchive9.dat");
    DeleteDatabaseFile( "%sModelData.dat");
    DeleteDatabaseFile( "%sModelWeek.dat");
    mydbfree();
    mywlfree();

#ifdef CAPEQ_VERSION
    WatchDataDirty =
    WorkOrderDataDirty =
    DefectiveEquipmentDataDirty = 0;

    wotreeroot = (WONODE *)
    (ProbCodeRoot = (PROBCODE *)
    (FindCodeRoot = (FINDCODE *)
    (SolCodeRoot = (SOLCODE *)
    (DiscCodeRoot = (DISCCODE *)
    (detreeroot = (DENODE *)
    (mwtreeroot = (MWNODE *)
    (cttreeroot = (CTNODE *) NULL)))))));
#else
    cvtreeroot = (CVNODE *)
    (mwtreeroot = (MWNODE *)
    (cttreeroot = (CTNODE *) NULL));
#endif
    MWDatabaseMode = 0;
    *CurrentWeek = '\0';
}


/*
 * DELETEDATABASEFILE
 */
void DeleteDatabaseFile( char *Template)
{
    char FileName[200];

    sprintf( FileName, Template, DatabaseDir);
    DeleteFile( FileName);
}


/*
 * WRITEWLDATATODISK - Write the watch list database to disk.
 */
void WriteWLDataToDisk( void)
{
    FILE *ofh1;
    char line[201];
    char **wlpptr, *wlptr;
    WLNODE *nptr;

    // Write out each block of the watch list database.
    // First store an end-flag in the next free spot of the last block.

#if DEBUGWCOUNT
    bxtreeroot = treeroot;
    treeroot = (NODE *) wltreeroot;
    CountWLRecords();
    treeroot = bxtreeroot;
#endif
    if (!(wlptr = mywlspacelist)) return;
    wlpptr = (char **) mywlspaceptr;
    *wlpptr = (char *) 101;

    sprintf( line, "%s%s3.dat", DatabaseDir, OutDatabaseName);
    if (!(ofh1 = fopen( line, "wb"))) return;

    do {
        fwrite( wlptr, WLSSPACESIZE, 1, ofh1);
        wlpptr = (char **) wlptr;

        wlptr += sizeof( char *);
        while (1) {
            nptr = (WLNODE *) wlptr;
            if (nptr->balance >= 100) break;
            wlptr += sizeof( WLNODE);
        }
    } while (wlptr = *wlpptr);

    WatchDataDirty = 0;
    fclose( ofh1);
}


/*
 * READWLDATAFROMDISK - Read the watch list database from disk and save
 * the data in the binary tree. (This is called from local routines).
 * Note: Assumes that treeroot points to the WL tree.
 * Returns 1 on success, -1 on failure, 0 if there is no data.
 */
long ReadWLDataFromDisk( char DataValue)
{
    FILE *ifh1;
    char *mptr;
    char line[201];
    WLNODE *nptr;
    short ret;

    // database mode:
    // '0' database has not yet been read
    // '1' read and write CableBoxData
    // '2' read and write CableBoxArchive
    // '3' read CableBoxArchive, write CableBoxData

    // If the data has already been read in, there's nothing to do.
    // Ditto if the data file is known not to exist.

    if (!DataValue) DataValue = '1';
    if (WLDatabaseMode == DataValue) return 1;
    if (WatchDataDirty == -1) return 0;

    // If there currently is database data, then write it out if it's
    // now coming from a different place. Otherwise don't need to read
    // it again.

    if (WLDatabaseMode) WriteWLDataToDisk();

    if (DataValue == '1')
        InDatabaseName = OutDatabaseName = "CableBoxData";
    else if (DataValue == '2')
        InDatabaseName = OutDatabaseName = "CableBoxArchive";
    else {
        InDatabaseName = "CableBoxArchive";
        OutDatabaseName = "CableBoxData";
    }

    if (((WLDatabaseMode == '2') && (DataValue == '3')) ||
        ((WLDatabaseMode == '3') && (DataValue == '2'))) {
            WLDatabaseMode = DataValue;
            return 1;
    }
    WLDatabaseMode = DataValue;

    // Open the database file, read it in block by block, saving all
    // the nodes in each block in the binary tree.

    wlbtinit();
    sprintf( line, "%s%s3.dat", DatabaseDir, InDatabaseName);
    if (!(ifh1 = fopen( line, "rb"))) {
        WatchDataDirty = -1;
        ret = 0;
        goto Done;
    }

    // Read the first block into treeroot.

    ret = 1;
    fread( mywlspacelist, WLSSPACESIZE, 1, ifh1);
    treeroot->llink = treeroot->rlink = (NODE *) NULL;

    mptr = ((char *) treeroot) + sizeof( WLNODE);
    goto Proceed;

    while (1) {
        mywlspaceptr = (char *) nptr;
        mptr = mywlmalloc( WLSSPACESIZE);

        // read a block into mptr

        if ((!fread( mptr, sizeof( char *), 1, ifh1)) ||
            (!fread( mptr, WLSSPACESIZE - sizeof( char *), 1, ifh1))) {
                ret = -1;
                goto CloseUp;
        }

Proceed:
        while (1) {
            nptr = (WLNODE *) mptr;
            if (nptr->balance >= 100) break;
            btreestore( (NODE *) nptr);
            mptr += sizeof( WLNODE);
        }
        if (nptr->balance == 101) break;
    }

    // Set the last block's next pointer to NULL.

    *mywlspacecur = (char *) NULL;
    mywlspaceptr = (char *) nptr;
    mywlspacesize = WLSSPACESIZE - sizeof( char *) - sizeof( char *) -
        (((char *) nptr) - ((char *) mywlspacecur));

    // Close the database file and return success or failure.

CloseUp:
    fclose( ifh1);
Done:
#if DEBUGWCOUNT
    WatchListCount = -1;
    CountWLRecords();
#endif
    wltreeroot = (WLNODE *) treeroot;
    return ret;
}


#if DEBUGWCOUNT
/*
 * COUNTWLRECORDS - Count the watch list records.
 * Note that on entry treeroot points to wltreeroot (and on exit too).
 */
void CountWLRecords( void)
{
    long Count;

    // Count all the watch list records.

    Count = 0;
//  bxtreeroot = treeroot;
//  treeroot = (NODE *) wltreeroot;

    wlcurnode = (WLNODE *) btfirstnode();
    while (wlcurnode) {
        ++Count;
        wlcurnode = (WLNODE *) btnextnode();
    }
//  treeroot = bxtreeroot;

    // On entry, just save the count.
    // On exit, compare the count with the saved count. If it diminished,
    // log a message.

    if (Count < WatchListCount) {
        FILE *lfhdl;
        time_t curtime;
        struct tm *tmptr;

        if (!LogFileFile || !*LogFileFile) goto Done;
        if (!(lfhdl = fopen( LogFileFile, "a"))) goto Done;

        time( &curtime);
        tmptr = localtime( &curtime);

        fprintf( lfhdl, "%02d/%02d/%04d %02d:%02d:%02d: ",
            tmptr->tm_mon + 1, tmptr->tm_mday, tmptr->tm_year + 1900,
            tmptr->tm_hour, tmptr->tm_min, tmptr->tm_sec);

        fprintf( lfhdl, "***** Count of watch list records diminished from %d to %d\n",
            WatchListCount,
            Count);

        fclose( lfhdl);
    }
Done:
    WatchListCount = Count;
}
#endif


/*
 * WRITEMWDATATODISK - Write the weekly model counts database to disk.
 * Assumes treeroot points to the weekly model counts tree.
 */
void WriteMWDataToDisk( void)
{
    FILE *ofh1;
    char line[201];

    // Write out each record of the weekly model counts database, all as text.

    if (!(mwcurnode = (MWNODE *) btfirstnode())) return;

    sprintf( line, "%s%s9.dat", DatabaseDir, OutDatabaseName);
    if (!(ofh1 = fopen( line, "w"))) return;

    while (mwcurnode) {
#if DEBUGWKCHK
        CheckWeek( mwcurnode->Week_SiteID_Model);
#endif
        fprintf( ofh1, "%s\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t"
            "%d\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t"
            "%d\t%d\t%d\t%d\t%d\t%d\t\n",
            mwcurnode->Week_SiteID_Model,
            mwcurnode->GL_Count,
            mwcurnode->GL_SIHCount,
            mwcurnode->WL_AddCount,
            mwcurnode->WL_RemCount,
            mwcurnode->WL_Count,
            mwcurnode->GL_InHouse,
            mwcurnode->WL_InHouse,
            mwcurnode->GL_InRepair,
            mwcurnode->WL_InRepairI,
            mwcurnode->GL_InOther,
            mwcurnode->WL_InOther,
            mwcurnode->GL_Installed,
            mwcurnode->WL_Installed,
            mwcurnode->GL_Repair,
            mwcurnode->WL_Repair,
            mwcurnode->GL_Other,
            mwcurnode->WL_Other,
            mwcurnode->WL_OtherCount,
            mwcurnode->WL_ScrapCount,
            mwcurnode->WL_HouseCount,
            mwcurnode->WL_RepairCount,
            mwcurnode->GL_DaysHouse,
            mwcurnode->WL_DaysHouse,
            mwcurnode->GL_DaysTotal,
            mwcurnode->WL_DaysTotal,
            mwcurnode->GL_OutOfService,
            mwcurnode->WL_OutOfServiceI,
            mwcurnode->WL_InHouseI);

        mwcurnode = (MWNODE *) btnextnode();
    }
    fclose( ofh1);
}


/*
 * READMWDATAFROMDISK - Read the weekly model counts data from disk.
 * Assumes treeroot points to the weekly model counts tree.
 */
long ReadMWDataFromDisk( char DataValue)
{
    FILE *ifh1;
    char line[501], *sptr, *kptr;
    short ret;

    // database mode:
    // '0' database has not yet been read
    // '1' read and write CableBoxData
    // '2' read and write CableBoxArchive
    // '3' read CableBoxArchive, write CableBoxData

    // If the data has already been read in, there's nothing to do.
    // Ditto if the data file is known not to exist.

    if (!DataValue) DataValue = '1';
    if (MWDatabaseMode == DataValue) return 1;

    // If there currently is database data, then write it out if it's
    // now coming from a different place. Otherwise don't need to read
    // it again.

    if (MWDatabaseMode) WriteMWDataToDisk();

    if (DataValue == '1')
        InDatabaseName = OutDatabaseName = "CableBoxData";
    else if (DataValue == '2')
        InDatabaseName = OutDatabaseName = "CableBoxArchive";
    else {
        InDatabaseName = "CableBoxArchive";
        OutDatabaseName = "CableBoxData";
    }

    if (((MWDatabaseMode == '2') && (DataValue == '3')) ||
        ((MWDatabaseMode == '3') && (DataValue == '2'))) {
            MWDatabaseMode = DataValue;
            return 1;
    }
    MWDatabaseMode = DataValue;

    // Open the database file, read it in block by block, saving all
    // the nodes in each block in the binary tree.

    pmbtinit();
    sprintf( line, "%s%s9.dat", DatabaseDir, InDatabaseName);
    if (!(ifh1 = fopen( line, "r"))) {
        ret = 0;
        goto Done;
    }

    // Read and store each record.

    ret = 1;
    while (fgets( line, 500, ifh1)) {
        sptr = line;
        kptr = NextString( &sptr);
        mwcurnode = (MWNODE *) mypermmalloc( sizeof( MWNODE));
        mwcurnode->Week_SiteID_Model = mypermmalloc( 1 + strlen( kptr));
        strcpy( mwcurnode->Week_SiteID_Model, kptr);
#if DEBUGWKCHK
        CheckWeek( mwcurnode->Week_SiteID_Model);
#endif
        mwcurnode->GL_Count = atol( NextString( &sptr));
        mwcurnode->GL_SIHCount = atol( NextString( &sptr));
        mwcurnode->WL_AddCount = atol( NextString( &sptr));
        mwcurnode->WL_RemCount = atol( NextString( &sptr));
        mwcurnode->WL_Count = atol( NextString( &sptr));
        mwcurnode->GL_InHouse = atol( NextString( &sptr));
        mwcurnode->WL_InHouse = atol( NextString( &sptr));
        mwcurnode->GL_InRepair = atol( NextString( &sptr));
        mwcurnode->WL_InRepairI = atol( NextString( &sptr));
        mwcurnode->GL_InOther = atol( NextString( &sptr));
        mwcurnode->WL_InOther = atol( NextString( &sptr));
        mwcurnode->GL_Installed = atol( NextString( &sptr));
        mwcurnode->WL_Installed = atol( NextString( &sptr));
        mwcurnode->GL_Repair = atol( NextString( &sptr));
        mwcurnode->WL_Repair = atol( NextString( &sptr));
        mwcurnode->GL_Other = atol( NextString( &sptr));
        mwcurnode->WL_Other = atol( NextString( &sptr));
        mwcurnode->WL_OtherCount = atol( NextString( &sptr));
        mwcurnode->WL_ScrapCount = atol( NextString( &sptr));
        mwcurnode->WL_HouseCount = atol( NextString( &sptr));
        mwcurnode->WL_RepairCount = atol( NextString( &sptr));
        mwcurnode->GL_DaysHouse = atol( NextString( &sptr));
        mwcurnode->WL_DaysHouse = atol( NextString( &sptr));
        mwcurnode->GL_DaysTotal = atol( NextString( &sptr));
        mwcurnode->WL_DaysTotal = atol( NextString( &sptr));
        mwcurnode->GL_OutOfService = atol( NextString( &sptr));
        mwcurnode->WL_OutOfServiceI = atol( NextString( &sptr));
        mwcurnode->WL_InHouseI = atol( NextString( &sptr));

        btreestorep( (CTNODE *) mwcurnode);
    }

    fclose( ifh1);
Done:
    mwtreeroot = (MWNODE *) treeroot;
    return ret;
}


/*
 * APPENDMODELCOUNTDATA - Append the current set of model counts to
 * the database file, for the given week.
 */
void AppendModelCountData( char *Week)
{
    FILE *ofh1;
    char line[100];

    sprintf( line, "%s%s9.dat", DatabaseDir, OutDatabaseName);
    if (!(ofh1 = fopen( line, "a"))) return;

    bxtreeroot = treeroot;
    treeroot = (NODE *) cttreeroot;
    ctcurnode = (CTNODE *) btfirstnode();
    while (ctcurnode) {
        fprintf( ofh1,
            "%s,%s\t%d\t0\t0\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t"
            "%d\t%d\t%d\t0\t0\t0\t0\t%d\t%d\t%d\t%d\t%d\t%d\t%d\t\n",
            Week,
            ctcurnode->SiteID_Model,
            ctcurnode->GL_Count,
            ctcurnode->WL_RemCount,
            ctcurnode->WL_Count,
            ctcurnode->GL_InHouse,
            ctcurnode->WL_InHouse,
            ctcurnode->GL_InRepair,
            ctcurnode->WL_InRepairI,
            ctcurnode->GL_InOther,
            ctcurnode->WL_InOther,
            ctcurnode->GL_Installed,
            ctcurnode->WL_Installed,
            ctcurnode->GL_Repair,
            ctcurnode->WL_Repair,
            ctcurnode->GL_Other,
            ctcurnode->WL_Other,
            ctcurnode->GL_DaysHouse,
            ctcurnode->WL_DaysHouse,
            ctcurnode->GL_DaysTotal,
            ctcurnode->WL_DaysTotal,
            ctcurnode->GL_OutOfService,
            ctcurnode->WL_OutOfServiceI,
            ctcurnode->WL_InHouseI);

        ctcurnode = (CTNODE *) btnextnode();
    }
    fclose( ofh1);
    cttreeroot = (CTNODE *) treeroot;
    treeroot = bxtreeroot;
    MWDatabaseMode = 0;

    printf( "    Done appending model counts for  %s\n", Week);
    AppendErrorMessage( "Done appending model counts for  %s\n", Week, 0);
}


/*
 * BUILDINITIALMODELCOUNTDATA - Walk through the cable box data and
 * build the starting model counts data.
 */
void BuildInitialModelCountData( void)
{
    char Key[100];
    short Watching, TotalDays, DaysInState;

    printf( "    Begin appending model counts for %s\n", CurrentWeek);
    AppendErrorMessage( "Begin appending model counts for %s\n", CurrentWeek, 0);

    // Get the date of the last day of the "current" week.

    *(CurrentWeek + 5) = '\0';
    Watching = atoi( CurrentWeek + 1);
    TotalDays = 7 * atoi( CurrentWeek + 6);
    if (TotalDays > 364) TotalDays = 365;
    sprintf( Key, "1/%d/%d", TotalDays, Watching);
    DateOfNow = ConvertMDYToTimet( Key);
    *(CurrentWeek + 5) = '-';

    ReadDatabaseFromDisk( DatabaseMode);
    bxtreeroot = treeroot;
    treeroot = (NODE *) wltreeroot;
    ReadWLDataFromDisk( DatabaseMode);

    pmbtinit();
    cttreeroot = (CTNODE *) treeroot;
    treeroot = bxtreeroot;

    if (!(curnode = btfirstnode())) return;
    while (curnode) {
        BuildSiteAndModel( Key, 1);

        // See if this box is currently being watched.

        treeroot = (NODE *) wltreeroot;
        Watching = WF_DELETED;
        if (wlcurnode = (WLNODE *) btreefind( curnode->CableBoxSerial))
            Watching = wlcurnode->WatchFlag;

        // If the record exists, bump its count. Otherwise create it.

        treeroot = (NODE *) cttreeroot;
        if (ctcurnode = (CTNODE *) btreefindp( Key)) ++ctcurnode->GL_Count;
        else {
            ctcurnode = (CTNODE *) mypermmalloc( sizeof( CTNODE));
            ctcurnode->SiteID_Model = mypermmalloc( 1 + strlen( Key));
            strcpy( ctcurnode->SiteID_Model, Key);
            ctcurnode->GL_Count = 1;
            ctcurnode->WL_Count =
            ctcurnode->WL_RemCount =
            ctcurnode->GL_InHouse =
            ctcurnode->WL_InHouse =
            ctcurnode->GL_InRepair =
            ctcurnode->WL_InRepairI =
            ctcurnode->GL_InOther =
            ctcurnode->WL_InOther =
            ctcurnode->GL_Installed =
            ctcurnode->WL_Installed =
            ctcurnode->GL_Repair =
            ctcurnode->WL_Repair =
            ctcurnode->GL_Other =
            ctcurnode->WL_Other =
            ctcurnode->GL_DaysHouse =
            ctcurnode->WL_DaysHouse =
            ctcurnode->GL_DaysTotal =
            ctcurnode->WL_DaysTotal =
            ctcurnode->GL_OutOfService =
            ctcurnode->WL_OutOfServiceI =
            ctcurnode->WL_InHouseI = 0;

            btreestorep( ctcurnode);
        }

        // Bump counts depending on the current state.

        DaysInState = 0;
        if (curnode->CurrentState == 'H') {
            ++ctcurnode->GL_InHouse;
            if (Watching >= WF_ACTIVE) ++ctcurnode->WL_InHouse;
            else if (Watching == WF_INACTIVE) ++ctcurnode->WL_InHouseI;
            DaysInState = (short) ((DateOfNow - curnode->DateOfState) / SECSINADAY);
        }
        else if (curnode->CurrentState == 'P') {
            ++ctcurnode->GL_InRepair;
            if (Watching == WF_INACTIVE) ++ctcurnode->WL_InRepairI;
        }
        else if (curnode->CurrentState == 'S') {
            ++ctcurnode->GL_OutOfService;
            if (Watching == WF_INACTIVE) ++ctcurnode->WL_OutOfServiceI;
        }
        else if (curnode->CurrentState != 'U') {
            ++ctcurnode->GL_InOther;
            if (Watching >= WF_ACTIVE) ++ctcurnode->WL_InOther;
        }

        ctcurnode->GL_Installed += curnode->PToHouse;
        ctcurnode->GL_Repair += curnode->PToRepair;
        ctcurnode->GL_Other +=
            curnode->PToReturn + curnode->PToTech + curnode->PToOther;

        // Sum up the days in House and the total days.

        ctcurnode->GL_DaysHouse += curnode->PDaysHouse + DaysInState;
        ctcurnode->GL_DaysTotal += (TotalDays = curnode->PDaysHouse +
            curnode->PDaysReturn + curnode->PDaysRepair +
            curnode->PDaysOther + curnode->PDaysTech + DaysInState);

        if (Watching >= WF_ACTIVE) {
            ++ctcurnode->WL_Count;
            ctcurnode->WL_Installed += curnode->PToHouse;
            ctcurnode->WL_Repair += curnode->PToRepair;
            ctcurnode->WL_Other +=
                curnode->PToReturn + curnode->PToTech + curnode->PToOther;
        }
        else if (Watching == WF_INACTIVE) {
            ++ctcurnode->WL_RemCount;
            if ((wlcurnode->RollbackReason != RBR_SERVICE) &&
                (wlcurnode->RollbackReason != RBR_FILES))
            {
                ctcurnode->WL_DaysTotal += TotalDays;
                if (curnode->CurrentState == 'H')
                    ctcurnode->WL_DaysHouse += curnode->PDaysHouse + DaysInState;
            }
        }

//@@@
#if DEBUGWATCH
        if ((Watching >= WF_ACTIVE) &&
            (ctcurnode->WL_Count ==
             1 + ctcurnode->WL_InHouse + ctcurnode->WL_InOther))
        {
            FILE *lfhdl;
            time_t curtime;
            struct tm *tmptr;

            if (!LogFileFile || !*LogFileFile) goto Done;
            if (!(lfhdl = fopen( LogFileFile, "a"))) goto Done;

            time( &curtime);
            tmptr = localtime( &curtime);

            fprintf( lfhdl, "%02d/%02d/%04d %02d:%02d:%02d: ",
                tmptr->tm_mon + 1, tmptr->tm_mday, tmptr->tm_year + 1900,
                tmptr->tm_hour, tmptr->tm_min, tmptr->tm_sec);

            fprintf( lfhdl, "WATCH COUNT HIGH %s (%c) %d = %d + %d\n",
                curnode->CableBoxSerial,
                curnode->CurrentState,
                ctcurnode->WL_Count,
                ctcurnode->WL_InHouse,
                ctcurnode->WL_InOther);

            fclose( lfhdl);
        }
Done:
#endif

        cttreeroot = (CTNODE *) treeroot;
        treeroot = bxtreeroot;

        curnode = btnextnode();
    }
}


/*
 * BUILDSITEANDMODEL - This ridiculous-looking code finds the SiteID,
 * which is the 7th field of Strings, and the model number, which is
 * the first part of the third field. The resulting string consists of
 * the Site ID, in quotes, comma, and the Model, in quotes.
 *
 * Call with IncludeModel = 1 to get Site,Model; = 0 for just Site.
 */
char *BuildSiteAndModel( char *Key, short IncludeModel)
{
    char *sptr, *mptr, *dptr;

    dptr = Key;
    sptr = curnode->Strings - 1;
    while (*++sptr && (*sptr != '\t'));
    while (*++sptr && (*sptr != '\t'));
    mptr = sptr;                            // hold the 3rd field
    while (*++sptr && (*sptr != '\t'));     // find the 7th field
    while (*++sptr && (*sptr != '\t'));
    while (*++sptr && (*sptr != '\t'));
    while (*++sptr && (*sptr != '\t'));

    *dptr++ = '"';                          // copy the SiteID
    while (*++sptr && (*sptr != '\t')) *dptr++ = *sptr;
    *dptr++ = '"';

    if (IncludeModel) {
        *dptr++ = ',';
        *dptr++ = '"';                      // copy the model number
//@@    while (*++mptr && (*mptr != '|')) *dptr++ = *mptr;
//      *dptr++ = '|';
//      while (*++mptr && (*mptr != '|'));
        while (*++mptr && (*mptr != '\t')) *dptr++ = *mptr;
        *dptr++ = '"';
    }
    *dptr++ = '\0';
    return Key;
}


/*
 * WRITECVDATATODISK - Write the Cablevision database to disk.
 * Note: Assumes that treeroot points to the CV tree.
 */
void WriteCVDataToDisk( void)
{
    FILE *ofh1;
    char line[201];

    // Write out each record of the Cablevision database.
    // Open the database file.

    sprintf( line, "%s%s8.dat", DatabaseDir, OutDatabaseName);
    if (!(ofh1 = fopen( line, "w"))) return;

    // Walk through the Cablevision tree and write out all the records.
    // Note that the result is a text file.

    cvcurnode = (CVNODE *) btfirstnode();
    while (cvcurnode) {
        fprintf( ofh1, "%s\t", cvcurnode->CableBoxSerial);
        fprintf( ofh1, "%d\t", cvcurnode->StringSize);
        fprintf( ofh1, "%d\t", cvcurnode->TCWFindate);
        fprintf( ofh1, "%d\t", cvcurnode->CDFlagCCount);
        fprintf( ofh1, "%d\t", cvcurnode->CDFlagICount);
        fprintf( ofh1, "%d\t", cvcurnode->TCWFindateDays);
        fprintf( ofh1, "%d\t", cvcurnode->RprWarrantyNWCt);
        fprintf( ofh1, "%d\t", cvcurnode->RprWarrantyNWAmt);
        fprintf( ofh1, "%d\t", cvcurnode->RprWarrantyWXCt);
        fprintf( ofh1, "%d\t", cvcurnode->RprWarrantyWXAmt);
        fprintf( ofh1, "%d\t", cvcurnode->RprWarrantyFWCt);
        fprintf( ofh1, "%d\t", cvcurnode->RprWarrantyFWAmt);
        fprintf( ofh1, "%d\t", cvcurnode->RprWarrantyURCt);
        fprintf( ofh1, "%d\t", cvcurnode->RprWarrantyURAmt);
        fprintf( ofh1, "%d\t", cvcurnode->RprWarrantyFSCt);
        fprintf( ofh1, "%d\t", cvcurnode->RprWarrantyFSAmt);
        fprintf( ofh1, "%d\t", cvcurnode->RprWarrantyOTCt);
        fprintf( ofh1, "%d\t", cvcurnode->RprWarrantyOTAmt);
        fprintf( ofh1, "%d\t", cvcurnode->RprChargeCount);
        fprintf( ofh1, "%d\t", cvcurnode->RprTotalCharge);
        fprintf( ofh1, "%d\t", cvcurnode->TCSwapFlagCount);
        fprintf( ofh1, "%d\t", cvcurnode->LocMDSLNKCount);
        fprintf( ofh1, "%d\t", cvcurnode->LocMDSLNKDate);
        fprintf( ofh1, "%s\t", cvcurnode->SiteID_C);
        fprintf( ofh1, "%s\t", cvcurnode->SiteID_B);
        fprintf( ofh1, "%s\t", cvcurnode->SiteID_A);
        fprintf( ofh1, "%s\t", cvcurnode->CurBoxAddMethod);
        fprintf( ofh1, "%s\t", cvcurnode->PrevBoxAddMethod);
        fprintf( ofh1, "%s\t", cvcurnode->CurBoxReturnMethod);
        fprintf( ofh1, "%s\t", cvcurnode->PrevBoxReturnMethod);
        fprintf( ofh1, "%s\t", cvcurnode->Locator);
        fprintf( ofh1, "%s\t", cvcurnode->PrevSubInventoryCode);
        fprintf( ofh1, "%s\t", cvcurnode->PrevOrganizationCode);
        fprintf( ofh1, "%s\t", cvcurnode->PrevOrgAcronym);
        fprintf( ofh1, "%s\t", cvcurnode->TCTech);
        fprintf( ofh1, "%s\t", cvcurnode->TCInhouseContFlag);


        fprintf( ofh1, "%s\t", cvcurnode->TCFixCodeStr);
        fprintf( ofh1, "%s\t", cvcurnode->RprScrappedFlag);
        fprintf( ofh1, "%s\t", cvcurnode->RprPartNbrStr);
        fprintf( ofh1, "%s\t", cvcurnode->RprPartDescr);
        fprintf( ofh1, "%s\t", cvcurnode->OrganizationCode);
        fprintf( ofh1, "%s\t\n", cvcurnode->OrgAcronym);

        cvcurnode = (CVNODE *) btnextnode();
    }

    fclose( ofh1);
}


/*
 * READCVDATAFROMDISK - Read the Cablevision database from disk and
 * save the data in the binary tree. (This is called from local routines).
 * Note: Assumes that treeroot points to the CV tree.
 * Returns 1 on success, -1 on failure, 0 if there is no data.
 */
long ReadCVDataFromDisk( char DataValue)
{
    FILE *ifh1;
    char line[801], *sptr, *dptr;
    short ret;

    // database mode:
    // '0' database has not yet been read
    // '1' read and write CableBoxData
    // '2' read and write CableBoxArchive
    // '3' read CableBoxArchive, write CableBoxData

    // If the data has already been read in, there's nothing to do.
    // Ditto if the data file is known not to exist.

    if (!DataValue) DataValue = '1';
    if (CVDatabaseMode == DataValue) return 1;

    // If there currently is database data, then write it out if it's
    // now coming from a different place. Otherwise don't need to read
    // it again.

    if (CVDatabaseMode) WriteCVDataToDisk();

    if (DataValue == '1')
        InDatabaseName = OutDatabaseName = "CableBoxData";
    else if (DataValue == '2')
        InDatabaseName = OutDatabaseName = "CableBoxArchive";
    else {
        InDatabaseName = "CableBoxArchive";
        OutDatabaseName = "CableBoxData";
    }

    if (((CVDatabaseMode == '2') && (DataValue == '3')) ||
        ((CVDatabaseMode == '3') && (DataValue == '2'))) {
            CVDatabaseMode = DataValue;
            return 1;
    }
    CVDatabaseMode = DataValue;

    // Open the database file, read it in record by record,
    // and save each node in the binary tree.

    pmbtinit();
    sprintf( line, "%s%s8.dat", DatabaseDir, InDatabaseName);
    if (!(ifh1 = fopen( line, "r"))) {
        ret = 0;
        goto Done;
    }

    // Read and store each record.

    ret = 1;
    while (fgets( line, 800, ifh1)) {
        cvcurnode = (CVNODE *) mypermmalloc( sizeof( CVNODE));

        dptr = line;
        strcpy( cvcurnode->CableBoxSerial, NextString( &dptr));
        cvcurnode->StringSize =       atoi( NextString( &dptr));
        cvcurnode->TCWFindate =       atol( NextString( &dptr));
        cvcurnode->CDFlagCCount =     atoi( NextString( &dptr));
        cvcurnode->CDFlagICount =     atoi( NextString( &dptr));
        cvcurnode->TCWFindateDays =   atoi( NextString( &dptr));
        cvcurnode->RprWarrantyNWCt =  atoi( NextString( &dptr));
        cvcurnode->RprWarrantyNWAmt = atol( NextString( &dptr));
        cvcurnode->RprWarrantyWXCt =  atoi( NextString( &dptr));
        cvcurnode->RprWarrantyWXAmt = atol( NextString( &dptr));
        cvcurnode->RprWarrantyFWCt =  atoi( NextString( &dptr));
        cvcurnode->RprWarrantyFWAmt = atol( NextString( &dptr));
        cvcurnode->RprWarrantyURCt =  atoi( NextString( &dptr));
        cvcurnode->RprWarrantyURAmt = atol( NextString( &dptr));
        cvcurnode->RprWarrantyFSCt =  atoi( NextString( &dptr));
        cvcurnode->RprWarrantyFSAmt = atol( NextString( &dptr));
        cvcurnode->RprWarrantyOTCt =  atoi( NextString( &dptr));
        cvcurnode->RprWarrantyOTAmt = atol( NextString( &dptr));
        cvcurnode->RprChargeCount =   atoi( NextString( &dptr));
        cvcurnode->RprTotalCharge =   atol( NextString( &dptr));
        cvcurnode->TCSwapFlagCount =  atoi( NextString( &dptr));
        cvcurnode->LocMDSLNKCount =   atoi( NextString( &dptr));
        cvcurnode->LocMDSLNKDate =    atol( NextString( &dptr));

        sptr = mypermmalloc( 1 + cvcurnode->StringSize);
        strcpy( sptr, dptr);

        cvcurnode->SiteID_C =             NextString( &sptr);
        cvcurnode->SiteID_B =             NextString( &sptr);
        cvcurnode->SiteID_A =             NextString( &sptr);
        cvcurnode->CurBoxAddMethod =      NextString( &sptr);
        cvcurnode->PrevBoxAddMethod =     NextString( &sptr);
        cvcurnode->CurBoxReturnMethod =   NextString( &sptr);
        cvcurnode->PrevBoxReturnMethod =  NextString( &sptr);
        cvcurnode->Locator =              NextString( &sptr);
        cvcurnode->PrevSubInventoryCode = NextString( &sptr);
        cvcurnode->PrevOrganizationCode = NextString( &sptr);
        cvcurnode->PrevOrgAcronym =       NextString( &sptr);
        cvcurnode->TCTech =               NextString( &sptr);
        cvcurnode->TCInhouseContFlag =    NextString( &sptr);
        cvcurnode->TCFixCodeStr =         NextString( &sptr);
        cvcurnode->RprScrappedFlag =      NextString( &sptr);
        cvcurnode->RprPartNbrStr =        NextString( &sptr);
        cvcurnode->RprPartDescr =         NextString( &sptr);
        cvcurnode->OrganizationCode =     NextString( &sptr);
        cvcurnode->OrgAcronym =           NextString( &sptr);

        btreestore( (NODE *) cvcurnode);
    }
    fclose( ifh1);

Done:
    cvtreeroot = (CVNODE *) treeroot;
    return ret;
}


#ifdef CAPEQ_VERSION
/*
 * WRITEWODATATODISK - Write the work order database to disk.
 * Note: Assumes that treeroot points to the WO tree.
 */
void WriteWODataToDisk( void)
{
    FILE *ofh1;
    char line[201];

    // Write out each record of the defective equipment database.
    // Open the database file.

    sprintf( line, "%s%s6.dat", DatabaseDir, OutDatabaseName);
    if (!(ofh1 = fopen( line, "w"))) return;

    // Walk through the Work Order tree and write out all the records.
    // Note that the result is a text file.

    wocurnode = (WONODE *) btfirstnode();
    while (wocurnode) {
        fprintf( ofh1, "%s\t", wocurnode->CableBoxSerial);
        fprintf( ofh1, "%d\t", wocurnode->WOCompletionDatePrev);
        fprintf( ofh1, "%d\t", wocurnode->WOCompletionDateCur);
        fprintf( ofh1, "%d\t", wocurnode->DateEntered);
        fprintf( ofh1, "%d\t", wocurnode->PrevDateEntered);
        fprintf( ofh1, "%d\t", wocurnode->FirstDateEntered);
        fprintf( ofh1, "%d\t", wocurnode->CheckinDatePrev);
        fprintf( ofh1, "%d\t", wocurnode->CheckinDateCur);
        fprintf( ofh1, "%d\t", wocurnode->TimesDiscovered);

        fprintf( ofh1, "%s\t", wocurnode->ProblemCodePrev);
        fprintf( ofh1, "%s\t", wocurnode->ProblemCodeCur);
        fprintf( ofh1, "%s\t", wocurnode->FindingCodePrev);
        fprintf( ofh1, "%s\t", wocurnode->FindingCodeCur);
        fprintf( ofh1, "%s\t", wocurnode->SolutionCodePrev);
        fprintf( ofh1, "%s\t", wocurnode->SolutionCodeCur);
        fprintf( ofh1, "%s\t", wocurnode->WOtype);
        fprintf( ofh1, "%s\t", wocurnode->WOclass);
        fprintf( ofh1, "%s\t", wocurnode->WOstatus);
        fprintf( ofh1, "%s\t", wocurnode->QCode);
        fprintf( ofh1, "%s\t", wocurnode->DisconnectCode);

        fprintf( ofh1, "%s\t", wocurnode->SiteID_C);
        fprintf( ofh1, "%s\t", wocurnode->SiteID_B);
        fprintf( ofh1, "%s\t", wocurnode->SiteID_A);
        fprintf( ofh1, "%s\t", wocurnode->AccountNo);
        fprintf( ofh1, "%s\t", wocurnode->AssignedInstallerPrev);
        fprintf( ofh1, "%s\t", wocurnode->AssignedInstallerCur);
        fprintf( ofh1, "%s\t", wocurnode->WorkOrderNoPrev);
        fprintf( ofh1, "%s\t", wocurnode->WorkOrderNoCur);
        fprintf( ofh1, "%s\t", wocurnode->BillTypeCode);
        fprintf( ofh1, "%s\t\n", wocurnode->ItemNumber);

        wocurnode = (WONODE *) btnextnode();
    }

    fclose( ofh1);

    // Now write out all the code/description pairs.

    sprintf( line, "%s%s7.dat", DatabaseDir, OutDatabaseName);
    if (!(ofh1 = fopen( line, "w"))) return;

    for (ProbCodeCur = ProbCodeRoot; ProbCodeCur; ProbCodeCur = ProbCodeCur->next)
        fprintf( ofh1, "P%s\t%s\n", ProbCodeCur->ProblemCode, ProbCodeCur->ProblemDesc);

    for (FindCodeCur = FindCodeRoot; FindCodeCur; FindCodeCur = FindCodeCur->next)
        fprintf( ofh1, "F%s\t%s\n", FindCodeCur->FindingCode, FindCodeCur->FindingDesc);

    for (SolCodeCur = SolCodeRoot; SolCodeCur; SolCodeCur = SolCodeCur->next)
        fprintf( ofh1, "S%s\t%s\n", SolCodeCur->SolutionCode, SolCodeCur->SolutionDesc);

    for (DiscCodeCur = DiscCodeRoot; DiscCodeCur; DiscCodeCur = DiscCodeCur->next)
        fprintf( ofh1, "D%s\t%s\n", DiscCodeCur->DisconnectCode, DiscCodeCur->DisconnectDesc);

    fclose( ofh1);
    WorkOrderDataDirty = 0;
}


/*
 * READWODATAFROMDISK - Read the Work Order database from disk and save
 * the data in the binary tree. (This is called from local routines).
 * Note: Assumes that treeroot points to the WO tree.
 * Returns 1 on success, -1 on failure, 0 if there is no data.
 */
long ReadWODataFromDisk( char DataValue)
{
    FILE *ifh1;
    char line[801], *sptr, *dptr;
    short ret;

    // database mode:
    // '0' database has not yet been read
    // '1' read and write CableBoxData
    // '2' read and write CableBoxArchive
    // '3' read CableBoxArchive, write CableBoxData

    // If the data has already been read in, there's nothing to do.
    // Ditto if the data file is known not to exist.

    if (!DataValue) DataValue = '1';
    if (WODatabaseMode == DataValue) return 1;
    if (WorkOrderDataDirty == -1) return 0;

    // If there currently is database data, then write it out if it's
    // now coming from a different place. Otherwise don't need to read
    // it again.

    if (WODatabaseMode) WriteWODataToDisk();

    if (DataValue == '1')
        InDatabaseName = OutDatabaseName = "CableBoxData";
    else if (DataValue == '2')
        InDatabaseName = OutDatabaseName = "CableBoxArchive";
    else {
        InDatabaseName = "CableBoxArchive";
        OutDatabaseName = "CableBoxData";
    }

    if (((WODatabaseMode == '2') && (DataValue == '3')) ||
        ((WODatabaseMode == '3') && (DataValue == '2'))) {
            WODatabaseMode = DataValue;
            return 1;
    }
    WODatabaseMode = DataValue;

    // Open the database file, read it in record by record,
    // and save each node in the binary tree.

    pmbtinit();
    sprintf( line, "%s%s6.dat", DatabaseDir, InDatabaseName);
    if (!(ifh1 = fopen( line, "r"))) {
Fail:   WorkOrderDataDirty = -1;
        ret = 0;
        goto Done;
    }

    // Read and store each record.

    ret = 1;
    while (fgets( line, 800, ifh1)) {
        wocurnode = (WONODE *) mypermmalloc( sizeof( WONODE));

        dptr = line;
        strcpy( wocurnode->CableBoxSerial, NextString( &dptr));

        wocurnode->WOCompletionDatePrev =  atol( NextString( &dptr));
        wocurnode->WOCompletionDateCur =   atol( NextString( &dptr));
        wocurnode->DateEntered =           atol( NextString( &dptr));
        wocurnode->PrevDateEntered =       atol( NextString( &dptr));
        wocurnode->FirstDateEntered =      atol( NextString( &dptr));
        wocurnode->CheckinDatePrev =       atol( NextString( &dptr));
        wocurnode->CheckinDateCur =        atol( NextString( &dptr));
        wocurnode->TimesDiscovered =       atoi( NextString( &dptr));

        strcpy( wocurnode->ProblemCodePrev,  NextString( &dptr));
        strcpy( wocurnode->ProblemCodeCur,   NextString( &dptr));
        strcpy( wocurnode->FindingCodePrev,  NextString( &dptr));
        strcpy( wocurnode->FindingCodeCur,   NextString( &dptr));
        strcpy( wocurnode->SolutionCodePrev, NextString( &dptr));
        strcpy( wocurnode->SolutionCodeCur,  NextString( &dptr));
        strcpy( wocurnode->WOtype,           NextString( &dptr));
        strcpy( wocurnode->WOclass,          NextString( &dptr));
        strcpy( wocurnode->WOstatus,         NextString( &dptr));
        strcpy( wocurnode->QCode,            NextString( &dptr));
        strcpy( wocurnode->DisconnectCode,   NextString( &dptr));

        sptr = mypermmalloc( 1 + strlen( dptr));
        strcpy( sptr, dptr);

        wocurnode->SiteID_C =              NextString( &sptr);
        wocurnode->SiteID_B =              NextString( &sptr);
        wocurnode->SiteID_A =              NextString( &sptr);
        wocurnode->AccountNo =             NextString( &sptr);
        wocurnode->AssignedInstallerPrev = NextString( &sptr);
        wocurnode->AssignedInstallerCur =  NextString( &sptr);
        wocurnode->WorkOrderNoPrev =       NextString( &sptr);
        wocurnode->WorkOrderNoCur =        NextString( &sptr);
        wocurnode->BillTypeCode =          NextString( &sptr);
        wocurnode->ItemNumber =            NextString( &sptr);

        btreestore( (NODE *) wocurnode);
    }
    fclose( ifh1);

    // Now read all the code/description pairs.

    sprintf( line, "%s%s7.dat", DatabaseDir, InDatabaseName);
    if (!(ifh1 = fopen( line, "r"))) goto Fail;

    ProbCodeRoot = (PROBCODE *) (FindCodeRoot = (FINDCODE *) SolCodeRoot = NULL);
    while (fgets( line, 200, ifh1)) {
        sptr = line;
        while (*sptr != '\t') ++sptr;
        *sptr++ = '\0';
        dptr = sptr;
        while (*dptr >= ' ') ++dptr;
        *dptr = '\0';

        ProbCodeCur = (PROBCODE *)
            mypermmalloc( sizeof( PROBCODE) + strlen( sptr));
        strcpy( ProbCodeCur->ProblemCode, line + 1);
        strcpy( ProbCodeCur->ProblemDesc, sptr);

        if (*line == 'P') {
            ProbCodeCur->next = ProbCodeRoot;
            ProbCodeRoot = ProbCodeCur;
        }
        else if (*line == 'F') {
            FindCodeCur = (FINDCODE *) ProbCodeCur;
            FindCodeCur->next = FindCodeRoot;
            FindCodeRoot = FindCodeCur;
        }
        else if (*line == 'S') {
            SolCodeCur = (SOLCODE *) ProbCodeCur;
            SolCodeCur->next = SolCodeRoot;
            SolCodeRoot = SolCodeCur;
        }
        else if (*line == 'D') {
            DiscCodeCur = (DISCCODE *) ProbCodeCur;
            DiscCodeCur->next = DiscCodeRoot;
            DiscCodeRoot = DiscCodeCur;
        }
    }
    fclose( ifh1);

Done:
    wotreeroot = (WONODE *) treeroot;
    return ret;
}


/*
 * WRITEDEDATATODISK - Write the defective equipment database to disk.
 * Note: Assumes that treeroot points to the DE tree.
 */
void WriteDEDataToDisk( void)
{
    FILE *ofh1;
    char line[201];

    // Write out each record of the defective equipment database.
    // Open the database file.

    sprintf( line, "%s%s5.dat", DatabaseDir, OutDatabaseName);
    if (!(ofh1 = fopen( line, "w"))) return;

    // Walk through the Defective Equipment tree and write out all the records.
    // Note that the result is a text file.

    decurnode = (DENODE *) btfirstnode();
    while (decurnode) {
        fprintf( ofh1, "%s\t", decurnode->CableBoxSerial);
        fprintf( ofh1, "%d\t", decurnode->CreatedDate);
        fprintf( ofh1, "%d\t", decurnode->PrevCreateDate);
        fprintf( ofh1, "%d\t", decurnode->FirstCreateDate);
        fprintf( ofh1, "%d\t", decurnode->ResolvedDate);
        fprintf( ofh1, "%d\t", decurnode->TimesDiscovered);
        fprintf( ofh1, "%s\t", decurnode->SiteID);
        fprintf( ofh1, "%s\t", decurnode->Submitter);
        fprintf( ofh1, "%s\t", decurnode->SalesNo);
        fprintf( ofh1, "%s\t", decurnode->Model);
        fprintf( ofh1, "%s\t", decurnode->ProblemPrev);
        fprintf( ofh1, "%s\t", decurnode->ProblemCur);
        fprintf( ofh1, "%s\t", decurnode->Details);
        fprintf( ofh1, "%s\t", decurnode->DiagnosisPrev);
        fprintf( ofh1, "%s\t", decurnode->DiagnosisCur);
        fprintf( ofh1, "%s\t", decurnode->Solution);
        fprintf( ofh1, "%s\t\n", decurnode->Resolver);

        decurnode = (DENODE *) btnextnode();
    }

    fclose( ofh1);
    DefectiveEquipmentDataDirty = 0;
}


/*
 * READDEDATAFROMDISK - Read the defective equipment database from disk and
 * save the data in the binary tree. (This is called from local routines).
 * Note: Assumes that treeroot points to the DE tree.
 * Returns 1 on success, -1 on failure, 0 if there is no data.
 */
long ReadDEDataFromDisk( char DataValue)
{
    FILE *ifh1;
    char line[801], *sptr, *dptr;
    short ret;

    // database mode:
    // '0' database has not yet been read
    // '1' read and write CableBoxData
    // '2' read and write CableBoxArchive
    // '3' read CableBoxArchive, write CableBoxData

    // If the data has already been read in, there's nothing to do.
    // Ditto if the data file is known not to exist.

    if (!DataValue) DataValue = '1';
    if (DEDatabaseMode == DataValue) return 1;
    if (DefectiveEquipmentDataDirty == -1) return 0;

    // If there currently is database data, then write it out if it's
    // now coming from a different place. Otherwise don't need to read
    // it again.

    if (DEDatabaseMode) WriteDEDataToDisk();

    if (DataValue == '1')
        InDatabaseName = OutDatabaseName = "CableBoxData";
    else if (DataValue == '2')
        InDatabaseName = OutDatabaseName = "CableBoxArchive";
    else {
        InDatabaseName = "CableBoxArchive";
        OutDatabaseName = "CableBoxData";
    }

    if (((DEDatabaseMode == '2') && (DataValue == '3')) ||
        ((DEDatabaseMode == '3') && (DataValue == '2'))) {
            DEDatabaseMode = DataValue;
            return 1;
    }
    DEDatabaseMode = DataValue;

    // Open the database file, read it in record by record,
    // and save each node in the binary tree.

    pmbtinit();
    sprintf( line, "%s%s5.dat", DatabaseDir, InDatabaseName);
    if (!(ifh1 = fopen( line, "r"))) {
        DefectiveEquipmentDataDirty = -1;
        ret = 0;
        goto Done;
    }

    // Read and store each record.

    ret = 1;
    while (fgets( line, 800, ifh1)) {
        decurnode = (DENODE *) mypermmalloc( sizeof( DENODE));

        dptr = line;
        strcpy( decurnode->CableBoxSerial, NextString( &dptr));
        decurnode->CreatedDate =     atol( NextString( &dptr));
        decurnode->PrevCreateDate =  atol( NextString( &dptr));
        decurnode->FirstCreateDate = atol( NextString( &dptr));
        decurnode->ResolvedDate =    atol( NextString( &dptr));
        decurnode->TimesDiscovered = atoi( NextString( &dptr));

        sptr = mypermmalloc( 1 + strlen( dptr));
        strcpy( sptr, dptr);

        decurnode->SiteID =        NextString( &sptr);
        decurnode->Submitter =     NextString( &sptr);
        decurnode->SalesNo =       NextString( &sptr);
        decurnode->Model =         NextString( &sptr);
        decurnode->ProblemPrev =   NextString( &sptr);
        decurnode->ProblemCur =    NextString( &sptr);
        decurnode->Details =       NextString( &sptr);
        decurnode->DiagnosisPrev = NextString( &sptr);
        decurnode->DiagnosisCur =  NextString( &sptr);
        decurnode->Solution =      NextString( &sptr);
        decurnode->Resolver =      NextString( &sptr);

        btreestore( (NODE *) decurnode);
    }
    fclose( ifh1);

Done:
    detreeroot = (DENODE *) treeroot;
    return ret;
}
#endif


/*
 * NEXTSTRING - Find the tab at the end of the string, change it to a NULL,
 * and return the pointer to the start of the string.
 */
char *NextString( char **spptr)
{
    char *osptr, *sptr;

    osptr = sptr = *spptr;
    while (*sptr != '\t') ++sptr;
    *sptr++ = '\0';
    *spptr = sptr;

    return osptr;
}


/*
 * MYDBMALLOC - Allocate temporary storage in very large blocks.
 * This memory should only be used for the cable box database.
 */
char *mydbmalloc( long size)
{
    char *returnarg, **ppptr;

    // If there is no room left in the current block, get another.

    if (mydbspacesize < size) {
        if (mydbspaceptr) {
            ppptr = (char **) mydbspaceptr;
            *ppptr = (char *) 100;
        }

        // Get it off the freespace list, if available. Else allocate it.

        if (mydbspacefree) {
            mydbspaceptr = mydbspacefree;
            ppptr = (char **) mydbspacefree;
            mydbspacefree = (char *) *ppptr;
        }
        else mydbspaceptr = (char *) malloc( DBSSPACESIZE);
        mydbspacesize = DBSSPACESIZE - sizeof( char *) - sizeof( char *);

        ppptr = (char **) mydbspaceptr;
        *ppptr = (char *) NULL;

        if (mydbspacelist) *mydbspacecur = mydbspaceptr;
        else               mydbspacelist = mydbspaceptr;

        mydbspacecur = (char **) mydbspaceptr;
        mydbspaceptr += sizeof( char *);
    }

    // Chop off the requested space and return a pointer to it.

    returnarg = mydbspaceptr;
    mydbspaceptr += size;
    mydbspacesize -= size;
    return returnarg;
}


/*
 * MYDBFREE - Free all database storage and string storage.
 */
void mydbfree( void)
{
    char *dbptr, **dbpptr, *nextptr;

    // Free the database storage.

    DatabaseMode = 0;
    if (!mydbspacelist) goto FreeString; // if nothing is allocated, done

    // Just link the whole list onto the freespace list.

    mydbspacefree = mydbspacelist;
    mydbspacelist = (char *) NULL;
    mydbspacesize = 0;

    // Free the string storage.

FreeString:
    if (!mystgspacelist) return;        // if nothing is allocated, done

    dbptr = mystgspacelist;             // free all the blocks
    while (dbptr) {
        dbpptr = (char **) dbptr;
        nextptr = (char *) *dbpptr;
        free( dbptr);
        dbptr = nextptr;
    }

    stringlist50 = stringlist60 = stringlist = (struct string_s *) NULL;
    listlen50 = listlen60 = listlen = 0;

    mystgspacelist = mystgspaceptr = (char *) NULL;
    mystgspacesize = 0;
}


/*
 * MYWLMALLOC - Allocate temporary storage in very large blocks.
 * This memory should only be used for watch list data.
 */
char *mywlmalloc( long size)
{
    char *returnarg, **ppptr;

    // If there is no room left in the current block, get another.

    if (mywlspacesize < size) {
        if (mywlspaceptr) {
            ppptr = (char **) mywlspaceptr;
            *ppptr = (char *) 100;
        }

        if (mywlspacefree) {
            mywlspaceptr = mywlspacefree;
            ppptr = (char **) mywlspacefree;
            mywlspacefree = (char *) *ppptr;
        }
        else mywlspaceptr = (char *) malloc( WLSSPACESIZE);
        mywlspacesize = WLSSPACESIZE - sizeof( char *) - sizeof( char *);

        ppptr = (char **) mywlspaceptr;
        *ppptr = (char *) NULL;

        if (mywlspacelist) *mywlspacecur = mywlspaceptr;
        else               mywlspacelist = mywlspaceptr;

        mywlspacecur = (char **) mywlspaceptr;
        mywlspaceptr += sizeof( char *);
    }

    // Chop off the requested space and return a pointer to it.

    returnarg = mywlspaceptr;
    mywlspaceptr += size;
    mywlspacesize -= size;
    return returnarg;
}


/*
 * MYWLFREE - Move all watch list storage to the free list.
 */
void mywlfree( void)
{
    WLDatabaseMode = 0;
    if (mywlspacelist) {
        mywlspacefree = mywlspacelist;
        mywlspacelist = (char *) NULL;
        mywlspacesize = 0;
    }
}


/*
 * MYSTGMALLOC - Allocate temporary storage in very large blocks.
 * This memory can be freed and re-allocated.
 */
char *mystgmalloc( long size)
{
    char *returnarg, **ppptr;;

    // If there is no room left in the current block, get another.

    if (mystgspacesize < size) {
        mystgspaceptr = (char *) malloc( STGSPACESIZE);
        mystgspacesize = STGSPACESIZE - sizeof( char *);

        ppptr = (char **) mystgspaceptr;
        *ppptr = mystgspacelist;
        mystgspacelist = mystgspaceptr;
        mystgspaceptr += sizeof( char *);
    }

    // Chop off the requested space and return a pointer to it.

    returnarg = mystgspaceptr;
    mystgspaceptr += size;
    mystgspacesize -= size;
    return returnarg;
}


/*
 * MYPERMMALLOC - Allocate temporary storage in very large blocks.
 * This storage is never released.
 */
char *mypermmalloc( long size)
{
    char *returnarg;

    // If there is no room left in the current block, get another.

    if (mypermspacesize < size) {
        mypermspaceptr = (char *) malloc( PERMSPACESIZE);
        mypermspacesize = PERMSPACESIZE;
    }

    // Chop off the requested space and return a pointer to it.

    returnarg = mypermspaceptr;
    mypermspaceptr += size;
    mypermspacesize -= size;
    return returnarg;
}


/*
 * APPENDERRORMESSAGE - Append the given message to the error log.
 */
void AppendErrorMessage( char *mptr, char *data1, long val1)
{
    FILE *lfhdl;
    time_t curtime;
    struct tm *tmptr;

    if (!LogFileFile || !*LogFileFile) return;
    if (!(lfhdl = fopen( LogFileFile, "a"))) return;

    time( &curtime);
    tmptr = localtime( &curtime);

    fprintf( lfhdl, "%02d/%02d/%04d %02d:%02d:%02d: BAS ",
        tmptr->tm_mon + 1, tmptr->tm_mday, tmptr->tm_year + 1900,
        tmptr->tm_hour, tmptr->tm_min, tmptr->tm_sec);

    fprintf( lfhdl, mptr, data1, val1);
    fclose( lfhdl);
}


#if DEBUGMSGSW
/*
 * ERRORWATCHDATA - Append watch values to the error log.
 * Call with flag ==
 *  0   resetting and removing from list
 *  1   adding to list
 *  2   deciding not to add to list (usually turned off)
 *  3   discovered already on list
 *  4   fudging: setting WatchFlag to Inactive
 *  5   fudging: removing from list
 */
void ErrorWatchData( short flag, long PercentInHouse, long AvgDaysInHouse, short DaysInState)
{
    FILE *lfhdl;
    time_t curtime;
    struct tm *tmptr;

    if (!LogFileFile || !*LogFileFile) return;
    if (!(lfhdl = fopen( LogFileFile, "a"))) return;

    time( &curtime);
    tmptr = localtime( &curtime);

    fprintf( lfhdl, "%02d/%02d/%04d %02d:%02d:%02d: ",
        tmptr->tm_mon + 1, tmptr->tm_mday, tmptr->tm_year + 1900,
        tmptr->tm_hour, tmptr->tm_min, tmptr->tm_sec);

    if (!flag) {
        fprintf( lfhdl, "RESET %s Days in House %d >= 90\n",
            curnode->CableBoxSerial,
            DaysInState);
    }
    else {
        if (flag == 1)      fprintf( lfhdl, "WATCH ");
        else if (flag == 2) fprintf( lfhdl, "NOWATCH ");
        else if (flag == 3) fprintf( lfhdl, "DISCOVER ");
        else if (flag == 4) fprintf( lfhdl, "ADJUST-- ");
        else                fprintf( lfhdl, "ADJUSTXX ");

        fprintf( lfhdl,
            "%s SIH %d >= %d, AvDIH (%d/%d) %2.2f <= %d, "
            "%%DIH (%d/%d) %2.2f <= %d, ST %c",
            curnode->CableBoxSerial,
            curnode->ShortInHouse, WatchSIH,
            curnode->RDaysHouse,
            curnode->RToHouse,
            (((float) AvgDaysInHouse / 1000)), (WatchAverageDays / 1000),
            curnode->RDaysHouse,
            curnode->RDaysHouse + curnode->RDaysReturn + curnode->RDaysRepair +
                curnode->RDaysOther + curnode->RDaysTech,
            (((float) PercentInHouse / 1000)), (WatchPercentDays / 1000),
            curnode->CurrentState);

        if (curnode->CurrentState == 'H')
            fprintf( lfhdl, " Days %d < 90", DaysInState);

        fprintf( lfhdl, "\n");
    }
    fclose( lfhdl);
}
#endif


#if DEBUGWKCHK
/*
 * CHECKWEEK - Verify that the given week string is legal.
 * Put a breakpoint on "ii = 10;" to see if it is not.
 */
void CheckWeek( char *Week)
{
    char *sptr, chr;
    short ii;

    sptr = Week;
    if (*sptr == '"') ++sptr;

    for (ii = 0; ii < 7; ++ii) {
        if (((chr = *sptr++) != '-') && (chr < '0') && (chr > '9')) {
            ii = 10;
        }
    }
}
#endif
